""" Cisco_IOS_XR_ipv4_ospf_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-ospf package operational data.

This module contains definitions
for the following management objects\:
  ospf\: OSPF operational data

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.entity_utils import get_relative_entity_path as _get_relative_entity_path
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class Authentication(Enum):
    """
    Authentication

    Authentication

    .. data:: mgmt_ospf_auth_none = 0

    	No Authentication

    .. data:: mgmt_ospf_auth_ct = 1

    	Clear Text

    .. data:: mgmt_ospf_auth_md = 2

    	MD5

    .. data:: mgmt_ospf_auth_kc = 3

    	Keychain

    """

    mgmt_ospf_auth_none = Enum.YLeaf(0, "mgmt-ospf-auth-none")

    mgmt_ospf_auth_ct = Enum.YLeaf(1, "mgmt-ospf-auth-ct")

    mgmt_ospf_auth_md = Enum.YLeaf(2, "mgmt-ospf-auth-md")

    mgmt_ospf_auth_kc = Enum.YLeaf(3, "mgmt-ospf-auth-kc")


class DrBdrState(Enum):
    """
    DrBdrState

    Dr bdr state

    .. data:: mgmt_dbdr_none = 0

    	None

    .. data:: mgmt_dbdr_dr = 1

    	Designated Router

    .. data:: mgmt_dbdr_bdr = 2

    	Backup Designated Router

    .. data:: mgmt_dbdr_dr_other = 3

    	Designated Router Other

    """

    mgmt_dbdr_none = Enum.YLeaf(0, "mgmt-dbdr-none")

    mgmt_dbdr_dr = Enum.YLeaf(1, "mgmt-dbdr-dr")

    mgmt_dbdr_bdr = Enum.YLeaf(2, "mgmt-dbdr-bdr")

    mgmt_dbdr_dr_other = Enum.YLeaf(3, "mgmt-dbdr-dr-other")


class ExMetric(Enum):
    """
    ExMetric

    Ex metric

    .. data:: mgmt_ex_metric_type_none = 0

    	No metric type

    .. data:: mgmt_ex_metric_type_1 = 1

    	Type 1 External

    .. data:: mgmt_ex_metric_type_2 = 2

    	Type 2 External

    """

    mgmt_ex_metric_type_none = Enum.YLeaf(0, "mgmt-ex-metric-type-none")

    mgmt_ex_metric_type_1 = Enum.YLeaf(1, "mgmt-ex-metric-type-1")

    mgmt_ex_metric_type_2 = Enum.YLeaf(2, "mgmt-ex-metric-type-2")


class GsState(Enum):
    """
    GsState

    Gs state

    .. data:: mgmt_gs_init = 0

    	Process in initialization 

    .. data:: mgmt_gs_normal = 1

    	Graceful Shutdown not running

    .. data:: mgmt_gs_delay = 2

    	Delaying  before Graceful Shutdown

    .. data:: mgmt_gs_flush = 3

    	Flushing self originated LSAs

    .. data:: mgmt_gs_hello = 4

    	Sending empty hellos

    .. data:: mgmt_gs_quiet = 5

    	Shutdown mode.

    """

    mgmt_gs_init = Enum.YLeaf(0, "mgmt-gs-init")

    mgmt_gs_normal = Enum.YLeaf(1, "mgmt-gs-normal")

    mgmt_gs_delay = Enum.YLeaf(2, "mgmt-gs-delay")

    mgmt_gs_flush = Enum.YLeaf(3, "mgmt-gs-flush")

    mgmt_gs_hello = Enum.YLeaf(4, "mgmt-gs-hello")

    mgmt_gs_quiet = Enum.YLeaf(5, "mgmt-gs-quiet")


class IgpteLibBwModel(Enum):
    """
    IgpteLibBwModel

    Bandwidth model

    .. data:: rdm = 0

    	Russian Dolls Model

    .. data:: mam = 1

    	Maximum Allocation Model

    .. data:: not_set = 2

    	No model set

    """

    rdm = Enum.YLeaf(0, "rdm")

    mam = Enum.YLeaf(1, "mam")

    not_set = Enum.YLeaf(2, "not-set")


class Interface(Enum):
    """
    Interface

    Interface

    .. data:: mgmt_if_broadcast = 1

    	Broadcast

    .. data:: mgmt_if_nonbroadcast = 2

    	Non broadcast multi access

    .. data:: mgmt_if_point_to_point = 3

    	Point to Point

    .. data:: mgmt_if_point_to_m_point = 4

    	Point to multipoint

    .. data:: mgmt_if_p2mp_non_bcast = 5

    	Non broadcast point to multipoint

    .. data:: mgmt_if_virtual_link = 6

    	Virtual link

    .. data:: mgmt_if_sham_link = 7

    	Sham link

    .. data:: mgmt_if_loop_back = 8

    	Loopback

    """

    mgmt_if_broadcast = Enum.YLeaf(1, "mgmt-if-broadcast")

    mgmt_if_nonbroadcast = Enum.YLeaf(2, "mgmt-if-nonbroadcast")

    mgmt_if_point_to_point = Enum.YLeaf(3, "mgmt-if-point-to-point")

    mgmt_if_point_to_m_point = Enum.YLeaf(4, "mgmt-if-point-to-m-point")

    mgmt_if_p2mp_non_bcast = Enum.YLeaf(5, "mgmt-if-p2mp-non-bcast")

    mgmt_if_virtual_link = Enum.YLeaf(6, "mgmt-if-virtual-link")

    mgmt_if_sham_link = Enum.YLeaf(7, "mgmt-if-sham-link")

    mgmt_if_loop_back = Enum.YLeaf(8, "mgmt-if-loop-back")


class InterfaceState(Enum):
    """
    InterfaceState

    Interface state

    .. data:: mgmt_ifs_unknown = 0

    	Interface state unknown

    .. data:: mgmt_ifs_admin_down = 1

    	Interface is administratively down

    .. data:: mgmt_ifs_down = 2

    	Interface is down

    .. data:: mgmt_ifs_up = 3

    	Interface is up

    .. data:: mgmt_ifs_shutdown = 4

    	Interface is administratively down

    """

    mgmt_ifs_unknown = Enum.YLeaf(0, "mgmt-ifs-unknown")

    mgmt_ifs_admin_down = Enum.YLeaf(1, "mgmt-ifs-admin-down")

    mgmt_ifs_down = Enum.YLeaf(2, "mgmt-ifs-down")

    mgmt_ifs_up = Enum.YLeaf(3, "mgmt-ifs-up")

    mgmt_ifs_shutdown = Enum.YLeaf(4, "mgmt-ifs-shutdown")


class Ipfrr(Enum):
    """
    Ipfrr

    FRR Types

    .. data:: none = 0

    	Disabled

    .. data:: per_link = 1

    	Per link

    .. data:: per_prefix = 2

    	Per prefix

    """

    none = Enum.YLeaf(0, "none")

    per_link = Enum.YLeaf(1, "per-link")

    per_prefix = Enum.YLeaf(2, "per-prefix")


class IpfrrTbrkr(Enum):
    """
    IpfrrTbrkr

    FRR Tiebreakers

    .. data:: downstream = 0

    	Downsteram

    .. data:: line_card_disjoint = 1

    	LC Disjoint

    .. data:: backup_metric = 2

    	Backup metric

    .. data:: node_protect = 3

    	Node protection

    .. data:: primary_path = 4

    	Primary path

    .. data:: secondary_path = 5

    	Secondary path

    .. data:: srlg_disjoint = 6

    	SRLG disjoint

    .. data:: tunnel = 7

    	Tunnel

    .. data:: post_convergence = 8

    	Post Convergence

    """

    downstream = Enum.YLeaf(0, "downstream")

    line_card_disjoint = Enum.YLeaf(1, "line-card-disjoint")

    backup_metric = Enum.YLeaf(2, "backup-metric")

    node_protect = Enum.YLeaf(3, "node-protect")

    primary_path = Enum.YLeaf(4, "primary-path")

    secondary_path = Enum.YLeaf(5, "secondary-path")

    srlg_disjoint = Enum.YLeaf(6, "srlg-disjoint")

    tunnel = Enum.YLeaf(7, "tunnel")

    post_convergence = Enum.YLeaf(8, "post-convergence")


class LinkSubnet(Enum):
    """
    LinkSubnet

    Link subnet

    .. data:: mgmt_igp_subnet_type_none = 0

    	None

    .. data:: mgmt_igp_subnet_type_p2p = 1

    	Point to Point

    .. data:: mgmt_igp_subnet_type_broadcast = 2

    	Broadcast

    .. data:: mgmt_igp_subnet_type_nbma = 3

    	Non Broadcast Multi Access

    .. data:: mgmt_igp_subnet_type_p2mp = 4

    	Point to multipoint

    .. data:: mgmt_igp_subnet_type_loop_back = 5

    	Loopback

    .. data:: mgmt_igp_subnet_type_max = 6

    	Unsupported

    """

    mgmt_igp_subnet_type_none = Enum.YLeaf(0, "mgmt-igp-subnet-type-none")

    mgmt_igp_subnet_type_p2p = Enum.YLeaf(1, "mgmt-igp-subnet-type-p2p")

    mgmt_igp_subnet_type_broadcast = Enum.YLeaf(2, "mgmt-igp-subnet-type-broadcast")

    mgmt_igp_subnet_type_nbma = Enum.YLeaf(3, "mgmt-igp-subnet-type-nbma")

    mgmt_igp_subnet_type_p2mp = Enum.YLeaf(4, "mgmt-igp-subnet-type-p2mp")

    mgmt_igp_subnet_type_loop_back = Enum.YLeaf(5, "mgmt-igp-subnet-type-loop-back")

    mgmt_igp_subnet_type_max = Enum.YLeaf(6, "mgmt-igp-subnet-type-max")


class Lsa(Enum):
    """
    Lsa

    Lsa

    .. data:: mgmt_lsa_type_rtr = 1

    	Router LSA

    .. data:: mgmt_lsa_type_net = 2

    	Network LSA

    .. data:: mgmt_lsa_type_sum_net = 3

    	Summary LSA

    .. data:: mgmt_lsa_type_sum_asb = 4

    	Summary-ASBR LSA

    .. data:: mgmt_lsa_type_ext = 5

    	AS external LSA

    .. data:: mgmt_lsa_type_mospf = 6

    	MOSPF LSA

    .. data:: mgmt_lsa_type_7_ase = 7

    	Type-7 External LSA

    .. data:: mgmt_lsa_type_8_ignore = 8

    	Invalid type

    .. data:: mgmt_lsa_type_opq_link = 9

    	Opaque link LSA

    .. data:: mgmt_lsa_type_opq_area = 10

    	Opaque Area LSA

    .. data:: mgmt_lsa_type_opq_as = 11

    	Opaque AS LSA

    """

    mgmt_lsa_type_rtr = Enum.YLeaf(1, "mgmt-lsa-type-rtr")

    mgmt_lsa_type_net = Enum.YLeaf(2, "mgmt-lsa-type-net")

    mgmt_lsa_type_sum_net = Enum.YLeaf(3, "mgmt-lsa-type-sum-net")

    mgmt_lsa_type_sum_asb = Enum.YLeaf(4, "mgmt-lsa-type-sum-asb")

    mgmt_lsa_type_ext = Enum.YLeaf(5, "mgmt-lsa-type-ext")

    mgmt_lsa_type_mospf = Enum.YLeaf(6, "mgmt-lsa-type-mospf")

    mgmt_lsa_type_7_ase = Enum.YLeaf(7, "mgmt-lsa-type-7-ase")

    mgmt_lsa_type_8_ignore = Enum.YLeaf(8, "mgmt-lsa-type-8-ignore")

    mgmt_lsa_type_opq_link = Enum.YLeaf(9, "mgmt-lsa-type-opq-link")

    mgmt_lsa_type_opq_area = Enum.YLeaf(10, "mgmt-lsa-type-opq-area")

    mgmt_lsa_type_opq_as = Enum.YLeaf(11, "mgmt-lsa-type-opq-as")


class MaxMetricSetReason(Enum):
    """
    MaxMetricSetReason

    Max metric set reason

    .. data:: mgmt_max_metric_on_proc_migration = 0

    	proc migration

    .. data:: mgmt_max_metric_on_proc_restart = 1

    	proc restart

    .. data:: mgmt_max_metric_on_switchover = 2

    	switch over

    .. data:: mgmt_max_metric_on_startup = 3

    	start up

    .. data:: mgmt_max_metric_always = 4

    	always

    .. data:: mgmt_max_metric_reason_none = 5

    	none

    """

    mgmt_max_metric_on_proc_migration = Enum.YLeaf(0, "mgmt-max-metric-on-proc-migration")

    mgmt_max_metric_on_proc_restart = Enum.YLeaf(1, "mgmt-max-metric-on-proc-restart")

    mgmt_max_metric_on_switchover = Enum.YLeaf(2, "mgmt-max-metric-on-switchover")

    mgmt_max_metric_on_startup = Enum.YLeaf(3, "mgmt-max-metric-on-startup")

    mgmt_max_metric_always = Enum.YLeaf(4, "mgmt-max-metric-always")

    mgmt_max_metric_reason_none = Enum.YLeaf(5, "mgmt-max-metric-reason-none")


class MaxMetricUnsetReason(Enum):
    """
    MaxMetricUnsetReason

    Max metric unset reason

    .. data:: mgmt_max_metric_unset_none = 0

    	none

    .. data:: mgmt_max_metric_unset_bgp = 1

    	BGP converged

    .. data:: mgmt_max_metric_unset_timer = 2

    	timer expired

    .. data:: mgmt_max_metric_unset_cfg = 3

    	unconfigured

    .. data:: mgmt_max_metric_unset_process_cleared = 4

    	process cleared

    .. data:: mgmt_max_metric_unset_over_write = 5

    	set for other reason

    """

    mgmt_max_metric_unset_none = Enum.YLeaf(0, "mgmt-max-metric-unset-none")

    mgmt_max_metric_unset_bgp = Enum.YLeaf(1, "mgmt-max-metric-unset-bgp")

    mgmt_max_metric_unset_timer = Enum.YLeaf(2, "mgmt-max-metric-unset-timer")

    mgmt_max_metric_unset_cfg = Enum.YLeaf(3, "mgmt-max-metric-unset-cfg")

    mgmt_max_metric_unset_process_cleared = Enum.YLeaf(4, "mgmt-max-metric-unset-process-cleared")

    mgmt_max_metric_unset_over_write = Enum.YLeaf(5, "mgmt-max-metric-unset-over-write")


class MplsTeOptTlv(Enum):
    """
    MplsTeOptTlv

    Mpls te opt tlv

    .. data:: mpls_te_opt_tlv_type_none = 0

    	None

    .. data:: mpls_te_opt_tlv_type_srlg = 1

    	SRLGs

    .. data:: mpls_te_opt_tlv_type_bc = 2

    	Bandwidth Constraints

    .. data:: mpls_te_opt_tlv_type_ixcd = 3

    	Intarface Switching Capability Descriptor

    .. data:: mpls_te_opt_tlv_type_uni_delay = 4

    	Unidirectional Link Delay

    """

    mpls_te_opt_tlv_type_none = Enum.YLeaf(0, "mpls-te-opt-tlv-type-none")

    mpls_te_opt_tlv_type_srlg = Enum.YLeaf(1, "mpls-te-opt-tlv-type-srlg")

    mpls_te_opt_tlv_type_bc = Enum.YLeaf(2, "mpls-te-opt-tlv-type-bc")

    mpls_te_opt_tlv_type_ixcd = Enum.YLeaf(3, "mpls-te-opt-tlv-type-ixcd")

    mpls_te_opt_tlv_type_uni_delay = Enum.YLeaf(4, "mpls-te-opt-tlv-type-uni-delay")


class NeighborState(Enum):
    """
    NeighborState

    Neighbor state

    .. data:: mgmt_nbr_down = 0

    	Down

    .. data:: mgmt_nbr_attempt = 1

    	Attempt

    .. data:: mgmt_nbr_init = 2

    	Init

    .. data:: mgmt_nbr_2way = 3

    	2 Way

    .. data:: mgmt_nbr_ex_start = 4

    	Exstart

    .. data:: mgmt_nbr_ex_change = 5

    	Exchange

    .. data:: mgmt_nbr_load_ing = 6

    	Loading

    .. data:: mgmt_nbr_full = 7

    	Full

    .. data:: mgmt_nbr_sc_virtual = 8

    	SCvirtual

    """

    mgmt_nbr_down = Enum.YLeaf(0, "mgmt-nbr-down")

    mgmt_nbr_attempt = Enum.YLeaf(1, "mgmt-nbr-attempt")

    mgmt_nbr_init = Enum.YLeaf(2, "mgmt-nbr-init")

    mgmt_nbr_2way = Enum.YLeaf(3, "mgmt-nbr-2way")

    mgmt_nbr_ex_start = Enum.YLeaf(4, "mgmt-nbr-ex-start")

    mgmt_nbr_ex_change = Enum.YLeaf(5, "mgmt-nbr-ex-change")

    mgmt_nbr_load_ing = Enum.YLeaf(6, "mgmt-nbr-load-ing")

    mgmt_nbr_full = Enum.YLeaf(7, "mgmt-nbr-full")

    mgmt_nbr_sc_virtual = Enum.YLeaf(8, "mgmt-nbr-sc-virtual")


class NsfRtr(Enum):
    """
    NsfRtr

    Nsf rtr

    .. data:: mgmt_nsf_rtr_none = 0

    	None

    .. data:: mgmt_nsf_rtr_requester = 1

    	Requester

    .. data:: mgmt_nsf_rtr_receiver = 2

    	Receiver

    """

    mgmt_nsf_rtr_none = Enum.YLeaf(0, "mgmt-nsf-rtr-none")

    mgmt_nsf_rtr_requester = Enum.YLeaf(1, "mgmt-nsf-rtr-requester")

    mgmt_nsf_rtr_receiver = Enum.YLeaf(2, "mgmt-nsf-rtr-receiver")


class OspfBr(Enum):
    """
    OspfBr

    Ospf br

    .. data:: mgmt_d_type_abr_asbr = 0

    	Both Area Border Router and AS Border Router

    .. data:: mgmt_d_type_asbr = 1

    	AS Border Router

    .. data:: mgmt_d_type_abr = 2

    	Area Border Router

    """

    mgmt_d_type_abr_asbr = Enum.YLeaf(0, "mgmt-d-type-abr-asbr")

    mgmt_d_type_asbr = Enum.YLeaf(1, "mgmt-d-type-asbr")

    mgmt_d_type_abr = Enum.YLeaf(2, "mgmt-d-type-abr")


class OspfGrReason(Enum):
    """
    OspfGrReason

    Ospf gr reason

    .. data:: mgmt_gr_reason_unknown = 0

    	Unknown

    .. data:: mgmt_gr_reason_sw_restart = 1

    	Software restart

    .. data:: mgmt_gr_reason_sw_upgrade = 2

    	Software reload/upgrade

    .. data:: mgmt_gr_reason_switchover = 3

    	Switch to redundant control processor

    """

    mgmt_gr_reason_unknown = Enum.YLeaf(0, "mgmt-gr-reason-unknown")

    mgmt_gr_reason_sw_restart = Enum.YLeaf(1, "mgmt-gr-reason-sw-restart")

    mgmt_gr_reason_sw_upgrade = Enum.YLeaf(2, "mgmt-gr-reason-sw-upgrade")

    mgmt_gr_reason_switchover = Enum.YLeaf(3, "mgmt-gr-reason-switchover")


class OspfInterfaceState(Enum):
    """
    OspfInterfaceState

    Ospf interface state

    .. data:: mgmt_ospf_ifs_down = 0

    	Down

    .. data:: mgmt_ospf_ifs_loop_back = 1

    	Loopback

    .. data:: mgmt_ospf_ifs_waiting = 2

    	Waiting

    .. data:: mgmt_ospf_ifs_point_to_m_point = 3

    	Point to multipoint

    .. data:: mgmt_ospf_ifs_point_to_point = 4

    	Point to point

    .. data:: mgmt_ospf_ifs_dr = 5

    	DesignatedRouter

    .. data:: mgmt_ospf_ifs_backup = 6

    	Backup Designated Router

    .. data:: mgmt_ospf_ifs_other = 7

    	Designated Router Other

    """

    mgmt_ospf_ifs_down = Enum.YLeaf(0, "mgmt-ospf-ifs-down")

    mgmt_ospf_ifs_loop_back = Enum.YLeaf(1, "mgmt-ospf-ifs-loop-back")

    mgmt_ospf_ifs_waiting = Enum.YLeaf(2, "mgmt-ospf-ifs-waiting")

    mgmt_ospf_ifs_point_to_m_point = Enum.YLeaf(3, "mgmt-ospf-ifs-point-to-m-point")

    mgmt_ospf_ifs_point_to_point = Enum.YLeaf(4, "mgmt-ospf-ifs-point-to-point")

    mgmt_ospf_ifs_dr = Enum.YLeaf(5, "mgmt-ospf-ifs-dr")

    mgmt_ospf_ifs_backup = Enum.YLeaf(6, "mgmt-ospf-ifs-backup")

    mgmt_ospf_ifs_other = Enum.YLeaf(7, "mgmt-ospf-ifs-other")


class OspfInternalLsaTypes(Enum):
    """
    OspfInternalLsaTypes

    OSPF LSA format types

    .. data:: mgmt_rtr_type = 1

    	Router LSA

    .. data:: mgmt_ntwk_type = 2

    	Network LSA

    .. data:: mgmt_sum_type = 3

    	Summary and ASBR summary LSA

    .. data:: mgmt_ext_type = 4

    	Type 5 and NSSA external LSA

    .. data:: mgmt_opq_type = 5

    	Generic AS/Area Opaque LSA

    .. data:: mgmt_opq_link_type = 6

    	Generic Link Opaque LSA

    .. data:: mgmt_opq_rrr_type = 7

    	Opaque Area type 1 LSA

    .. data:: mgmt_opq_gr_type = 8

    	Opaque link type 1 LSA

    .. data:: mgmt_opq_ri_type = 9

    	Opaque Router Information LSA

    .. data:: mgmt_opq_epl_type = 10

    	Opaque Area type 128

    .. data:: mgmt_opq_ell_type = 11

    	Opaque Area type 8

    """

    mgmt_rtr_type = Enum.YLeaf(1, "mgmt-rtr-type")

    mgmt_ntwk_type = Enum.YLeaf(2, "mgmt-ntwk-type")

    mgmt_sum_type = Enum.YLeaf(3, "mgmt-sum-type")

    mgmt_ext_type = Enum.YLeaf(4, "mgmt-ext-type")

    mgmt_opq_type = Enum.YLeaf(5, "mgmt-opq-type")

    mgmt_opq_link_type = Enum.YLeaf(6, "mgmt-opq-link-type")

    mgmt_opq_rrr_type = Enum.YLeaf(7, "mgmt-opq-rrr-type")

    mgmt_opq_gr_type = Enum.YLeaf(8, "mgmt-opq-gr-type")

    mgmt_opq_ri_type = Enum.YLeaf(9, "mgmt-opq-ri-type")

    mgmt_opq_epl_type = Enum.YLeaf(10, "mgmt-opq-epl-type")

    mgmt_opq_ell_type = Enum.YLeaf(11, "mgmt-opq-ell-type")


class OspfLinkTypes(Enum):
    """
    OspfLinkTypes

    Type of router LSA links

    .. data:: mgmt_rtr_link = 1

    	Link to a Router

    .. data:: mgmt_trans_link = 2

    	Link to a transit network

    .. data:: mgmt_stub_net = 3

    	Link to Stub network

    .. data:: mgmt_vitural_link = 4

    	Link to Virtual Link

    """

    mgmt_rtr_link = Enum.YLeaf(1, "mgmt-rtr-link")

    mgmt_trans_link = Enum.YLeaf(2, "mgmt-trans-link")

    mgmt_stub_net = Enum.YLeaf(3, "mgmt-stub-net")

    mgmt_vitural_link = Enum.YLeaf(4, "mgmt-vitural-link")


class OspfLs(Enum):
    """
    OspfLs

    Ospf ls

    .. data:: router = 1

    	Router LSA

    .. data:: network = 2

    	Network LSA

    .. data:: summary = 3

    	Summary LSA

    .. data:: asbr_summary = 4

    	ASBR-Summary LSA

    .. data:: external = 5

    	External LSA

    .. data:: nssa_external = 7

    	NSSA External LSA

    .. data:: opaque_link = 9

    	Opaque LSALink Scope

    .. data:: opaque_area = 10

    	Opaque LSA Area Scope

    .. data:: opaque_as = 11

    	Opaque LSA AS Scope

    """

    router = Enum.YLeaf(1, "router")

    network = Enum.YLeaf(2, "network")

    summary = Enum.YLeaf(3, "summary")

    asbr_summary = Enum.YLeaf(4, "asbr-summary")

    external = Enum.YLeaf(5, "external")

    nssa_external = Enum.YLeaf(7, "nssa-external")

    opaque_link = Enum.YLeaf(9, "opaque-link")

    opaque_area = Enum.YLeaf(10, "opaque-area")

    opaque_as = Enum.YLeaf(11, "opaque-as")


class OspfLsaOpqRiScope(Enum):
    """
    OspfLsaOpqRiScope

    OSPF Router Information LSA scope types

    .. data:: mgmt_lsa_opq_ri_scope_link = 9

    	Link-local Router Information LSA

    .. data:: mgmt_lsa_opq_ri_scope_area = 10

    	Area-scope Router Information LSA

    .. data:: mgmt_lsa_opq_ri_scope_as = 11

    	AS-scope Router Information LSA

    """

    mgmt_lsa_opq_ri_scope_link = Enum.YLeaf(9, "mgmt-lsa-opq-ri-scope-link")

    mgmt_lsa_opq_ri_scope_area = Enum.YLeaf(10, "mgmt-lsa-opq-ri-scope-area")

    mgmt_lsa_opq_ri_scope_as = Enum.YLeaf(11, "mgmt-lsa-opq-ri-scope-as")


class OspfMaxMetricAbrOffReasons(Enum):
    """
    OspfMaxMetricAbrOffReasons

    Ospf max metric abr off reasons

    .. data:: ospf_max_metric_abr_off_reason_none = 0

    	No reason

    .. data:: ospf_max_metric_abr_off_reason_no_nbr = 1

    	No neighbors seen yet

    .. data:: ospf_max_metric_abr_off_reason_new_nbr = 2

    	New neighbor seen recently

    .. data:: ospf_max_metric_abr_off_reason_nbr_full = 4

    	Adjacency FULL seen recently

    .. data:: ospf_max_metric_abr_off_reason_flush_p_end = 8

    	LSA flushes pending

    """

    ospf_max_metric_abr_off_reason_none = Enum.YLeaf(0, "ospf-max-metric-abr-off-reason-none")

    ospf_max_metric_abr_off_reason_no_nbr = Enum.YLeaf(1, "ospf-max-metric-abr-off-reason-no-nbr")

    ospf_max_metric_abr_off_reason_new_nbr = Enum.YLeaf(2, "ospf-max-metric-abr-off-reason-new-nbr")

    ospf_max_metric_abr_off_reason_nbr_full = Enum.YLeaf(4, "ospf-max-metric-abr-off-reason-nbr-full")

    ospf_max_metric_abr_off_reason_flush_p_end = Enum.YLeaf(8, "ospf-max-metric-abr-off-reason-flush-p-end")


class OspfRoute(Enum):
    """
    OspfRoute

    Ospf route

    .. data:: mgmt_r_type_none = 0

    	No route type

    .. data:: mgmt_r_type_other = 1

    	Not set

    .. data:: mgmt_r_type_intra = 2

    	Intra-area route

    .. data:: mgmt_r_type_inter = 4

    	Inter-area route

    .. data:: mgmt_r_type_extern1 = 8

    	Type 1 External route

    .. data:: mgmt_r_type_extern2 = 16

    	Type 2 External route

    .. data:: mgmt_r_type_isis_sum = 32

    	IS-IS summary route

    .. data:: mgmt_r_type_isis_l1 = 64

    	IS-IS level 1 route

    .. data:: mgmt_r_type_isis_l2 = 128

    	IS-IS level 2 route

    .. data:: mgmt_r_type_isis_l1_ia = 256

    	IS-IS level 1 inter-area route

    .. data:: mgmt_r_type_bgp_int = 512

    	iBGP route

    .. data:: mgmt_r_type_bgp_ext = 1024

    	eBGP route

    .. data:: mgmt_r_type_bgp_loc = 2048

    	BGP local route

    .. data:: mgmt_r_type_nssa1 = 4096

    	Type 1 NSSA route

    .. data:: mgmt_r_type_nssa2 = 8192

    	Type 2 NSSA route

    .. data:: mgmt_r_type_i_grp2_int = 16384

    	EIGRP internal route

    .. data:: mgmt_r_type_i_grp2_ext = 32768

    	EIGRP external route

    """

    mgmt_r_type_none = Enum.YLeaf(0, "mgmt-r-type-none")

    mgmt_r_type_other = Enum.YLeaf(1, "mgmt-r-type-other")

    mgmt_r_type_intra = Enum.YLeaf(2, "mgmt-r-type-intra")

    mgmt_r_type_inter = Enum.YLeaf(4, "mgmt-r-type-inter")

    mgmt_r_type_extern1 = Enum.YLeaf(8, "mgmt-r-type-extern1")

    mgmt_r_type_extern2 = Enum.YLeaf(16, "mgmt-r-type-extern2")

    mgmt_r_type_isis_sum = Enum.YLeaf(32, "mgmt-r-type-isis-sum")

    mgmt_r_type_isis_l1 = Enum.YLeaf(64, "mgmt-r-type-isis-l1")

    mgmt_r_type_isis_l2 = Enum.YLeaf(128, "mgmt-r-type-isis-l2")

    mgmt_r_type_isis_l1_ia = Enum.YLeaf(256, "mgmt-r-type-isis-l1-ia")

    mgmt_r_type_bgp_int = Enum.YLeaf(512, "mgmt-r-type-bgp-int")

    mgmt_r_type_bgp_ext = Enum.YLeaf(1024, "mgmt-r-type-bgp-ext")

    mgmt_r_type_bgp_loc = Enum.YLeaf(2048, "mgmt-r-type-bgp-loc")

    mgmt_r_type_nssa1 = Enum.YLeaf(4096, "mgmt-r-type-nssa1")

    mgmt_r_type_nssa2 = Enum.YLeaf(8192, "mgmt-r-type-nssa2")

    mgmt_r_type_i_grp2_int = Enum.YLeaf(16384, "mgmt-r-type-i-grp2-int")

    mgmt_r_type_i_grp2_ext = Enum.YLeaf(32768, "mgmt-r-type-i-grp2-ext")


class OspfShOpqRiPceAddrTypes(Enum):
    """
    OspfShOpqRiPceAddrTypes

    OSPF PCE Address Type

    .. data:: mgmt_ospf_opq_pce_addr_type_invalid = 0

    	Invalid PCE Address

    .. data:: mgmt_ospf_opq_pce_addr_type_ipv4 = 1

    	IPv4 PCE Address

    .. data:: mgmt_ospf_opq_pce_addr_type_ipv6 = 2

    	IPv6 PCE Address

    """

    mgmt_ospf_opq_pce_addr_type_invalid = Enum.YLeaf(0, "mgmt-ospf-opq-pce-addr-type-invalid")

    mgmt_ospf_opq_pce_addr_type_ipv4 = Enum.YLeaf(1, "mgmt-ospf-opq-pce-addr-type-ipv4")

    mgmt_ospf_opq_pce_addr_type_ipv6 = Enum.YLeaf(2, "mgmt-ospf-opq-pce-addr-type-ipv6")


class OspfShOpqRiTlvTypes(Enum):
    """
    OspfShOpqRiTlvTypes

    OSPF Router Information TLV types

    .. data:: mgmt_ospf_opq_ri_tlv_type_unknown = 0

    	Unknown

    .. data:: mgmt_ospf_opq_ri_tlv_type_rtrcap = 1

    	Router Capabilities

    .. data:: mgmt_ospf_opq_ri_tlv_type_pce_discovery = 2

    	PCE Discovery

    .. data:: mgmt_ospf_opq_ri_tlv_type_sr_algo = 3

    	Segment Routing Algorithm

    .. data:: mgmt_ospf_opq_ri_tlv_type_sr_range = 4

    	Segment Routing SID Range

    """

    mgmt_ospf_opq_ri_tlv_type_unknown = Enum.YLeaf(0, "mgmt-ospf-opq-ri-tlv-type-unknown")

    mgmt_ospf_opq_ri_tlv_type_rtrcap = Enum.YLeaf(1, "mgmt-ospf-opq-ri-tlv-type-rtrcap")

    mgmt_ospf_opq_ri_tlv_type_pce_discovery = Enum.YLeaf(2, "mgmt-ospf-opq-ri-tlv-type-pce-discovery")

    mgmt_ospf_opq_ri_tlv_type_sr_algo = Enum.YLeaf(3, "mgmt-ospf-opq-ri-tlv-type-sr-algo")

    mgmt_ospf_opq_ri_tlv_type_sr_range = Enum.YLeaf(4, "mgmt-ospf-opq-ri-tlv-type-sr-range")


class OspfSrgbStatus(Enum):
    """
    OspfSrgbStatus

    Ospf srgb status

    .. data:: not_allocated = 0

    	Not allocated

    .. data:: pending = 1

    	Allocation pending

    .. data:: allocated = 2

    	Allocated

    """

    not_allocated = Enum.YLeaf(0, "not-allocated")

    pending = Enum.YLeaf(1, "pending")

    allocated = Enum.YLeaf(2, "allocated")


class RedistProtocol(Enum):
    """
    RedistProtocol

    Redist protocol

    .. data:: mgmt_rib_protocol_all = 0

    	Unknown

    .. data:: mgmt_rib_protocol_connected = 1

    	Connected

    .. data:: mgmt_rib_protocol_local = 2

    	Local

    .. data:: mgmt_rib_protocol_static = 3

    	Static

    .. data:: mgmt_rib_protocol_bgp = 4

    	BGP

    .. data:: mgmt_rib_protocol_rip = 5

    	RIP

    .. data:: mgmt_rib_protocol_isis = 6

    	ISIS

    .. data:: mgmt_rib_protocol_ospf = 7

    	OSPF

    .. data:: mgmt_rib_protocol_eigrp = 8

    	EIGRP

    .. data:: mgmt_rib_protocol_dagr = 9

    	DAGR

    .. data:: mgmt_rib_protocol_subscriber = 10

    	Subscriber

    .. data:: mgmt_rib_protocol_application = 11

    	Application

    .. data:: mgmt_rib_protocol_mobile = 12

    	Mobile

    """

    mgmt_rib_protocol_all = Enum.YLeaf(0, "mgmt-rib-protocol-all")

    mgmt_rib_protocol_connected = Enum.YLeaf(1, "mgmt-rib-protocol-connected")

    mgmt_rib_protocol_local = Enum.YLeaf(2, "mgmt-rib-protocol-local")

    mgmt_rib_protocol_static = Enum.YLeaf(3, "mgmt-rib-protocol-static")

    mgmt_rib_protocol_bgp = Enum.YLeaf(4, "mgmt-rib-protocol-bgp")

    mgmt_rib_protocol_rip = Enum.YLeaf(5, "mgmt-rib-protocol-rip")

    mgmt_rib_protocol_isis = Enum.YLeaf(6, "mgmt-rib-protocol-isis")

    mgmt_rib_protocol_ospf = Enum.YLeaf(7, "mgmt-rib-protocol-ospf")

    mgmt_rib_protocol_eigrp = Enum.YLeaf(8, "mgmt-rib-protocol-eigrp")

    mgmt_rib_protocol_dagr = Enum.YLeaf(9, "mgmt-rib-protocol-dagr")

    mgmt_rib_protocol_subscriber = Enum.YLeaf(10, "mgmt-rib-protocol-subscriber")

    mgmt_rib_protocol_application = Enum.YLeaf(11, "mgmt-rib-protocol-application")

    mgmt_rib_protocol_mobile = Enum.YLeaf(12, "mgmt-rib-protocol-mobile")


class SrUloopEvent(Enum):
    """
    SrUloopEvent

    Sr uloop event

    .. data:: none = 0

    	No SR uloop event

    .. data:: link_down = 1

    	SR Uloop Event Link Down

    .. data:: link_up = 2

    	SR Uloop Event Link Up

    """

    none = Enum.YLeaf(0, "none")

    link_down = Enum.YLeaf(1, "link-down")

    link_up = Enum.YLeaf(2, "link-up")


class SrmsMiAfEB(Enum):
    """
    SrmsMiAfEB

    Srms mi af e b

    .. data:: none = 0

    	None

    .. data:: ipv4 = 1

    	IPv4

    .. data:: ipv6 = 2

    	IPv6

    """

    none = Enum.YLeaf(0, "none")

    ipv4 = Enum.YLeaf(1, "ipv4")

    ipv6 = Enum.YLeaf(2, "ipv6")


class SrmsMiFlagEB(Enum):
    """
    SrmsMiFlagEB

    Srms mi flag e b

    .. data:: false = 0

    	False

    .. data:: true = 1

    	True

    """

    false = Enum.YLeaf(0, "false")

    true = Enum.YLeaf(1, "true")


class SrmsMiSrcEB(Enum):
    """
    SrmsMiSrcEB

    Srms mi src e b

    .. data:: none = 0

    	None

    .. data:: local = 1

    	Local

    .. data:: remote = 2

    	Remote

    """

    none = Enum.YLeaf(0, "none")

    local = Enum.YLeaf(1, "local")

    remote = Enum.YLeaf(2, "remote")


class Stlv(Enum):
    """
    Stlv

    OSPF Opaque\-area Type 1 sub TLV types

    .. data:: mgmt_rrr_link_type = 1

    	Link Type

    .. data:: mgmt_rrr_link_id = 2

    	Link ID

    .. data:: mgmt_rrr_link_local_if_addr = 3

    	Local interface IP address

    .. data:: mgmt_rrr_link_remote_if_addr = 4

    	Remote interface IP address

    .. data:: mgmt_rrr_link_metric = 5

    	Traffic Engineering metric

    .. data:: mgmt_rrr_link_max_bw = 6

    	Maximum Link Bandwidth

    .. data:: mgmt_rrr_link_max_reservable_bw = 7

    	Maximum Reservable bandwidth

    .. data:: mgmt_rrr_link_unreserved_bw = 8

    	Unreserved Bandwidth

    .. data:: mgmt_rrr_link_re_source_class = 9

    	Administrative group

    .. data:: mgmt_rrr_link_in_out_if_id = 11

    	Link Local/Remote Identifiers

    .. data:: mgmt_rrr_link_if_switching_cap_desc = 15

    	Interface Switching Capability Descriptor

    .. data:: mgmt_ospf_rrr_link_srlg = 16

    	Shared Risk Link Group

    .. data:: mgmt_rrr_link_bw_constraints_sub = 17

    	Bandwidth constraints

    .. data:: mgmt_ospf_rrr_link_uni_delay = 27

    	Unidirectional link delay

    .. data:: mgmt_ospf_rrr_link_max_reservable_bw_sub = 32768

    	Maximum reservable sub-pool bandwidth

    .. data:: mgmt_ospf_rrr_link_unreserved_bw_sub = 32769

    	Unreserved sub-pool bandwidth

    .. data:: mgmt_rrr_link_igp_metric = 32770

    	IGP Link Metric

    .. data:: mgmt_ospf_rrr_link_ext_admin_sub = 32771

    	Extended admin

    """

    mgmt_rrr_link_type = Enum.YLeaf(1, "mgmt-rrr-link-type")

    mgmt_rrr_link_id = Enum.YLeaf(2, "mgmt-rrr-link-id")

    mgmt_rrr_link_local_if_addr = Enum.YLeaf(3, "mgmt-rrr-link-local-if-addr")

    mgmt_rrr_link_remote_if_addr = Enum.YLeaf(4, "mgmt-rrr-link-remote-if-addr")

    mgmt_rrr_link_metric = Enum.YLeaf(5, "mgmt-rrr-link-metric")

    mgmt_rrr_link_max_bw = Enum.YLeaf(6, "mgmt-rrr-link-max-bw")

    mgmt_rrr_link_max_reservable_bw = Enum.YLeaf(7, "mgmt-rrr-link-max-reservable-bw")

    mgmt_rrr_link_unreserved_bw = Enum.YLeaf(8, "mgmt-rrr-link-unreserved-bw")

    mgmt_rrr_link_re_source_class = Enum.YLeaf(9, "mgmt-rrr-link-re-source-class")

    mgmt_rrr_link_in_out_if_id = Enum.YLeaf(11, "mgmt-rrr-link-in-out-if-id")

    mgmt_rrr_link_if_switching_cap_desc = Enum.YLeaf(15, "mgmt-rrr-link-if-switching-cap-desc")

    mgmt_ospf_rrr_link_srlg = Enum.YLeaf(16, "mgmt-ospf-rrr-link-srlg")

    mgmt_rrr_link_bw_constraints_sub = Enum.YLeaf(17, "mgmt-rrr-link-bw-constraints-sub")

    mgmt_ospf_rrr_link_uni_delay = Enum.YLeaf(27, "mgmt-ospf-rrr-link-uni-delay")

    mgmt_ospf_rrr_link_max_reservable_bw_sub = Enum.YLeaf(32768, "mgmt-ospf-rrr-link-max-reservable-bw-sub")

    mgmt_ospf_rrr_link_unreserved_bw_sub = Enum.YLeaf(32769, "mgmt-ospf-rrr-link-unreserved-bw-sub")

    mgmt_rrr_link_igp_metric = Enum.YLeaf(32770, "mgmt-rrr-link-igp-metric")

    mgmt_ospf_rrr_link_ext_admin_sub = Enum.YLeaf(32771, "mgmt-ospf-rrr-link-ext-admin-sub")


class Timer(Enum):
    """
    Timer

    The LSA timer running can be refresh, checksum or

    maxage

    .. data:: mgmt_db_stop = 0

    	Timer stopped

    .. data:: mgmt_db_refresh = 1

    	Refresh

    .. data:: mgmt_db_checksum = 2

    	Checksum

    .. data:: mgmt_db_max_age = 3

    	Maxage

    """

    mgmt_db_stop = Enum.YLeaf(0, "mgmt-db-stop")

    mgmt_db_refresh = Enum.YLeaf(1, "mgmt-db-refresh")

    mgmt_db_checksum = Enum.YLeaf(2, "mgmt-db-checksum")

    mgmt_db_max_age = Enum.YLeaf(3, "mgmt-db-max-age")


class TimerTable(Enum):
    """
    TimerTable

    The throttled LSA can be in second, buffer or

    minute timer table

    .. data:: mgmt_db_no_table = 0

    	Not in time table

    .. data:: mgmt_db_sec_table = 1

    	In second table

    .. data:: mgmt_db_buffer_table = 2

    	In buffer table

    .. data:: mgmt_db_min_table = 3

    	In minute table

    """

    mgmt_db_no_table = Enum.YLeaf(0, "mgmt-db-no-table")

    mgmt_db_sec_table = Enum.YLeaf(1, "mgmt-db-sec-table")

    mgmt_db_buffer_table = Enum.YLeaf(2, "mgmt-db-buffer-table")

    mgmt_db_min_table = Enum.YLeaf(3, "mgmt-db-min-table")


class UloopAvoidance(Enum):
    """
    UloopAvoidance

    Uloop avoidance

    .. data:: none = 0

    	No uloop avoidance

    .. data:: protected_prefixes = 1

    	Apply Local uloop avoidance only for protected

    	prefixes

    .. data:: all_prefixes = 2

    	Apply Local uloop avoidance for all prefixes

    .. data:: segment_routing_uloop = 3

    	Apply segment routing uloop avoidance

    """

    none = Enum.YLeaf(0, "none")

    protected_prefixes = Enum.YLeaf(1, "protected-prefixes")

    all_prefixes = Enum.YLeaf(2, "all-prefixes")

    segment_routing_uloop = Enum.YLeaf(3, "segment-routing-uloop")



class Ospf(Entity):
    """
    OSPF operational data
    
    .. attribute:: processes
    
    	Table for each process
    	**type**\:   :py:class:`Processes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes>`
    
    

    """

    _prefix = 'ipv4-ospf-oper'
    _revision = '2017-01-02'

    def __init__(self):
        super(Ospf, self).__init__()
        self._top_entity = None

        self.yang_name = "ospf"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-ospf-oper"

        self.processes = Ospf.Processes()
        self.processes.parent = self
        self._children_name_map["processes"] = "processes"
        self._children_yang_names.add("processes")


    class Processes(Entity):
        """
        Table for each process
        
        .. attribute:: process
        
        	Operational data for a particular OSPF process
        	**type**\: list of    :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process>`
        
        

        """

        _prefix = 'ipv4-ospf-oper'
        _revision = '2017-01-02'

        def __init__(self):
            super(Ospf.Processes, self).__init__()

            self.yang_name = "processes"
            self.yang_parent_name = "ospf"

            self.process = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Ospf.Processes, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Ospf.Processes, self).__setattr__(name, value)


        class Process(Entity):
            """
            Operational data for a particular OSPF process
            
            .. attribute:: process_name  <key>
            
            	OSPF process
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: default_vrf
            
            	Operational data for the default VRF (instance) in the OSPF process
            	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf>`
            
            .. attribute:: srms
            
            	Segment Routing Mapping Server operational data
            	**type**\:   :py:class:`Srms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms>`
            
            .. attribute:: vrfs
            
            	Table for each VRF
            	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs>`
            
            

            """

            _prefix = 'ipv4-ospf-oper'
            _revision = '2017-01-02'

            def __init__(self):
                super(Ospf.Processes.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "processes"

                self.process_name = YLeaf(YType.str, "process-name")

                self.default_vrf = Ospf.Processes.Process.DefaultVrf()
                self.default_vrf.parent = self
                self._children_name_map["default_vrf"] = "default-vrf"
                self._children_yang_names.add("default-vrf")

                self.srms = Ospf.Processes.Process.Srms()
                self.srms.parent = self
                self._children_name_map["srms"] = "srms"
                self._children_yang_names.add("srms")

                self.vrfs = Ospf.Processes.Process.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"
                self._children_yang_names.add("vrfs")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("process_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Ospf.Processes.Process, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Ospf.Processes.Process, self).__setattr__(name, value)


            class Vrfs(Entity):
                """
                Table for each VRF
                
                .. attribute:: vrf
                
                	Operational data for a particular VRF (instance) in the OSPF process
                	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf>`
                
                

                """

                _prefix = 'ipv4-ospf-oper'
                _revision = '2017-01-02'

                def __init__(self):
                    super(Ospf.Processes.Process.Vrfs, self).__init__()

                    self.yang_name = "vrfs"
                    self.yang_parent_name = "process"

                    self.vrf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ospf.Processes.Process.Vrfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ospf.Processes.Process.Vrfs, self).__setattr__(name, value)


                class Vrf(Entity):
                    """
                    Operational data for a particular VRF
                    (instance) in the OSPF process
                    
                    .. attribute:: vrf_name  <key>
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: adjacency_information
                    
                    	Container for OSPF Interfaces
                    	**type**\:   :py:class:`AdjacencyInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation>`
                    
                    .. attribute:: area_statistics
                    
                    	Container for Statistics
                    	**type**\:   :py:class:`AreaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics>`
                    
                    .. attribute:: areas
                    
                    	Area table
                    	**type**\:   :py:class:`Areas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas>`
                    
                    .. attribute:: border_routers
                    
                    	Border router table
                    	**type**\:   :py:class:`BorderRouters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.BorderRouters>`
                    
                    .. attribute:: database
                    
                    	OSPF Link State Database
                    	**type**\:   :py:class:`Database <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database>`
                    
                    .. attribute:: fast_reroute
                    
                    	Container for FastReroute
                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FastReroute>`
                    
                    .. attribute:: flood_list_table
                    
                    	Flood list table
                    	**type**\:   :py:class:`FloodListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FloodListTable>`
                    
                    .. attribute:: interface_information
                    
                    	Container for OSPF Interfaces/links
                    	**type**\:   :py:class:`InterfaceInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation>`
                    
                    .. attribute:: interface_vrf_information
                    
                    	Container for OSPF Interfaces/links under a VRF
                    	**type**\:   :py:class:`InterfaceVrfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation>`
                    
                    .. attribute:: mpls_te
                    
                    	Container for MPLS TE
                    	**type**\:   :py:class:`MplsTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe>`
                    
                    .. attribute:: ospf_summary
                    
                    	Fast\-reroute topology information
                    	**type**\:   :py:class:`OspfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.OspfSummary>`
                    
                    .. attribute:: process_information
                    
                    	Container for OSPF Process information
                    	**type**\:   :py:class:`ProcessInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation>`
                    
                    .. attribute:: route_information
                    
                    	Container for OSPF routing tables
                    	**type**\:   :py:class:`RouteInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation>`
                    
                    .. attribute:: statistics
                    
                    	Container for Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics>`
                    
                    .. attribute:: summary_prefixes
                    
                    	Summary prefix table
                    	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.Vrfs.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "vrfs"

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.adjacency_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation()
                        self.adjacency_information.parent = self
                        self._children_name_map["adjacency_information"] = "adjacency-information"
                        self._children_yang_names.add("adjacency-information")

                        self.area_statistics = Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics()
                        self.area_statistics.parent = self
                        self._children_name_map["area_statistics"] = "area-statistics"
                        self._children_yang_names.add("area-statistics")

                        self.areas = Ospf.Processes.Process.Vrfs.Vrf.Areas()
                        self.areas.parent = self
                        self._children_name_map["areas"] = "areas"
                        self._children_yang_names.add("areas")

                        self.border_routers = Ospf.Processes.Process.Vrfs.Vrf.BorderRouters()
                        self.border_routers.parent = self
                        self._children_name_map["border_routers"] = "border-routers"
                        self._children_yang_names.add("border-routers")

                        self.database = Ospf.Processes.Process.Vrfs.Vrf.Database()
                        self.database.parent = self
                        self._children_name_map["database"] = "database"
                        self._children_yang_names.add("database")

                        self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"
                        self._children_yang_names.add("fast-reroute")

                        self.flood_list_table = Ospf.Processes.Process.Vrfs.Vrf.FloodListTable()
                        self.flood_list_table.parent = self
                        self._children_name_map["flood_list_table"] = "flood-list-table"
                        self._children_yang_names.add("flood-list-table")

                        self.interface_information = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation()
                        self.interface_information.parent = self
                        self._children_name_map["interface_information"] = "interface-information"
                        self._children_yang_names.add("interface-information")

                        self.interface_vrf_information = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation()
                        self.interface_vrf_information.parent = self
                        self._children_name_map["interface_vrf_information"] = "interface-vrf-information"
                        self._children_yang_names.add("interface-vrf-information")

                        self.mpls_te = Ospf.Processes.Process.Vrfs.Vrf.MplsTe()
                        self.mpls_te.parent = self
                        self._children_name_map["mpls_te"] = "mpls-te"
                        self._children_yang_names.add("mpls-te")

                        self.ospf_summary = Ospf.Processes.Process.Vrfs.Vrf.OspfSummary()
                        self.ospf_summary.parent = self
                        self._children_name_map["ospf_summary"] = "ospf-summary"
                        self._children_yang_names.add("ospf-summary")

                        self.process_information = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation()
                        self.process_information.parent = self
                        self._children_name_map["process_information"] = "process-information"
                        self._children_yang_names.add("process-information")

                        self.route_information = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation()
                        self.route_information.parent = self
                        self._children_name_map["route_information"] = "route-information"
                        self._children_yang_names.add("route-information")

                        self.statistics = Ospf.Processes.Process.Vrfs.Vrf.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                        self.summary_prefixes = Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes()
                        self.summary_prefixes.parent = self
                        self._children_name_map["summary_prefixes"] = "summary-prefixes"
                        self._children_yang_names.add("summary-prefixes")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.Vrfs.Vrf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.Vrfs.Vrf, self).__setattr__(name, value)


                    class InterfaceVrfInformation(Entity):
                        """
                        Container for OSPF Interfaces/links under a
                        VRF
                        
                        .. attribute:: sham_links
                        
                        	Sham Link table
                        	**type**\:   :py:class:`ShamLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation, self).__init__()

                            self.yang_name = "interface-vrf-information"
                            self.yang_parent_name = "vrf"

                            self.sham_links = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks()
                            self.sham_links.parent = self
                            self._children_name_map["sham_links"] = "sham-links"
                            self._children_yang_names.add("sham-links")


                        class ShamLinks(Entity):
                            """
                            Sham Link table
                            
                            .. attribute:: sham_link
                            
                            	Information for one Sham link
                            	**type**\: list of    :py:class:`ShamLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks, self).__init__()

                                self.yang_name = "sham-links"
                                self.yang_parent_name = "interface-vrf-information"

                                self.sham_link = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks, self).__setattr__(name, value)


                            class ShamLink(Entity):
                                """
                                Information for one Sham link
                                
                                .. attribute:: sham_link_name  <key>
                                
                                	Sham link
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: sham_link_area
                                
                                	Area id
                                	**type**\:  str
                                
                                .. attribute:: sham_link_authentication_type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                
                                .. attribute:: sham_link_cost
                                
                                	Cost of the sham link
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: sham_link_dc_bitless_lsa
                                
                                	Number of LSA's with demand circuit bit not set
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_dead_interval
                                
                                	Dead interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_demand_circuit
                                
                                	If true, the link runs as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: sham_link_dest_address
                                
                                	Sham\-link dest
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sham_link_hello_interval
                                
                                	Hello interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_hello_interval_ms
                                
                                	Hello interval (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_ifindex
                                
                                	Sham\-link ifindex
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_keychain_id
                                
                                	Sham Link Keychain ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sham_link_last_nsf
                                
                                	Time in seconds since last NSF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: sham_link_md_key
                                
                                	List of old MD keys (if any)
                                	**type**\: list of    :py:class:`ShamLinkMdKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkMdKey>`
                                
                                .. attribute:: sham_link_name_xr
                                
                                	Sham link name
                                	**type**\:  str
                                
                                .. attribute:: sham_link_neighbor
                                
                                	Neighbor information
                                	**type**\:   :py:class:`ShamLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor>`
                                
                                .. attribute:: sham_link_neighbor_id
                                
                                	Neighbor on other end of this sham link
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sham_link_next_hello
                                
                                	Time until next hello (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_next_hello_ms
                                
                                	Time until next hello (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_nsf
                                
                                	If true, NSF restart in progress on the sham link
                                	**type**\:  bool
                                
                                .. attribute:: sham_link_nsf_enabled
                                
                                	If true, NSF enabled
                                	**type**\:  bool
                                
                                .. attribute:: sham_link_old_md_key_count
                                
                                	Number of neighbors still using the old key (rollover in progress)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_passive
                                
                                	If true, interface is passive
                                	**type**\:  bool
                                
                                .. attribute:: sham_link_retransmission_interval
                                
                                	Retransmission interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_source_address
                                
                                	Sham\-link source
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sham_link_state
                                
                                	OSPF interface state for the sham link
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                .. attribute:: sham_link_transmission_delay
                                
                                	Transmission delay in seconds
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: sham_link_wait_interval
                                
                                	Wait interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_youngest_md_key
                                
                                	If true, MD key configured
                                	**type**\:  bool
                                
                                .. attribute:: sham_link_youngest_md_key_id
                                
                                	Youngest MD key ID
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink, self).__init__()

                                    self.yang_name = "sham-link"
                                    self.yang_parent_name = "sham-links"

                                    self.sham_link_name = YLeaf(YType.str, "sham-link-name")

                                    self.sham_link_area = YLeaf(YType.str, "sham-link-area")

                                    self.sham_link_authentication_type = YLeaf(YType.enumeration, "sham-link-authentication-type")

                                    self.sham_link_cost = YLeaf(YType.uint16, "sham-link-cost")

                                    self.sham_link_dc_bitless_lsa = YLeaf(YType.uint32, "sham-link-dc-bitless-lsa")

                                    self.sham_link_dead_interval = YLeaf(YType.uint32, "sham-link-dead-interval")

                                    self.sham_link_demand_circuit = YLeaf(YType.boolean, "sham-link-demand-circuit")

                                    self.sham_link_dest_address = YLeaf(YType.str, "sham-link-dest-address")

                                    self.sham_link_hello_interval = YLeaf(YType.uint32, "sham-link-hello-interval")

                                    self.sham_link_hello_interval_ms = YLeaf(YType.uint32, "sham-link-hello-interval-ms")

                                    self.sham_link_ifindex = YLeaf(YType.uint32, "sham-link-ifindex")

                                    self.sham_link_keychain_id = YLeaf(YType.uint64, "sham-link-keychain-id")

                                    self.sham_link_last_nsf = YLeaf(YType.uint32, "sham-link-last-nsf")

                                    self.sham_link_name_xr = YLeaf(YType.str, "sham-link-name-xr")

                                    self.sham_link_neighbor_id = YLeaf(YType.str, "sham-link-neighbor-id")

                                    self.sham_link_next_hello = YLeaf(YType.uint32, "sham-link-next-hello")

                                    self.sham_link_next_hello_ms = YLeaf(YType.uint32, "sham-link-next-hello-ms")

                                    self.sham_link_nsf = YLeaf(YType.boolean, "sham-link-nsf")

                                    self.sham_link_nsf_enabled = YLeaf(YType.boolean, "sham-link-nsf-enabled")

                                    self.sham_link_old_md_key_count = YLeaf(YType.uint32, "sham-link-old-md-key-count")

                                    self.sham_link_passive = YLeaf(YType.boolean, "sham-link-passive")

                                    self.sham_link_retransmission_interval = YLeaf(YType.uint32, "sham-link-retransmission-interval")

                                    self.sham_link_source_address = YLeaf(YType.str, "sham-link-source-address")

                                    self.sham_link_state = YLeaf(YType.enumeration, "sham-link-state")

                                    self.sham_link_transmission_delay = YLeaf(YType.uint16, "sham-link-transmission-delay")

                                    self.sham_link_wait_interval = YLeaf(YType.uint32, "sham-link-wait-interval")

                                    self.sham_link_youngest_md_key = YLeaf(YType.boolean, "sham-link-youngest-md-key")

                                    self.sham_link_youngest_md_key_id = YLeaf(YType.uint16, "sham-link-youngest-md-key-id")

                                    self.sham_link_neighbor = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor()
                                    self.sham_link_neighbor.parent = self
                                    self._children_name_map["sham_link_neighbor"] = "sham-link-neighbor"
                                    self._children_yang_names.add("sham-link-neighbor")

                                    self.sham_link_md_key = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("sham_link_name",
                                                    "sham_link_area",
                                                    "sham_link_authentication_type",
                                                    "sham_link_cost",
                                                    "sham_link_dc_bitless_lsa",
                                                    "sham_link_dead_interval",
                                                    "sham_link_demand_circuit",
                                                    "sham_link_dest_address",
                                                    "sham_link_hello_interval",
                                                    "sham_link_hello_interval_ms",
                                                    "sham_link_ifindex",
                                                    "sham_link_keychain_id",
                                                    "sham_link_last_nsf",
                                                    "sham_link_name_xr",
                                                    "sham_link_neighbor_id",
                                                    "sham_link_next_hello",
                                                    "sham_link_next_hello_ms",
                                                    "sham_link_nsf",
                                                    "sham_link_nsf_enabled",
                                                    "sham_link_old_md_key_count",
                                                    "sham_link_passive",
                                                    "sham_link_retransmission_interval",
                                                    "sham_link_source_address",
                                                    "sham_link_state",
                                                    "sham_link_transmission_delay",
                                                    "sham_link_wait_interval",
                                                    "sham_link_youngest_md_key",
                                                    "sham_link_youngest_md_key_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink, self).__setattr__(name, value)


                                class ShamLinkNeighbor(Entity):
                                    """
                                    Neighbor information
                                    
                                    .. attribute:: sham_link_retransmissoin
                                    
                                    	Neighbor retransmission info
                                    	**type**\:   :py:class:`ShamLinkRetransmissoin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor.ShamLinkRetransmissoin>`
                                    
                                    .. attribute:: sham_link_state
                                    
                                    	Adjacency state
                                    	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                    
                                    .. attribute:: sham_link_suppress_hello
                                    
                                    	If true Hellos suppressed
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor, self).__init__()

                                        self.yang_name = "sham-link-neighbor"
                                        self.yang_parent_name = "sham-link"

                                        self.sham_link_state = YLeaf(YType.enumeration, "sham-link-state")

                                        self.sham_link_suppress_hello = YLeaf(YType.boolean, "sham-link-suppress-hello")

                                        self.sham_link_retransmissoin = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor.ShamLinkRetransmissoin()
                                        self.sham_link_retransmissoin.parent = self
                                        self._children_name_map["sham_link_retransmissoin"] = "sham-link-retransmissoin"
                                        self._children_yang_names.add("sham-link-retransmissoin")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("sham_link_state",
                                                        "sham_link_suppress_hello") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor, self).__setattr__(name, value)


                                    class ShamLinkRetransmissoin(Entity):
                                        """
                                        Neighbor retransmission info
                                        
                                        .. attribute:: area_first_flood_information
                                        
                                        	First flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood_information_index
                                        
                                        	Index of the first flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_flooding_index
                                        
                                        	Area scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_information
                                        
                                        	Next flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_information_index
                                        
                                        	Index of next flood item for Area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_information
                                        
                                        	First flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_information_index
                                        
                                        	Index for first flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_flood_index
                                        
                                        	AS scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_information
                                        
                                        	Next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_information_index
                                        
                                        	Index of next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dbd_retransmission_count
                                        
                                        	Number of DBD retransmissions during last exchange
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dbd_retransmission_total_count
                                        
                                        	Total number of DBD retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_length
                                        
                                        	Number of LSAs sent in last retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_time
                                        
                                        	Last retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_retransmission_timer
                                        
                                        	Time until next LSA retransmission (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_length
                                        
                                        	Maximum number of LSAs sent in a retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_time
                                        
                                        	Maximum retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmission_count
                                        
                                        	Retransmission queue length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_retransmissions
                                        
                                        	Number of retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor.ShamLinkRetransmissoin, self).__init__()

                                            self.yang_name = "sham-link-retransmissoin"
                                            self.yang_parent_name = "sham-link-neighbor"

                                            self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                            self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                            self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                            self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                            self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                            self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                            self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                            self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                            self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                            self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                            self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                            self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                            self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                            self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                            self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                            self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                            self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                            self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                            self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("area_first_flood_information",
                                                            "area_first_flood_information_index",
                                                            "area_flooding_index",
                                                            "area_next_flood_information",
                                                            "area_next_flood_information_index",
                                                            "as_first_flood_information",
                                                            "as_first_flood_information_index",
                                                            "as_flood_index",
                                                            "as_next_flood_information",
                                                            "as_next_flood_information_index",
                                                            "dbd_retransmission_count",
                                                            "dbd_retransmission_total_count",
                                                            "last_retransmission_length",
                                                            "last_retransmission_time",
                                                            "lsa_retransmission_timer",
                                                            "maximum_retransmission_length",
                                                            "maximum_retransmission_time",
                                                            "neighbor_retransmission_count",
                                                            "number_of_retransmissions") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor.ShamLinkRetransmissoin, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor.ShamLinkRetransmissoin, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.area_first_flood_information.is_set or
                                                self.area_first_flood_information_index.is_set or
                                                self.area_flooding_index.is_set or
                                                self.area_next_flood_information.is_set or
                                                self.area_next_flood_information_index.is_set or
                                                self.as_first_flood_information.is_set or
                                                self.as_first_flood_information_index.is_set or
                                                self.as_flood_index.is_set or
                                                self.as_next_flood_information.is_set or
                                                self.as_next_flood_information_index.is_set or
                                                self.dbd_retransmission_count.is_set or
                                                self.dbd_retransmission_total_count.is_set or
                                                self.last_retransmission_length.is_set or
                                                self.last_retransmission_time.is_set or
                                                self.lsa_retransmission_timer.is_set or
                                                self.maximum_retransmission_length.is_set or
                                                self.maximum_retransmission_time.is_set or
                                                self.neighbor_retransmission_count.is_set or
                                                self.number_of_retransmissions.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.area_first_flood_information.yfilter != YFilter.not_set or
                                                self.area_first_flood_information_index.yfilter != YFilter.not_set or
                                                self.area_flooding_index.yfilter != YFilter.not_set or
                                                self.area_next_flood_information.yfilter != YFilter.not_set or
                                                self.area_next_flood_information_index.yfilter != YFilter.not_set or
                                                self.as_first_flood_information.yfilter != YFilter.not_set or
                                                self.as_first_flood_information_index.yfilter != YFilter.not_set or
                                                self.as_flood_index.yfilter != YFilter.not_set or
                                                self.as_next_flood_information.yfilter != YFilter.not_set or
                                                self.as_next_flood_information_index.yfilter != YFilter.not_set or
                                                self.dbd_retransmission_count.yfilter != YFilter.not_set or
                                                self.dbd_retransmission_total_count.yfilter != YFilter.not_set or
                                                self.last_retransmission_length.yfilter != YFilter.not_set or
                                                self.last_retransmission_time.yfilter != YFilter.not_set or
                                                self.lsa_retransmission_timer.yfilter != YFilter.not_set or
                                                self.maximum_retransmission_length.yfilter != YFilter.not_set or
                                                self.maximum_retransmission_time.yfilter != YFilter.not_set or
                                                self.neighbor_retransmission_count.yfilter != YFilter.not_set or
                                                self.number_of_retransmissions.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sham-link-retransmissoin" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.area_first_flood_information.is_set or self.area_first_flood_information.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_first_flood_information.get_name_leafdata())
                                            if (self.area_first_flood_information_index.is_set or self.area_first_flood_information_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_first_flood_information_index.get_name_leafdata())
                                            if (self.area_flooding_index.is_set or self.area_flooding_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_flooding_index.get_name_leafdata())
                                            if (self.area_next_flood_information.is_set or self.area_next_flood_information.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_next_flood_information.get_name_leafdata())
                                            if (self.area_next_flood_information_index.is_set or self.area_next_flood_information_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_next_flood_information_index.get_name_leafdata())
                                            if (self.as_first_flood_information.is_set or self.as_first_flood_information.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_first_flood_information.get_name_leafdata())
                                            if (self.as_first_flood_information_index.is_set or self.as_first_flood_information_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_first_flood_information_index.get_name_leafdata())
                                            if (self.as_flood_index.is_set or self.as_flood_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_flood_index.get_name_leafdata())
                                            if (self.as_next_flood_information.is_set or self.as_next_flood_information.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_next_flood_information.get_name_leafdata())
                                            if (self.as_next_flood_information_index.is_set or self.as_next_flood_information_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_next_flood_information_index.get_name_leafdata())
                                            if (self.dbd_retransmission_count.is_set or self.dbd_retransmission_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dbd_retransmission_count.get_name_leafdata())
                                            if (self.dbd_retransmission_total_count.is_set or self.dbd_retransmission_total_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dbd_retransmission_total_count.get_name_leafdata())
                                            if (self.last_retransmission_length.is_set or self.last_retransmission_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.last_retransmission_length.get_name_leafdata())
                                            if (self.last_retransmission_time.is_set or self.last_retransmission_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.last_retransmission_time.get_name_leafdata())
                                            if (self.lsa_retransmission_timer.is_set or self.lsa_retransmission_timer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_retransmission_timer.get_name_leafdata())
                                            if (self.maximum_retransmission_length.is_set or self.maximum_retransmission_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_retransmission_length.get_name_leafdata())
                                            if (self.maximum_retransmission_time.is_set or self.maximum_retransmission_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_retransmission_time.get_name_leafdata())
                                            if (self.neighbor_retransmission_count.is_set or self.neighbor_retransmission_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_retransmission_count.get_name_leafdata())
                                            if (self.number_of_retransmissions.is_set or self.number_of_retransmissions.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.number_of_retransmissions.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "area-first-flood-information" or name == "area-first-flood-information-index" or name == "area-flooding-index" or name == "area-next-flood-information" or name == "area-next-flood-information-index" or name == "as-first-flood-information" or name == "as-first-flood-information-index" or name == "as-flood-index" or name == "as-next-flood-information" or name == "as-next-flood-information-index" or name == "dbd-retransmission-count" or name == "dbd-retransmission-total-count" or name == "last-retransmission-length" or name == "last-retransmission-time" or name == "lsa-retransmission-timer" or name == "maximum-retransmission-length" or name == "maximum-retransmission-time" or name == "neighbor-retransmission-count" or name == "number-of-retransmissions"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "area-first-flood-information"):
                                                self.area_first_flood_information = value
                                                self.area_first_flood_information.value_namespace = name_space
                                                self.area_first_flood_information.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-first-flood-information-index"):
                                                self.area_first_flood_information_index = value
                                                self.area_first_flood_information_index.value_namespace = name_space
                                                self.area_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-flooding-index"):
                                                self.area_flooding_index = value
                                                self.area_flooding_index.value_namespace = name_space
                                                self.area_flooding_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-next-flood-information"):
                                                self.area_next_flood_information = value
                                                self.area_next_flood_information.value_namespace = name_space
                                                self.area_next_flood_information.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-next-flood-information-index"):
                                                self.area_next_flood_information_index = value
                                                self.area_next_flood_information_index.value_namespace = name_space
                                                self.area_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-first-flood-information"):
                                                self.as_first_flood_information = value
                                                self.as_first_flood_information.value_namespace = name_space
                                                self.as_first_flood_information.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-first-flood-information-index"):
                                                self.as_first_flood_information_index = value
                                                self.as_first_flood_information_index.value_namespace = name_space
                                                self.as_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-flood-index"):
                                                self.as_flood_index = value
                                                self.as_flood_index.value_namespace = name_space
                                                self.as_flood_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-next-flood-information"):
                                                self.as_next_flood_information = value
                                                self.as_next_flood_information.value_namespace = name_space
                                                self.as_next_flood_information.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-next-flood-information-index"):
                                                self.as_next_flood_information_index = value
                                                self.as_next_flood_information_index.value_namespace = name_space
                                                self.as_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dbd-retransmission-count"):
                                                self.dbd_retransmission_count = value
                                                self.dbd_retransmission_count.value_namespace = name_space
                                                self.dbd_retransmission_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dbd-retransmission-total-count"):
                                                self.dbd_retransmission_total_count = value
                                                self.dbd_retransmission_total_count.value_namespace = name_space
                                                self.dbd_retransmission_total_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "last-retransmission-length"):
                                                self.last_retransmission_length = value
                                                self.last_retransmission_length.value_namespace = name_space
                                                self.last_retransmission_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "last-retransmission-time"):
                                                self.last_retransmission_time = value
                                                self.last_retransmission_time.value_namespace = name_space
                                                self.last_retransmission_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-retransmission-timer"):
                                                self.lsa_retransmission_timer = value
                                                self.lsa_retransmission_timer.value_namespace = name_space
                                                self.lsa_retransmission_timer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-retransmission-length"):
                                                self.maximum_retransmission_length = value
                                                self.maximum_retransmission_length.value_namespace = name_space
                                                self.maximum_retransmission_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-retransmission-time"):
                                                self.maximum_retransmission_time = value
                                                self.maximum_retransmission_time.value_namespace = name_space
                                                self.maximum_retransmission_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-retransmission-count"):
                                                self.neighbor_retransmission_count = value
                                                self.neighbor_retransmission_count.value_namespace = name_space
                                                self.neighbor_retransmission_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "number-of-retransmissions"):
                                                self.number_of_retransmissions = value
                                                self.number_of_retransmissions.value_namespace = name_space
                                                self.number_of_retransmissions.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.sham_link_state.is_set or
                                            self.sham_link_suppress_hello.is_set or
                                            (self.sham_link_retransmissoin is not None and self.sham_link_retransmissoin.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.sham_link_state.yfilter != YFilter.not_set or
                                            self.sham_link_suppress_hello.yfilter != YFilter.not_set or
                                            (self.sham_link_retransmissoin is not None and self.sham_link_retransmissoin.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sham-link-neighbor" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.sham_link_state.is_set or self.sham_link_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sham_link_state.get_name_leafdata())
                                        if (self.sham_link_suppress_hello.is_set or self.sham_link_suppress_hello.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sham_link_suppress_hello.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "sham-link-retransmissoin"):
                                            if (self.sham_link_retransmissoin is None):
                                                self.sham_link_retransmissoin = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor.ShamLinkRetransmissoin()
                                                self.sham_link_retransmissoin.parent = self
                                                self._children_name_map["sham_link_retransmissoin"] = "sham-link-retransmissoin"
                                            return self.sham_link_retransmissoin

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "sham-link-retransmissoin" or name == "sham-link-state" or name == "sham-link-suppress-hello"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "sham-link-state"):
                                            self.sham_link_state = value
                                            self.sham_link_state.value_namespace = name_space
                                            self.sham_link_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sham-link-suppress-hello"):
                                            self.sham_link_suppress_hello = value
                                            self.sham_link_suppress_hello.value_namespace = name_space
                                            self.sham_link_suppress_hello.value_namespace_prefix = name_space_prefix


                                class ShamLinkMdKey(Entity):
                                    """
                                    List of old MD keys (if any)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkMdKey, self).__init__()

                                        self.yang_name = "sham-link-md-key"
                                        self.yang_parent_name = "sham-link"

                                        self.entry = YLeaf(YType.uint16, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkMdKey, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkMdKey, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sham-link-md-key" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.sham_link_md_key:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.sham_link_name.is_set or
                                        self.sham_link_area.is_set or
                                        self.sham_link_authentication_type.is_set or
                                        self.sham_link_cost.is_set or
                                        self.sham_link_dc_bitless_lsa.is_set or
                                        self.sham_link_dead_interval.is_set or
                                        self.sham_link_demand_circuit.is_set or
                                        self.sham_link_dest_address.is_set or
                                        self.sham_link_hello_interval.is_set or
                                        self.sham_link_hello_interval_ms.is_set or
                                        self.sham_link_ifindex.is_set or
                                        self.sham_link_keychain_id.is_set or
                                        self.sham_link_last_nsf.is_set or
                                        self.sham_link_name_xr.is_set or
                                        self.sham_link_neighbor_id.is_set or
                                        self.sham_link_next_hello.is_set or
                                        self.sham_link_next_hello_ms.is_set or
                                        self.sham_link_nsf.is_set or
                                        self.sham_link_nsf_enabled.is_set or
                                        self.sham_link_old_md_key_count.is_set or
                                        self.sham_link_passive.is_set or
                                        self.sham_link_retransmission_interval.is_set or
                                        self.sham_link_source_address.is_set or
                                        self.sham_link_state.is_set or
                                        self.sham_link_transmission_delay.is_set or
                                        self.sham_link_wait_interval.is_set or
                                        self.sham_link_youngest_md_key.is_set or
                                        self.sham_link_youngest_md_key_id.is_set or
                                        (self.sham_link_neighbor is not None and self.sham_link_neighbor.has_data()))

                                def has_operation(self):
                                    for c in self.sham_link_md_key:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.sham_link_name.yfilter != YFilter.not_set or
                                        self.sham_link_area.yfilter != YFilter.not_set or
                                        self.sham_link_authentication_type.yfilter != YFilter.not_set or
                                        self.sham_link_cost.yfilter != YFilter.not_set or
                                        self.sham_link_dc_bitless_lsa.yfilter != YFilter.not_set or
                                        self.sham_link_dead_interval.yfilter != YFilter.not_set or
                                        self.sham_link_demand_circuit.yfilter != YFilter.not_set or
                                        self.sham_link_dest_address.yfilter != YFilter.not_set or
                                        self.sham_link_hello_interval.yfilter != YFilter.not_set or
                                        self.sham_link_hello_interval_ms.yfilter != YFilter.not_set or
                                        self.sham_link_ifindex.yfilter != YFilter.not_set or
                                        self.sham_link_keychain_id.yfilter != YFilter.not_set or
                                        self.sham_link_last_nsf.yfilter != YFilter.not_set or
                                        self.sham_link_name_xr.yfilter != YFilter.not_set or
                                        self.sham_link_neighbor_id.yfilter != YFilter.not_set or
                                        self.sham_link_next_hello.yfilter != YFilter.not_set or
                                        self.sham_link_next_hello_ms.yfilter != YFilter.not_set or
                                        self.sham_link_nsf.yfilter != YFilter.not_set or
                                        self.sham_link_nsf_enabled.yfilter != YFilter.not_set or
                                        self.sham_link_old_md_key_count.yfilter != YFilter.not_set or
                                        self.sham_link_passive.yfilter != YFilter.not_set or
                                        self.sham_link_retransmission_interval.yfilter != YFilter.not_set or
                                        self.sham_link_source_address.yfilter != YFilter.not_set or
                                        self.sham_link_state.yfilter != YFilter.not_set or
                                        self.sham_link_transmission_delay.yfilter != YFilter.not_set or
                                        self.sham_link_wait_interval.yfilter != YFilter.not_set or
                                        self.sham_link_youngest_md_key.yfilter != YFilter.not_set or
                                        self.sham_link_youngest_md_key_id.yfilter != YFilter.not_set or
                                        (self.sham_link_neighbor is not None and self.sham_link_neighbor.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sham-link" + "[sham-link-name='" + self.sham_link_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.sham_link_name.is_set or self.sham_link_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_name.get_name_leafdata())
                                    if (self.sham_link_area.is_set or self.sham_link_area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_area.get_name_leafdata())
                                    if (self.sham_link_authentication_type.is_set or self.sham_link_authentication_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_authentication_type.get_name_leafdata())
                                    if (self.sham_link_cost.is_set or self.sham_link_cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_cost.get_name_leafdata())
                                    if (self.sham_link_dc_bitless_lsa.is_set or self.sham_link_dc_bitless_lsa.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_dc_bitless_lsa.get_name_leafdata())
                                    if (self.sham_link_dead_interval.is_set or self.sham_link_dead_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_dead_interval.get_name_leafdata())
                                    if (self.sham_link_demand_circuit.is_set or self.sham_link_demand_circuit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_demand_circuit.get_name_leafdata())
                                    if (self.sham_link_dest_address.is_set or self.sham_link_dest_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_dest_address.get_name_leafdata())
                                    if (self.sham_link_hello_interval.is_set or self.sham_link_hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_hello_interval.get_name_leafdata())
                                    if (self.sham_link_hello_interval_ms.is_set or self.sham_link_hello_interval_ms.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_hello_interval_ms.get_name_leafdata())
                                    if (self.sham_link_ifindex.is_set or self.sham_link_ifindex.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_ifindex.get_name_leafdata())
                                    if (self.sham_link_keychain_id.is_set or self.sham_link_keychain_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_keychain_id.get_name_leafdata())
                                    if (self.sham_link_last_nsf.is_set or self.sham_link_last_nsf.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_last_nsf.get_name_leafdata())
                                    if (self.sham_link_name_xr.is_set or self.sham_link_name_xr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_name_xr.get_name_leafdata())
                                    if (self.sham_link_neighbor_id.is_set or self.sham_link_neighbor_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_neighbor_id.get_name_leafdata())
                                    if (self.sham_link_next_hello.is_set or self.sham_link_next_hello.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_next_hello.get_name_leafdata())
                                    if (self.sham_link_next_hello_ms.is_set or self.sham_link_next_hello_ms.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_next_hello_ms.get_name_leafdata())
                                    if (self.sham_link_nsf.is_set or self.sham_link_nsf.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_nsf.get_name_leafdata())
                                    if (self.sham_link_nsf_enabled.is_set or self.sham_link_nsf_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_nsf_enabled.get_name_leafdata())
                                    if (self.sham_link_old_md_key_count.is_set or self.sham_link_old_md_key_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_old_md_key_count.get_name_leafdata())
                                    if (self.sham_link_passive.is_set or self.sham_link_passive.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_passive.get_name_leafdata())
                                    if (self.sham_link_retransmission_interval.is_set or self.sham_link_retransmission_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_retransmission_interval.get_name_leafdata())
                                    if (self.sham_link_source_address.is_set or self.sham_link_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_source_address.get_name_leafdata())
                                    if (self.sham_link_state.is_set or self.sham_link_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_state.get_name_leafdata())
                                    if (self.sham_link_transmission_delay.is_set or self.sham_link_transmission_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_transmission_delay.get_name_leafdata())
                                    if (self.sham_link_wait_interval.is_set or self.sham_link_wait_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_wait_interval.get_name_leafdata())
                                    if (self.sham_link_youngest_md_key.is_set or self.sham_link_youngest_md_key.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_youngest_md_key.get_name_leafdata())
                                    if (self.sham_link_youngest_md_key_id.is_set or self.sham_link_youngest_md_key_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sham_link_youngest_md_key_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sham-link-md-key"):
                                        for c in self.sham_link_md_key:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkMdKey()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.sham_link_md_key.append(c)
                                        return c

                                    if (child_yang_name == "sham-link-neighbor"):
                                        if (self.sham_link_neighbor is None):
                                            self.sham_link_neighbor = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor()
                                            self.sham_link_neighbor.parent = self
                                            self._children_name_map["sham_link_neighbor"] = "sham-link-neighbor"
                                        return self.sham_link_neighbor

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sham-link-md-key" or name == "sham-link-neighbor" or name == "sham-link-name" or name == "sham-link-area" or name == "sham-link-authentication-type" or name == "sham-link-cost" or name == "sham-link-dc-bitless-lsa" or name == "sham-link-dead-interval" or name == "sham-link-demand-circuit" or name == "sham-link-dest-address" or name == "sham-link-hello-interval" or name == "sham-link-hello-interval-ms" or name == "sham-link-ifindex" or name == "sham-link-keychain-id" or name == "sham-link-last-nsf" or name == "sham-link-name-xr" or name == "sham-link-neighbor-id" or name == "sham-link-next-hello" or name == "sham-link-next-hello-ms" or name == "sham-link-nsf" or name == "sham-link-nsf-enabled" or name == "sham-link-old-md-key-count" or name == "sham-link-passive" or name == "sham-link-retransmission-interval" or name == "sham-link-source-address" or name == "sham-link-state" or name == "sham-link-transmission-delay" or name == "sham-link-wait-interval" or name == "sham-link-youngest-md-key" or name == "sham-link-youngest-md-key-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "sham-link-name"):
                                        self.sham_link_name = value
                                        self.sham_link_name.value_namespace = name_space
                                        self.sham_link_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-area"):
                                        self.sham_link_area = value
                                        self.sham_link_area.value_namespace = name_space
                                        self.sham_link_area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-authentication-type"):
                                        self.sham_link_authentication_type = value
                                        self.sham_link_authentication_type.value_namespace = name_space
                                        self.sham_link_authentication_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-cost"):
                                        self.sham_link_cost = value
                                        self.sham_link_cost.value_namespace = name_space
                                        self.sham_link_cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-dc-bitless-lsa"):
                                        self.sham_link_dc_bitless_lsa = value
                                        self.sham_link_dc_bitless_lsa.value_namespace = name_space
                                        self.sham_link_dc_bitless_lsa.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-dead-interval"):
                                        self.sham_link_dead_interval = value
                                        self.sham_link_dead_interval.value_namespace = name_space
                                        self.sham_link_dead_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-demand-circuit"):
                                        self.sham_link_demand_circuit = value
                                        self.sham_link_demand_circuit.value_namespace = name_space
                                        self.sham_link_demand_circuit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-dest-address"):
                                        self.sham_link_dest_address = value
                                        self.sham_link_dest_address.value_namespace = name_space
                                        self.sham_link_dest_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-hello-interval"):
                                        self.sham_link_hello_interval = value
                                        self.sham_link_hello_interval.value_namespace = name_space
                                        self.sham_link_hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-hello-interval-ms"):
                                        self.sham_link_hello_interval_ms = value
                                        self.sham_link_hello_interval_ms.value_namespace = name_space
                                        self.sham_link_hello_interval_ms.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-ifindex"):
                                        self.sham_link_ifindex = value
                                        self.sham_link_ifindex.value_namespace = name_space
                                        self.sham_link_ifindex.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-keychain-id"):
                                        self.sham_link_keychain_id = value
                                        self.sham_link_keychain_id.value_namespace = name_space
                                        self.sham_link_keychain_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-last-nsf"):
                                        self.sham_link_last_nsf = value
                                        self.sham_link_last_nsf.value_namespace = name_space
                                        self.sham_link_last_nsf.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-name-xr"):
                                        self.sham_link_name_xr = value
                                        self.sham_link_name_xr.value_namespace = name_space
                                        self.sham_link_name_xr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-neighbor-id"):
                                        self.sham_link_neighbor_id = value
                                        self.sham_link_neighbor_id.value_namespace = name_space
                                        self.sham_link_neighbor_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-next-hello"):
                                        self.sham_link_next_hello = value
                                        self.sham_link_next_hello.value_namespace = name_space
                                        self.sham_link_next_hello.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-next-hello-ms"):
                                        self.sham_link_next_hello_ms = value
                                        self.sham_link_next_hello_ms.value_namespace = name_space
                                        self.sham_link_next_hello_ms.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-nsf"):
                                        self.sham_link_nsf = value
                                        self.sham_link_nsf.value_namespace = name_space
                                        self.sham_link_nsf.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-nsf-enabled"):
                                        self.sham_link_nsf_enabled = value
                                        self.sham_link_nsf_enabled.value_namespace = name_space
                                        self.sham_link_nsf_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-old-md-key-count"):
                                        self.sham_link_old_md_key_count = value
                                        self.sham_link_old_md_key_count.value_namespace = name_space
                                        self.sham_link_old_md_key_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-passive"):
                                        self.sham_link_passive = value
                                        self.sham_link_passive.value_namespace = name_space
                                        self.sham_link_passive.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-retransmission-interval"):
                                        self.sham_link_retransmission_interval = value
                                        self.sham_link_retransmission_interval.value_namespace = name_space
                                        self.sham_link_retransmission_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-source-address"):
                                        self.sham_link_source_address = value
                                        self.sham_link_source_address.value_namespace = name_space
                                        self.sham_link_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-state"):
                                        self.sham_link_state = value
                                        self.sham_link_state.value_namespace = name_space
                                        self.sham_link_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-transmission-delay"):
                                        self.sham_link_transmission_delay = value
                                        self.sham_link_transmission_delay.value_namespace = name_space
                                        self.sham_link_transmission_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-wait-interval"):
                                        self.sham_link_wait_interval = value
                                        self.sham_link_wait_interval.value_namespace = name_space
                                        self.sham_link_wait_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-youngest-md-key"):
                                        self.sham_link_youngest_md_key = value
                                        self.sham_link_youngest_md_key.value_namespace = name_space
                                        self.sham_link_youngest_md_key.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sham-link-youngest-md-key-id"):
                                        self.sham_link_youngest_md_key_id = value
                                        self.sham_link_youngest_md_key_id.value_namespace = name_space
                                        self.sham_link_youngest_md_key_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.sham_link:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.sham_link:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sham-links" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sham-link"):
                                    for c in self.sham_link:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.sham_link.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sham-link"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.sham_links is not None and self.sham_links.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.sham_links is not None and self.sham_links.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-vrf-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sham-links"):
                                if (self.sham_links is None):
                                    self.sham_links = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks()
                                    self.sham_links.parent = self
                                    self._children_name_map["sham_links"] = "sham-links"
                                return self.sham_links

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sham-links"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class FloodListTable(Entity):
                        """
                        Flood list table
                        
                        .. attribute:: flood
                        
                        	Flooding information for a specific interface
                        	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable, self).__init__()

                            self.yang_name = "flood-list-table"
                            self.yang_parent_name = "vrf"

                            self.flood = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable, self).__setattr__(name, value)


                        class Flood(Entity):
                            """
                            Flooding information for a specific interface
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: area_flood
                            
                            	Area scope floodlist
                            	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AreaFlood>`
                            
                            .. attribute:: as_flood
                            
                            	AS scope floodlist
                            	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AsFlood>`
                            
                            .. attribute:: flood_interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: flood_lsa_count
                            
                            	Number of LSAs currently being flooded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flood_pacing_timer
                            
                            	Time until next LS update due (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood, self).__init__()

                                self.yang_name = "flood"
                                self.yang_parent_name = "flood-list-table"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.flood_interface_name = YLeaf(YType.str, "flood-interface-name")

                                self.flood_lsa_count = YLeaf(YType.uint32, "flood-lsa-count")

                                self.flood_pacing_timer = YLeaf(YType.uint32, "flood-pacing-timer")

                                self.area_flood = YList(self)
                                self.as_flood = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "flood_interface_name",
                                                "flood_lsa_count",
                                                "flood_pacing_timer") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood, self).__setattr__(name, value)


                            class AreaFlood(Entity):
                                """
                                Area scope floodlist
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_ls_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_checksum
                                
                                	Checksum of the LSA
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA Type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AreaFlood, self).__init__()

                                    self.yang_name = "area-flood"
                                    self.yang_parent_name = "flood"

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("header_advertising_router",
                                                    "header_ls_id",
                                                    "header_lsa_age",
                                                    "header_lsa_checksum",
                                                    "header_lsa_type",
                                                    "header_sequence_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AreaFlood, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AreaFlood, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.header_advertising_router.is_set or
                                        self.header_ls_id.is_set or
                                        self.header_lsa_age.is_set or
                                        self.header_lsa_checksum.is_set or
                                        self.header_lsa_type.is_set or
                                        self.header_sequence_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.header_advertising_router.yfilter != YFilter.not_set or
                                        self.header_ls_id.yfilter != YFilter.not_set or
                                        self.header_lsa_age.yfilter != YFilter.not_set or
                                        self.header_lsa_checksum.yfilter != YFilter.not_set or
                                        self.header_lsa_type.yfilter != YFilter.not_set or
                                        self.header_sequence_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "area-flood" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                    if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                    if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                    if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                    if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                    if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "header-advertising-router"):
                                        self.header_advertising_router = value
                                        self.header_advertising_router.value_namespace = name_space
                                        self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-ls-id"):
                                        self.header_ls_id = value
                                        self.header_ls_id.value_namespace = name_space
                                        self.header_ls_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-age"):
                                        self.header_lsa_age = value
                                        self.header_lsa_age.value_namespace = name_space
                                        self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-checksum"):
                                        self.header_lsa_checksum = value
                                        self.header_lsa_checksum.value_namespace = name_space
                                        self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-type"):
                                        self.header_lsa_type = value
                                        self.header_lsa_type.value_namespace = name_space
                                        self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-sequence-number"):
                                        self.header_sequence_number = value
                                        self.header_sequence_number.value_namespace = name_space
                                        self.header_sequence_number.value_namespace_prefix = name_space_prefix


                            class AsFlood(Entity):
                                """
                                AS scope floodlist
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_ls_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_checksum
                                
                                	Checksum of the LSA
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA Type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AsFlood, self).__init__()

                                    self.yang_name = "as-flood"
                                    self.yang_parent_name = "flood"

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("header_advertising_router",
                                                    "header_ls_id",
                                                    "header_lsa_age",
                                                    "header_lsa_checksum",
                                                    "header_lsa_type",
                                                    "header_sequence_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AsFlood, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AsFlood, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.header_advertising_router.is_set or
                                        self.header_ls_id.is_set or
                                        self.header_lsa_age.is_set or
                                        self.header_lsa_checksum.is_set or
                                        self.header_lsa_type.is_set or
                                        self.header_sequence_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.header_advertising_router.yfilter != YFilter.not_set or
                                        self.header_ls_id.yfilter != YFilter.not_set or
                                        self.header_lsa_age.yfilter != YFilter.not_set or
                                        self.header_lsa_checksum.yfilter != YFilter.not_set or
                                        self.header_lsa_type.yfilter != YFilter.not_set or
                                        self.header_sequence_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "as-flood" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                    if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                    if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                    if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                    if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                    if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "header-advertising-router"):
                                        self.header_advertising_router = value
                                        self.header_advertising_router.value_namespace = name_space
                                        self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-ls-id"):
                                        self.header_ls_id = value
                                        self.header_ls_id.value_namespace = name_space
                                        self.header_ls_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-age"):
                                        self.header_lsa_age = value
                                        self.header_lsa_age.value_namespace = name_space
                                        self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-checksum"):
                                        self.header_lsa_checksum = value
                                        self.header_lsa_checksum.value_namespace = name_space
                                        self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-type"):
                                        self.header_lsa_type = value
                                        self.header_lsa_type.value_namespace = name_space
                                        self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-sequence-number"):
                                        self.header_sequence_number = value
                                        self.header_sequence_number.value_namespace = name_space
                                        self.header_sequence_number.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.area_flood:
                                    if (c.has_data()):
                                        return True
                                for c in self.as_flood:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.interface_name.is_set or
                                    self.flood_interface_name.is_set or
                                    self.flood_lsa_count.is_set or
                                    self.flood_pacing_timer.is_set)

                            def has_operation(self):
                                for c in self.area_flood:
                                    if (c.has_operation()):
                                        return True
                                for c in self.as_flood:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.flood_interface_name.yfilter != YFilter.not_set or
                                    self.flood_lsa_count.yfilter != YFilter.not_set or
                                    self.flood_pacing_timer.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "flood" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.flood_interface_name.is_set or self.flood_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_interface_name.get_name_leafdata())
                                if (self.flood_lsa_count.is_set or self.flood_lsa_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_lsa_count.get_name_leafdata())
                                if (self.flood_pacing_timer.is_set or self.flood_pacing_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_pacing_timer.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "area-flood"):
                                    for c in self.area_flood:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AreaFlood()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.area_flood.append(c)
                                    return c

                                if (child_yang_name == "as-flood"):
                                    for c in self.as_flood:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AsFlood()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.as_flood.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "area-flood" or name == "as-flood" or name == "interface-name" or name == "flood-interface-name" or name == "flood-lsa-count" or name == "flood-pacing-timer"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-interface-name"):
                                    self.flood_interface_name = value
                                    self.flood_interface_name.value_namespace = name_space
                                    self.flood_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-lsa-count"):
                                    self.flood_lsa_count = value
                                    self.flood_lsa_count.value_namespace = name_space
                                    self.flood_lsa_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-pacing-timer"):
                                    self.flood_pacing_timer = value
                                    self.flood_pacing_timer.value_namespace = name_space
                                    self.flood_pacing_timer.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.flood:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.flood:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "flood-list-table" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "flood"):
                                for c in self.flood:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.flood.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "flood"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class MplsTe(Entity):
                        """
                        Container for MPLS TE
                        
                        .. attribute:: mpls_te_fragments
                        
                        	MPLS TE Fragment information table
                        	**type**\:   :py:class:`MplsTeFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments>`
                        
                        .. attribute:: mpls_te_links
                        
                        	MPLS TE link information table
                        	**type**\:   :py:class:`MplsTeLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe, self).__init__()

                            self.yang_name = "mpls-te"
                            self.yang_parent_name = "vrf"

                            self.mpls_te_fragments = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments()
                            self.mpls_te_fragments.parent = self
                            self._children_name_map["mpls_te_fragments"] = "mpls-te-fragments"
                            self._children_yang_names.add("mpls-te-fragments")

                            self.mpls_te_links = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks()
                            self.mpls_te_links.parent = self
                            self._children_name_map["mpls_te_links"] = "mpls-te-links"
                            self._children_yang_names.add("mpls-te-links")


                        class MplsTeLinks(Entity):
                            """
                            MPLS TE link information table
                            
                            .. attribute:: mpls_te_link
                            
                            	MPLS TE link information
                            	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks, self).__init__()

                                self.yang_name = "mpls-te-links"
                                self.yang_parent_name = "mpls-te"

                                self.mpls_te_link = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks, self).__setattr__(name, value)


                            class MplsTeLink(Entity):
                                """
                                MPLS TE link information
                                
                                .. attribute:: area_id  <key>
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mpls_te_area_id
                                
                                	Area ID string in decimal or dotted decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: mpls_te_area_instance
                                
                                	Area information instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_te_enabled
                                
                                	If true, MPLS\-TE enabled in area
                                	**type**\:  bool
                                
                                .. attribute:: mpls_te_fragment
                                
                                	MPLS TE fragments in the area
                                	**type**\: list of    :py:class:`MplsTeFragment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment>`
                                
                                .. attribute:: mpls_te_initialized
                                
                                	If true, MPLS\-TE initialized in the area
                                	**type**\:  bool
                                
                                .. attribute:: mpls_te_link
                                
                                	MPLS\-TE links in the area
                                	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink>`
                                
                                .. attribute:: mpls_te_next_fragment_id
                                
                                	Next MPLS\-TE fragment ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_te_router_address
                                
                                	MPLS\-TE router address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mpls_te_router_id
                                
                                	OSPF MPLS\-TE router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: spacious_fragment
                                
                                	If true, fragment has space for next link
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink, self).__init__()

                                    self.yang_name = "mpls-te-link"
                                    self.yang_parent_name = "mpls-te-links"

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.mpls_te_area_id = YLeaf(YType.str, "mpls-te-area-id")

                                    self.mpls_te_area_instance = YLeaf(YType.uint32, "mpls-te-area-instance")

                                    self.mpls_te_enabled = YLeaf(YType.boolean, "mpls-te-enabled")

                                    self.mpls_te_initialized = YLeaf(YType.boolean, "mpls-te-initialized")

                                    self.mpls_te_next_fragment_id = YLeaf(YType.uint32, "mpls-te-next-fragment-id")

                                    self.mpls_te_router_address = YLeaf(YType.str, "mpls-te-router-address")

                                    self.mpls_te_router_id = YLeaf(YType.str, "mpls-te-router-id")

                                    self.spacious_fragment = YLeaf(YType.boolean, "spacious-fragment")

                                    self.mpls_te_fragment = YList(self)
                                    self.mpls_te_link = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_id",
                                                    "mpls_te_area_id",
                                                    "mpls_te_area_instance",
                                                    "mpls_te_enabled",
                                                    "mpls_te_initialized",
                                                    "mpls_te_next_fragment_id",
                                                    "mpls_te_router_address",
                                                    "mpls_te_router_id",
                                                    "spacious_fragment") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink, self).__setattr__(name, value)


                                class MplsTeLink(Entity):
                                    """
                                    MPLS\-TE links in the area
                                    
                                    .. attribute:: affinity
                                    
                                    	Affinity
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dste_allocation_model_id
                                    
                                    	DS\-TE Allocation Model ID
                                    	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                    
                                    .. attribute:: dste_in_use
                                    
                                    	A DS\-TE Allocation Model in use
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_admin_group_list
                                    
                                    	Extended Admin Group
                                    	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList>`
                                    
                                    .. attribute:: fragment_id
                                    
                                    	Fragment ID for this link
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: global_unreserve_bw_per_priority
                                    
                                    	Global pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                    
                                    .. attribute:: igp_metric
                                    
                                    	Link IGP metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: input_interface_id
                                    
                                    	Input interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_address
                                    
                                    	The local interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: link_protocol_priority_capability
                                    
                                    	Link protocol and protocol priority capability
                                    	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability>`
                                    
                                    .. attribute:: link_sw_capability
                                    
                                    	Link switching capability
                                    	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability>`
                                    
                                    .. attribute:: maximum_link_bw
                                    
                                    	Maximum link bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_reservable_bw
                                    
                                    	Maximum link global pool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_sub_reservable_bw
                                    
                                    	Maximum link subpool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: mpls_link_instance
                                    
                                    	Link instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mpls_link_type
                                    
                                    	Type of link
                                    	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                    
                                    .. attribute:: mplste_link_opt_tlv
                                    
                                    	List of Optional TLVs
                                    	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv>`
                                    
                                    .. attribute:: neighbor_ip_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_system_id
                                    
                                    	Neighbor system ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: new_link
                                    
                                    	If true, Link is new
                                    	**type**\:  bool
                                    
                                    .. attribute:: number_of_optional_tl_vs
                                    
                                    	Number of Optional TLVs
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: output_interface_id
                                    
                                    	Output interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: priority_count
                                    
                                    	Number of priorities
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_pool_unreserve_bw_per_priority
                                    
                                    	Sub pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                    
                                    .. attribute:: te_metric
                                    
                                    	Link TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink, self).__init__()

                                        self.yang_name = "mpls-te-link"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.affinity = YLeaf(YType.uint32, "affinity")

                                        self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                        self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                        self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                        self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                        self.link_address = YLeaf(YType.str, "link-address")

                                        self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                        self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                        self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                        self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                        self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                        self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                        self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                        self.new_link = YLeaf(YType.boolean, "new-link")

                                        self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                        self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                        self.priority_count = YLeaf(YType.int32, "priority-count")

                                        self.te_metric = YLeaf(YType.uint32, "te-metric")

                                        self.extended_admin_group_list = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList()
                                        self.extended_admin_group_list.parent = self
                                        self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                        self._children_yang_names.add("extended-admin-group-list")

                                        self.global_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority()
                                        self.global_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                        self._children_yang_names.add("global-unreserve-bw-per-priority")

                                        self.link_protocol_priority_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability()
                                        self.link_protocol_priority_capability.parent = self
                                        self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                        self._children_yang_names.add("link-protocol-priority-capability")

                                        self.link_sw_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability()
                                        self.link_sw_capability.parent = self
                                        self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                        self._children_yang_names.add("link-sw-capability")

                                        self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                        self.sub_pool_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                        self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                        self.mplste_link_opt_tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("affinity",
                                                        "dste_allocation_model_id",
                                                        "dste_in_use",
                                                        "fragment_id",
                                                        "igp_metric",
                                                        "input_interface_id",
                                                        "link_address",
                                                        "maximum_link_bw",
                                                        "maximum_link_reservable_bw",
                                                        "maximum_link_sub_reservable_bw",
                                                        "mpls_link_instance",
                                                        "mpls_link_type",
                                                        "neighbor_ip_address",
                                                        "neighbor_system_id",
                                                        "new_link",
                                                        "number_of_optional_tl_vs",
                                                        "output_interface_id",
                                                        "priority_count",
                                                        "te_metric") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink, self).__setattr__(name, value)


                                    class GlobalUnreserveBwPerPriority(Entity):
                                        """
                                        Global pool unreserved bandwidth for each
                                        priority (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "global-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.bw_per_priority = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "global-unreserve-bw-per-priority"

                                                self.entry = YLeaf(YType.uint64, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "global-unreserve-bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "bw-per-priority"):
                                                for c in self.bw_per_priority:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.bw_per_priority.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bw-per-priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SubPoolUnreserveBwPerPriority(Entity):
                                        """
                                        Sub pool unreserved bandwidth for each priority
                                        (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.bw_per_priority = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"

                                                self.entry = YLeaf(YType.uint64, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sub-pool-unreserve-bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "bw-per-priority"):
                                                for c in self.bw_per_priority:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.bw_per_priority.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bw-per-priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class LinkProtocolPriorityCapability(Entity):
                                        """
                                        Link protocol and protocol priority capability
                                        
                                        .. attribute:: link_protocol_capability
                                        
                                        	Link protocol capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_protocol_priority
                                        
                                        	Link protocol priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                            self.yang_name = "link-protocol-priority-capability"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                            self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("link_protocol_capability",
                                                            "link_protocol_priority") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.link_protocol_capability.is_set or
                                                self.link_protocol_priority.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.link_protocol_capability.yfilter != YFilter.not_set or
                                                self.link_protocol_priority.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "link-protocol-priority-capability" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.link_protocol_capability.is_set or self.link_protocol_capability.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_protocol_capability.get_name_leafdata())
                                            if (self.link_protocol_priority.is_set or self.link_protocol_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_protocol_priority.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "link-protocol-capability" or name == "link-protocol-priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "link-protocol-capability"):
                                                self.link_protocol_capability = value
                                                self.link_protocol_capability.value_namespace = name_space
                                                self.link_protocol_capability.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-protocol-priority"):
                                                self.link_protocol_priority = value
                                                self.link_protocol_priority.value_namespace = name_space
                                                self.link_protocol_priority.value_namespace_prefix = name_space_prefix


                                    class LinkSwCapability(Entity):
                                        """
                                        Link switching capability
                                        
                                        .. attribute:: link_encoding
                                        
                                        	Link Encoding
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_mtu
                                        
                                        	Link MTU size (bytes)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: link_switching_capability
                                        
                                        	Link Switching Capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: maximum_lsp_bw_per_priority
                                        
                                        	Maximum LSP bandwidth for each priority  (bytes/s)
                                        	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                        
                                        .. attribute:: minimum_lsp_bw
                                        
                                        	Minimum LSP bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability, self).__init__()

                                            self.yang_name = "link-sw-capability"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                            self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                            self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                            self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                            self.maximum_lsp_bw_per_priority = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("link_encoding",
                                                            "link_mtu",
                                                            "link_switching_capability",
                                                            "minimum_lsp_bw") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)


                                        class MaximumLspBwPerPriority(Entity):
                                            """
                                            Maximum LSP bandwidth for each priority
                                            
                                            (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                                self.yang_name = "maximum-lsp-bw-per-priority"
                                                self.yang_parent_name = "link-sw-capability"

                                                self.entry = YLeaf(YType.uint64, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "maximum-lsp-bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.maximum_lsp_bw_per_priority:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.link_encoding.is_set or
                                                self.link_mtu.is_set or
                                                self.link_switching_capability.is_set or
                                                self.minimum_lsp_bw.is_set)

                                        def has_operation(self):
                                            for c in self.maximum_lsp_bw_per_priority:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.link_encoding.yfilter != YFilter.not_set or
                                                self.link_mtu.yfilter != YFilter.not_set or
                                                self.link_switching_capability.yfilter != YFilter.not_set or
                                                self.minimum_lsp_bw.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "link-sw-capability" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.link_encoding.is_set or self.link_encoding.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_encoding.get_name_leafdata())
                                            if (self.link_mtu.is_set or self.link_mtu.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_mtu.get_name_leafdata())
                                            if (self.link_switching_capability.is_set or self.link_switching_capability.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_switching_capability.get_name_leafdata())
                                            if (self.minimum_lsp_bw.is_set or self.minimum_lsp_bw.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_lsp_bw.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "maximum-lsp-bw-per-priority"):
                                                for c in self.maximum_lsp_bw_per_priority:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.maximum_lsp_bw_per_priority.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "maximum-lsp-bw-per-priority" or name == "link-encoding" or name == "link-mtu" or name == "link-switching-capability" or name == "minimum-lsp-bw"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "link-encoding"):
                                                self.link_encoding = value
                                                self.link_encoding.value_namespace = name_space
                                                self.link_encoding.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-mtu"):
                                                self.link_mtu = value
                                                self.link_mtu.value_namespace = name_space
                                                self.link_mtu.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-switching-capability"):
                                                self.link_switching_capability = value
                                                self.link_switching_capability.value_namespace = name_space
                                                self.link_switching_capability.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-lsp-bw"):
                                                self.minimum_lsp_bw = value
                                                self.minimum_lsp_bw.value_namespace = name_space
                                                self.minimum_lsp_bw.value_namespace_prefix = name_space_prefix


                                    class ExtendedAdminGroupList(Entity):
                                        """
                                        Extended Admin Group
                                        
                                        .. attribute:: ext_admin_data
                                        
                                        	Value of Extended Admin Group
                                        	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                        
                                        .. attribute:: extended_admin_size
                                        
                                        	Size of the extended admin group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                            self.yang_name = "extended-admin-group-list"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                            self.ext_admin_data = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("extended_admin_size") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)


                                        class ExtAdminData(Entity):
                                            """
                                            Value of Extended Admin Group
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                                self.yang_name = "ext-admin-data"
                                                self.yang_parent_name = "extended-admin-group-list"

                                                self.entry = YLeaf(YType.uint32, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ext-admin-data" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.ext_admin_data:
                                                if (c.has_data()):
                                                    return True
                                            return self.extended_admin_size.is_set

                                        def has_operation(self):
                                            for c in self.ext_admin_data:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.extended_admin_size.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "extended-admin-group-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.extended_admin_size.is_set or self.extended_admin_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.extended_admin_size.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "ext-admin-data"):
                                                for c in self.ext_admin_data:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ext_admin_data.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ext-admin-data" or name == "extended-admin-size"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "extended-admin-size"):
                                                self.extended_admin_size = value
                                                self.extended_admin_size.value_namespace = name_space
                                                self.extended_admin_size.value_namespace_prefix = name_space_prefix


                                    class MplsteLinkOptTlv(Entity):
                                        """
                                        List of Optional TLVs
                                        
                                        .. attribute:: mplste_link_opt_tlv_len
                                        
                                        	Length of Opt TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mplste_link_opt_tlv_type
                                        
                                        	Type of Opt TLV
                                        	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                        
                                        .. attribute:: mplste_link_opt_tlv_value
                                        
                                        	Value of Opt TLV
                                        	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                            self.yang_name = "mplste-link-opt-tlv"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                            self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                            self.mplste_link_opt_tlv_value = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("mplste_link_opt_tlv_len",
                                                            "mplste_link_opt_tlv_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)


                                        class MplsteLinkOptTlvValue(Entity):
                                            """
                                            Value of Opt TLV
                                            
                                            .. attribute:: bctlv_value
                                            
                                            	Value of Bandwidth Constraints TLV
                                            	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                            
                                            .. attribute:: ixcdtlv_value
                                            
                                            	Value of IXCD TLV
                                            	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                            
                                            .. attribute:: opaque_tlv_type
                                            
                                            	OpaqueTLVType
                                            	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                            
                                            .. attribute:: srlgtlv_value
                                            
                                            	Value of SRLG TLV
                                            	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                            
                                            .. attribute:: unidtlv_value
                                            
                                            	Value of Uni Delay TLV
                                            	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                                self.yang_name = "mplste-link-opt-tlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv"

                                                self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                                self.bctlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                self.bctlv_value.parent = self
                                                self._children_name_map["bctlv_value"] = "bctlv-value"
                                                self._children_yang_names.add("bctlv-value")

                                                self.ixcdtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                self.ixcdtlv_value.parent = self
                                                self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                self._children_yang_names.add("ixcdtlv-value")

                                                self.srlgtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                self.srlgtlv_value.parent = self
                                                self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                self._children_yang_names.add("srlgtlv-value")

                                                self.unidtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                self.unidtlv_value.parent = self
                                                self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                self._children_yang_names.add("unidtlv-value")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("opaque_tlv_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)


                                            class BctlvValue(Entity):
                                                """
                                                Value of Bandwidth Constraints TLV
                                                
                                                .. attribute:: model_id
                                                
                                                	Allocation Model ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mplste_link_bc_bandwidth
                                                
                                                	Value of BC TLV
                                                	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                                
                                                .. attribute:: num_b_cs
                                                
                                                	Number of BC TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                    self.yang_name = "bctlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.model_id = YLeaf(YType.uint8, "model-id")

                                                    self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                    self.mplste_link_bc_bandwidth = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("model_id",
                                                                    "num_b_cs") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)


                                                class MplsteLinkBcBandwidth(Entity):
                                                    """
                                                    Value of BC TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                        self.yang_name = "mplste-link-bc-bandwidth"
                                                        self.yang_parent_name = "bctlv-value"

                                                        self.entry = YLeaf(YType.uint64, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "mplste-link-bc-bandwidth" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.mplste_link_bc_bandwidth:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.model_id.is_set or
                                                        self.num_b_cs.is_set)

                                                def has_operation(self):
                                                    for c in self.mplste_link_bc_bandwidth:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.model_id.yfilter != YFilter.not_set or
                                                        self.num_b_cs.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bctlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.model_id.is_set or self.model_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.model_id.get_name_leafdata())
                                                    if (self.num_b_cs.is_set or self.num_b_cs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_b_cs.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "mplste-link-bc-bandwidth"):
                                                        for c in self.mplste_link_bc_bandwidth:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.mplste_link_bc_bandwidth.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "mplste-link-bc-bandwidth" or name == "model-id" or name == "num-b-cs"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "model-id"):
                                                        self.model_id = value
                                                        self.model_id.value_namespace = name_space
                                                        self.model_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-b-cs"):
                                                        self.num_b_cs = value
                                                        self.num_b_cs.value_namespace = name_space
                                                        self.num_b_cs.value_namespace_prefix = name_space_prefix


                                            class SrlgtlvValue(Entity):
                                                """
                                                Value of SRLG TLV
                                                
                                                .. attribute:: mplste_link_srlg_data
                                                
                                                	Value of SRLG TLV
                                                	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                                
                                                .. attribute:: num_srl_gs
                                                
                                                	Number of SRLG TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: srlg_len
                                                
                                                	Length of SRLG TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                    self.yang_name = "srlgtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                    self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                    self.mplste_link_srlg_data = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("num_srl_gs",
                                                                    "srlg_len") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)


                                                class MplsteLinkSrlgData(Entity):
                                                    """
                                                    Value of SRLG TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                        self.yang_name = "mplste-link-srlg-data"
                                                        self.yang_parent_name = "srlgtlv-value"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "mplste-link-srlg-data" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.mplste_link_srlg_data:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.num_srl_gs.is_set or
                                                        self.srlg_len.is_set)

                                                def has_operation(self):
                                                    for c in self.mplste_link_srlg_data:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.num_srl_gs.yfilter != YFilter.not_set or
                                                        self.srlg_len.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "srlgtlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.num_srl_gs.is_set or self.num_srl_gs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_srl_gs.get_name_leafdata())
                                                    if (self.srlg_len.is_set or self.srlg_len.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.srlg_len.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "mplste-link-srlg-data"):
                                                        for c in self.mplste_link_srlg_data:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.mplste_link_srlg_data.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "mplste-link-srlg-data" or name == "num-srl-gs" or name == "srlg-len"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "num-srl-gs"):
                                                        self.num_srl_gs = value
                                                        self.num_srl_gs.value_namespace = name_space
                                                        self.num_srl_gs.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "srlg-len"):
                                                        self.srlg_len = value
                                                        self.srlg_len.value_namespace = name_space
                                                        self.srlg_len.value_namespace_prefix = name_space_prefix


                                            class IxcdtlvValue(Entity):
                                                """
                                                Value of IXCD TLV
                                                
                                                .. attribute:: fixed_scsi_count
                                                
                                                	Fixed SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flex_scsi_count
                                                
                                                	Flexible SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ixcd_switching_cap_type
                                                
                                                	Switching Cap type
                                                	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                                
                                                .. attribute:: max_lspbw
                                                
                                                	Max LSP bandwidth array
                                                	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                                
                                                .. attribute:: rile_len_code
                                                
                                                	Rile LenCode
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: switching_cap
                                                
                                                	SCap
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                    self.yang_name = "ixcdtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                    self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                    self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                    self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                    self.ixcd_switching_cap_type = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                    self.ixcd_switching_cap_type.parent = self
                                                    self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                    self._children_yang_names.add("ixcd-switching-cap-type")

                                                    self.max_lspbw = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("fixed_scsi_count",
                                                                    "flex_scsi_count",
                                                                    "rile_len_code",
                                                                    "switching_cap") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)


                                                class IxcdSwitchingCapType(Entity):
                                                    """
                                                    Switching Cap type
                                                    
                                                    .. attribute:: ixcdbw_sub_tlv
                                                    
                                                    	Sub TLVs
                                                    	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                    
                                                    .. attribute:: ixcdpsc_info
                                                    
                                                    	IXCD PSC information
                                                    	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                    
                                                    .. attribute:: switching_cap_type
                                                    
                                                    	SwitchingCapType
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                        self.yang_name = "ixcd-switching-cap-type"
                                                        self.yang_parent_name = "ixcdtlv-value"

                                                        self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                        self.ixcdbw_sub_tlv = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                        self.ixcdbw_sub_tlv.parent = self
                                                        self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                        self._children_yang_names.add("ixcdbw-sub-tlv")

                                                        self.ixcdpsc_info = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                        self.ixcdpsc_info.parent = self
                                                        self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                        self._children_yang_names.add("ixcdpsc-info")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("switching_cap_type") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)


                                                    class IxcdpscInfo(Entity):
                                                        """
                                                        IXCD PSC information
                                                        
                                                        .. attribute:: min_lsp_bandwidth
                                                        
                                                        	Min LSP bandwidth
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: psc_interface_mtu
                                                        
                                                        	 Interface MTU
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                            self.yang_name = "ixcdpsc-info"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"

                                                            self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                            self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("min_lsp_bandwidth",
                                                                            "psc_interface_mtu") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.min_lsp_bandwidth.is_set or
                                                                self.psc_interface_mtu.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.min_lsp_bandwidth.yfilter != YFilter.not_set or
                                                                self.psc_interface_mtu.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ixcdpsc-info" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.min_lsp_bandwidth.is_set or self.min_lsp_bandwidth.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.min_lsp_bandwidth.get_name_leafdata())
                                                            if (self.psc_interface_mtu.is_set or self.psc_interface_mtu.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.psc_interface_mtu.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "min-lsp-bandwidth" or name == "psc-interface-mtu"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "min-lsp-bandwidth"):
                                                                self.min_lsp_bandwidth = value
                                                                self.min_lsp_bandwidth.value_namespace = name_space
                                                                self.min_lsp_bandwidth.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "psc-interface-mtu"):
                                                                self.psc_interface_mtu = value
                                                                self.psc_interface_mtu.value_namespace = name_space
                                                                self.psc_interface_mtu.value_namespace_prefix = name_space_prefix


                                                    class IxcdbwSubTlv(Entity):
                                                        """
                                                        Sub TLVs
                                                        
                                                        .. attribute:: arr_bw_sub_tlv
                                                        
                                                        	Array of sub tlvs
                                                        	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                            self.yang_name = "ixcdbw-sub-tlv"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"

                                                            self.arr_bw_sub_tlv = YList(self)

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in () and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)


                                                        class ArrBwSubTlv(Entity):
                                                            """
                                                            Array of sub tlvs
                                                            
                                                            .. attribute:: bw_sub_tlv_length
                                                            
                                                            	Length of BW Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_type
                                                            
                                                            	Type of Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_value
                                                            
                                                            	Value of BW Sub TLV
                                                            	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                                self.yang_name = "arr-bw-sub-tlv"
                                                                self.yang_parent_name = "ixcdbw-sub-tlv"

                                                                self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                                self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                                self.bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                self.bw_sub_tlv_value.parent = self
                                                                self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                self._children_yang_names.add("bw-sub-tlv-value")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("bw_sub_tlv_length",
                                                                                "bw_sub_tlv_type") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)


                                                            class BwSubTlvValue(Entity):
                                                                """
                                                                Value of BW Sub TLV
                                                                
                                                                .. attribute:: fixed_bw_sub_tlv_value
                                                                
                                                                	Value of Fixed Sub TLV
                                                                	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                                
                                                                .. attribute:: flex_bw_sub_tlv_value
                                                                
                                                                	Value of Flex Sub TLV
                                                                	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                                
                                                                .. attribute:: ixcdbw_sub_tlv_type
                                                                
                                                                	IXCDBWSubTLVType
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-01-02'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                    self.yang_name = "bw-sub-tlv-value"
                                                                    self.yang_parent_name = "arr-bw-sub-tlv"

                                                                    self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                    self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                    self.fixed_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                    self.flex_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                    self.flex_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("flex-bw-sub-tlv-value")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("ixcdbw_sub_tlv_type") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)


                                                                class FixedBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Fixed Sub TLV
                                                                    
                                                                    .. attribute:: fixed_sub_tlv_value
                                                                    
                                                                    	Value of Fixed Sub TLV
                                                                    	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                    
                                                                    .. attribute:: unres_oduj_prio
                                                                    
                                                                    	Array of Unres Oduj Prio
                                                                    	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "fixed-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"

                                                                        self.fixed_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                        self.fixed_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                        self._children_yang_names.add("fixed-sub-tlv-value")

                                                                        self.unres_oduj_prio = YList(self)

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in () and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)


                                                                    class FixedSubTlvValue(Entity):
                                                                        """
                                                                        Value of Fixed Sub TLV
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                            self.yang_name = "fixed-sub-tlv-value"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("num_stages",
                                                                                            "priority_bit0",
                                                                                            "priority_bit1",
                                                                                            "priority_bit2",
                                                                                            "priority_bit3",
                                                                                            "priority_bit4",
                                                                                            "priority_bit5",
                                                                                            "priority_bit6",
                                                                                            "priority_bit7",
                                                                                            "res",
                                                                                            "sbit",
                                                                                            "signal_type",
                                                                                            "stage",
                                                                                            "tbit",
                                                                                            "tsg") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return (
                                                                                self.num_stages.is_set or
                                                                                self.priority_bit0.is_set or
                                                                                self.priority_bit1.is_set or
                                                                                self.priority_bit2.is_set or
                                                                                self.priority_bit3.is_set or
                                                                                self.priority_bit4.is_set or
                                                                                self.priority_bit5.is_set or
                                                                                self.priority_bit6.is_set or
                                                                                self.priority_bit7.is_set or
                                                                                self.res.is_set or
                                                                                self.sbit.is_set or
                                                                                self.signal_type.is_set or
                                                                                self.stage.is_set or
                                                                                self.tbit.is_set or
                                                                                self.tsg.is_set)

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.num_stages.yfilter != YFilter.not_set or
                                                                                self.priority_bit0.yfilter != YFilter.not_set or
                                                                                self.priority_bit1.yfilter != YFilter.not_set or
                                                                                self.priority_bit2.yfilter != YFilter.not_set or
                                                                                self.priority_bit3.yfilter != YFilter.not_set or
                                                                                self.priority_bit4.yfilter != YFilter.not_set or
                                                                                self.priority_bit5.yfilter != YFilter.not_set or
                                                                                self.priority_bit6.yfilter != YFilter.not_set or
                                                                                self.priority_bit7.yfilter != YFilter.not_set or
                                                                                self.res.yfilter != YFilter.not_set or
                                                                                self.sbit.yfilter != YFilter.not_set or
                                                                                self.signal_type.yfilter != YFilter.not_set or
                                                                                self.stage.yfilter != YFilter.not_set or
                                                                                self.tbit.yfilter != YFilter.not_set or
                                                                                self.tsg.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "fixed-sub-tlv-value" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                            if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                            if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                            if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                            if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                            if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                            if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                            if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                            if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                            if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.res.get_name_leafdata())
                                                                            if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                            if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                            if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.stage.get_name_leafdata())
                                                                            if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                            if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "num-stages"):
                                                                                self.num_stages = value
                                                                                self.num_stages.value_namespace = name_space
                                                                                self.num_stages.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit0"):
                                                                                self.priority_bit0 = value
                                                                                self.priority_bit0.value_namespace = name_space
                                                                                self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit1"):
                                                                                self.priority_bit1 = value
                                                                                self.priority_bit1.value_namespace = name_space
                                                                                self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit2"):
                                                                                self.priority_bit2 = value
                                                                                self.priority_bit2.value_namespace = name_space
                                                                                self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit3"):
                                                                                self.priority_bit3 = value
                                                                                self.priority_bit3.value_namespace = name_space
                                                                                self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit4"):
                                                                                self.priority_bit4 = value
                                                                                self.priority_bit4.value_namespace = name_space
                                                                                self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit5"):
                                                                                self.priority_bit5 = value
                                                                                self.priority_bit5.value_namespace = name_space
                                                                                self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit6"):
                                                                                self.priority_bit6 = value
                                                                                self.priority_bit6.value_namespace = name_space
                                                                                self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit7"):
                                                                                self.priority_bit7 = value
                                                                                self.priority_bit7.value_namespace = name_space
                                                                                self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "res"):
                                                                                self.res = value
                                                                                self.res.value_namespace = name_space
                                                                                self.res.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "sbit"):
                                                                                self.sbit = value
                                                                                self.sbit.value_namespace = name_space
                                                                                self.sbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "signal-type"):
                                                                                self.signal_type = value
                                                                                self.signal_type.value_namespace = name_space
                                                                                self.signal_type.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "stage"):
                                                                                self.stage = value
                                                                                self.stage.value_namespace = name_space
                                                                                self.stage.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tbit"):
                                                                                self.tbit = value
                                                                                self.tbit.value_namespace = name_space
                                                                                self.tbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tsg"):
                                                                                self.tsg = value
                                                                                self.tsg.value_namespace = name_space
                                                                                self.tsg.value_namespace_prefix = name_space_prefix


                                                                    class UnresOdujPrio(Entity):
                                                                        """
                                                                        Array of Unres Oduj Prio
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                            self.yang_name = "unres-oduj-prio"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                            self.entry = YLeaf(YType.uint32, "entry")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("entry") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return self.entry.is_set

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.entry.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "unres-oduj-prio" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "entry"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "entry"):
                                                                                self.entry = value
                                                                                self.entry.value_namespace = name_space
                                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                                    def has_data(self):
                                                                        for c in self.unres_oduj_prio:
                                                                            if (c.has_data()):
                                                                                return True
                                                                        return (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_data())

                                                                    def has_operation(self):
                                                                        for c in self.unres_oduj_prio:
                                                                            if (c.has_operation()):
                                                                                return True
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_operation()))

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "fixed-bw-sub-tlv-value" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        if (child_yang_name == "fixed-sub-tlv-value"):
                                                                            if (self.fixed_sub_tlv_value is None):
                                                                                self.fixed_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                                self.fixed_sub_tlv_value.parent = self
                                                                                self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                            return self.fixed_sub_tlv_value

                                                                        if (child_yang_name == "unres-oduj-prio"):
                                                                            for c in self.unres_oduj_prio:
                                                                                segment = c.get_segment_path()
                                                                                if (segment_path == segment):
                                                                                    return c
                                                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio()
                                                                            c.parent = self
                                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                                            self._local_refs[local_reference_key] = c
                                                                            self.unres_oduj_prio.append(c)
                                                                            return c

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "fixed-sub-tlv-value" or name == "unres-oduj-prio"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        pass


                                                                class FlexBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Flex Sub TLV
                                                                    
                                                                    .. attribute:: flex_sub_tlv_value_common
                                                                    
                                                                    	Flex Sub TLV Value
                                                                    	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                    
                                                                    .. attribute:: max_lspbw
                                                                    
                                                                    	Max LSP BW Array
                                                                    	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                    
                                                                    .. attribute:: unres_lspbw
                                                                    
                                                                    	Array of Unres LSP BW
                                                                    	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "flex-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"

                                                                        self.flex_sub_tlv_value_common = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                        self.flex_sub_tlv_value_common.parent = self
                                                                        self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                        self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                        self.max_lspbw = YList(self)
                                                                        self.unres_lspbw = YList(self)

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in () and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)


                                                                    class FlexSubTlvValueCommon(Entity):
                                                                        """
                                                                        Flex Sub TLV Value
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                            self.yang_name = "flex-sub-tlv-value-common"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("num_stages",
                                                                                            "priority_bit0",
                                                                                            "priority_bit1",
                                                                                            "priority_bit2",
                                                                                            "priority_bit3",
                                                                                            "priority_bit4",
                                                                                            "priority_bit5",
                                                                                            "priority_bit6",
                                                                                            "priority_bit7",
                                                                                            "res",
                                                                                            "sbit",
                                                                                            "signal_type",
                                                                                            "stage",
                                                                                            "tbit",
                                                                                            "tsg") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return (
                                                                                self.num_stages.is_set or
                                                                                self.priority_bit0.is_set or
                                                                                self.priority_bit1.is_set or
                                                                                self.priority_bit2.is_set or
                                                                                self.priority_bit3.is_set or
                                                                                self.priority_bit4.is_set or
                                                                                self.priority_bit5.is_set or
                                                                                self.priority_bit6.is_set or
                                                                                self.priority_bit7.is_set or
                                                                                self.res.is_set or
                                                                                self.sbit.is_set or
                                                                                self.signal_type.is_set or
                                                                                self.stage.is_set or
                                                                                self.tbit.is_set or
                                                                                self.tsg.is_set)

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.num_stages.yfilter != YFilter.not_set or
                                                                                self.priority_bit0.yfilter != YFilter.not_set or
                                                                                self.priority_bit1.yfilter != YFilter.not_set or
                                                                                self.priority_bit2.yfilter != YFilter.not_set or
                                                                                self.priority_bit3.yfilter != YFilter.not_set or
                                                                                self.priority_bit4.yfilter != YFilter.not_set or
                                                                                self.priority_bit5.yfilter != YFilter.not_set or
                                                                                self.priority_bit6.yfilter != YFilter.not_set or
                                                                                self.priority_bit7.yfilter != YFilter.not_set or
                                                                                self.res.yfilter != YFilter.not_set or
                                                                                self.sbit.yfilter != YFilter.not_set or
                                                                                self.signal_type.yfilter != YFilter.not_set or
                                                                                self.stage.yfilter != YFilter.not_set or
                                                                                self.tbit.yfilter != YFilter.not_set or
                                                                                self.tsg.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "flex-sub-tlv-value-common" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                            if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                            if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                            if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                            if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                            if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                            if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                            if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                            if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                            if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.res.get_name_leafdata())
                                                                            if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                            if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                            if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.stage.get_name_leafdata())
                                                                            if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                            if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "num-stages"):
                                                                                self.num_stages = value
                                                                                self.num_stages.value_namespace = name_space
                                                                                self.num_stages.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit0"):
                                                                                self.priority_bit0 = value
                                                                                self.priority_bit0.value_namespace = name_space
                                                                                self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit1"):
                                                                                self.priority_bit1 = value
                                                                                self.priority_bit1.value_namespace = name_space
                                                                                self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit2"):
                                                                                self.priority_bit2 = value
                                                                                self.priority_bit2.value_namespace = name_space
                                                                                self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit3"):
                                                                                self.priority_bit3 = value
                                                                                self.priority_bit3.value_namespace = name_space
                                                                                self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit4"):
                                                                                self.priority_bit4 = value
                                                                                self.priority_bit4.value_namespace = name_space
                                                                                self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit5"):
                                                                                self.priority_bit5 = value
                                                                                self.priority_bit5.value_namespace = name_space
                                                                                self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit6"):
                                                                                self.priority_bit6 = value
                                                                                self.priority_bit6.value_namespace = name_space
                                                                                self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit7"):
                                                                                self.priority_bit7 = value
                                                                                self.priority_bit7.value_namespace = name_space
                                                                                self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "res"):
                                                                                self.res = value
                                                                                self.res.value_namespace = name_space
                                                                                self.res.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "sbit"):
                                                                                self.sbit = value
                                                                                self.sbit.value_namespace = name_space
                                                                                self.sbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "signal-type"):
                                                                                self.signal_type = value
                                                                                self.signal_type.value_namespace = name_space
                                                                                self.signal_type.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "stage"):
                                                                                self.stage = value
                                                                                self.stage.value_namespace = name_space
                                                                                self.stage.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tbit"):
                                                                                self.tbit = value
                                                                                self.tbit.value_namespace = name_space
                                                                                self.tbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tsg"):
                                                                                self.tsg = value
                                                                                self.tsg.value_namespace = name_space
                                                                                self.tsg.value_namespace_prefix = name_space_prefix


                                                                    class UnresLspbw(Entity):
                                                                        """
                                                                        Array of Unres LSP BW
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                            self.yang_name = "unres-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                            self.entry = YLeaf(YType.uint64, "entry")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("entry") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return self.entry.is_set

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.entry.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "unres-lspbw" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "entry"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "entry"):
                                                                                self.entry = value
                                                                                self.entry.value_namespace = name_space
                                                                                self.entry.value_namespace_prefix = name_space_prefix


                                                                    class MaxLspbw(Entity):
                                                                        """
                                                                        Max LSP BW Array
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                            self.yang_name = "max-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                            self.entry = YLeaf(YType.uint64, "entry")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("entry") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return self.entry.is_set

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.entry.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "max-lspbw" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "entry"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "entry"):
                                                                                self.entry = value
                                                                                self.entry.value_namespace = name_space
                                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                                    def has_data(self):
                                                                        for c in self.max_lspbw:
                                                                            if (c.has_data()):
                                                                                return True
                                                                        for c in self.unres_lspbw:
                                                                            if (c.has_data()):
                                                                                return True
                                                                        return (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_data())

                                                                    def has_operation(self):
                                                                        for c in self.max_lspbw:
                                                                            if (c.has_operation()):
                                                                                return True
                                                                        for c in self.unres_lspbw:
                                                                            if (c.has_operation()):
                                                                                return True
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_operation()))

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "flex-bw-sub-tlv-value" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        if (child_yang_name == "flex-sub-tlv-value-common"):
                                                                            if (self.flex_sub_tlv_value_common is None):
                                                                                self.flex_sub_tlv_value_common = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                                self.flex_sub_tlv_value_common.parent = self
                                                                                self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                            return self.flex_sub_tlv_value_common

                                                                        if (child_yang_name == "max-lspbw"):
                                                                            for c in self.max_lspbw:
                                                                                segment = c.get_segment_path()
                                                                                if (segment_path == segment):
                                                                                    return c
                                                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw()
                                                                            c.parent = self
                                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                                            self._local_refs[local_reference_key] = c
                                                                            self.max_lspbw.append(c)
                                                                            return c

                                                                        if (child_yang_name == "unres-lspbw"):
                                                                            for c in self.unres_lspbw:
                                                                                segment = c.get_segment_path()
                                                                                if (segment_path == segment):
                                                                                    return c
                                                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw()
                                                                            c.parent = self
                                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                                            self._local_refs[local_reference_key] = c
                                                                            self.unres_lspbw.append(c)
                                                                            return c

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "flex-sub-tlv-value-common" or name == "max-lspbw" or name == "unres-lspbw"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        pass

                                                                def has_data(self):
                                                                    return (
                                                                        self.ixcdbw_sub_tlv_type.is_set or
                                                                        (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_data()) or
                                                                        (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_data()))

                                                                def has_operation(self):
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                        (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_operation()) or
                                                                        (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_operation()))

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "bw-sub-tlv-value" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.ixcdbw_sub_tlv_type.is_set or self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ixcdbw_sub_tlv_type.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    if (child_yang_name == "fixed-bw-sub-tlv-value"):
                                                                        if (self.fixed_bw_sub_tlv_value is None):
                                                                            self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                            self.fixed_bw_sub_tlv_value.parent = self
                                                                            self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                        return self.fixed_bw_sub_tlv_value

                                                                    if (child_yang_name == "flex-bw-sub-tlv-value"):
                                                                        if (self.flex_bw_sub_tlv_value is None):
                                                                            self.flex_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                            self.flex_bw_sub_tlv_value.parent = self
                                                                            self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                        return self.flex_bw_sub_tlv_value

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "fixed-bw-sub-tlv-value" or name == "flex-bw-sub-tlv-value" or name == "ixcdbw-sub-tlv-type"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "ixcdbw-sub-tlv-type"):
                                                                        self.ixcdbw_sub_tlv_type = value
                                                                        self.ixcdbw_sub_tlv_type.value_namespace = name_space
                                                                        self.ixcdbw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                return (
                                                                    self.bw_sub_tlv_length.is_set or
                                                                    self.bw_sub_tlv_type.is_set or
                                                                    (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_data()))

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.bw_sub_tlv_length.yfilter != YFilter.not_set or
                                                                    self.bw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                    (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_operation()))

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "arr-bw-sub-tlv" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.bw_sub_tlv_length.is_set or self.bw_sub_tlv_length.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.bw_sub_tlv_length.get_name_leafdata())
                                                                if (self.bw_sub_tlv_type.is_set or self.bw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.bw_sub_tlv_type.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "bw-sub-tlv-value"):
                                                                    if (self.bw_sub_tlv_value is None):
                                                                        self.bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                        self.bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                    return self.bw_sub_tlv_value

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "bw-sub-tlv-value" or name == "bw-sub-tlv-length" or name == "bw-sub-tlv-type"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "bw-sub-tlv-length"):
                                                                    self.bw_sub_tlv_length = value
                                                                    self.bw_sub_tlv_length.value_namespace = name_space
                                                                    self.bw_sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "bw-sub-tlv-type"):
                                                                    self.bw_sub_tlv_type = value
                                                                    self.bw_sub_tlv_type.value_namespace = name_space
                                                                    self.bw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                        def has_data(self):
                                                            for c in self.arr_bw_sub_tlv:
                                                                if (c.has_data()):
                                                                    return True
                                                            return False

                                                        def has_operation(self):
                                                            for c in self.arr_bw_sub_tlv:
                                                                if (c.has_operation()):
                                                                    return True
                                                            return self.yfilter != YFilter.not_set

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ixcdbw-sub-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "arr-bw-sub-tlv"):
                                                                for c in self.arr_bw_sub_tlv:
                                                                    segment = c.get_segment_path()
                                                                    if (segment_path == segment):
                                                                        return c
                                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv()
                                                                c.parent = self
                                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                                self._local_refs[local_reference_key] = c
                                                                self.arr_bw_sub_tlv.append(c)
                                                                return c

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "arr-bw-sub-tlv"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            pass

                                                    def has_data(self):
                                                        return (
                                                            self.switching_cap_type.is_set or
                                                            (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_data()) or
                                                            (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_data()))

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.switching_cap_type.yfilter != YFilter.not_set or
                                                            (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_operation()) or
                                                            (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_operation()))

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ixcd-switching-cap-type" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.switching_cap_type.is_set or self.switching_cap_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.switching_cap_type.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ixcdbw-sub-tlv"):
                                                            if (self.ixcdbw_sub_tlv is None):
                                                                self.ixcdbw_sub_tlv = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                                self.ixcdbw_sub_tlv.parent = self
                                                                self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                            return self.ixcdbw_sub_tlv

                                                        if (child_yang_name == "ixcdpsc-info"):
                                                            if (self.ixcdpsc_info is None):
                                                                self.ixcdpsc_info = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                                self.ixcdpsc_info.parent = self
                                                                self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                            return self.ixcdpsc_info

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ixcdbw-sub-tlv" or name == "ixcdpsc-info" or name == "switching-cap-type"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "switching-cap-type"):
                                                            self.switching_cap_type = value
                                                            self.switching_cap_type.value_namespace = name_space
                                                            self.switching_cap_type.value_namespace_prefix = name_space_prefix


                                                class MaxLspbw(Entity):
                                                    """
                                                    Max LSP bandwidth array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-9223372036854775808..9223372036854775807
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                        self.yang_name = "max-lspbw"
                                                        self.yang_parent_name = "ixcdtlv-value"

                                                        self.entry = YLeaf(YType.int64, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "max-lspbw" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.max_lspbw:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.fixed_scsi_count.is_set or
                                                        self.flex_scsi_count.is_set or
                                                        self.rile_len_code.is_set or
                                                        self.switching_cap.is_set or
                                                        (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_data()))

                                                def has_operation(self):
                                                    for c in self.max_lspbw:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.fixed_scsi_count.yfilter != YFilter.not_set or
                                                        self.flex_scsi_count.yfilter != YFilter.not_set or
                                                        self.rile_len_code.yfilter != YFilter.not_set or
                                                        self.switching_cap.yfilter != YFilter.not_set or
                                                        (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ixcdtlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.fixed_scsi_count.is_set or self.fixed_scsi_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fixed_scsi_count.get_name_leafdata())
                                                    if (self.flex_scsi_count.is_set or self.flex_scsi_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flex_scsi_count.get_name_leafdata())
                                                    if (self.rile_len_code.is_set or self.rile_len_code.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rile_len_code.get_name_leafdata())
                                                    if (self.switching_cap.is_set or self.switching_cap.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.switching_cap.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ixcd-switching-cap-type"):
                                                        if (self.ixcd_switching_cap_type is None):
                                                            self.ixcd_switching_cap_type = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                            self.ixcd_switching_cap_type.parent = self
                                                            self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                        return self.ixcd_switching_cap_type

                                                    if (child_yang_name == "max-lspbw"):
                                                        for c in self.max_lspbw:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.max_lspbw.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ixcd-switching-cap-type" or name == "max-lspbw" or name == "fixed-scsi-count" or name == "flex-scsi-count" or name == "rile-len-code" or name == "switching-cap"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "fixed-scsi-count"):
                                                        self.fixed_scsi_count = value
                                                        self.fixed_scsi_count.value_namespace = name_space
                                                        self.fixed_scsi_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flex-scsi-count"):
                                                        self.flex_scsi_count = value
                                                        self.flex_scsi_count.value_namespace = name_space
                                                        self.flex_scsi_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rile-len-code"):
                                                        self.rile_len_code = value
                                                        self.rile_len_code.value_namespace = name_space
                                                        self.rile_len_code.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "switching-cap"):
                                                        self.switching_cap = value
                                                        self.switching_cap.value_namespace = name_space
                                                        self.switching_cap.value_namespace_prefix = name_space_prefix


                                            class UnidtlvValue(Entity):
                                                """
                                                Value of Uni Delay TLV
                                                
                                                .. attribute:: uni_dir_delay
                                                
                                                	Uni Dir Delay
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                    self.yang_name = "unidtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("uni_dir_delay") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.uni_dir_delay.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.uni_dir_delay.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unidtlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.uni_dir_delay.is_set or self.uni_dir_delay.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.uni_dir_delay.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "uni-dir-delay"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "uni-dir-delay"):
                                                        self.uni_dir_delay = value
                                                        self.uni_dir_delay.value_namespace = name_space
                                                        self.uni_dir_delay.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.opaque_tlv_type.is_set or
                                                    (self.bctlv_value is not None and self.bctlv_value.has_data()) or
                                                    (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_data()) or
                                                    (self.srlgtlv_value is not None and self.srlgtlv_value.has_data()) or
                                                    (self.unidtlv_value is not None and self.unidtlv_value.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.opaque_tlv_type.yfilter != YFilter.not_set or
                                                    (self.bctlv_value is not None and self.bctlv_value.has_operation()) or
                                                    (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_operation()) or
                                                    (self.srlgtlv_value is not None and self.srlgtlv_value.has_operation()) or
                                                    (self.unidtlv_value is not None and self.unidtlv_value.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mplste-link-opt-tlv-value" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.opaque_tlv_type.is_set or self.opaque_tlv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.opaque_tlv_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bctlv-value"):
                                                    if (self.bctlv_value is None):
                                                        self.bctlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                        self.bctlv_value.parent = self
                                                        self._children_name_map["bctlv_value"] = "bctlv-value"
                                                    return self.bctlv_value

                                                if (child_yang_name == "ixcdtlv-value"):
                                                    if (self.ixcdtlv_value is None):
                                                        self.ixcdtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                        self.ixcdtlv_value.parent = self
                                                        self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                    return self.ixcdtlv_value

                                                if (child_yang_name == "srlgtlv-value"):
                                                    if (self.srlgtlv_value is None):
                                                        self.srlgtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                        self.srlgtlv_value.parent = self
                                                        self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                    return self.srlgtlv_value

                                                if (child_yang_name == "unidtlv-value"):
                                                    if (self.unidtlv_value is None):
                                                        self.unidtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                        self.unidtlv_value.parent = self
                                                        self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                    return self.unidtlv_value

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bctlv-value" or name == "ixcdtlv-value" or name == "srlgtlv-value" or name == "unidtlv-value" or name == "opaque-tlv-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "opaque-tlv-type"):
                                                    self.opaque_tlv_type = value
                                                    self.opaque_tlv_type.value_namespace = name_space
                                                    self.opaque_tlv_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.mplste_link_opt_tlv_value:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.mplste_link_opt_tlv_len.is_set or
                                                self.mplste_link_opt_tlv_type.is_set)

                                        def has_operation(self):
                                            for c in self.mplste_link_opt_tlv_value:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set or
                                                self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mplste-link-opt-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.mplste_link_opt_tlv_len.is_set or self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mplste_link_opt_tlv_len.get_name_leafdata())
                                            if (self.mplste_link_opt_tlv_type.is_set or self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mplste_link_opt_tlv_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "mplste-link-opt-tlv-value"):
                                                for c in self.mplste_link_opt_tlv_value:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.mplste_link_opt_tlv_value.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "mplste-link-opt-tlv-value" or name == "mplste-link-opt-tlv-len" or name == "mplste-link-opt-tlv-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "mplste-link-opt-tlv-len"):
                                                self.mplste_link_opt_tlv_len = value
                                                self.mplste_link_opt_tlv_len.value_namespace = name_space
                                                self.mplste_link_opt_tlv_len.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mplste-link-opt-tlv-type"):
                                                self.mplste_link_opt_tlv_type = value
                                                self.mplste_link_opt_tlv_type.value_namespace = name_space
                                                self.mplste_link_opt_tlv_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.mplste_link_opt_tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.affinity.is_set or
                                            self.dste_allocation_model_id.is_set or
                                            self.dste_in_use.is_set or
                                            self.fragment_id.is_set or
                                            self.igp_metric.is_set or
                                            self.input_interface_id.is_set or
                                            self.link_address.is_set or
                                            self.maximum_link_bw.is_set or
                                            self.maximum_link_reservable_bw.is_set or
                                            self.maximum_link_sub_reservable_bw.is_set or
                                            self.mpls_link_instance.is_set or
                                            self.mpls_link_type.is_set or
                                            self.neighbor_ip_address.is_set or
                                            self.neighbor_system_id.is_set or
                                            self.new_link.is_set or
                                            self.number_of_optional_tl_vs.is_set or
                                            self.output_interface_id.is_set or
                                            self.priority_count.is_set or
                                            self.te_metric.is_set or
                                            (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_data()) or
                                            (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_data()) or
                                            (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_data()) or
                                            (self.link_sw_capability is not None and self.link_sw_capability.has_data()) or
                                            (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_data()))

                                    def has_operation(self):
                                        for c in self.mplste_link_opt_tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.affinity.yfilter != YFilter.not_set or
                                            self.dste_allocation_model_id.yfilter != YFilter.not_set or
                                            self.dste_in_use.yfilter != YFilter.not_set or
                                            self.fragment_id.yfilter != YFilter.not_set or
                                            self.igp_metric.yfilter != YFilter.not_set or
                                            self.input_interface_id.yfilter != YFilter.not_set or
                                            self.link_address.yfilter != YFilter.not_set or
                                            self.maximum_link_bw.yfilter != YFilter.not_set or
                                            self.maximum_link_reservable_bw.yfilter != YFilter.not_set or
                                            self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set or
                                            self.mpls_link_instance.yfilter != YFilter.not_set or
                                            self.mpls_link_type.yfilter != YFilter.not_set or
                                            self.neighbor_ip_address.yfilter != YFilter.not_set or
                                            self.neighbor_system_id.yfilter != YFilter.not_set or
                                            self.new_link.yfilter != YFilter.not_set or
                                            self.number_of_optional_tl_vs.yfilter != YFilter.not_set or
                                            self.output_interface_id.yfilter != YFilter.not_set or
                                            self.priority_count.yfilter != YFilter.not_set or
                                            self.te_metric.yfilter != YFilter.not_set or
                                            (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_operation()) or
                                            (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_operation()) or
                                            (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_operation()) or
                                            (self.link_sw_capability is not None and self.link_sw_capability.has_operation()) or
                                            (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls-te-link" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.affinity.is_set or self.affinity.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.affinity.get_name_leafdata())
                                        if (self.dste_allocation_model_id.is_set or self.dste_allocation_model_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dste_allocation_model_id.get_name_leafdata())
                                        if (self.dste_in_use.is_set or self.dste_in_use.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dste_in_use.get_name_leafdata())
                                        if (self.fragment_id.is_set or self.fragment_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fragment_id.get_name_leafdata())
                                        if (self.igp_metric.is_set or self.igp_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igp_metric.get_name_leafdata())
                                        if (self.input_interface_id.is_set or self.input_interface_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.input_interface_id.get_name_leafdata())
                                        if (self.link_address.is_set or self.link_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_address.get_name_leafdata())
                                        if (self.maximum_link_bw.is_set or self.maximum_link_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_link_bw.get_name_leafdata())
                                        if (self.maximum_link_reservable_bw.is_set or self.maximum_link_reservable_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_link_reservable_bw.get_name_leafdata())
                                        if (self.maximum_link_sub_reservable_bw.is_set or self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_link_sub_reservable_bw.get_name_leafdata())
                                        if (self.mpls_link_instance.is_set or self.mpls_link_instance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_link_instance.get_name_leafdata())
                                        if (self.mpls_link_type.is_set or self.mpls_link_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_link_type.get_name_leafdata())
                                        if (self.neighbor_ip_address.is_set or self.neighbor_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_ip_address.get_name_leafdata())
                                        if (self.neighbor_system_id.is_set or self.neighbor_system_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_system_id.get_name_leafdata())
                                        if (self.new_link.is_set or self.new_link.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.new_link.get_name_leafdata())
                                        if (self.number_of_optional_tl_vs.is_set or self.number_of_optional_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number_of_optional_tl_vs.get_name_leafdata())
                                        if (self.output_interface_id.is_set or self.output_interface_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.output_interface_id.get_name_leafdata())
                                        if (self.priority_count.is_set or self.priority_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.priority_count.get_name_leafdata())
                                        if (self.te_metric.is_set or self.te_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_metric.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "extended-admin-group-list"):
                                            if (self.extended_admin_group_list is None):
                                                self.extended_admin_group_list = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList()
                                                self.extended_admin_group_list.parent = self
                                                self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                            return self.extended_admin_group_list

                                        if (child_yang_name == "global-unreserve-bw-per-priority"):
                                            if (self.global_unreserve_bw_per_priority is None):
                                                self.global_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority()
                                                self.global_unreserve_bw_per_priority.parent = self
                                                self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                            return self.global_unreserve_bw_per_priority

                                        if (child_yang_name == "link-protocol-priority-capability"):
                                            if (self.link_protocol_priority_capability is None):
                                                self.link_protocol_priority_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability()
                                                self.link_protocol_priority_capability.parent = self
                                                self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                            return self.link_protocol_priority_capability

                                        if (child_yang_name == "link-sw-capability"):
                                            if (self.link_sw_capability is None):
                                                self.link_sw_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability()
                                                self.link_sw_capability.parent = self
                                                self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                            return self.link_sw_capability

                                        if (child_yang_name == "mplste-link-opt-tlv"):
                                            for c in self.mplste_link_opt_tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.mplste_link_opt_tlv.append(c)
                                            return c

                                        if (child_yang_name == "sub-pool-unreserve-bw-per-priority"):
                                            if (self.sub_pool_unreserve_bw_per_priority is None):
                                                self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                                self.sub_pool_unreserve_bw_per_priority.parent = self
                                                self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                            return self.sub_pool_unreserve_bw_per_priority

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "extended-admin-group-list" or name == "global-unreserve-bw-per-priority" or name == "link-protocol-priority-capability" or name == "link-sw-capability" or name == "mplste-link-opt-tlv" or name == "sub-pool-unreserve-bw-per-priority" or name == "affinity" or name == "dste-allocation-model-id" or name == "dste-in-use" or name == "fragment-id" or name == "igp-metric" or name == "input-interface-id" or name == "link-address" or name == "maximum-link-bw" or name == "maximum-link-reservable-bw" or name == "maximum-link-sub-reservable-bw" or name == "mpls-link-instance" or name == "mpls-link-type" or name == "neighbor-ip-address" or name == "neighbor-system-id" or name == "new-link" or name == "number-of-optional-tl-vs" or name == "output-interface-id" or name == "priority-count" or name == "te-metric"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "affinity"):
                                            self.affinity = value
                                            self.affinity.value_namespace = name_space
                                            self.affinity.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dste-allocation-model-id"):
                                            self.dste_allocation_model_id = value
                                            self.dste_allocation_model_id.value_namespace = name_space
                                            self.dste_allocation_model_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dste-in-use"):
                                            self.dste_in_use = value
                                            self.dste_in_use.value_namespace = name_space
                                            self.dste_in_use.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fragment-id"):
                                            self.fragment_id = value
                                            self.fragment_id.value_namespace = name_space
                                            self.fragment_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igp-metric"):
                                            self.igp_metric = value
                                            self.igp_metric.value_namespace = name_space
                                            self.igp_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "input-interface-id"):
                                            self.input_interface_id = value
                                            self.input_interface_id.value_namespace = name_space
                                            self.input_interface_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-address"):
                                            self.link_address = value
                                            self.link_address.value_namespace = name_space
                                            self.link_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-link-bw"):
                                            self.maximum_link_bw = value
                                            self.maximum_link_bw.value_namespace = name_space
                                            self.maximum_link_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-link-reservable-bw"):
                                            self.maximum_link_reservable_bw = value
                                            self.maximum_link_reservable_bw.value_namespace = name_space
                                            self.maximum_link_reservable_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-link-sub-reservable-bw"):
                                            self.maximum_link_sub_reservable_bw = value
                                            self.maximum_link_sub_reservable_bw.value_namespace = name_space
                                            self.maximum_link_sub_reservable_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-link-instance"):
                                            self.mpls_link_instance = value
                                            self.mpls_link_instance.value_namespace = name_space
                                            self.mpls_link_instance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-link-type"):
                                            self.mpls_link_type = value
                                            self.mpls_link_type.value_namespace = name_space
                                            self.mpls_link_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-ip-address"):
                                            self.neighbor_ip_address = value
                                            self.neighbor_ip_address.value_namespace = name_space
                                            self.neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-system-id"):
                                            self.neighbor_system_id = value
                                            self.neighbor_system_id.value_namespace = name_space
                                            self.neighbor_system_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "new-link"):
                                            self.new_link = value
                                            self.new_link.value_namespace = name_space
                                            self.new_link.value_namespace_prefix = name_space_prefix
                                        if(value_path == "number-of-optional-tl-vs"):
                                            self.number_of_optional_tl_vs = value
                                            self.number_of_optional_tl_vs.value_namespace = name_space
                                            self.number_of_optional_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "output-interface-id"):
                                            self.output_interface_id = value
                                            self.output_interface_id.value_namespace = name_space
                                            self.output_interface_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "priority-count"):
                                            self.priority_count = value
                                            self.priority_count.value_namespace = name_space
                                            self.priority_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-metric"):
                                            self.te_metric = value
                                            self.te_metric.value_namespace = name_space
                                            self.te_metric.value_namespace_prefix = name_space_prefix


                                class MplsTeFragment(Entity):
                                    """
                                    MPLS TE fragments in the area
                                    
                                    .. attribute:: dste_model_id
                                    
                                    	DS\-TE Allocation Model ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: fragment_id
                                    
                                    	Fragment ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fragment_instance
                                    
                                    	Fragment instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mpls_te_link
                                    
                                    	List of fragment links
                                    	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink>`
                                    
                                    .. attribute:: same_fragment_count
                                    
                                    	Number of fragment links which haven't changed since the last update
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment, self).__init__()

                                        self.yang_name = "mpls-te-fragment"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.dste_model_id = YLeaf(YType.uint8, "dste-model-id")

                                        self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                        self.fragment_instance = YLeaf(YType.uint32, "fragment-instance")

                                        self.same_fragment_count = YLeaf(YType.uint8, "same-fragment-count")

                                        self.mpls_te_link = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dste_model_id",
                                                        "fragment_id",
                                                        "fragment_instance",
                                                        "same_fragment_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment, self).__setattr__(name, value)


                                    class MplsTeLink(Entity):
                                        """
                                        List of fragment links
                                        
                                        .. attribute:: affinity
                                        
                                        	Affinity
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dste_allocation_model_id
                                        
                                        	DS\-TE Allocation Model ID
                                        	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                        
                                        .. attribute:: dste_in_use
                                        
                                        	A DS\-TE Allocation Model in use
                                        	**type**\:  bool
                                        
                                        .. attribute:: extended_admin_group_list
                                        
                                        	Extended Admin Group
                                        	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList>`
                                        
                                        .. attribute:: fragment_id
                                        
                                        	Fragment ID for this link
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: global_unreserve_bw_per_priority
                                        
                                        	Global pool unreserved bandwidth for each priority (bytes/s)
                                        	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                        
                                        .. attribute:: igp_metric
                                        
                                        	Link IGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: input_interface_id
                                        
                                        	Input interface ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_address
                                        
                                        	The local interface address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: link_protocol_priority_capability
                                        
                                        	Link protocol and protocol priority capability
                                        	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability>`
                                        
                                        .. attribute:: link_sw_capability
                                        
                                        	Link switching capability
                                        	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability>`
                                        
                                        .. attribute:: maximum_link_bw
                                        
                                        	Maximum link bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte/s
                                        
                                        .. attribute:: maximum_link_reservable_bw
                                        
                                        	Maximum link global pool reservable bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte/s
                                        
                                        .. attribute:: maximum_link_sub_reservable_bw
                                        
                                        	Maximum link subpool reservable bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte/s
                                        
                                        .. attribute:: mpls_link_instance
                                        
                                        	Link instance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mpls_link_type
                                        
                                        	Type of link
                                        	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                        
                                        .. attribute:: mplste_link_opt_tlv
                                        
                                        	List of Optional TLVs
                                        	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv>`
                                        
                                        .. attribute:: neighbor_ip_address
                                        
                                        	Neighbor IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_system_id
                                        
                                        	Neighbor system ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: new_link
                                        
                                        	If true, Link is new
                                        	**type**\:  bool
                                        
                                        .. attribute:: number_of_optional_tl_vs
                                        
                                        	Number of Optional TLVs
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: output_interface_id
                                        
                                        	Output interface ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority_count
                                        
                                        	Number of priorities
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_pool_unreserve_bw_per_priority
                                        
                                        	Sub pool unreserved bandwidth for each priority (bytes/s)
                                        	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                        
                                        .. attribute:: te_metric
                                        
                                        	Link TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink, self).__init__()

                                            self.yang_name = "mpls-te-link"
                                            self.yang_parent_name = "mpls-te-fragment"

                                            self.affinity = YLeaf(YType.uint32, "affinity")

                                            self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                            self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                            self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                            self.link_address = YLeaf(YType.str, "link-address")

                                            self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                            self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                            self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                            self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                            self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                            self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                            self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                            self.new_link = YLeaf(YType.boolean, "new-link")

                                            self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                            self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                            self.priority_count = YLeaf(YType.int32, "priority-count")

                                            self.te_metric = YLeaf(YType.uint32, "te-metric")

                                            self.extended_admin_group_list = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                            self.extended_admin_group_list.parent = self
                                            self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                            self._children_yang_names.add("extended-admin-group-list")

                                            self.global_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                            self.global_unreserve_bw_per_priority.parent = self
                                            self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                            self._children_yang_names.add("global-unreserve-bw-per-priority")

                                            self.link_protocol_priority_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                            self.link_protocol_priority_capability.parent = self
                                            self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                            self._children_yang_names.add("link-protocol-priority-capability")

                                            self.link_sw_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                            self.link_sw_capability.parent = self
                                            self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                            self._children_yang_names.add("link-sw-capability")

                                            self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                            self.sub_pool_unreserve_bw_per_priority.parent = self
                                            self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                            self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                            self.mplste_link_opt_tlv = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("affinity",
                                                            "dste_allocation_model_id",
                                                            "dste_in_use",
                                                            "fragment_id",
                                                            "igp_metric",
                                                            "input_interface_id",
                                                            "link_address",
                                                            "maximum_link_bw",
                                                            "maximum_link_reservable_bw",
                                                            "maximum_link_sub_reservable_bw",
                                                            "mpls_link_instance",
                                                            "mpls_link_type",
                                                            "neighbor_ip_address",
                                                            "neighbor_system_id",
                                                            "new_link",
                                                            "number_of_optional_tl_vs",
                                                            "output_interface_id",
                                                            "priority_count",
                                                            "te_metric") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink, self).__setattr__(name, value)


                                        class GlobalUnreserveBwPerPriority(Entity):
                                            """
                                            Global pool unreserved bandwidth for each
                                            priority (bytes/s)
                                            
                                            .. attribute:: bw_per_priority
                                            
                                            	Unreserved bandwidth for each priority (bytes/s)
                                            	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                                self.yang_name = "global-unreserve-bw-per-priority"
                                                self.yang_parent_name = "mpls-te-link"

                                                self.bw_per_priority = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)


                                            class BwPerPriority(Entity):
                                                """
                                                Unreserved bandwidth for each priority (bytes/s)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte/s
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                    self.yang_name = "bw-per-priority"
                                                    self.yang_parent_name = "global-unreserve-bw-per-priority"

                                                    self.entry = YLeaf(YType.uint64, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bw-per-priority" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.bw_per_priority:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.bw_per_priority:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "global-unreserve-bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bw-per-priority"):
                                                    for c in self.bw_per_priority:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.bw_per_priority.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bw-per-priority"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class SubPoolUnreserveBwPerPriority(Entity):
                                            """
                                            Sub pool unreserved bandwidth for each priority
                                            (bytes/s)
                                            
                                            .. attribute:: bw_per_priority
                                            
                                            	Unreserved bandwidth for each priority (bytes/s)
                                            	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                                self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                                self.yang_parent_name = "mpls-te-link"

                                                self.bw_per_priority = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)


                                            class BwPerPriority(Entity):
                                                """
                                                Unreserved bandwidth for each priority (bytes/s)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte/s
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                    self.yang_name = "bw-per-priority"
                                                    self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"

                                                    self.entry = YLeaf(YType.uint64, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bw-per-priority" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.bw_per_priority:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.bw_per_priority:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sub-pool-unreserve-bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bw-per-priority"):
                                                    for c in self.bw_per_priority:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.bw_per_priority.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bw-per-priority"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class LinkProtocolPriorityCapability(Entity):
                                            """
                                            Link protocol and protocol priority capability
                                            
                                            .. attribute:: link_protocol_capability
                                            
                                            	Link protocol capability
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: link_protocol_priority
                                            
                                            	Link protocol priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                                self.yang_name = "link-protocol-priority-capability"
                                                self.yang_parent_name = "mpls-te-link"

                                                self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                                self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("link_protocol_capability",
                                                                "link_protocol_priority") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.link_protocol_capability.is_set or
                                                    self.link_protocol_priority.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.link_protocol_capability.yfilter != YFilter.not_set or
                                                    self.link_protocol_priority.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "link-protocol-priority-capability" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.link_protocol_capability.is_set or self.link_protocol_capability.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_protocol_capability.get_name_leafdata())
                                                if (self.link_protocol_priority.is_set or self.link_protocol_priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_protocol_priority.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "link-protocol-capability" or name == "link-protocol-priority"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "link-protocol-capability"):
                                                    self.link_protocol_capability = value
                                                    self.link_protocol_capability.value_namespace = name_space
                                                    self.link_protocol_capability.value_namespace_prefix = name_space_prefix
                                                if(value_path == "link-protocol-priority"):
                                                    self.link_protocol_priority = value
                                                    self.link_protocol_priority.value_namespace = name_space
                                                    self.link_protocol_priority.value_namespace_prefix = name_space_prefix


                                        class LinkSwCapability(Entity):
                                            """
                                            Link switching capability
                                            
                                            .. attribute:: link_encoding
                                            
                                            	Link Encoding
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: link_mtu
                                            
                                            	Link MTU size (bytes)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: link_switching_capability
                                            
                                            	Link Switching Capability
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: maximum_lsp_bw_per_priority
                                            
                                            	Maximum LSP bandwidth for each priority  (bytes/s)
                                            	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                            
                                            .. attribute:: minimum_lsp_bw
                                            
                                            	Minimum LSP bandwidth (bytes/s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__init__()

                                                self.yang_name = "link-sw-capability"
                                                self.yang_parent_name = "mpls-te-link"

                                                self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                                self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                                self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                                self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                                self.maximum_lsp_bw_per_priority = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("link_encoding",
                                                                "link_mtu",
                                                                "link_switching_capability",
                                                                "minimum_lsp_bw") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)


                                            class MaximumLspBwPerPriority(Entity):
                                                """
                                                Maximum LSP bandwidth for each priority
                                                
                                                (bytes/s)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte/s
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                                    self.yang_name = "maximum-lsp-bw-per-priority"
                                                    self.yang_parent_name = "link-sw-capability"

                                                    self.entry = YLeaf(YType.uint64, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "maximum-lsp-bw-per-priority" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.maximum_lsp_bw_per_priority:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.link_encoding.is_set or
                                                    self.link_mtu.is_set or
                                                    self.link_switching_capability.is_set or
                                                    self.minimum_lsp_bw.is_set)

                                            def has_operation(self):
                                                for c in self.maximum_lsp_bw_per_priority:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.link_encoding.yfilter != YFilter.not_set or
                                                    self.link_mtu.yfilter != YFilter.not_set or
                                                    self.link_switching_capability.yfilter != YFilter.not_set or
                                                    self.minimum_lsp_bw.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "link-sw-capability" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.link_encoding.is_set or self.link_encoding.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_encoding.get_name_leafdata())
                                                if (self.link_mtu.is_set or self.link_mtu.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_mtu.get_name_leafdata())
                                                if (self.link_switching_capability.is_set or self.link_switching_capability.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_switching_capability.get_name_leafdata())
                                                if (self.minimum_lsp_bw.is_set or self.minimum_lsp_bw.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_lsp_bw.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "maximum-lsp-bw-per-priority"):
                                                    for c in self.maximum_lsp_bw_per_priority:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.maximum_lsp_bw_per_priority.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "maximum-lsp-bw-per-priority" or name == "link-encoding" or name == "link-mtu" or name == "link-switching-capability" or name == "minimum-lsp-bw"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "link-encoding"):
                                                    self.link_encoding = value
                                                    self.link_encoding.value_namespace = name_space
                                                    self.link_encoding.value_namespace_prefix = name_space_prefix
                                                if(value_path == "link-mtu"):
                                                    self.link_mtu = value
                                                    self.link_mtu.value_namespace = name_space
                                                    self.link_mtu.value_namespace_prefix = name_space_prefix
                                                if(value_path == "link-switching-capability"):
                                                    self.link_switching_capability = value
                                                    self.link_switching_capability.value_namespace = name_space
                                                    self.link_switching_capability.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-lsp-bw"):
                                                    self.minimum_lsp_bw = value
                                                    self.minimum_lsp_bw.value_namespace = name_space
                                                    self.minimum_lsp_bw.value_namespace_prefix = name_space_prefix


                                        class ExtendedAdminGroupList(Entity):
                                            """
                                            Extended Admin Group
                                            
                                            .. attribute:: ext_admin_data
                                            
                                            	Value of Extended Admin Group
                                            	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                            
                                            .. attribute:: extended_admin_size
                                            
                                            	Size of the extended admin group
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                                self.yang_name = "extended-admin-group-list"
                                                self.yang_parent_name = "mpls-te-link"

                                                self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                                self.ext_admin_data = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("extended_admin_size") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)


                                            class ExtAdminData(Entity):
                                                """
                                                Value of Extended Admin Group
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                                    self.yang_name = "ext-admin-data"
                                                    self.yang_parent_name = "extended-admin-group-list"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ext-admin-data" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.ext_admin_data:
                                                    if (c.has_data()):
                                                        return True
                                                return self.extended_admin_size.is_set

                                            def has_operation(self):
                                                for c in self.ext_admin_data:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.extended_admin_size.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "extended-admin-group-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.extended_admin_size.is_set or self.extended_admin_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.extended_admin_size.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ext-admin-data"):
                                                    for c in self.ext_admin_data:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.ext_admin_data.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ext-admin-data" or name == "extended-admin-size"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "extended-admin-size"):
                                                    self.extended_admin_size = value
                                                    self.extended_admin_size.value_namespace = name_space
                                                    self.extended_admin_size.value_namespace_prefix = name_space_prefix


                                        class MplsteLinkOptTlv(Entity):
                                            """
                                            List of Optional TLVs
                                            
                                            .. attribute:: mplste_link_opt_tlv_len
                                            
                                            	Length of Opt TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mplste_link_opt_tlv_type
                                            
                                            	Type of Opt TLV
                                            	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                            
                                            .. attribute:: mplste_link_opt_tlv_value
                                            
                                            	Value of Opt TLV
                                            	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                                self.yang_name = "mplste-link-opt-tlv"
                                                self.yang_parent_name = "mpls-te-link"

                                                self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                                self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                                self.mplste_link_opt_tlv_value = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("mplste_link_opt_tlv_len",
                                                                "mplste_link_opt_tlv_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)


                                            class MplsteLinkOptTlvValue(Entity):
                                                """
                                                Value of Opt TLV
                                                
                                                .. attribute:: bctlv_value
                                                
                                                	Value of Bandwidth Constraints TLV
                                                	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                                
                                                .. attribute:: ixcdtlv_value
                                                
                                                	Value of IXCD TLV
                                                	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                                
                                                .. attribute:: opaque_tlv_type
                                                
                                                	OpaqueTLVType
                                                	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                                
                                                .. attribute:: srlgtlv_value
                                                
                                                	Value of SRLG TLV
                                                	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                                
                                                .. attribute:: unidtlv_value
                                                
                                                	Value of Uni Delay TLV
                                                	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                                    self.yang_name = "mplste-link-opt-tlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv"

                                                    self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                                    self.bctlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                    self.bctlv_value.parent = self
                                                    self._children_name_map["bctlv_value"] = "bctlv-value"
                                                    self._children_yang_names.add("bctlv-value")

                                                    self.ixcdtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                    self.ixcdtlv_value.parent = self
                                                    self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                    self._children_yang_names.add("ixcdtlv-value")

                                                    self.srlgtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                    self.srlgtlv_value.parent = self
                                                    self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                    self._children_yang_names.add("srlgtlv-value")

                                                    self.unidtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                    self.unidtlv_value.parent = self
                                                    self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                    self._children_yang_names.add("unidtlv-value")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("opaque_tlv_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)


                                                class BctlvValue(Entity):
                                                    """
                                                    Value of Bandwidth Constraints TLV
                                                    
                                                    .. attribute:: model_id
                                                    
                                                    	Allocation Model ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mplste_link_bc_bandwidth
                                                    
                                                    	Value of BC TLV
                                                    	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                                    
                                                    .. attribute:: num_b_cs
                                                    
                                                    	Number of BC TLVs
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                        self.yang_name = "bctlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                        self.model_id = YLeaf(YType.uint8, "model-id")

                                                        self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                        self.mplste_link_bc_bandwidth = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("model_id",
                                                                        "num_b_cs") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)


                                                    class MplsteLinkBcBandwidth(Entity):
                                                        """
                                                        Value of BC TLV
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                            self.yang_name = "mplste-link-bc-bandwidth"
                                                            self.yang_parent_name = "bctlv-value"

                                                            self.entry = YLeaf(YType.uint64, "entry")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("entry") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return self.entry.is_set

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.entry.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "mplste-link-bc-bandwidth" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "entry"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "entry"):
                                                                self.entry = value
                                                                self.entry.value_namespace = name_space
                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.mplste_link_bc_bandwidth:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.model_id.is_set or
                                                            self.num_b_cs.is_set)

                                                    def has_operation(self):
                                                        for c in self.mplste_link_bc_bandwidth:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.model_id.yfilter != YFilter.not_set or
                                                            self.num_b_cs.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "bctlv-value" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.model_id.is_set or self.model_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.model_id.get_name_leafdata())
                                                        if (self.num_b_cs.is_set or self.num_b_cs.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_b_cs.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "mplste-link-bc-bandwidth"):
                                                            for c in self.mplste_link_bc_bandwidth:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.mplste_link_bc_bandwidth.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "mplste-link-bc-bandwidth" or name == "model-id" or name == "num-b-cs"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "model-id"):
                                                            self.model_id = value
                                                            self.model_id.value_namespace = name_space
                                                            self.model_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-b-cs"):
                                                            self.num_b_cs = value
                                                            self.num_b_cs.value_namespace = name_space
                                                            self.num_b_cs.value_namespace_prefix = name_space_prefix


                                                class SrlgtlvValue(Entity):
                                                    """
                                                    Value of SRLG TLV
                                                    
                                                    .. attribute:: mplste_link_srlg_data
                                                    
                                                    	Value of SRLG TLV
                                                    	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                                    
                                                    .. attribute:: num_srl_gs
                                                    
                                                    	Number of SRLG TLVs
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: srlg_len
                                                    
                                                    	Length of SRLG TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                        self.yang_name = "srlgtlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                        self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                        self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                        self.mplste_link_srlg_data = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("num_srl_gs",
                                                                        "srlg_len") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)


                                                    class MplsteLinkSrlgData(Entity):
                                                        """
                                                        Value of SRLG TLV
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                            self.yang_name = "mplste-link-srlg-data"
                                                            self.yang_parent_name = "srlgtlv-value"

                                                            self.entry = YLeaf(YType.uint32, "entry")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("entry") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return self.entry.is_set

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.entry.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "mplste-link-srlg-data" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "entry"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "entry"):
                                                                self.entry = value
                                                                self.entry.value_namespace = name_space
                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.mplste_link_srlg_data:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.num_srl_gs.is_set or
                                                            self.srlg_len.is_set)

                                                    def has_operation(self):
                                                        for c in self.mplste_link_srlg_data:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.num_srl_gs.yfilter != YFilter.not_set or
                                                            self.srlg_len.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "srlgtlv-value" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.num_srl_gs.is_set or self.num_srl_gs.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_srl_gs.get_name_leafdata())
                                                        if (self.srlg_len.is_set or self.srlg_len.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.srlg_len.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "mplste-link-srlg-data"):
                                                            for c in self.mplste_link_srlg_data:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.mplste_link_srlg_data.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "mplste-link-srlg-data" or name == "num-srl-gs" or name == "srlg-len"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "num-srl-gs"):
                                                            self.num_srl_gs = value
                                                            self.num_srl_gs.value_namespace = name_space
                                                            self.num_srl_gs.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "srlg-len"):
                                                            self.srlg_len = value
                                                            self.srlg_len.value_namespace = name_space
                                                            self.srlg_len.value_namespace_prefix = name_space_prefix


                                                class IxcdtlvValue(Entity):
                                                    """
                                                    Value of IXCD TLV
                                                    
                                                    .. attribute:: fixed_scsi_count
                                                    
                                                    	Fixed SCSI count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flex_scsi_count
                                                    
                                                    	Flexible SCSI count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ixcd_switching_cap_type
                                                    
                                                    	Switching Cap type
                                                    	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                                    
                                                    .. attribute:: max_lspbw
                                                    
                                                    	Max LSP bandwidth array
                                                    	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                                    
                                                    .. attribute:: rile_len_code
                                                    
                                                    	Rile LenCode
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: switching_cap
                                                    
                                                    	SCap
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                        self.yang_name = "ixcdtlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                        self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                        self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                        self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                        self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                        self.ixcd_switching_cap_type = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                        self.ixcd_switching_cap_type.parent = self
                                                        self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                        self._children_yang_names.add("ixcd-switching-cap-type")

                                                        self.max_lspbw = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("fixed_scsi_count",
                                                                        "flex_scsi_count",
                                                                        "rile_len_code",
                                                                        "switching_cap") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)


                                                    class IxcdSwitchingCapType(Entity):
                                                        """
                                                        Switching Cap type
                                                        
                                                        .. attribute:: ixcdbw_sub_tlv
                                                        
                                                        	Sub TLVs
                                                        	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                        
                                                        .. attribute:: ixcdpsc_info
                                                        
                                                        	IXCD PSC information
                                                        	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                        
                                                        .. attribute:: switching_cap_type
                                                        
                                                        	SwitchingCapType
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                            self.yang_name = "ixcd-switching-cap-type"
                                                            self.yang_parent_name = "ixcdtlv-value"

                                                            self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                            self.ixcdbw_sub_tlv = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                            self.ixcdbw_sub_tlv.parent = self
                                                            self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                            self._children_yang_names.add("ixcdbw-sub-tlv")

                                                            self.ixcdpsc_info = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                            self.ixcdpsc_info.parent = self
                                                            self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                            self._children_yang_names.add("ixcdpsc-info")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("switching_cap_type") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)


                                                        class IxcdpscInfo(Entity):
                                                            """
                                                            IXCD PSC information
                                                            
                                                            .. attribute:: min_lsp_bandwidth
                                                            
                                                            	Min LSP bandwidth
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: psc_interface_mtu
                                                            
                                                            	 Interface MTU
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                                self.yang_name = "ixcdpsc-info"
                                                                self.yang_parent_name = "ixcd-switching-cap-type"

                                                                self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                                self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("min_lsp_bandwidth",
                                                                                "psc_interface_mtu") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)

                                                            def has_data(self):
                                                                return (
                                                                    self.min_lsp_bandwidth.is_set or
                                                                    self.psc_interface_mtu.is_set)

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.min_lsp_bandwidth.yfilter != YFilter.not_set or
                                                                    self.psc_interface_mtu.yfilter != YFilter.not_set)

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "ixcdpsc-info" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.min_lsp_bandwidth.is_set or self.min_lsp_bandwidth.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.min_lsp_bandwidth.get_name_leafdata())
                                                                if (self.psc_interface_mtu.is_set or self.psc_interface_mtu.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.psc_interface_mtu.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "min-lsp-bandwidth" or name == "psc-interface-mtu"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "min-lsp-bandwidth"):
                                                                    self.min_lsp_bandwidth = value
                                                                    self.min_lsp_bandwidth.value_namespace = name_space
                                                                    self.min_lsp_bandwidth.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "psc-interface-mtu"):
                                                                    self.psc_interface_mtu = value
                                                                    self.psc_interface_mtu.value_namespace = name_space
                                                                    self.psc_interface_mtu.value_namespace_prefix = name_space_prefix


                                                        class IxcdbwSubTlv(Entity):
                                                            """
                                                            Sub TLVs
                                                            
                                                            .. attribute:: arr_bw_sub_tlv
                                                            
                                                            	Array of sub tlvs
                                                            	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                                self.yang_name = "ixcdbw-sub-tlv"
                                                                self.yang_parent_name = "ixcd-switching-cap-type"

                                                                self.arr_bw_sub_tlv = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)


                                                            class ArrBwSubTlv(Entity):
                                                                """
                                                                Array of sub tlvs
                                                                
                                                                .. attribute:: bw_sub_tlv_length
                                                                
                                                                	Length of BW Sub TLV
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: bw_sub_tlv_type
                                                                
                                                                	Type of Sub TLV
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: bw_sub_tlv_value
                                                                
                                                                	Value of BW Sub TLV
                                                                	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-01-02'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                                    self.yang_name = "arr-bw-sub-tlv"
                                                                    self.yang_parent_name = "ixcdbw-sub-tlv"

                                                                    self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                                    self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                                    self.bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                    self.bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                    self._children_yang_names.add("bw-sub-tlv-value")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("bw_sub_tlv_length",
                                                                                    "bw_sub_tlv_type") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)


                                                                class BwSubTlvValue(Entity):
                                                                    """
                                                                    Value of BW Sub TLV
                                                                    
                                                                    .. attribute:: fixed_bw_sub_tlv_value
                                                                    
                                                                    	Value of Fixed Sub TLV
                                                                    	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                                    
                                                                    .. attribute:: flex_bw_sub_tlv_value
                                                                    
                                                                    	Value of Flex Sub TLV
                                                                    	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                                    
                                                                    .. attribute:: ixcdbw_sub_tlv_type
                                                                    
                                                                    	IXCDBWSubTLVType
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                        self.yang_name = "bw-sub-tlv-value"
                                                                        self.yang_parent_name = "arr-bw-sub-tlv"

                                                                        self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                        self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                        self.fixed_bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                        self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                        self.flex_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                        self.flex_bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                        self._children_yang_names.add("flex-bw-sub-tlv-value")

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in ("ixcdbw_sub_tlv_type") and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)


                                                                    class FixedBwSubTlvValue(Entity):
                                                                        """
                                                                        Value of Fixed Sub TLV
                                                                        
                                                                        .. attribute:: fixed_sub_tlv_value
                                                                        
                                                                        	Value of Fixed Sub TLV
                                                                        	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                        
                                                                        .. attribute:: unres_oduj_prio
                                                                        
                                                                        	Array of Unres Oduj Prio
                                                                        	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                            self.yang_name = "fixed-bw-sub-tlv-value"
                                                                            self.yang_parent_name = "bw-sub-tlv-value"

                                                                            self.fixed_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                            self.fixed_sub_tlv_value.parent = self
                                                                            self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                            self._children_yang_names.add("fixed-sub-tlv-value")

                                                                            self.unres_oduj_prio = YList(self)

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in () and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)


                                                                        class FixedSubTlvValue(Entity):
                                                                            """
                                                                            Value of Fixed Sub TLV
                                                                            
                                                                            .. attribute:: num_stages
                                                                            
                                                                            	Number of stages
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit0
                                                                            
                                                                            	Priority 0
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit1
                                                                            
                                                                            	Priority 1
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit2
                                                                            
                                                                            	Priority 2
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit3
                                                                            
                                                                            	Priority 3
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit4
                                                                            
                                                                            	Priority 4
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit5
                                                                            
                                                                            	Priority 5
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit6
                                                                            
                                                                            	Priority 6
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit7
                                                                            
                                                                            	Priority 7
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: res
                                                                            
                                                                            	Res
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: sbit
                                                                            
                                                                            	S Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: signal_type
                                                                            
                                                                            	Signal Type
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: stage
                                                                            
                                                                            	Array of Stages
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                            
                                                                            .. attribute:: tbit
                                                                            
                                                                            	T Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: tsg
                                                                            
                                                                            	TSG
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-01-02'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                                self.yang_name = "fixed-sub-tlv-value"
                                                                                self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                                self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                                self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                                self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                                self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                                self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                                self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                                self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                                self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                                self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                                self.res = YLeaf(YType.uint8, "res")

                                                                                self.sbit = YLeaf(YType.uint8, "sbit")

                                                                                self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                                self.stage = YLeaf(YType.str, "stage")

                                                                                self.tbit = YLeaf(YType.uint8, "tbit")

                                                                                self.tsg = YLeaf(YType.uint8, "tsg")

                                                                            def __setattr__(self, name, value):
                                                                                self._check_monkey_patching_error(name, value)
                                                                                with _handle_type_error():
                                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                            "Please use list append or extend method."
                                                                                                            .format(value))
                                                                                    if isinstance(value, Enum.YLeaf):
                                                                                        value = value.name
                                                                                    if name in ("num_stages",
                                                                                                "priority_bit0",
                                                                                                "priority_bit1",
                                                                                                "priority_bit2",
                                                                                                "priority_bit3",
                                                                                                "priority_bit4",
                                                                                                "priority_bit5",
                                                                                                "priority_bit6",
                                                                                                "priority_bit7",
                                                                                                "res",
                                                                                                "sbit",
                                                                                                "signal_type",
                                                                                                "stage",
                                                                                                "tbit",
                                                                                                "tsg") and name in self.__dict__:
                                                                                        if isinstance(value, YLeaf):
                                                                                            self.__dict__[name].set(value.get())
                                                                                        elif isinstance(value, YLeafList):
                                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)
                                                                                        else:
                                                                                            self.__dict__[name].set(value)
                                                                                    else:
                                                                                        if hasattr(value, "parent") and name != "parent":
                                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                                value.parent = self
                                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                                value.parent = self
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)

                                                                            def has_data(self):
                                                                                return (
                                                                                    self.num_stages.is_set or
                                                                                    self.priority_bit0.is_set or
                                                                                    self.priority_bit1.is_set or
                                                                                    self.priority_bit2.is_set or
                                                                                    self.priority_bit3.is_set or
                                                                                    self.priority_bit4.is_set or
                                                                                    self.priority_bit5.is_set or
                                                                                    self.priority_bit6.is_set or
                                                                                    self.priority_bit7.is_set or
                                                                                    self.res.is_set or
                                                                                    self.sbit.is_set or
                                                                                    self.signal_type.is_set or
                                                                                    self.stage.is_set or
                                                                                    self.tbit.is_set or
                                                                                    self.tsg.is_set)

                                                                            def has_operation(self):
                                                                                return (
                                                                                    self.yfilter != YFilter.not_set or
                                                                                    self.num_stages.yfilter != YFilter.not_set or
                                                                                    self.priority_bit0.yfilter != YFilter.not_set or
                                                                                    self.priority_bit1.yfilter != YFilter.not_set or
                                                                                    self.priority_bit2.yfilter != YFilter.not_set or
                                                                                    self.priority_bit3.yfilter != YFilter.not_set or
                                                                                    self.priority_bit4.yfilter != YFilter.not_set or
                                                                                    self.priority_bit5.yfilter != YFilter.not_set or
                                                                                    self.priority_bit6.yfilter != YFilter.not_set or
                                                                                    self.priority_bit7.yfilter != YFilter.not_set or
                                                                                    self.res.yfilter != YFilter.not_set or
                                                                                    self.sbit.yfilter != YFilter.not_set or
                                                                                    self.signal_type.yfilter != YFilter.not_set or
                                                                                    self.stage.yfilter != YFilter.not_set or
                                                                                    self.tbit.yfilter != YFilter.not_set or
                                                                                    self.tsg.yfilter != YFilter.not_set)

                                                                            def get_segment_path(self):
                                                                                path_buffer = ""
                                                                                path_buffer = "fixed-sub-tlv-value" + path_buffer

                                                                                return path_buffer

                                                                            def get_entity_path(self, ancestor):
                                                                                path_buffer = ""
                                                                                if (ancestor is None):
                                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                                else:
                                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                                leaf_name_data = LeafDataList()
                                                                                if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                                if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                                if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                                if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                                if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                                if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                                if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                                if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                                if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                                if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.res.get_name_leafdata())
                                                                                if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                                if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                                if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.stage.get_name_leafdata())
                                                                                if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                                if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                                return entity_path

                                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                                if child is not None:
                                                                                    return child

                                                                                return None

                                                                            def has_leaf_or_child_of_name(self, name):
                                                                                if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                                    return True
                                                                                return False

                                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                                if(value_path == "num-stages"):
                                                                                    self.num_stages = value
                                                                                    self.num_stages.value_namespace = name_space
                                                                                    self.num_stages.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit0"):
                                                                                    self.priority_bit0 = value
                                                                                    self.priority_bit0.value_namespace = name_space
                                                                                    self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit1"):
                                                                                    self.priority_bit1 = value
                                                                                    self.priority_bit1.value_namespace = name_space
                                                                                    self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit2"):
                                                                                    self.priority_bit2 = value
                                                                                    self.priority_bit2.value_namespace = name_space
                                                                                    self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit3"):
                                                                                    self.priority_bit3 = value
                                                                                    self.priority_bit3.value_namespace = name_space
                                                                                    self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit4"):
                                                                                    self.priority_bit4 = value
                                                                                    self.priority_bit4.value_namespace = name_space
                                                                                    self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit5"):
                                                                                    self.priority_bit5 = value
                                                                                    self.priority_bit5.value_namespace = name_space
                                                                                    self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit6"):
                                                                                    self.priority_bit6 = value
                                                                                    self.priority_bit6.value_namespace = name_space
                                                                                    self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit7"):
                                                                                    self.priority_bit7 = value
                                                                                    self.priority_bit7.value_namespace = name_space
                                                                                    self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "res"):
                                                                                    self.res = value
                                                                                    self.res.value_namespace = name_space
                                                                                    self.res.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "sbit"):
                                                                                    self.sbit = value
                                                                                    self.sbit.value_namespace = name_space
                                                                                    self.sbit.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "signal-type"):
                                                                                    self.signal_type = value
                                                                                    self.signal_type.value_namespace = name_space
                                                                                    self.signal_type.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "stage"):
                                                                                    self.stage = value
                                                                                    self.stage.value_namespace = name_space
                                                                                    self.stage.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "tbit"):
                                                                                    self.tbit = value
                                                                                    self.tbit.value_namespace = name_space
                                                                                    self.tbit.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "tsg"):
                                                                                    self.tsg = value
                                                                                    self.tsg.value_namespace = name_space
                                                                                    self.tsg.value_namespace_prefix = name_space_prefix


                                                                        class UnresOdujPrio(Entity):
                                                                            """
                                                                            Array of Unres Oduj Prio
                                                                            
                                                                            .. attribute:: entry
                                                                            
                                                                            	
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-01-02'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                                self.yang_name = "unres-oduj-prio"
                                                                                self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                                self.entry = YLeaf(YType.uint32, "entry")

                                                                            def __setattr__(self, name, value):
                                                                                self._check_monkey_patching_error(name, value)
                                                                                with _handle_type_error():
                                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                            "Please use list append or extend method."
                                                                                                            .format(value))
                                                                                    if isinstance(value, Enum.YLeaf):
                                                                                        value = value.name
                                                                                    if name in ("entry") and name in self.__dict__:
                                                                                        if isinstance(value, YLeaf):
                                                                                            self.__dict__[name].set(value.get())
                                                                                        elif isinstance(value, YLeafList):
                                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)
                                                                                        else:
                                                                                            self.__dict__[name].set(value)
                                                                                    else:
                                                                                        if hasattr(value, "parent") and name != "parent":
                                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                                value.parent = self
                                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                                value.parent = self
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)

                                                                            def has_data(self):
                                                                                return self.entry.is_set

                                                                            def has_operation(self):
                                                                                return (
                                                                                    self.yfilter != YFilter.not_set or
                                                                                    self.entry.yfilter != YFilter.not_set)

                                                                            def get_segment_path(self):
                                                                                path_buffer = ""
                                                                                path_buffer = "unres-oduj-prio" + path_buffer

                                                                                return path_buffer

                                                                            def get_entity_path(self, ancestor):
                                                                                path_buffer = ""
                                                                                if (ancestor is None):
                                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                                else:
                                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                                leaf_name_data = LeafDataList()
                                                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                                return entity_path

                                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                                if child is not None:
                                                                                    return child

                                                                                return None

                                                                            def has_leaf_or_child_of_name(self, name):
                                                                                if(name == "entry"):
                                                                                    return True
                                                                                return False

                                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                                if(value_path == "entry"):
                                                                                    self.entry = value
                                                                                    self.entry.value_namespace = name_space
                                                                                    self.entry.value_namespace_prefix = name_space_prefix

                                                                        def has_data(self):
                                                                            for c in self.unres_oduj_prio:
                                                                                if (c.has_data()):
                                                                                    return True
                                                                            return (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_data())

                                                                        def has_operation(self):
                                                                            for c in self.unres_oduj_prio:
                                                                                if (c.has_operation()):
                                                                                    return True
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_operation()))

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "fixed-bw-sub-tlv-value" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            if (child_yang_name == "fixed-sub-tlv-value"):
                                                                                if (self.fixed_sub_tlv_value is None):
                                                                                    self.fixed_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                                    self.fixed_sub_tlv_value.parent = self
                                                                                    self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                                return self.fixed_sub_tlv_value

                                                                            if (child_yang_name == "unres-oduj-prio"):
                                                                                for c in self.unres_oduj_prio:
                                                                                    segment = c.get_segment_path()
                                                                                    if (segment_path == segment):
                                                                                        return c
                                                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio()
                                                                                c.parent = self
                                                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                                                self._local_refs[local_reference_key] = c
                                                                                self.unres_oduj_prio.append(c)
                                                                                return c

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "fixed-sub-tlv-value" or name == "unres-oduj-prio"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            pass


                                                                    class FlexBwSubTlvValue(Entity):
                                                                        """
                                                                        Value of Flex Sub TLV
                                                                        
                                                                        .. attribute:: flex_sub_tlv_value_common
                                                                        
                                                                        	Flex Sub TLV Value
                                                                        	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                        
                                                                        .. attribute:: max_lspbw
                                                                        
                                                                        	Max LSP BW Array
                                                                        	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                        
                                                                        .. attribute:: unres_lspbw
                                                                        
                                                                        	Array of Unres LSP BW
                                                                        	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                            self.yang_name = "flex-bw-sub-tlv-value"
                                                                            self.yang_parent_name = "bw-sub-tlv-value"

                                                                            self.flex_sub_tlv_value_common = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                            self.flex_sub_tlv_value_common.parent = self
                                                                            self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                            self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                            self.max_lspbw = YList(self)
                                                                            self.unres_lspbw = YList(self)

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in () and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)


                                                                        class FlexSubTlvValueCommon(Entity):
                                                                            """
                                                                            Flex Sub TLV Value
                                                                            
                                                                            .. attribute:: num_stages
                                                                            
                                                                            	Number of stages
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit0
                                                                            
                                                                            	Priority 0
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit1
                                                                            
                                                                            	Priority 1
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit2
                                                                            
                                                                            	Priority 2
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit3
                                                                            
                                                                            	Priority 3
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit4
                                                                            
                                                                            	Priority 4
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit5
                                                                            
                                                                            	Priority 5
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit6
                                                                            
                                                                            	Priority 6
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit7
                                                                            
                                                                            	Priority 7
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: res
                                                                            
                                                                            	Res
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: sbit
                                                                            
                                                                            	S Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: signal_type
                                                                            
                                                                            	Signal Type
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: stage
                                                                            
                                                                            	Array of Stages
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                            
                                                                            .. attribute:: tbit
                                                                            
                                                                            	T Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: tsg
                                                                            
                                                                            	TSG
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-01-02'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                                self.yang_name = "flex-sub-tlv-value-common"
                                                                                self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                                self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                                self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                                self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                                self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                                self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                                self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                                self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                                self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                                self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                                self.res = YLeaf(YType.uint8, "res")

                                                                                self.sbit = YLeaf(YType.uint8, "sbit")

                                                                                self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                                self.stage = YLeaf(YType.str, "stage")

                                                                                self.tbit = YLeaf(YType.uint8, "tbit")

                                                                                self.tsg = YLeaf(YType.uint8, "tsg")

                                                                            def __setattr__(self, name, value):
                                                                                self._check_monkey_patching_error(name, value)
                                                                                with _handle_type_error():
                                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                            "Please use list append or extend method."
                                                                                                            .format(value))
                                                                                    if isinstance(value, Enum.YLeaf):
                                                                                        value = value.name
                                                                                    if name in ("num_stages",
                                                                                                "priority_bit0",
                                                                                                "priority_bit1",
                                                                                                "priority_bit2",
                                                                                                "priority_bit3",
                                                                                                "priority_bit4",
                                                                                                "priority_bit5",
                                                                                                "priority_bit6",
                                                                                                "priority_bit7",
                                                                                                "res",
                                                                                                "sbit",
                                                                                                "signal_type",
                                                                                                "stage",
                                                                                                "tbit",
                                                                                                "tsg") and name in self.__dict__:
                                                                                        if isinstance(value, YLeaf):
                                                                                            self.__dict__[name].set(value.get())
                                                                                        elif isinstance(value, YLeafList):
                                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)
                                                                                        else:
                                                                                            self.__dict__[name].set(value)
                                                                                    else:
                                                                                        if hasattr(value, "parent") and name != "parent":
                                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                                value.parent = self
                                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                                value.parent = self
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)

                                                                            def has_data(self):
                                                                                return (
                                                                                    self.num_stages.is_set or
                                                                                    self.priority_bit0.is_set or
                                                                                    self.priority_bit1.is_set or
                                                                                    self.priority_bit2.is_set or
                                                                                    self.priority_bit3.is_set or
                                                                                    self.priority_bit4.is_set or
                                                                                    self.priority_bit5.is_set or
                                                                                    self.priority_bit6.is_set or
                                                                                    self.priority_bit7.is_set or
                                                                                    self.res.is_set or
                                                                                    self.sbit.is_set or
                                                                                    self.signal_type.is_set or
                                                                                    self.stage.is_set or
                                                                                    self.tbit.is_set or
                                                                                    self.tsg.is_set)

                                                                            def has_operation(self):
                                                                                return (
                                                                                    self.yfilter != YFilter.not_set or
                                                                                    self.num_stages.yfilter != YFilter.not_set or
                                                                                    self.priority_bit0.yfilter != YFilter.not_set or
                                                                                    self.priority_bit1.yfilter != YFilter.not_set or
                                                                                    self.priority_bit2.yfilter != YFilter.not_set or
                                                                                    self.priority_bit3.yfilter != YFilter.not_set or
                                                                                    self.priority_bit4.yfilter != YFilter.not_set or
                                                                                    self.priority_bit5.yfilter != YFilter.not_set or
                                                                                    self.priority_bit6.yfilter != YFilter.not_set or
                                                                                    self.priority_bit7.yfilter != YFilter.not_set or
                                                                                    self.res.yfilter != YFilter.not_set or
                                                                                    self.sbit.yfilter != YFilter.not_set or
                                                                                    self.signal_type.yfilter != YFilter.not_set or
                                                                                    self.stage.yfilter != YFilter.not_set or
                                                                                    self.tbit.yfilter != YFilter.not_set or
                                                                                    self.tsg.yfilter != YFilter.not_set)

                                                                            def get_segment_path(self):
                                                                                path_buffer = ""
                                                                                path_buffer = "flex-sub-tlv-value-common" + path_buffer

                                                                                return path_buffer

                                                                            def get_entity_path(self, ancestor):
                                                                                path_buffer = ""
                                                                                if (ancestor is None):
                                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                                else:
                                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                                leaf_name_data = LeafDataList()
                                                                                if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                                if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                                if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                                if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                                if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                                if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                                if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                                if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                                if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                                if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.res.get_name_leafdata())
                                                                                if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                                if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                                if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.stage.get_name_leafdata())
                                                                                if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                                if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                                return entity_path

                                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                                if child is not None:
                                                                                    return child

                                                                                return None

                                                                            def has_leaf_or_child_of_name(self, name):
                                                                                if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                                    return True
                                                                                return False

                                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                                if(value_path == "num-stages"):
                                                                                    self.num_stages = value
                                                                                    self.num_stages.value_namespace = name_space
                                                                                    self.num_stages.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit0"):
                                                                                    self.priority_bit0 = value
                                                                                    self.priority_bit0.value_namespace = name_space
                                                                                    self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit1"):
                                                                                    self.priority_bit1 = value
                                                                                    self.priority_bit1.value_namespace = name_space
                                                                                    self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit2"):
                                                                                    self.priority_bit2 = value
                                                                                    self.priority_bit2.value_namespace = name_space
                                                                                    self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit3"):
                                                                                    self.priority_bit3 = value
                                                                                    self.priority_bit3.value_namespace = name_space
                                                                                    self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit4"):
                                                                                    self.priority_bit4 = value
                                                                                    self.priority_bit4.value_namespace = name_space
                                                                                    self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit5"):
                                                                                    self.priority_bit5 = value
                                                                                    self.priority_bit5.value_namespace = name_space
                                                                                    self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit6"):
                                                                                    self.priority_bit6 = value
                                                                                    self.priority_bit6.value_namespace = name_space
                                                                                    self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit7"):
                                                                                    self.priority_bit7 = value
                                                                                    self.priority_bit7.value_namespace = name_space
                                                                                    self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "res"):
                                                                                    self.res = value
                                                                                    self.res.value_namespace = name_space
                                                                                    self.res.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "sbit"):
                                                                                    self.sbit = value
                                                                                    self.sbit.value_namespace = name_space
                                                                                    self.sbit.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "signal-type"):
                                                                                    self.signal_type = value
                                                                                    self.signal_type.value_namespace = name_space
                                                                                    self.signal_type.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "stage"):
                                                                                    self.stage = value
                                                                                    self.stage.value_namespace = name_space
                                                                                    self.stage.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "tbit"):
                                                                                    self.tbit = value
                                                                                    self.tbit.value_namespace = name_space
                                                                                    self.tbit.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "tsg"):
                                                                                    self.tsg = value
                                                                                    self.tsg.value_namespace = name_space
                                                                                    self.tsg.value_namespace_prefix = name_space_prefix


                                                                        class UnresLspbw(Entity):
                                                                            """
                                                                            Array of Unres LSP BW
                                                                            
                                                                            .. attribute:: entry
                                                                            
                                                                            	
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..18446744073709551615
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-01-02'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                                self.yang_name = "unres-lspbw"
                                                                                self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                                self.entry = YLeaf(YType.uint64, "entry")

                                                                            def __setattr__(self, name, value):
                                                                                self._check_monkey_patching_error(name, value)
                                                                                with _handle_type_error():
                                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                            "Please use list append or extend method."
                                                                                                            .format(value))
                                                                                    if isinstance(value, Enum.YLeaf):
                                                                                        value = value.name
                                                                                    if name in ("entry") and name in self.__dict__:
                                                                                        if isinstance(value, YLeaf):
                                                                                            self.__dict__[name].set(value.get())
                                                                                        elif isinstance(value, YLeafList):
                                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)
                                                                                        else:
                                                                                            self.__dict__[name].set(value)
                                                                                    else:
                                                                                        if hasattr(value, "parent") and name != "parent":
                                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                                value.parent = self
                                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                                value.parent = self
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)

                                                                            def has_data(self):
                                                                                return self.entry.is_set

                                                                            def has_operation(self):
                                                                                return (
                                                                                    self.yfilter != YFilter.not_set or
                                                                                    self.entry.yfilter != YFilter.not_set)

                                                                            def get_segment_path(self):
                                                                                path_buffer = ""
                                                                                path_buffer = "unres-lspbw" + path_buffer

                                                                                return path_buffer

                                                                            def get_entity_path(self, ancestor):
                                                                                path_buffer = ""
                                                                                if (ancestor is None):
                                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                                else:
                                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                                leaf_name_data = LeafDataList()
                                                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                                return entity_path

                                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                                if child is not None:
                                                                                    return child

                                                                                return None

                                                                            def has_leaf_or_child_of_name(self, name):
                                                                                if(name == "entry"):
                                                                                    return True
                                                                                return False

                                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                                if(value_path == "entry"):
                                                                                    self.entry = value
                                                                                    self.entry.value_namespace = name_space
                                                                                    self.entry.value_namespace_prefix = name_space_prefix


                                                                        class MaxLspbw(Entity):
                                                                            """
                                                                            Max LSP BW Array
                                                                            
                                                                            .. attribute:: entry
                                                                            
                                                                            	
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..18446744073709551615
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-01-02'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                                self.yang_name = "max-lspbw"
                                                                                self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                                self.entry = YLeaf(YType.uint64, "entry")

                                                                            def __setattr__(self, name, value):
                                                                                self._check_monkey_patching_error(name, value)
                                                                                with _handle_type_error():
                                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                            "Please use list append or extend method."
                                                                                                            .format(value))
                                                                                    if isinstance(value, Enum.YLeaf):
                                                                                        value = value.name
                                                                                    if name in ("entry") and name in self.__dict__:
                                                                                        if isinstance(value, YLeaf):
                                                                                            self.__dict__[name].set(value.get())
                                                                                        elif isinstance(value, YLeafList):
                                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                                        else:
                                                                                            self.__dict__[name].set(value)
                                                                                    else:
                                                                                        if hasattr(value, "parent") and name != "parent":
                                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                                value.parent = self
                                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                                value.parent = self
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)

                                                                            def has_data(self):
                                                                                return self.entry.is_set

                                                                            def has_operation(self):
                                                                                return (
                                                                                    self.yfilter != YFilter.not_set or
                                                                                    self.entry.yfilter != YFilter.not_set)

                                                                            def get_segment_path(self):
                                                                                path_buffer = ""
                                                                                path_buffer = "max-lspbw" + path_buffer

                                                                                return path_buffer

                                                                            def get_entity_path(self, ancestor):
                                                                                path_buffer = ""
                                                                                if (ancestor is None):
                                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                                else:
                                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                                leaf_name_data = LeafDataList()
                                                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                                return entity_path

                                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                                if child is not None:
                                                                                    return child

                                                                                return None

                                                                            def has_leaf_or_child_of_name(self, name):
                                                                                if(name == "entry"):
                                                                                    return True
                                                                                return False

                                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                                if(value_path == "entry"):
                                                                                    self.entry = value
                                                                                    self.entry.value_namespace = name_space
                                                                                    self.entry.value_namespace_prefix = name_space_prefix

                                                                        def has_data(self):
                                                                            for c in self.max_lspbw:
                                                                                if (c.has_data()):
                                                                                    return True
                                                                            for c in self.unres_lspbw:
                                                                                if (c.has_data()):
                                                                                    return True
                                                                            return (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_data())

                                                                        def has_operation(self):
                                                                            for c in self.max_lspbw:
                                                                                if (c.has_operation()):
                                                                                    return True
                                                                            for c in self.unres_lspbw:
                                                                                if (c.has_operation()):
                                                                                    return True
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_operation()))

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "flex-bw-sub-tlv-value" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            if (child_yang_name == "flex-sub-tlv-value-common"):
                                                                                if (self.flex_sub_tlv_value_common is None):
                                                                                    self.flex_sub_tlv_value_common = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                                    self.flex_sub_tlv_value_common.parent = self
                                                                                    self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                                return self.flex_sub_tlv_value_common

                                                                            if (child_yang_name == "max-lspbw"):
                                                                                for c in self.max_lspbw:
                                                                                    segment = c.get_segment_path()
                                                                                    if (segment_path == segment):
                                                                                        return c
                                                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw()
                                                                                c.parent = self
                                                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                                                self._local_refs[local_reference_key] = c
                                                                                self.max_lspbw.append(c)
                                                                                return c

                                                                            if (child_yang_name == "unres-lspbw"):
                                                                                for c in self.unres_lspbw:
                                                                                    segment = c.get_segment_path()
                                                                                    if (segment_path == segment):
                                                                                        return c
                                                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw()
                                                                                c.parent = self
                                                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                                                self._local_refs[local_reference_key] = c
                                                                                self.unres_lspbw.append(c)
                                                                                return c

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "flex-sub-tlv-value-common" or name == "max-lspbw" or name == "unres-lspbw"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            pass

                                                                    def has_data(self):
                                                                        return (
                                                                            self.ixcdbw_sub_tlv_type.is_set or
                                                                            (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_data()) or
                                                                            (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_data()))

                                                                    def has_operation(self):
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                            (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_operation()) or
                                                                            (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_operation()))

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "bw-sub-tlv-value" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()
                                                                        if (self.ixcdbw_sub_tlv_type.is_set or self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.ixcdbw_sub_tlv_type.get_name_leafdata())

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        if (child_yang_name == "fixed-bw-sub-tlv-value"):
                                                                            if (self.fixed_bw_sub_tlv_value is None):
                                                                                self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                                self.fixed_bw_sub_tlv_value.parent = self
                                                                                self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                            return self.fixed_bw_sub_tlv_value

                                                                        if (child_yang_name == "flex-bw-sub-tlv-value"):
                                                                            if (self.flex_bw_sub_tlv_value is None):
                                                                                self.flex_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                                self.flex_bw_sub_tlv_value.parent = self
                                                                                self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                            return self.flex_bw_sub_tlv_value

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "fixed-bw-sub-tlv-value" or name == "flex-bw-sub-tlv-value" or name == "ixcdbw-sub-tlv-type"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        if(value_path == "ixcdbw-sub-tlv-type"):
                                                                            self.ixcdbw_sub_tlv_type = value
                                                                            self.ixcdbw_sub_tlv_type.value_namespace = name_space
                                                                            self.ixcdbw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                                def has_data(self):
                                                                    return (
                                                                        self.bw_sub_tlv_length.is_set or
                                                                        self.bw_sub_tlv_type.is_set or
                                                                        (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_data()))

                                                                def has_operation(self):
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.bw_sub_tlv_length.yfilter != YFilter.not_set or
                                                                        self.bw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                        (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_operation()))

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "arr-bw-sub-tlv" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.bw_sub_tlv_length.is_set or self.bw_sub_tlv_length.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.bw_sub_tlv_length.get_name_leafdata())
                                                                    if (self.bw_sub_tlv_type.is_set or self.bw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.bw_sub_tlv_type.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    if (child_yang_name == "bw-sub-tlv-value"):
                                                                        if (self.bw_sub_tlv_value is None):
                                                                            self.bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                            self.bw_sub_tlv_value.parent = self
                                                                            self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                        return self.bw_sub_tlv_value

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "bw-sub-tlv-value" or name == "bw-sub-tlv-length" or name == "bw-sub-tlv-type"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "bw-sub-tlv-length"):
                                                                        self.bw_sub_tlv_length = value
                                                                        self.bw_sub_tlv_length.value_namespace = name_space
                                                                        self.bw_sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "bw-sub-tlv-type"):
                                                                        self.bw_sub_tlv_type = value
                                                                        self.bw_sub_tlv_type.value_namespace = name_space
                                                                        self.bw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.arr_bw_sub_tlv:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.arr_bw_sub_tlv:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "ixcdbw-sub-tlv" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "arr-bw-sub-tlv"):
                                                                    for c in self.arr_bw_sub_tlv:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.arr_bw_sub_tlv.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "arr-bw-sub-tlv"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.switching_cap_type.is_set or
                                                                (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_data()) or
                                                                (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.switching_cap_type.yfilter != YFilter.not_set or
                                                                (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_operation()) or
                                                                (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ixcd-switching-cap-type" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.switching_cap_type.is_set or self.switching_cap_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.switching_cap_type.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "ixcdbw-sub-tlv"):
                                                                if (self.ixcdbw_sub_tlv is None):
                                                                    self.ixcdbw_sub_tlv = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                                    self.ixcdbw_sub_tlv.parent = self
                                                                    self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                                return self.ixcdbw_sub_tlv

                                                            if (child_yang_name == "ixcdpsc-info"):
                                                                if (self.ixcdpsc_info is None):
                                                                    self.ixcdpsc_info = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                                    self.ixcdpsc_info.parent = self
                                                                    self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                                return self.ixcdpsc_info

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "ixcdbw-sub-tlv" or name == "ixcdpsc-info" or name == "switching-cap-type"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "switching-cap-type"):
                                                                self.switching_cap_type = value
                                                                self.switching_cap_type.value_namespace = name_space
                                                                self.switching_cap_type.value_namespace_prefix = name_space_prefix


                                                    class MaxLspbw(Entity):
                                                        """
                                                        Max LSP bandwidth array
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-9223372036854775808..9223372036854775807
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                            self.yang_name = "max-lspbw"
                                                            self.yang_parent_name = "ixcdtlv-value"

                                                            self.entry = YLeaf(YType.int64, "entry")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("entry") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return self.entry.is_set

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.entry.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "max-lspbw" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "entry"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "entry"):
                                                                self.entry = value
                                                                self.entry.value_namespace = name_space
                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.max_lspbw:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.fixed_scsi_count.is_set or
                                                            self.flex_scsi_count.is_set or
                                                            self.rile_len_code.is_set or
                                                            self.switching_cap.is_set or
                                                            (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_data()))

                                                    def has_operation(self):
                                                        for c in self.max_lspbw:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.fixed_scsi_count.yfilter != YFilter.not_set or
                                                            self.flex_scsi_count.yfilter != YFilter.not_set or
                                                            self.rile_len_code.yfilter != YFilter.not_set or
                                                            self.switching_cap.yfilter != YFilter.not_set or
                                                            (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_operation()))

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ixcdtlv-value" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.fixed_scsi_count.is_set or self.fixed_scsi_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.fixed_scsi_count.get_name_leafdata())
                                                        if (self.flex_scsi_count.is_set or self.flex_scsi_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flex_scsi_count.get_name_leafdata())
                                                        if (self.rile_len_code.is_set or self.rile_len_code.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rile_len_code.get_name_leafdata())
                                                        if (self.switching_cap.is_set or self.switching_cap.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.switching_cap.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ixcd-switching-cap-type"):
                                                            if (self.ixcd_switching_cap_type is None):
                                                                self.ixcd_switching_cap_type = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                                self.ixcd_switching_cap_type.parent = self
                                                                self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                            return self.ixcd_switching_cap_type

                                                        if (child_yang_name == "max-lspbw"):
                                                            for c in self.max_lspbw:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.max_lspbw.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ixcd-switching-cap-type" or name == "max-lspbw" or name == "fixed-scsi-count" or name == "flex-scsi-count" or name == "rile-len-code" or name == "switching-cap"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "fixed-scsi-count"):
                                                            self.fixed_scsi_count = value
                                                            self.fixed_scsi_count.value_namespace = name_space
                                                            self.fixed_scsi_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flex-scsi-count"):
                                                            self.flex_scsi_count = value
                                                            self.flex_scsi_count.value_namespace = name_space
                                                            self.flex_scsi_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rile-len-code"):
                                                            self.rile_len_code = value
                                                            self.rile_len_code.value_namespace = name_space
                                                            self.rile_len_code.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "switching-cap"):
                                                            self.switching_cap = value
                                                            self.switching_cap.value_namespace = name_space
                                                            self.switching_cap.value_namespace_prefix = name_space_prefix


                                                class UnidtlvValue(Entity):
                                                    """
                                                    Value of Uni Delay TLV
                                                    
                                                    .. attribute:: uni_dir_delay
                                                    
                                                    	Uni Dir Delay
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                        self.yang_name = "unidtlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                        self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("uni_dir_delay") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.uni_dir_delay.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.uni_dir_delay.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "unidtlv-value" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.uni_dir_delay.is_set or self.uni_dir_delay.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.uni_dir_delay.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "uni-dir-delay"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "uni-dir-delay"):
                                                            self.uni_dir_delay = value
                                                            self.uni_dir_delay.value_namespace = name_space
                                                            self.uni_dir_delay.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.opaque_tlv_type.is_set or
                                                        (self.bctlv_value is not None and self.bctlv_value.has_data()) or
                                                        (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_data()) or
                                                        (self.srlgtlv_value is not None and self.srlgtlv_value.has_data()) or
                                                        (self.unidtlv_value is not None and self.unidtlv_value.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.opaque_tlv_type.yfilter != YFilter.not_set or
                                                        (self.bctlv_value is not None and self.bctlv_value.has_operation()) or
                                                        (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_operation()) or
                                                        (self.srlgtlv_value is not None and self.srlgtlv_value.has_operation()) or
                                                        (self.unidtlv_value is not None and self.unidtlv_value.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "mplste-link-opt-tlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.opaque_tlv_type.is_set or self.opaque_tlv_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.opaque_tlv_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "bctlv-value"):
                                                        if (self.bctlv_value is None):
                                                            self.bctlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                            self.bctlv_value.parent = self
                                                            self._children_name_map["bctlv_value"] = "bctlv-value"
                                                        return self.bctlv_value

                                                    if (child_yang_name == "ixcdtlv-value"):
                                                        if (self.ixcdtlv_value is None):
                                                            self.ixcdtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                            self.ixcdtlv_value.parent = self
                                                            self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                        return self.ixcdtlv_value

                                                    if (child_yang_name == "srlgtlv-value"):
                                                        if (self.srlgtlv_value is None):
                                                            self.srlgtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                            self.srlgtlv_value.parent = self
                                                            self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                        return self.srlgtlv_value

                                                    if (child_yang_name == "unidtlv-value"):
                                                        if (self.unidtlv_value is None):
                                                            self.unidtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                            self.unidtlv_value.parent = self
                                                            self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                        return self.unidtlv_value

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bctlv-value" or name == "ixcdtlv-value" or name == "srlgtlv-value" or name == "unidtlv-value" or name == "opaque-tlv-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "opaque-tlv-type"):
                                                        self.opaque_tlv_type = value
                                                        self.opaque_tlv_type.value_namespace = name_space
                                                        self.opaque_tlv_type.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.mplste_link_opt_tlv_value:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.mplste_link_opt_tlv_len.is_set or
                                                    self.mplste_link_opt_tlv_type.is_set)

                                            def has_operation(self):
                                                for c in self.mplste_link_opt_tlv_value:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set or
                                                    self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mplste-link-opt-tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.mplste_link_opt_tlv_len.is_set or self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mplste_link_opt_tlv_len.get_name_leafdata())
                                                if (self.mplste_link_opt_tlv_type.is_set or self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mplste_link_opt_tlv_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "mplste-link-opt-tlv-value"):
                                                    for c in self.mplste_link_opt_tlv_value:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.mplste_link_opt_tlv_value.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "mplste-link-opt-tlv-value" or name == "mplste-link-opt-tlv-len" or name == "mplste-link-opt-tlv-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "mplste-link-opt-tlv-len"):
                                                    self.mplste_link_opt_tlv_len = value
                                                    self.mplste_link_opt_tlv_len.value_namespace = name_space
                                                    self.mplste_link_opt_tlv_len.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mplste-link-opt-tlv-type"):
                                                    self.mplste_link_opt_tlv_type = value
                                                    self.mplste_link_opt_tlv_type.value_namespace = name_space
                                                    self.mplste_link_opt_tlv_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.mplste_link_opt_tlv:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.affinity.is_set or
                                                self.dste_allocation_model_id.is_set or
                                                self.dste_in_use.is_set or
                                                self.fragment_id.is_set or
                                                self.igp_metric.is_set or
                                                self.input_interface_id.is_set or
                                                self.link_address.is_set or
                                                self.maximum_link_bw.is_set or
                                                self.maximum_link_reservable_bw.is_set or
                                                self.maximum_link_sub_reservable_bw.is_set or
                                                self.mpls_link_instance.is_set or
                                                self.mpls_link_type.is_set or
                                                self.neighbor_ip_address.is_set or
                                                self.neighbor_system_id.is_set or
                                                self.new_link.is_set or
                                                self.number_of_optional_tl_vs.is_set or
                                                self.output_interface_id.is_set or
                                                self.priority_count.is_set or
                                                self.te_metric.is_set or
                                                (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_data()) or
                                                (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_data()) or
                                                (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_data()) or
                                                (self.link_sw_capability is not None and self.link_sw_capability.has_data()) or
                                                (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_data()))

                                        def has_operation(self):
                                            for c in self.mplste_link_opt_tlv:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.affinity.yfilter != YFilter.not_set or
                                                self.dste_allocation_model_id.yfilter != YFilter.not_set or
                                                self.dste_in_use.yfilter != YFilter.not_set or
                                                self.fragment_id.yfilter != YFilter.not_set or
                                                self.igp_metric.yfilter != YFilter.not_set or
                                                self.input_interface_id.yfilter != YFilter.not_set or
                                                self.link_address.yfilter != YFilter.not_set or
                                                self.maximum_link_bw.yfilter != YFilter.not_set or
                                                self.maximum_link_reservable_bw.yfilter != YFilter.not_set or
                                                self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set or
                                                self.mpls_link_instance.yfilter != YFilter.not_set or
                                                self.mpls_link_type.yfilter != YFilter.not_set or
                                                self.neighbor_ip_address.yfilter != YFilter.not_set or
                                                self.neighbor_system_id.yfilter != YFilter.not_set or
                                                self.new_link.yfilter != YFilter.not_set or
                                                self.number_of_optional_tl_vs.yfilter != YFilter.not_set or
                                                self.output_interface_id.yfilter != YFilter.not_set or
                                                self.priority_count.yfilter != YFilter.not_set or
                                                self.te_metric.yfilter != YFilter.not_set or
                                                (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_operation()) or
                                                (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_operation()) or
                                                (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_operation()) or
                                                (self.link_sw_capability is not None and self.link_sw_capability.has_operation()) or
                                                (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mpls-te-link" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.affinity.is_set or self.affinity.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.affinity.get_name_leafdata())
                                            if (self.dste_allocation_model_id.is_set or self.dste_allocation_model_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dste_allocation_model_id.get_name_leafdata())
                                            if (self.dste_in_use.is_set or self.dste_in_use.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dste_in_use.get_name_leafdata())
                                            if (self.fragment_id.is_set or self.fragment_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fragment_id.get_name_leafdata())
                                            if (self.igp_metric.is_set or self.igp_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igp_metric.get_name_leafdata())
                                            if (self.input_interface_id.is_set or self.input_interface_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.input_interface_id.get_name_leafdata())
                                            if (self.link_address.is_set or self.link_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_address.get_name_leafdata())
                                            if (self.maximum_link_bw.is_set or self.maximum_link_bw.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_link_bw.get_name_leafdata())
                                            if (self.maximum_link_reservable_bw.is_set or self.maximum_link_reservable_bw.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_link_reservable_bw.get_name_leafdata())
                                            if (self.maximum_link_sub_reservable_bw.is_set or self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_link_sub_reservable_bw.get_name_leafdata())
                                            if (self.mpls_link_instance.is_set or self.mpls_link_instance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mpls_link_instance.get_name_leafdata())
                                            if (self.mpls_link_type.is_set or self.mpls_link_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mpls_link_type.get_name_leafdata())
                                            if (self.neighbor_ip_address.is_set or self.neighbor_ip_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_ip_address.get_name_leafdata())
                                            if (self.neighbor_system_id.is_set or self.neighbor_system_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_system_id.get_name_leafdata())
                                            if (self.new_link.is_set or self.new_link.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.new_link.get_name_leafdata())
                                            if (self.number_of_optional_tl_vs.is_set or self.number_of_optional_tl_vs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.number_of_optional_tl_vs.get_name_leafdata())
                                            if (self.output_interface_id.is_set or self.output_interface_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.output_interface_id.get_name_leafdata())
                                            if (self.priority_count.is_set or self.priority_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.priority_count.get_name_leafdata())
                                            if (self.te_metric.is_set or self.te_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.te_metric.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "extended-admin-group-list"):
                                                if (self.extended_admin_group_list is None):
                                                    self.extended_admin_group_list = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                                    self.extended_admin_group_list.parent = self
                                                    self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                                return self.extended_admin_group_list

                                            if (child_yang_name == "global-unreserve-bw-per-priority"):
                                                if (self.global_unreserve_bw_per_priority is None):
                                                    self.global_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                                    self.global_unreserve_bw_per_priority.parent = self
                                                    self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                                return self.global_unreserve_bw_per_priority

                                            if (child_yang_name == "link-protocol-priority-capability"):
                                                if (self.link_protocol_priority_capability is None):
                                                    self.link_protocol_priority_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                                    self.link_protocol_priority_capability.parent = self
                                                    self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                                return self.link_protocol_priority_capability

                                            if (child_yang_name == "link-sw-capability"):
                                                if (self.link_sw_capability is None):
                                                    self.link_sw_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                                    self.link_sw_capability.parent = self
                                                    self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                                return self.link_sw_capability

                                            if (child_yang_name == "mplste-link-opt-tlv"):
                                                for c in self.mplste_link_opt_tlv:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.mplste_link_opt_tlv.append(c)
                                                return c

                                            if (child_yang_name == "sub-pool-unreserve-bw-per-priority"):
                                                if (self.sub_pool_unreserve_bw_per_priority is None):
                                                    self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                                    self.sub_pool_unreserve_bw_per_priority.parent = self
                                                    self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                                return self.sub_pool_unreserve_bw_per_priority

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "extended-admin-group-list" or name == "global-unreserve-bw-per-priority" or name == "link-protocol-priority-capability" or name == "link-sw-capability" or name == "mplste-link-opt-tlv" or name == "sub-pool-unreserve-bw-per-priority" or name == "affinity" or name == "dste-allocation-model-id" or name == "dste-in-use" or name == "fragment-id" or name == "igp-metric" or name == "input-interface-id" or name == "link-address" or name == "maximum-link-bw" or name == "maximum-link-reservable-bw" or name == "maximum-link-sub-reservable-bw" or name == "mpls-link-instance" or name == "mpls-link-type" or name == "neighbor-ip-address" or name == "neighbor-system-id" or name == "new-link" or name == "number-of-optional-tl-vs" or name == "output-interface-id" or name == "priority-count" or name == "te-metric"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "affinity"):
                                                self.affinity = value
                                                self.affinity.value_namespace = name_space
                                                self.affinity.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dste-allocation-model-id"):
                                                self.dste_allocation_model_id = value
                                                self.dste_allocation_model_id.value_namespace = name_space
                                                self.dste_allocation_model_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dste-in-use"):
                                                self.dste_in_use = value
                                                self.dste_in_use.value_namespace = name_space
                                                self.dste_in_use.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fragment-id"):
                                                self.fragment_id = value
                                                self.fragment_id.value_namespace = name_space
                                                self.fragment_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igp-metric"):
                                                self.igp_metric = value
                                                self.igp_metric.value_namespace = name_space
                                                self.igp_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "input-interface-id"):
                                                self.input_interface_id = value
                                                self.input_interface_id.value_namespace = name_space
                                                self.input_interface_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-address"):
                                                self.link_address = value
                                                self.link_address.value_namespace = name_space
                                                self.link_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-link-bw"):
                                                self.maximum_link_bw = value
                                                self.maximum_link_bw.value_namespace = name_space
                                                self.maximum_link_bw.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-link-reservable-bw"):
                                                self.maximum_link_reservable_bw = value
                                                self.maximum_link_reservable_bw.value_namespace = name_space
                                                self.maximum_link_reservable_bw.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-link-sub-reservable-bw"):
                                                self.maximum_link_sub_reservable_bw = value
                                                self.maximum_link_sub_reservable_bw.value_namespace = name_space
                                                self.maximum_link_sub_reservable_bw.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mpls-link-instance"):
                                                self.mpls_link_instance = value
                                                self.mpls_link_instance.value_namespace = name_space
                                                self.mpls_link_instance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mpls-link-type"):
                                                self.mpls_link_type = value
                                                self.mpls_link_type.value_namespace = name_space
                                                self.mpls_link_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-ip-address"):
                                                self.neighbor_ip_address = value
                                                self.neighbor_ip_address.value_namespace = name_space
                                                self.neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-system-id"):
                                                self.neighbor_system_id = value
                                                self.neighbor_system_id.value_namespace = name_space
                                                self.neighbor_system_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "new-link"):
                                                self.new_link = value
                                                self.new_link.value_namespace = name_space
                                                self.new_link.value_namespace_prefix = name_space_prefix
                                            if(value_path == "number-of-optional-tl-vs"):
                                                self.number_of_optional_tl_vs = value
                                                self.number_of_optional_tl_vs.value_namespace = name_space
                                                self.number_of_optional_tl_vs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "output-interface-id"):
                                                self.output_interface_id = value
                                                self.output_interface_id.value_namespace = name_space
                                                self.output_interface_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "priority-count"):
                                                self.priority_count = value
                                                self.priority_count.value_namespace = name_space
                                                self.priority_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "te-metric"):
                                                self.te_metric = value
                                                self.te_metric.value_namespace = name_space
                                                self.te_metric.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.mpls_te_link:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.dste_model_id.is_set or
                                            self.fragment_id.is_set or
                                            self.fragment_instance.is_set or
                                            self.same_fragment_count.is_set)

                                    def has_operation(self):
                                        for c in self.mpls_te_link:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dste_model_id.yfilter != YFilter.not_set or
                                            self.fragment_id.yfilter != YFilter.not_set or
                                            self.fragment_instance.yfilter != YFilter.not_set or
                                            self.same_fragment_count.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls-te-fragment" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dste_model_id.is_set or self.dste_model_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dste_model_id.get_name_leafdata())
                                        if (self.fragment_id.is_set or self.fragment_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fragment_id.get_name_leafdata())
                                        if (self.fragment_instance.is_set or self.fragment_instance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fragment_instance.get_name_leafdata())
                                        if (self.same_fragment_count.is_set or self.same_fragment_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.same_fragment_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "mpls-te-link"):
                                            for c in self.mpls_te_link:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.mpls_te_link.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mpls-te-link" or name == "dste-model-id" or name == "fragment-id" or name == "fragment-instance" or name == "same-fragment-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dste-model-id"):
                                            self.dste_model_id = value
                                            self.dste_model_id.value_namespace = name_space
                                            self.dste_model_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fragment-id"):
                                            self.fragment_id = value
                                            self.fragment_id.value_namespace = name_space
                                            self.fragment_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fragment-instance"):
                                            self.fragment_instance = value
                                            self.fragment_instance.value_namespace = name_space
                                            self.fragment_instance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "same-fragment-count"):
                                            self.same_fragment_count = value
                                            self.same_fragment_count.value_namespace = name_space
                                            self.same_fragment_count.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.mpls_te_fragment:
                                        if (c.has_data()):
                                            return True
                                    for c in self.mpls_te_link:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.area_id.is_set or
                                        self.mpls_te_area_id.is_set or
                                        self.mpls_te_area_instance.is_set or
                                        self.mpls_te_enabled.is_set or
                                        self.mpls_te_initialized.is_set or
                                        self.mpls_te_next_fragment_id.is_set or
                                        self.mpls_te_router_address.is_set or
                                        self.mpls_te_router_id.is_set or
                                        self.spacious_fragment.is_set)

                                def has_operation(self):
                                    for c in self.mpls_te_fragment:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.mpls_te_link:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.mpls_te_area_id.yfilter != YFilter.not_set or
                                        self.mpls_te_area_instance.yfilter != YFilter.not_set or
                                        self.mpls_te_enabled.yfilter != YFilter.not_set or
                                        self.mpls_te_initialized.yfilter != YFilter.not_set or
                                        self.mpls_te_next_fragment_id.yfilter != YFilter.not_set or
                                        self.mpls_te_router_address.yfilter != YFilter.not_set or
                                        self.mpls_te_router_id.yfilter != YFilter.not_set or
                                        self.spacious_fragment.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mpls-te-link" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.mpls_te_area_id.is_set or self.mpls_te_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_area_id.get_name_leafdata())
                                    if (self.mpls_te_area_instance.is_set or self.mpls_te_area_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_area_instance.get_name_leafdata())
                                    if (self.mpls_te_enabled.is_set or self.mpls_te_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_enabled.get_name_leafdata())
                                    if (self.mpls_te_initialized.is_set or self.mpls_te_initialized.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_initialized.get_name_leafdata())
                                    if (self.mpls_te_next_fragment_id.is_set or self.mpls_te_next_fragment_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_next_fragment_id.get_name_leafdata())
                                    if (self.mpls_te_router_address.is_set or self.mpls_te_router_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_router_address.get_name_leafdata())
                                    if (self.mpls_te_router_id.is_set or self.mpls_te_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_router_id.get_name_leafdata())
                                    if (self.spacious_fragment.is_set or self.spacious_fragment.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spacious_fragment.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "mpls-te-fragment"):
                                        for c in self.mpls_te_fragment:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.mpls_te_fragment.append(c)
                                        return c

                                    if (child_yang_name == "mpls-te-link"):
                                        for c in self.mpls_te_link:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.mpls_te_link.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mpls-te-fragment" or name == "mpls-te-link" or name == "area-id" or name == "mpls-te-area-id" or name == "mpls-te-area-instance" or name == "mpls-te-enabled" or name == "mpls-te-initialized" or name == "mpls-te-next-fragment-id" or name == "mpls-te-router-address" or name == "mpls-te-router-id" or name == "spacious-fragment"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-area-id"):
                                        self.mpls_te_area_id = value
                                        self.mpls_te_area_id.value_namespace = name_space
                                        self.mpls_te_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-area-instance"):
                                        self.mpls_te_area_instance = value
                                        self.mpls_te_area_instance.value_namespace = name_space
                                        self.mpls_te_area_instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-enabled"):
                                        self.mpls_te_enabled = value
                                        self.mpls_te_enabled.value_namespace = name_space
                                        self.mpls_te_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-initialized"):
                                        self.mpls_te_initialized = value
                                        self.mpls_te_initialized.value_namespace = name_space
                                        self.mpls_te_initialized.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-next-fragment-id"):
                                        self.mpls_te_next_fragment_id = value
                                        self.mpls_te_next_fragment_id.value_namespace = name_space
                                        self.mpls_te_next_fragment_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-router-address"):
                                        self.mpls_te_router_address = value
                                        self.mpls_te_router_address.value_namespace = name_space
                                        self.mpls_te_router_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-router-id"):
                                        self.mpls_te_router_id = value
                                        self.mpls_te_router_id.value_namespace = name_space
                                        self.mpls_te_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spacious-fragment"):
                                        self.spacious_fragment = value
                                        self.spacious_fragment.value_namespace = name_space
                                        self.spacious_fragment.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.mpls_te_link:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.mpls_te_link:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mpls-te-links" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mpls-te-link"):
                                    for c in self.mpls_te_link:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.mpls_te_link.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mpls-te-link"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class MplsTeFragments(Entity):
                            """
                            MPLS TE Fragment information table
                            
                            .. attribute:: mpls_te_fragment
                            
                            	MPLS TE Fragment
                            	**type**\: list of    :py:class:`MplsTeFragment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments, self).__init__()

                                self.yang_name = "mpls-te-fragments"
                                self.yang_parent_name = "mpls-te"

                                self.mpls_te_fragment = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments, self).__setattr__(name, value)


                            class MplsTeFragment(Entity):
                                """
                                MPLS TE Fragment
                                
                                .. attribute:: area_id  <key>
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mpls_te_area_id
                                
                                	Area ID string in decimal or dotted decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: mpls_te_area_instance
                                
                                	Area information instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_te_enabled
                                
                                	If true, MPLS\-TE enabled in area
                                	**type**\:  bool
                                
                                .. attribute:: mpls_te_fragment
                                
                                	MPLS TE fragments in the area
                                	**type**\: list of    :py:class:`MplsTeFragment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment>`
                                
                                .. attribute:: mpls_te_initialized
                                
                                	If true, MPLS\-TE initialized in the area
                                	**type**\:  bool
                                
                                .. attribute:: mpls_te_link
                                
                                	MPLS\-TE links in the area
                                	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink>`
                                
                                .. attribute:: mpls_te_next_fragment_id
                                
                                	Next MPLS\-TE fragment ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_te_router_address
                                
                                	MPLS\-TE router address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mpls_te_router_id
                                
                                	OSPF MPLS\-TE router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: spacious_fragment
                                
                                	If true, fragment has space for next link
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment, self).__init__()

                                    self.yang_name = "mpls-te-fragment"
                                    self.yang_parent_name = "mpls-te-fragments"

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.mpls_te_area_id = YLeaf(YType.str, "mpls-te-area-id")

                                    self.mpls_te_area_instance = YLeaf(YType.uint32, "mpls-te-area-instance")

                                    self.mpls_te_enabled = YLeaf(YType.boolean, "mpls-te-enabled")

                                    self.mpls_te_initialized = YLeaf(YType.boolean, "mpls-te-initialized")

                                    self.mpls_te_next_fragment_id = YLeaf(YType.uint32, "mpls-te-next-fragment-id")

                                    self.mpls_te_router_address = YLeaf(YType.str, "mpls-te-router-address")

                                    self.mpls_te_router_id = YLeaf(YType.str, "mpls-te-router-id")

                                    self.spacious_fragment = YLeaf(YType.boolean, "spacious-fragment")

                                    self.mpls_te_fragment = YList(self)
                                    self.mpls_te_link = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_id",
                                                    "mpls_te_area_id",
                                                    "mpls_te_area_instance",
                                                    "mpls_te_enabled",
                                                    "mpls_te_initialized",
                                                    "mpls_te_next_fragment_id",
                                                    "mpls_te_router_address",
                                                    "mpls_te_router_id",
                                                    "spacious_fragment") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment, self).__setattr__(name, value)


                                class MplsTeLink(Entity):
                                    """
                                    MPLS\-TE links in the area
                                    
                                    .. attribute:: affinity
                                    
                                    	Affinity
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dste_allocation_model_id
                                    
                                    	DS\-TE Allocation Model ID
                                    	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                    
                                    .. attribute:: dste_in_use
                                    
                                    	A DS\-TE Allocation Model in use
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_admin_group_list
                                    
                                    	Extended Admin Group
                                    	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList>`
                                    
                                    .. attribute:: fragment_id
                                    
                                    	Fragment ID for this link
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: global_unreserve_bw_per_priority
                                    
                                    	Global pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                    
                                    .. attribute:: igp_metric
                                    
                                    	Link IGP metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: input_interface_id
                                    
                                    	Input interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_address
                                    
                                    	The local interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: link_protocol_priority_capability
                                    
                                    	Link protocol and protocol priority capability
                                    	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability>`
                                    
                                    .. attribute:: link_sw_capability
                                    
                                    	Link switching capability
                                    	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability>`
                                    
                                    .. attribute:: maximum_link_bw
                                    
                                    	Maximum link bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_reservable_bw
                                    
                                    	Maximum link global pool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_sub_reservable_bw
                                    
                                    	Maximum link subpool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: mpls_link_instance
                                    
                                    	Link instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mpls_link_type
                                    
                                    	Type of link
                                    	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                    
                                    .. attribute:: mplste_link_opt_tlv
                                    
                                    	List of Optional TLVs
                                    	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv>`
                                    
                                    .. attribute:: neighbor_ip_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_system_id
                                    
                                    	Neighbor system ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: new_link
                                    
                                    	If true, Link is new
                                    	**type**\:  bool
                                    
                                    .. attribute:: number_of_optional_tl_vs
                                    
                                    	Number of Optional TLVs
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: output_interface_id
                                    
                                    	Output interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: priority_count
                                    
                                    	Number of priorities
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_pool_unreserve_bw_per_priority
                                    
                                    	Sub pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                    
                                    .. attribute:: te_metric
                                    
                                    	Link TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink, self).__init__()

                                        self.yang_name = "mpls-te-link"
                                        self.yang_parent_name = "mpls-te-fragment"

                                        self.affinity = YLeaf(YType.uint32, "affinity")

                                        self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                        self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                        self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                        self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                        self.link_address = YLeaf(YType.str, "link-address")

                                        self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                        self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                        self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                        self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                        self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                        self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                        self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                        self.new_link = YLeaf(YType.boolean, "new-link")

                                        self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                        self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                        self.priority_count = YLeaf(YType.int32, "priority-count")

                                        self.te_metric = YLeaf(YType.uint32, "te-metric")

                                        self.extended_admin_group_list = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                        self.extended_admin_group_list.parent = self
                                        self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                        self._children_yang_names.add("extended-admin-group-list")

                                        self.global_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                        self.global_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                        self._children_yang_names.add("global-unreserve-bw-per-priority")

                                        self.link_protocol_priority_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                        self.link_protocol_priority_capability.parent = self
                                        self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                        self._children_yang_names.add("link-protocol-priority-capability")

                                        self.link_sw_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                        self.link_sw_capability.parent = self
                                        self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                        self._children_yang_names.add("link-sw-capability")

                                        self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                        self.sub_pool_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                        self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                        self.mplste_link_opt_tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("affinity",
                                                        "dste_allocation_model_id",
                                                        "dste_in_use",
                                                        "fragment_id",
                                                        "igp_metric",
                                                        "input_interface_id",
                                                        "link_address",
                                                        "maximum_link_bw",
                                                        "maximum_link_reservable_bw",
                                                        "maximum_link_sub_reservable_bw",
                                                        "mpls_link_instance",
                                                        "mpls_link_type",
                                                        "neighbor_ip_address",
                                                        "neighbor_system_id",
                                                        "new_link",
                                                        "number_of_optional_tl_vs",
                                                        "output_interface_id",
                                                        "priority_count",
                                                        "te_metric") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink, self).__setattr__(name, value)


                                    class GlobalUnreserveBwPerPriority(Entity):
                                        """
                                        Global pool unreserved bandwidth for each
                                        priority (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "global-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.bw_per_priority = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "global-unreserve-bw-per-priority"

                                                self.entry = YLeaf(YType.uint64, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "global-unreserve-bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "bw-per-priority"):
                                                for c in self.bw_per_priority:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.bw_per_priority.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bw-per-priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SubPoolUnreserveBwPerPriority(Entity):
                                        """
                                        Sub pool unreserved bandwidth for each priority
                                        (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.bw_per_priority = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"

                                                self.entry = YLeaf(YType.uint64, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sub-pool-unreserve-bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "bw-per-priority"):
                                                for c in self.bw_per_priority:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.bw_per_priority.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bw-per-priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class LinkProtocolPriorityCapability(Entity):
                                        """
                                        Link protocol and protocol priority capability
                                        
                                        .. attribute:: link_protocol_capability
                                        
                                        	Link protocol capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_protocol_priority
                                        
                                        	Link protocol priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                            self.yang_name = "link-protocol-priority-capability"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                            self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("link_protocol_capability",
                                                            "link_protocol_priority") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.link_protocol_capability.is_set or
                                                self.link_protocol_priority.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.link_protocol_capability.yfilter != YFilter.not_set or
                                                self.link_protocol_priority.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "link-protocol-priority-capability" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.link_protocol_capability.is_set or self.link_protocol_capability.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_protocol_capability.get_name_leafdata())
                                            if (self.link_protocol_priority.is_set or self.link_protocol_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_protocol_priority.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "link-protocol-capability" or name == "link-protocol-priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "link-protocol-capability"):
                                                self.link_protocol_capability = value
                                                self.link_protocol_capability.value_namespace = name_space
                                                self.link_protocol_capability.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-protocol-priority"):
                                                self.link_protocol_priority = value
                                                self.link_protocol_priority.value_namespace = name_space
                                                self.link_protocol_priority.value_namespace_prefix = name_space_prefix


                                    class LinkSwCapability(Entity):
                                        """
                                        Link switching capability
                                        
                                        .. attribute:: link_encoding
                                        
                                        	Link Encoding
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_mtu
                                        
                                        	Link MTU size (bytes)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: link_switching_capability
                                        
                                        	Link Switching Capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: maximum_lsp_bw_per_priority
                                        
                                        	Maximum LSP bandwidth for each priority  (bytes/s)
                                        	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                        
                                        .. attribute:: minimum_lsp_bw
                                        
                                        	Minimum LSP bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__init__()

                                            self.yang_name = "link-sw-capability"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                            self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                            self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                            self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                            self.maximum_lsp_bw_per_priority = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("link_encoding",
                                                            "link_mtu",
                                                            "link_switching_capability",
                                                            "minimum_lsp_bw") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)


                                        class MaximumLspBwPerPriority(Entity):
                                            """
                                            Maximum LSP bandwidth for each priority
                                            
                                            (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                                self.yang_name = "maximum-lsp-bw-per-priority"
                                                self.yang_parent_name = "link-sw-capability"

                                                self.entry = YLeaf(YType.uint64, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "maximum-lsp-bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.maximum_lsp_bw_per_priority:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.link_encoding.is_set or
                                                self.link_mtu.is_set or
                                                self.link_switching_capability.is_set or
                                                self.minimum_lsp_bw.is_set)

                                        def has_operation(self):
                                            for c in self.maximum_lsp_bw_per_priority:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.link_encoding.yfilter != YFilter.not_set or
                                                self.link_mtu.yfilter != YFilter.not_set or
                                                self.link_switching_capability.yfilter != YFilter.not_set or
                                                self.minimum_lsp_bw.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "link-sw-capability" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.link_encoding.is_set or self.link_encoding.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_encoding.get_name_leafdata())
                                            if (self.link_mtu.is_set or self.link_mtu.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_mtu.get_name_leafdata())
                                            if (self.link_switching_capability.is_set or self.link_switching_capability.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_switching_capability.get_name_leafdata())
                                            if (self.minimum_lsp_bw.is_set or self.minimum_lsp_bw.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_lsp_bw.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "maximum-lsp-bw-per-priority"):
                                                for c in self.maximum_lsp_bw_per_priority:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.maximum_lsp_bw_per_priority.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "maximum-lsp-bw-per-priority" or name == "link-encoding" or name == "link-mtu" or name == "link-switching-capability" or name == "minimum-lsp-bw"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "link-encoding"):
                                                self.link_encoding = value
                                                self.link_encoding.value_namespace = name_space
                                                self.link_encoding.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-mtu"):
                                                self.link_mtu = value
                                                self.link_mtu.value_namespace = name_space
                                                self.link_mtu.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-switching-capability"):
                                                self.link_switching_capability = value
                                                self.link_switching_capability.value_namespace = name_space
                                                self.link_switching_capability.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-lsp-bw"):
                                                self.minimum_lsp_bw = value
                                                self.minimum_lsp_bw.value_namespace = name_space
                                                self.minimum_lsp_bw.value_namespace_prefix = name_space_prefix


                                    class ExtendedAdminGroupList(Entity):
                                        """
                                        Extended Admin Group
                                        
                                        .. attribute:: ext_admin_data
                                        
                                        	Value of Extended Admin Group
                                        	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                        
                                        .. attribute:: extended_admin_size
                                        
                                        	Size of the extended admin group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                            self.yang_name = "extended-admin-group-list"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                            self.ext_admin_data = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("extended_admin_size") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)


                                        class ExtAdminData(Entity):
                                            """
                                            Value of Extended Admin Group
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                                self.yang_name = "ext-admin-data"
                                                self.yang_parent_name = "extended-admin-group-list"

                                                self.entry = YLeaf(YType.uint32, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ext-admin-data" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.ext_admin_data:
                                                if (c.has_data()):
                                                    return True
                                            return self.extended_admin_size.is_set

                                        def has_operation(self):
                                            for c in self.ext_admin_data:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.extended_admin_size.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "extended-admin-group-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.extended_admin_size.is_set or self.extended_admin_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.extended_admin_size.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "ext-admin-data"):
                                                for c in self.ext_admin_data:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ext_admin_data.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ext-admin-data" or name == "extended-admin-size"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "extended-admin-size"):
                                                self.extended_admin_size = value
                                                self.extended_admin_size.value_namespace = name_space
                                                self.extended_admin_size.value_namespace_prefix = name_space_prefix


                                    class MplsteLinkOptTlv(Entity):
                                        """
                                        List of Optional TLVs
                                        
                                        .. attribute:: mplste_link_opt_tlv_len
                                        
                                        	Length of Opt TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mplste_link_opt_tlv_type
                                        
                                        	Type of Opt TLV
                                        	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                        
                                        .. attribute:: mplste_link_opt_tlv_value
                                        
                                        	Value of Opt TLV
                                        	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                            self.yang_name = "mplste-link-opt-tlv"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                            self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                            self.mplste_link_opt_tlv_value = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("mplste_link_opt_tlv_len",
                                                            "mplste_link_opt_tlv_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)


                                        class MplsteLinkOptTlvValue(Entity):
                                            """
                                            Value of Opt TLV
                                            
                                            .. attribute:: bctlv_value
                                            
                                            	Value of Bandwidth Constraints TLV
                                            	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                            
                                            .. attribute:: ixcdtlv_value
                                            
                                            	Value of IXCD TLV
                                            	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                            
                                            .. attribute:: opaque_tlv_type
                                            
                                            	OpaqueTLVType
                                            	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                            
                                            .. attribute:: srlgtlv_value
                                            
                                            	Value of SRLG TLV
                                            	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                            
                                            .. attribute:: unidtlv_value
                                            
                                            	Value of Uni Delay TLV
                                            	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                                self.yang_name = "mplste-link-opt-tlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv"

                                                self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                                self.bctlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                self.bctlv_value.parent = self
                                                self._children_name_map["bctlv_value"] = "bctlv-value"
                                                self._children_yang_names.add("bctlv-value")

                                                self.ixcdtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                self.ixcdtlv_value.parent = self
                                                self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                self._children_yang_names.add("ixcdtlv-value")

                                                self.srlgtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                self.srlgtlv_value.parent = self
                                                self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                self._children_yang_names.add("srlgtlv-value")

                                                self.unidtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                self.unidtlv_value.parent = self
                                                self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                self._children_yang_names.add("unidtlv-value")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("opaque_tlv_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)


                                            class BctlvValue(Entity):
                                                """
                                                Value of Bandwidth Constraints TLV
                                                
                                                .. attribute:: model_id
                                                
                                                	Allocation Model ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mplste_link_bc_bandwidth
                                                
                                                	Value of BC TLV
                                                	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                                
                                                .. attribute:: num_b_cs
                                                
                                                	Number of BC TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                    self.yang_name = "bctlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.model_id = YLeaf(YType.uint8, "model-id")

                                                    self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                    self.mplste_link_bc_bandwidth = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("model_id",
                                                                    "num_b_cs") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)


                                                class MplsteLinkBcBandwidth(Entity):
                                                    """
                                                    Value of BC TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                        self.yang_name = "mplste-link-bc-bandwidth"
                                                        self.yang_parent_name = "bctlv-value"

                                                        self.entry = YLeaf(YType.uint64, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "mplste-link-bc-bandwidth" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.mplste_link_bc_bandwidth:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.model_id.is_set or
                                                        self.num_b_cs.is_set)

                                                def has_operation(self):
                                                    for c in self.mplste_link_bc_bandwidth:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.model_id.yfilter != YFilter.not_set or
                                                        self.num_b_cs.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bctlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.model_id.is_set or self.model_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.model_id.get_name_leafdata())
                                                    if (self.num_b_cs.is_set or self.num_b_cs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_b_cs.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "mplste-link-bc-bandwidth"):
                                                        for c in self.mplste_link_bc_bandwidth:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.mplste_link_bc_bandwidth.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "mplste-link-bc-bandwidth" or name == "model-id" or name == "num-b-cs"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "model-id"):
                                                        self.model_id = value
                                                        self.model_id.value_namespace = name_space
                                                        self.model_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-b-cs"):
                                                        self.num_b_cs = value
                                                        self.num_b_cs.value_namespace = name_space
                                                        self.num_b_cs.value_namespace_prefix = name_space_prefix


                                            class SrlgtlvValue(Entity):
                                                """
                                                Value of SRLG TLV
                                                
                                                .. attribute:: mplste_link_srlg_data
                                                
                                                	Value of SRLG TLV
                                                	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                                
                                                .. attribute:: num_srl_gs
                                                
                                                	Number of SRLG TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: srlg_len
                                                
                                                	Length of SRLG TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                    self.yang_name = "srlgtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                    self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                    self.mplste_link_srlg_data = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("num_srl_gs",
                                                                    "srlg_len") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)


                                                class MplsteLinkSrlgData(Entity):
                                                    """
                                                    Value of SRLG TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                        self.yang_name = "mplste-link-srlg-data"
                                                        self.yang_parent_name = "srlgtlv-value"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "mplste-link-srlg-data" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.mplste_link_srlg_data:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.num_srl_gs.is_set or
                                                        self.srlg_len.is_set)

                                                def has_operation(self):
                                                    for c in self.mplste_link_srlg_data:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.num_srl_gs.yfilter != YFilter.not_set or
                                                        self.srlg_len.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "srlgtlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.num_srl_gs.is_set or self.num_srl_gs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_srl_gs.get_name_leafdata())
                                                    if (self.srlg_len.is_set or self.srlg_len.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.srlg_len.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "mplste-link-srlg-data"):
                                                        for c in self.mplste_link_srlg_data:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.mplste_link_srlg_data.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "mplste-link-srlg-data" or name == "num-srl-gs" or name == "srlg-len"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "num-srl-gs"):
                                                        self.num_srl_gs = value
                                                        self.num_srl_gs.value_namespace = name_space
                                                        self.num_srl_gs.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "srlg-len"):
                                                        self.srlg_len = value
                                                        self.srlg_len.value_namespace = name_space
                                                        self.srlg_len.value_namespace_prefix = name_space_prefix


                                            class IxcdtlvValue(Entity):
                                                """
                                                Value of IXCD TLV
                                                
                                                .. attribute:: fixed_scsi_count
                                                
                                                	Fixed SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flex_scsi_count
                                                
                                                	Flexible SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ixcd_switching_cap_type
                                                
                                                	Switching Cap type
                                                	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                                
                                                .. attribute:: max_lspbw
                                                
                                                	Max LSP bandwidth array
                                                	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                                
                                                .. attribute:: rile_len_code
                                                
                                                	Rile LenCode
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: switching_cap
                                                
                                                	SCap
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                    self.yang_name = "ixcdtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                    self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                    self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                    self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                    self.ixcd_switching_cap_type = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                    self.ixcd_switching_cap_type.parent = self
                                                    self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                    self._children_yang_names.add("ixcd-switching-cap-type")

                                                    self.max_lspbw = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("fixed_scsi_count",
                                                                    "flex_scsi_count",
                                                                    "rile_len_code",
                                                                    "switching_cap") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)


                                                class IxcdSwitchingCapType(Entity):
                                                    """
                                                    Switching Cap type
                                                    
                                                    .. attribute:: ixcdbw_sub_tlv
                                                    
                                                    	Sub TLVs
                                                    	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                    
                                                    .. attribute:: ixcdpsc_info
                                                    
                                                    	IXCD PSC information
                                                    	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                    
                                                    .. attribute:: switching_cap_type
                                                    
                                                    	SwitchingCapType
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                        self.yang_name = "ixcd-switching-cap-type"
                                                        self.yang_parent_name = "ixcdtlv-value"

                                                        self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                        self.ixcdbw_sub_tlv = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                        self.ixcdbw_sub_tlv.parent = self
                                                        self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                        self._children_yang_names.add("ixcdbw-sub-tlv")

                                                        self.ixcdpsc_info = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                        self.ixcdpsc_info.parent = self
                                                        self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                        self._children_yang_names.add("ixcdpsc-info")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("switching_cap_type") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)


                                                    class IxcdpscInfo(Entity):
                                                        """
                                                        IXCD PSC information
                                                        
                                                        .. attribute:: min_lsp_bandwidth
                                                        
                                                        	Min LSP bandwidth
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: psc_interface_mtu
                                                        
                                                        	 Interface MTU
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                            self.yang_name = "ixcdpsc-info"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"

                                                            self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                            self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("min_lsp_bandwidth",
                                                                            "psc_interface_mtu") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.min_lsp_bandwidth.is_set or
                                                                self.psc_interface_mtu.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.min_lsp_bandwidth.yfilter != YFilter.not_set or
                                                                self.psc_interface_mtu.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ixcdpsc-info" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.min_lsp_bandwidth.is_set or self.min_lsp_bandwidth.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.min_lsp_bandwidth.get_name_leafdata())
                                                            if (self.psc_interface_mtu.is_set or self.psc_interface_mtu.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.psc_interface_mtu.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "min-lsp-bandwidth" or name == "psc-interface-mtu"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "min-lsp-bandwidth"):
                                                                self.min_lsp_bandwidth = value
                                                                self.min_lsp_bandwidth.value_namespace = name_space
                                                                self.min_lsp_bandwidth.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "psc-interface-mtu"):
                                                                self.psc_interface_mtu = value
                                                                self.psc_interface_mtu.value_namespace = name_space
                                                                self.psc_interface_mtu.value_namespace_prefix = name_space_prefix


                                                    class IxcdbwSubTlv(Entity):
                                                        """
                                                        Sub TLVs
                                                        
                                                        .. attribute:: arr_bw_sub_tlv
                                                        
                                                        	Array of sub tlvs
                                                        	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                            self.yang_name = "ixcdbw-sub-tlv"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"

                                                            self.arr_bw_sub_tlv = YList(self)

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in () and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)


                                                        class ArrBwSubTlv(Entity):
                                                            """
                                                            Array of sub tlvs
                                                            
                                                            .. attribute:: bw_sub_tlv_length
                                                            
                                                            	Length of BW Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_type
                                                            
                                                            	Type of Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_value
                                                            
                                                            	Value of BW Sub TLV
                                                            	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                                self.yang_name = "arr-bw-sub-tlv"
                                                                self.yang_parent_name = "ixcdbw-sub-tlv"

                                                                self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                                self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                                self.bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                self.bw_sub_tlv_value.parent = self
                                                                self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                self._children_yang_names.add("bw-sub-tlv-value")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("bw_sub_tlv_length",
                                                                                "bw_sub_tlv_type") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)


                                                            class BwSubTlvValue(Entity):
                                                                """
                                                                Value of BW Sub TLV
                                                                
                                                                .. attribute:: fixed_bw_sub_tlv_value
                                                                
                                                                	Value of Fixed Sub TLV
                                                                	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                                
                                                                .. attribute:: flex_bw_sub_tlv_value
                                                                
                                                                	Value of Flex Sub TLV
                                                                	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                                
                                                                .. attribute:: ixcdbw_sub_tlv_type
                                                                
                                                                	IXCDBWSubTLVType
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-01-02'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                    self.yang_name = "bw-sub-tlv-value"
                                                                    self.yang_parent_name = "arr-bw-sub-tlv"

                                                                    self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                    self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                    self.fixed_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                    self.flex_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                    self.flex_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("flex-bw-sub-tlv-value")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("ixcdbw_sub_tlv_type") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)


                                                                class FixedBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Fixed Sub TLV
                                                                    
                                                                    .. attribute:: fixed_sub_tlv_value
                                                                    
                                                                    	Value of Fixed Sub TLV
                                                                    	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                    
                                                                    .. attribute:: unres_oduj_prio
                                                                    
                                                                    	Array of Unres Oduj Prio
                                                                    	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "fixed-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"

                                                                        self.fixed_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                        self.fixed_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                        self._children_yang_names.add("fixed-sub-tlv-value")

                                                                        self.unres_oduj_prio = YList(self)

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in () and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)


                                                                    class FixedSubTlvValue(Entity):
                                                                        """
                                                                        Value of Fixed Sub TLV
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                            self.yang_name = "fixed-sub-tlv-value"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("num_stages",
                                                                                            "priority_bit0",
                                                                                            "priority_bit1",
                                                                                            "priority_bit2",
                                                                                            "priority_bit3",
                                                                                            "priority_bit4",
                                                                                            "priority_bit5",
                                                                                            "priority_bit6",
                                                                                            "priority_bit7",
                                                                                            "res",
                                                                                            "sbit",
                                                                                            "signal_type",
                                                                                            "stage",
                                                                                            "tbit",
                                                                                            "tsg") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return (
                                                                                self.num_stages.is_set or
                                                                                self.priority_bit0.is_set or
                                                                                self.priority_bit1.is_set or
                                                                                self.priority_bit2.is_set or
                                                                                self.priority_bit3.is_set or
                                                                                self.priority_bit4.is_set or
                                                                                self.priority_bit5.is_set or
                                                                                self.priority_bit6.is_set or
                                                                                self.priority_bit7.is_set or
                                                                                self.res.is_set or
                                                                                self.sbit.is_set or
                                                                                self.signal_type.is_set or
                                                                                self.stage.is_set or
                                                                                self.tbit.is_set or
                                                                                self.tsg.is_set)

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.num_stages.yfilter != YFilter.not_set or
                                                                                self.priority_bit0.yfilter != YFilter.not_set or
                                                                                self.priority_bit1.yfilter != YFilter.not_set or
                                                                                self.priority_bit2.yfilter != YFilter.not_set or
                                                                                self.priority_bit3.yfilter != YFilter.not_set or
                                                                                self.priority_bit4.yfilter != YFilter.not_set or
                                                                                self.priority_bit5.yfilter != YFilter.not_set or
                                                                                self.priority_bit6.yfilter != YFilter.not_set or
                                                                                self.priority_bit7.yfilter != YFilter.not_set or
                                                                                self.res.yfilter != YFilter.not_set or
                                                                                self.sbit.yfilter != YFilter.not_set or
                                                                                self.signal_type.yfilter != YFilter.not_set or
                                                                                self.stage.yfilter != YFilter.not_set or
                                                                                self.tbit.yfilter != YFilter.not_set or
                                                                                self.tsg.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "fixed-sub-tlv-value" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                            if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                            if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                            if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                            if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                            if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                            if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                            if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                            if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                            if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.res.get_name_leafdata())
                                                                            if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                            if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                            if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.stage.get_name_leafdata())
                                                                            if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                            if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "num-stages"):
                                                                                self.num_stages = value
                                                                                self.num_stages.value_namespace = name_space
                                                                                self.num_stages.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit0"):
                                                                                self.priority_bit0 = value
                                                                                self.priority_bit0.value_namespace = name_space
                                                                                self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit1"):
                                                                                self.priority_bit1 = value
                                                                                self.priority_bit1.value_namespace = name_space
                                                                                self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit2"):
                                                                                self.priority_bit2 = value
                                                                                self.priority_bit2.value_namespace = name_space
                                                                                self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit3"):
                                                                                self.priority_bit3 = value
                                                                                self.priority_bit3.value_namespace = name_space
                                                                                self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit4"):
                                                                                self.priority_bit4 = value
                                                                                self.priority_bit4.value_namespace = name_space
                                                                                self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit5"):
                                                                                self.priority_bit5 = value
                                                                                self.priority_bit5.value_namespace = name_space
                                                                                self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit6"):
                                                                                self.priority_bit6 = value
                                                                                self.priority_bit6.value_namespace = name_space
                                                                                self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit7"):
                                                                                self.priority_bit7 = value
                                                                                self.priority_bit7.value_namespace = name_space
                                                                                self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "res"):
                                                                                self.res = value
                                                                                self.res.value_namespace = name_space
                                                                                self.res.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "sbit"):
                                                                                self.sbit = value
                                                                                self.sbit.value_namespace = name_space
                                                                                self.sbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "signal-type"):
                                                                                self.signal_type = value
                                                                                self.signal_type.value_namespace = name_space
                                                                                self.signal_type.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "stage"):
                                                                                self.stage = value
                                                                                self.stage.value_namespace = name_space
                                                                                self.stage.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tbit"):
                                                                                self.tbit = value
                                                                                self.tbit.value_namespace = name_space
                                                                                self.tbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tsg"):
                                                                                self.tsg = value
                                                                                self.tsg.value_namespace = name_space
                                                                                self.tsg.value_namespace_prefix = name_space_prefix


                                                                    class UnresOdujPrio(Entity):
                                                                        """
                                                                        Array of Unres Oduj Prio
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                            self.yang_name = "unres-oduj-prio"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                            self.entry = YLeaf(YType.uint32, "entry")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("entry") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return self.entry.is_set

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.entry.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "unres-oduj-prio" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "entry"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "entry"):
                                                                                self.entry = value
                                                                                self.entry.value_namespace = name_space
                                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                                    def has_data(self):
                                                                        for c in self.unres_oduj_prio:
                                                                            if (c.has_data()):
                                                                                return True
                                                                        return (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_data())

                                                                    def has_operation(self):
                                                                        for c in self.unres_oduj_prio:
                                                                            if (c.has_operation()):
                                                                                return True
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_operation()))

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "fixed-bw-sub-tlv-value" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        if (child_yang_name == "fixed-sub-tlv-value"):
                                                                            if (self.fixed_sub_tlv_value is None):
                                                                                self.fixed_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                                self.fixed_sub_tlv_value.parent = self
                                                                                self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                            return self.fixed_sub_tlv_value

                                                                        if (child_yang_name == "unres-oduj-prio"):
                                                                            for c in self.unres_oduj_prio:
                                                                                segment = c.get_segment_path()
                                                                                if (segment_path == segment):
                                                                                    return c
                                                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio()
                                                                            c.parent = self
                                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                                            self._local_refs[local_reference_key] = c
                                                                            self.unres_oduj_prio.append(c)
                                                                            return c

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "fixed-sub-tlv-value" or name == "unres-oduj-prio"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        pass


                                                                class FlexBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Flex Sub TLV
                                                                    
                                                                    .. attribute:: flex_sub_tlv_value_common
                                                                    
                                                                    	Flex Sub TLV Value
                                                                    	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                    
                                                                    .. attribute:: max_lspbw
                                                                    
                                                                    	Max LSP BW Array
                                                                    	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                    
                                                                    .. attribute:: unres_lspbw
                                                                    
                                                                    	Array of Unres LSP BW
                                                                    	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "flex-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"

                                                                        self.flex_sub_tlv_value_common = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                        self.flex_sub_tlv_value_common.parent = self
                                                                        self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                        self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                        self.max_lspbw = YList(self)
                                                                        self.unres_lspbw = YList(self)

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in () and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)


                                                                    class FlexSubTlvValueCommon(Entity):
                                                                        """
                                                                        Flex Sub TLV Value
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                            self.yang_name = "flex-sub-tlv-value-common"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("num_stages",
                                                                                            "priority_bit0",
                                                                                            "priority_bit1",
                                                                                            "priority_bit2",
                                                                                            "priority_bit3",
                                                                                            "priority_bit4",
                                                                                            "priority_bit5",
                                                                                            "priority_bit6",
                                                                                            "priority_bit7",
                                                                                            "res",
                                                                                            "sbit",
                                                                                            "signal_type",
                                                                                            "stage",
                                                                                            "tbit",
                                                                                            "tsg") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return (
                                                                                self.num_stages.is_set or
                                                                                self.priority_bit0.is_set or
                                                                                self.priority_bit1.is_set or
                                                                                self.priority_bit2.is_set or
                                                                                self.priority_bit3.is_set or
                                                                                self.priority_bit4.is_set or
                                                                                self.priority_bit5.is_set or
                                                                                self.priority_bit6.is_set or
                                                                                self.priority_bit7.is_set or
                                                                                self.res.is_set or
                                                                                self.sbit.is_set or
                                                                                self.signal_type.is_set or
                                                                                self.stage.is_set or
                                                                                self.tbit.is_set or
                                                                                self.tsg.is_set)

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.num_stages.yfilter != YFilter.not_set or
                                                                                self.priority_bit0.yfilter != YFilter.not_set or
                                                                                self.priority_bit1.yfilter != YFilter.not_set or
                                                                                self.priority_bit2.yfilter != YFilter.not_set or
                                                                                self.priority_bit3.yfilter != YFilter.not_set or
                                                                                self.priority_bit4.yfilter != YFilter.not_set or
                                                                                self.priority_bit5.yfilter != YFilter.not_set or
                                                                                self.priority_bit6.yfilter != YFilter.not_set or
                                                                                self.priority_bit7.yfilter != YFilter.not_set or
                                                                                self.res.yfilter != YFilter.not_set or
                                                                                self.sbit.yfilter != YFilter.not_set or
                                                                                self.signal_type.yfilter != YFilter.not_set or
                                                                                self.stage.yfilter != YFilter.not_set or
                                                                                self.tbit.yfilter != YFilter.not_set or
                                                                                self.tsg.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "flex-sub-tlv-value-common" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                            if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                            if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                            if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                            if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                            if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                            if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                            if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                            if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                            if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.res.get_name_leafdata())
                                                                            if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                            if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                            if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.stage.get_name_leafdata())
                                                                            if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                            if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "num-stages"):
                                                                                self.num_stages = value
                                                                                self.num_stages.value_namespace = name_space
                                                                                self.num_stages.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit0"):
                                                                                self.priority_bit0 = value
                                                                                self.priority_bit0.value_namespace = name_space
                                                                                self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit1"):
                                                                                self.priority_bit1 = value
                                                                                self.priority_bit1.value_namespace = name_space
                                                                                self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit2"):
                                                                                self.priority_bit2 = value
                                                                                self.priority_bit2.value_namespace = name_space
                                                                                self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit3"):
                                                                                self.priority_bit3 = value
                                                                                self.priority_bit3.value_namespace = name_space
                                                                                self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit4"):
                                                                                self.priority_bit4 = value
                                                                                self.priority_bit4.value_namespace = name_space
                                                                                self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit5"):
                                                                                self.priority_bit5 = value
                                                                                self.priority_bit5.value_namespace = name_space
                                                                                self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit6"):
                                                                                self.priority_bit6 = value
                                                                                self.priority_bit6.value_namespace = name_space
                                                                                self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit7"):
                                                                                self.priority_bit7 = value
                                                                                self.priority_bit7.value_namespace = name_space
                                                                                self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "res"):
                                                                                self.res = value
                                                                                self.res.value_namespace = name_space
                                                                                self.res.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "sbit"):
                                                                                self.sbit = value
                                                                                self.sbit.value_namespace = name_space
                                                                                self.sbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "signal-type"):
                                                                                self.signal_type = value
                                                                                self.signal_type.value_namespace = name_space
                                                                                self.signal_type.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "stage"):
                                                                                self.stage = value
                                                                                self.stage.value_namespace = name_space
                                                                                self.stage.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tbit"):
                                                                                self.tbit = value
                                                                                self.tbit.value_namespace = name_space
                                                                                self.tbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tsg"):
                                                                                self.tsg = value
                                                                                self.tsg.value_namespace = name_space
                                                                                self.tsg.value_namespace_prefix = name_space_prefix


                                                                    class UnresLspbw(Entity):
                                                                        """
                                                                        Array of Unres LSP BW
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                            self.yang_name = "unres-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                            self.entry = YLeaf(YType.uint64, "entry")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("entry") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return self.entry.is_set

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.entry.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "unres-lspbw" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "entry"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "entry"):
                                                                                self.entry = value
                                                                                self.entry.value_namespace = name_space
                                                                                self.entry.value_namespace_prefix = name_space_prefix


                                                                    class MaxLspbw(Entity):
                                                                        """
                                                                        Max LSP BW Array
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                            self.yang_name = "max-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                            self.entry = YLeaf(YType.uint64, "entry")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("entry") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return self.entry.is_set

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.entry.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "max-lspbw" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "entry"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "entry"):
                                                                                self.entry = value
                                                                                self.entry.value_namespace = name_space
                                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                                    def has_data(self):
                                                                        for c in self.max_lspbw:
                                                                            if (c.has_data()):
                                                                                return True
                                                                        for c in self.unres_lspbw:
                                                                            if (c.has_data()):
                                                                                return True
                                                                        return (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_data())

                                                                    def has_operation(self):
                                                                        for c in self.max_lspbw:
                                                                            if (c.has_operation()):
                                                                                return True
                                                                        for c in self.unres_lspbw:
                                                                            if (c.has_operation()):
                                                                                return True
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_operation()))

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "flex-bw-sub-tlv-value" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        if (child_yang_name == "flex-sub-tlv-value-common"):
                                                                            if (self.flex_sub_tlv_value_common is None):
                                                                                self.flex_sub_tlv_value_common = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                                self.flex_sub_tlv_value_common.parent = self
                                                                                self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                            return self.flex_sub_tlv_value_common

                                                                        if (child_yang_name == "max-lspbw"):
                                                                            for c in self.max_lspbw:
                                                                                segment = c.get_segment_path()
                                                                                if (segment_path == segment):
                                                                                    return c
                                                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw()
                                                                            c.parent = self
                                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                                            self._local_refs[local_reference_key] = c
                                                                            self.max_lspbw.append(c)
                                                                            return c

                                                                        if (child_yang_name == "unres-lspbw"):
                                                                            for c in self.unres_lspbw:
                                                                                segment = c.get_segment_path()
                                                                                if (segment_path == segment):
                                                                                    return c
                                                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw()
                                                                            c.parent = self
                                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                                            self._local_refs[local_reference_key] = c
                                                                            self.unres_lspbw.append(c)
                                                                            return c

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "flex-sub-tlv-value-common" or name == "max-lspbw" or name == "unres-lspbw"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        pass

                                                                def has_data(self):
                                                                    return (
                                                                        self.ixcdbw_sub_tlv_type.is_set or
                                                                        (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_data()) or
                                                                        (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_data()))

                                                                def has_operation(self):
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                        (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_operation()) or
                                                                        (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_operation()))

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "bw-sub-tlv-value" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.ixcdbw_sub_tlv_type.is_set or self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ixcdbw_sub_tlv_type.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    if (child_yang_name == "fixed-bw-sub-tlv-value"):
                                                                        if (self.fixed_bw_sub_tlv_value is None):
                                                                            self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                            self.fixed_bw_sub_tlv_value.parent = self
                                                                            self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                        return self.fixed_bw_sub_tlv_value

                                                                    if (child_yang_name == "flex-bw-sub-tlv-value"):
                                                                        if (self.flex_bw_sub_tlv_value is None):
                                                                            self.flex_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                            self.flex_bw_sub_tlv_value.parent = self
                                                                            self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                        return self.flex_bw_sub_tlv_value

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "fixed-bw-sub-tlv-value" or name == "flex-bw-sub-tlv-value" or name == "ixcdbw-sub-tlv-type"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "ixcdbw-sub-tlv-type"):
                                                                        self.ixcdbw_sub_tlv_type = value
                                                                        self.ixcdbw_sub_tlv_type.value_namespace = name_space
                                                                        self.ixcdbw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                return (
                                                                    self.bw_sub_tlv_length.is_set or
                                                                    self.bw_sub_tlv_type.is_set or
                                                                    (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_data()))

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.bw_sub_tlv_length.yfilter != YFilter.not_set or
                                                                    self.bw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                    (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_operation()))

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "arr-bw-sub-tlv" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.bw_sub_tlv_length.is_set or self.bw_sub_tlv_length.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.bw_sub_tlv_length.get_name_leafdata())
                                                                if (self.bw_sub_tlv_type.is_set or self.bw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.bw_sub_tlv_type.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "bw-sub-tlv-value"):
                                                                    if (self.bw_sub_tlv_value is None):
                                                                        self.bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                        self.bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                    return self.bw_sub_tlv_value

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "bw-sub-tlv-value" or name == "bw-sub-tlv-length" or name == "bw-sub-tlv-type"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "bw-sub-tlv-length"):
                                                                    self.bw_sub_tlv_length = value
                                                                    self.bw_sub_tlv_length.value_namespace = name_space
                                                                    self.bw_sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "bw-sub-tlv-type"):
                                                                    self.bw_sub_tlv_type = value
                                                                    self.bw_sub_tlv_type.value_namespace = name_space
                                                                    self.bw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                        def has_data(self):
                                                            for c in self.arr_bw_sub_tlv:
                                                                if (c.has_data()):
                                                                    return True
                                                            return False

                                                        def has_operation(self):
                                                            for c in self.arr_bw_sub_tlv:
                                                                if (c.has_operation()):
                                                                    return True
                                                            return self.yfilter != YFilter.not_set

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ixcdbw-sub-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "arr-bw-sub-tlv"):
                                                                for c in self.arr_bw_sub_tlv:
                                                                    segment = c.get_segment_path()
                                                                    if (segment_path == segment):
                                                                        return c
                                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv()
                                                                c.parent = self
                                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                                self._local_refs[local_reference_key] = c
                                                                self.arr_bw_sub_tlv.append(c)
                                                                return c

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "arr-bw-sub-tlv"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            pass

                                                    def has_data(self):
                                                        return (
                                                            self.switching_cap_type.is_set or
                                                            (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_data()) or
                                                            (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_data()))

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.switching_cap_type.yfilter != YFilter.not_set or
                                                            (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_operation()) or
                                                            (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_operation()))

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ixcd-switching-cap-type" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.switching_cap_type.is_set or self.switching_cap_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.switching_cap_type.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ixcdbw-sub-tlv"):
                                                            if (self.ixcdbw_sub_tlv is None):
                                                                self.ixcdbw_sub_tlv = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                                self.ixcdbw_sub_tlv.parent = self
                                                                self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                            return self.ixcdbw_sub_tlv

                                                        if (child_yang_name == "ixcdpsc-info"):
                                                            if (self.ixcdpsc_info is None):
                                                                self.ixcdpsc_info = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                                self.ixcdpsc_info.parent = self
                                                                self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                            return self.ixcdpsc_info

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ixcdbw-sub-tlv" or name == "ixcdpsc-info" or name == "switching-cap-type"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "switching-cap-type"):
                                                            self.switching_cap_type = value
                                                            self.switching_cap_type.value_namespace = name_space
                                                            self.switching_cap_type.value_namespace_prefix = name_space_prefix


                                                class MaxLspbw(Entity):
                                                    """
                                                    Max LSP bandwidth array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-9223372036854775808..9223372036854775807
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                        self.yang_name = "max-lspbw"
                                                        self.yang_parent_name = "ixcdtlv-value"

                                                        self.entry = YLeaf(YType.int64, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "max-lspbw" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.max_lspbw:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.fixed_scsi_count.is_set or
                                                        self.flex_scsi_count.is_set or
                                                        self.rile_len_code.is_set or
                                                        self.switching_cap.is_set or
                                                        (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_data()))

                                                def has_operation(self):
                                                    for c in self.max_lspbw:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.fixed_scsi_count.yfilter != YFilter.not_set or
                                                        self.flex_scsi_count.yfilter != YFilter.not_set or
                                                        self.rile_len_code.yfilter != YFilter.not_set or
                                                        self.switching_cap.yfilter != YFilter.not_set or
                                                        (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ixcdtlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.fixed_scsi_count.is_set or self.fixed_scsi_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fixed_scsi_count.get_name_leafdata())
                                                    if (self.flex_scsi_count.is_set or self.flex_scsi_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flex_scsi_count.get_name_leafdata())
                                                    if (self.rile_len_code.is_set or self.rile_len_code.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rile_len_code.get_name_leafdata())
                                                    if (self.switching_cap.is_set or self.switching_cap.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.switching_cap.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ixcd-switching-cap-type"):
                                                        if (self.ixcd_switching_cap_type is None):
                                                            self.ixcd_switching_cap_type = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                            self.ixcd_switching_cap_type.parent = self
                                                            self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                        return self.ixcd_switching_cap_type

                                                    if (child_yang_name == "max-lspbw"):
                                                        for c in self.max_lspbw:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.max_lspbw.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ixcd-switching-cap-type" or name == "max-lspbw" or name == "fixed-scsi-count" or name == "flex-scsi-count" or name == "rile-len-code" or name == "switching-cap"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "fixed-scsi-count"):
                                                        self.fixed_scsi_count = value
                                                        self.fixed_scsi_count.value_namespace = name_space
                                                        self.fixed_scsi_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flex-scsi-count"):
                                                        self.flex_scsi_count = value
                                                        self.flex_scsi_count.value_namespace = name_space
                                                        self.flex_scsi_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rile-len-code"):
                                                        self.rile_len_code = value
                                                        self.rile_len_code.value_namespace = name_space
                                                        self.rile_len_code.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "switching-cap"):
                                                        self.switching_cap = value
                                                        self.switching_cap.value_namespace = name_space
                                                        self.switching_cap.value_namespace_prefix = name_space_prefix


                                            class UnidtlvValue(Entity):
                                                """
                                                Value of Uni Delay TLV
                                                
                                                .. attribute:: uni_dir_delay
                                                
                                                	Uni Dir Delay
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                    self.yang_name = "unidtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("uni_dir_delay") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.uni_dir_delay.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.uni_dir_delay.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unidtlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.uni_dir_delay.is_set or self.uni_dir_delay.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.uni_dir_delay.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "uni-dir-delay"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "uni-dir-delay"):
                                                        self.uni_dir_delay = value
                                                        self.uni_dir_delay.value_namespace = name_space
                                                        self.uni_dir_delay.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.opaque_tlv_type.is_set or
                                                    (self.bctlv_value is not None and self.bctlv_value.has_data()) or
                                                    (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_data()) or
                                                    (self.srlgtlv_value is not None and self.srlgtlv_value.has_data()) or
                                                    (self.unidtlv_value is not None and self.unidtlv_value.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.opaque_tlv_type.yfilter != YFilter.not_set or
                                                    (self.bctlv_value is not None and self.bctlv_value.has_operation()) or
                                                    (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_operation()) or
                                                    (self.srlgtlv_value is not None and self.srlgtlv_value.has_operation()) or
                                                    (self.unidtlv_value is not None and self.unidtlv_value.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mplste-link-opt-tlv-value" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.opaque_tlv_type.is_set or self.opaque_tlv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.opaque_tlv_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bctlv-value"):
                                                    if (self.bctlv_value is None):
                                                        self.bctlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                        self.bctlv_value.parent = self
                                                        self._children_name_map["bctlv_value"] = "bctlv-value"
                                                    return self.bctlv_value

                                                if (child_yang_name == "ixcdtlv-value"):
                                                    if (self.ixcdtlv_value is None):
                                                        self.ixcdtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                        self.ixcdtlv_value.parent = self
                                                        self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                    return self.ixcdtlv_value

                                                if (child_yang_name == "srlgtlv-value"):
                                                    if (self.srlgtlv_value is None):
                                                        self.srlgtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                        self.srlgtlv_value.parent = self
                                                        self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                    return self.srlgtlv_value

                                                if (child_yang_name == "unidtlv-value"):
                                                    if (self.unidtlv_value is None):
                                                        self.unidtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                        self.unidtlv_value.parent = self
                                                        self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                    return self.unidtlv_value

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bctlv-value" or name == "ixcdtlv-value" or name == "srlgtlv-value" or name == "unidtlv-value" or name == "opaque-tlv-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "opaque-tlv-type"):
                                                    self.opaque_tlv_type = value
                                                    self.opaque_tlv_type.value_namespace = name_space
                                                    self.opaque_tlv_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.mplste_link_opt_tlv_value:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.mplste_link_opt_tlv_len.is_set or
                                                self.mplste_link_opt_tlv_type.is_set)

                                        def has_operation(self):
                                            for c in self.mplste_link_opt_tlv_value:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set or
                                                self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mplste-link-opt-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.mplste_link_opt_tlv_len.is_set or self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mplste_link_opt_tlv_len.get_name_leafdata())
                                            if (self.mplste_link_opt_tlv_type.is_set or self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mplste_link_opt_tlv_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "mplste-link-opt-tlv-value"):
                                                for c in self.mplste_link_opt_tlv_value:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.mplste_link_opt_tlv_value.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "mplste-link-opt-tlv-value" or name == "mplste-link-opt-tlv-len" or name == "mplste-link-opt-tlv-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "mplste-link-opt-tlv-len"):
                                                self.mplste_link_opt_tlv_len = value
                                                self.mplste_link_opt_tlv_len.value_namespace = name_space
                                                self.mplste_link_opt_tlv_len.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mplste-link-opt-tlv-type"):
                                                self.mplste_link_opt_tlv_type = value
                                                self.mplste_link_opt_tlv_type.value_namespace = name_space
                                                self.mplste_link_opt_tlv_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.mplste_link_opt_tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.affinity.is_set or
                                            self.dste_allocation_model_id.is_set or
                                            self.dste_in_use.is_set or
                                            self.fragment_id.is_set or
                                            self.igp_metric.is_set or
                                            self.input_interface_id.is_set or
                                            self.link_address.is_set or
                                            self.maximum_link_bw.is_set or
                                            self.maximum_link_reservable_bw.is_set or
                                            self.maximum_link_sub_reservable_bw.is_set or
                                            self.mpls_link_instance.is_set or
                                            self.mpls_link_type.is_set or
                                            self.neighbor_ip_address.is_set or
                                            self.neighbor_system_id.is_set or
                                            self.new_link.is_set or
                                            self.number_of_optional_tl_vs.is_set or
                                            self.output_interface_id.is_set or
                                            self.priority_count.is_set or
                                            self.te_metric.is_set or
                                            (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_data()) or
                                            (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_data()) or
                                            (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_data()) or
                                            (self.link_sw_capability is not None and self.link_sw_capability.has_data()) or
                                            (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_data()))

                                    def has_operation(self):
                                        for c in self.mplste_link_opt_tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.affinity.yfilter != YFilter.not_set or
                                            self.dste_allocation_model_id.yfilter != YFilter.not_set or
                                            self.dste_in_use.yfilter != YFilter.not_set or
                                            self.fragment_id.yfilter != YFilter.not_set or
                                            self.igp_metric.yfilter != YFilter.not_set or
                                            self.input_interface_id.yfilter != YFilter.not_set or
                                            self.link_address.yfilter != YFilter.not_set or
                                            self.maximum_link_bw.yfilter != YFilter.not_set or
                                            self.maximum_link_reservable_bw.yfilter != YFilter.not_set or
                                            self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set or
                                            self.mpls_link_instance.yfilter != YFilter.not_set or
                                            self.mpls_link_type.yfilter != YFilter.not_set or
                                            self.neighbor_ip_address.yfilter != YFilter.not_set or
                                            self.neighbor_system_id.yfilter != YFilter.not_set or
                                            self.new_link.yfilter != YFilter.not_set or
                                            self.number_of_optional_tl_vs.yfilter != YFilter.not_set or
                                            self.output_interface_id.yfilter != YFilter.not_set or
                                            self.priority_count.yfilter != YFilter.not_set or
                                            self.te_metric.yfilter != YFilter.not_set or
                                            (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_operation()) or
                                            (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_operation()) or
                                            (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_operation()) or
                                            (self.link_sw_capability is not None and self.link_sw_capability.has_operation()) or
                                            (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls-te-link" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.affinity.is_set or self.affinity.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.affinity.get_name_leafdata())
                                        if (self.dste_allocation_model_id.is_set or self.dste_allocation_model_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dste_allocation_model_id.get_name_leafdata())
                                        if (self.dste_in_use.is_set or self.dste_in_use.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dste_in_use.get_name_leafdata())
                                        if (self.fragment_id.is_set or self.fragment_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fragment_id.get_name_leafdata())
                                        if (self.igp_metric.is_set or self.igp_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igp_metric.get_name_leafdata())
                                        if (self.input_interface_id.is_set or self.input_interface_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.input_interface_id.get_name_leafdata())
                                        if (self.link_address.is_set or self.link_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_address.get_name_leafdata())
                                        if (self.maximum_link_bw.is_set or self.maximum_link_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_link_bw.get_name_leafdata())
                                        if (self.maximum_link_reservable_bw.is_set or self.maximum_link_reservable_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_link_reservable_bw.get_name_leafdata())
                                        if (self.maximum_link_sub_reservable_bw.is_set or self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_link_sub_reservable_bw.get_name_leafdata())
                                        if (self.mpls_link_instance.is_set or self.mpls_link_instance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_link_instance.get_name_leafdata())
                                        if (self.mpls_link_type.is_set or self.mpls_link_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_link_type.get_name_leafdata())
                                        if (self.neighbor_ip_address.is_set or self.neighbor_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_ip_address.get_name_leafdata())
                                        if (self.neighbor_system_id.is_set or self.neighbor_system_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_system_id.get_name_leafdata())
                                        if (self.new_link.is_set or self.new_link.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.new_link.get_name_leafdata())
                                        if (self.number_of_optional_tl_vs.is_set or self.number_of_optional_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number_of_optional_tl_vs.get_name_leafdata())
                                        if (self.output_interface_id.is_set or self.output_interface_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.output_interface_id.get_name_leafdata())
                                        if (self.priority_count.is_set or self.priority_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.priority_count.get_name_leafdata())
                                        if (self.te_metric.is_set or self.te_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_metric.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "extended-admin-group-list"):
                                            if (self.extended_admin_group_list is None):
                                                self.extended_admin_group_list = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                                self.extended_admin_group_list.parent = self
                                                self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                            return self.extended_admin_group_list

                                        if (child_yang_name == "global-unreserve-bw-per-priority"):
                                            if (self.global_unreserve_bw_per_priority is None):
                                                self.global_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                                self.global_unreserve_bw_per_priority.parent = self
                                                self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                            return self.global_unreserve_bw_per_priority

                                        if (child_yang_name == "link-protocol-priority-capability"):
                                            if (self.link_protocol_priority_capability is None):
                                                self.link_protocol_priority_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                                self.link_protocol_priority_capability.parent = self
                                                self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                            return self.link_protocol_priority_capability

                                        if (child_yang_name == "link-sw-capability"):
                                            if (self.link_sw_capability is None):
                                                self.link_sw_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                                self.link_sw_capability.parent = self
                                                self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                            return self.link_sw_capability

                                        if (child_yang_name == "mplste-link-opt-tlv"):
                                            for c in self.mplste_link_opt_tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.mplste_link_opt_tlv.append(c)
                                            return c

                                        if (child_yang_name == "sub-pool-unreserve-bw-per-priority"):
                                            if (self.sub_pool_unreserve_bw_per_priority is None):
                                                self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                                self.sub_pool_unreserve_bw_per_priority.parent = self
                                                self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                            return self.sub_pool_unreserve_bw_per_priority

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "extended-admin-group-list" or name == "global-unreserve-bw-per-priority" or name == "link-protocol-priority-capability" or name == "link-sw-capability" or name == "mplste-link-opt-tlv" or name == "sub-pool-unreserve-bw-per-priority" or name == "affinity" or name == "dste-allocation-model-id" or name == "dste-in-use" or name == "fragment-id" or name == "igp-metric" or name == "input-interface-id" or name == "link-address" or name == "maximum-link-bw" or name == "maximum-link-reservable-bw" or name == "maximum-link-sub-reservable-bw" or name == "mpls-link-instance" or name == "mpls-link-type" or name == "neighbor-ip-address" or name == "neighbor-system-id" or name == "new-link" or name == "number-of-optional-tl-vs" or name == "output-interface-id" or name == "priority-count" or name == "te-metric"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "affinity"):
                                            self.affinity = value
                                            self.affinity.value_namespace = name_space
                                            self.affinity.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dste-allocation-model-id"):
                                            self.dste_allocation_model_id = value
                                            self.dste_allocation_model_id.value_namespace = name_space
                                            self.dste_allocation_model_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dste-in-use"):
                                            self.dste_in_use = value
                                            self.dste_in_use.value_namespace = name_space
                                            self.dste_in_use.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fragment-id"):
                                            self.fragment_id = value
                                            self.fragment_id.value_namespace = name_space
                                            self.fragment_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igp-metric"):
                                            self.igp_metric = value
                                            self.igp_metric.value_namespace = name_space
                                            self.igp_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "input-interface-id"):
                                            self.input_interface_id = value
                                            self.input_interface_id.value_namespace = name_space
                                            self.input_interface_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-address"):
                                            self.link_address = value
                                            self.link_address.value_namespace = name_space
                                            self.link_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-link-bw"):
                                            self.maximum_link_bw = value
                                            self.maximum_link_bw.value_namespace = name_space
                                            self.maximum_link_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-link-reservable-bw"):
                                            self.maximum_link_reservable_bw = value
                                            self.maximum_link_reservable_bw.value_namespace = name_space
                                            self.maximum_link_reservable_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-link-sub-reservable-bw"):
                                            self.maximum_link_sub_reservable_bw = value
                                            self.maximum_link_sub_reservable_bw.value_namespace = name_space
                                            self.maximum_link_sub_reservable_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-link-instance"):
                                            self.mpls_link_instance = value
                                            self.mpls_link_instance.value_namespace = name_space
                                            self.mpls_link_instance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-link-type"):
                                            self.mpls_link_type = value
                                            self.mpls_link_type.value_namespace = name_space
                                            self.mpls_link_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-ip-address"):
                                            self.neighbor_ip_address = value
                                            self.neighbor_ip_address.value_namespace = name_space
                                            self.neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-system-id"):
                                            self.neighbor_system_id = value
                                            self.neighbor_system_id.value_namespace = name_space
                                            self.neighbor_system_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "new-link"):
                                            self.new_link = value
                                            self.new_link.value_namespace = name_space
                                            self.new_link.value_namespace_prefix = name_space_prefix
                                        if(value_path == "number-of-optional-tl-vs"):
                                            self.number_of_optional_tl_vs = value
                                            self.number_of_optional_tl_vs.value_namespace = name_space
                                            self.number_of_optional_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "output-interface-id"):
                                            self.output_interface_id = value
                                            self.output_interface_id.value_namespace = name_space
                                            self.output_interface_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "priority-count"):
                                            self.priority_count = value
                                            self.priority_count.value_namespace = name_space
                                            self.priority_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-metric"):
                                            self.te_metric = value
                                            self.te_metric.value_namespace = name_space
                                            self.te_metric.value_namespace_prefix = name_space_prefix


                                class MplsTeFragment(Entity):
                                    """
                                    MPLS TE fragments in the area
                                    
                                    .. attribute:: dste_model_id
                                    
                                    	DS\-TE Allocation Model ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: fragment_id
                                    
                                    	Fragment ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fragment_instance
                                    
                                    	Fragment instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mpls_te_link
                                    
                                    	List of fragment links
                                    	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink>`
                                    
                                    .. attribute:: same_fragment_count
                                    
                                    	Number of fragment links which haven't changed since the last update
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment, self).__init__()

                                        self.yang_name = "mpls-te-fragment"
                                        self.yang_parent_name = "mpls-te-fragment"

                                        self.dste_model_id = YLeaf(YType.uint8, "dste-model-id")

                                        self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                        self.fragment_instance = YLeaf(YType.uint32, "fragment-instance")

                                        self.same_fragment_count = YLeaf(YType.uint8, "same-fragment-count")

                                        self.mpls_te_link = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dste_model_id",
                                                        "fragment_id",
                                                        "fragment_instance",
                                                        "same_fragment_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment, self).__setattr__(name, value)


                                    class MplsTeLink(Entity):
                                        """
                                        List of fragment links
                                        
                                        .. attribute:: affinity
                                        
                                        	Affinity
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dste_allocation_model_id
                                        
                                        	DS\-TE Allocation Model ID
                                        	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                        
                                        .. attribute:: dste_in_use
                                        
                                        	A DS\-TE Allocation Model in use
                                        	**type**\:  bool
                                        
                                        .. attribute:: extended_admin_group_list
                                        
                                        	Extended Admin Group
                                        	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList>`
                                        
                                        .. attribute:: fragment_id
                                        
                                        	Fragment ID for this link
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: global_unreserve_bw_per_priority
                                        
                                        	Global pool unreserved bandwidth for each priority (bytes/s)
                                        	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                        
                                        .. attribute:: igp_metric
                                        
                                        	Link IGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: input_interface_id
                                        
                                        	Input interface ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_address
                                        
                                        	The local interface address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: link_protocol_priority_capability
                                        
                                        	Link protocol and protocol priority capability
                                        	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability>`
                                        
                                        .. attribute:: link_sw_capability
                                        
                                        	Link switching capability
                                        	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability>`
                                        
                                        .. attribute:: maximum_link_bw
                                        
                                        	Maximum link bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte/s
                                        
                                        .. attribute:: maximum_link_reservable_bw
                                        
                                        	Maximum link global pool reservable bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte/s
                                        
                                        .. attribute:: maximum_link_sub_reservable_bw
                                        
                                        	Maximum link subpool reservable bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte/s
                                        
                                        .. attribute:: mpls_link_instance
                                        
                                        	Link instance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mpls_link_type
                                        
                                        	Type of link
                                        	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                        
                                        .. attribute:: mplste_link_opt_tlv
                                        
                                        	List of Optional TLVs
                                        	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv>`
                                        
                                        .. attribute:: neighbor_ip_address
                                        
                                        	Neighbor IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_system_id
                                        
                                        	Neighbor system ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: new_link
                                        
                                        	If true, Link is new
                                        	**type**\:  bool
                                        
                                        .. attribute:: number_of_optional_tl_vs
                                        
                                        	Number of Optional TLVs
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: output_interface_id
                                        
                                        	Output interface ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority_count
                                        
                                        	Number of priorities
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_pool_unreserve_bw_per_priority
                                        
                                        	Sub pool unreserved bandwidth for each priority (bytes/s)
                                        	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                        
                                        .. attribute:: te_metric
                                        
                                        	Link TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink, self).__init__()

                                            self.yang_name = "mpls-te-link"
                                            self.yang_parent_name = "mpls-te-fragment"

                                            self.affinity = YLeaf(YType.uint32, "affinity")

                                            self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                            self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                            self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                            self.link_address = YLeaf(YType.str, "link-address")

                                            self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                            self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                            self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                            self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                            self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                            self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                            self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                            self.new_link = YLeaf(YType.boolean, "new-link")

                                            self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                            self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                            self.priority_count = YLeaf(YType.int32, "priority-count")

                                            self.te_metric = YLeaf(YType.uint32, "te-metric")

                                            self.extended_admin_group_list = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                            self.extended_admin_group_list.parent = self
                                            self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                            self._children_yang_names.add("extended-admin-group-list")

                                            self.global_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                            self.global_unreserve_bw_per_priority.parent = self
                                            self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                            self._children_yang_names.add("global-unreserve-bw-per-priority")

                                            self.link_protocol_priority_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                            self.link_protocol_priority_capability.parent = self
                                            self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                            self._children_yang_names.add("link-protocol-priority-capability")

                                            self.link_sw_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                            self.link_sw_capability.parent = self
                                            self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                            self._children_yang_names.add("link-sw-capability")

                                            self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                            self.sub_pool_unreserve_bw_per_priority.parent = self
                                            self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                            self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                            self.mplste_link_opt_tlv = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("affinity",
                                                            "dste_allocation_model_id",
                                                            "dste_in_use",
                                                            "fragment_id",
                                                            "igp_metric",
                                                            "input_interface_id",
                                                            "link_address",
                                                            "maximum_link_bw",
                                                            "maximum_link_reservable_bw",
                                                            "maximum_link_sub_reservable_bw",
                                                            "mpls_link_instance",
                                                            "mpls_link_type",
                                                            "neighbor_ip_address",
                                                            "neighbor_system_id",
                                                            "new_link",
                                                            "number_of_optional_tl_vs",
                                                            "output_interface_id",
                                                            "priority_count",
                                                            "te_metric") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink, self).__setattr__(name, value)


                                        class GlobalUnreserveBwPerPriority(Entity):
                                            """
                                            Global pool unreserved bandwidth for each
                                            priority (bytes/s)
                                            
                                            .. attribute:: bw_per_priority
                                            
                                            	Unreserved bandwidth for each priority (bytes/s)
                                            	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                                self.yang_name = "global-unreserve-bw-per-priority"
                                                self.yang_parent_name = "mpls-te-link"

                                                self.bw_per_priority = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)


                                            class BwPerPriority(Entity):
                                                """
                                                Unreserved bandwidth for each priority (bytes/s)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte/s
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                    self.yang_name = "bw-per-priority"
                                                    self.yang_parent_name = "global-unreserve-bw-per-priority"

                                                    self.entry = YLeaf(YType.uint64, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bw-per-priority" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.bw_per_priority:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.bw_per_priority:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "global-unreserve-bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bw-per-priority"):
                                                    for c in self.bw_per_priority:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.bw_per_priority.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bw-per-priority"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class SubPoolUnreserveBwPerPriority(Entity):
                                            """
                                            Sub pool unreserved bandwidth for each priority
                                            (bytes/s)
                                            
                                            .. attribute:: bw_per_priority
                                            
                                            	Unreserved bandwidth for each priority (bytes/s)
                                            	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                                self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                                self.yang_parent_name = "mpls-te-link"

                                                self.bw_per_priority = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)


                                            class BwPerPriority(Entity):
                                                """
                                                Unreserved bandwidth for each priority (bytes/s)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte/s
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                    self.yang_name = "bw-per-priority"
                                                    self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"

                                                    self.entry = YLeaf(YType.uint64, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bw-per-priority" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.bw_per_priority:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.bw_per_priority:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sub-pool-unreserve-bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bw-per-priority"):
                                                    for c in self.bw_per_priority:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.bw_per_priority.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bw-per-priority"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class LinkProtocolPriorityCapability(Entity):
                                            """
                                            Link protocol and protocol priority capability
                                            
                                            .. attribute:: link_protocol_capability
                                            
                                            	Link protocol capability
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: link_protocol_priority
                                            
                                            	Link protocol priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                                self.yang_name = "link-protocol-priority-capability"
                                                self.yang_parent_name = "mpls-te-link"

                                                self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                                self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("link_protocol_capability",
                                                                "link_protocol_priority") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.link_protocol_capability.is_set or
                                                    self.link_protocol_priority.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.link_protocol_capability.yfilter != YFilter.not_set or
                                                    self.link_protocol_priority.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "link-protocol-priority-capability" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.link_protocol_capability.is_set or self.link_protocol_capability.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_protocol_capability.get_name_leafdata())
                                                if (self.link_protocol_priority.is_set or self.link_protocol_priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_protocol_priority.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "link-protocol-capability" or name == "link-protocol-priority"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "link-protocol-capability"):
                                                    self.link_protocol_capability = value
                                                    self.link_protocol_capability.value_namespace = name_space
                                                    self.link_protocol_capability.value_namespace_prefix = name_space_prefix
                                                if(value_path == "link-protocol-priority"):
                                                    self.link_protocol_priority = value
                                                    self.link_protocol_priority.value_namespace = name_space
                                                    self.link_protocol_priority.value_namespace_prefix = name_space_prefix


                                        class LinkSwCapability(Entity):
                                            """
                                            Link switching capability
                                            
                                            .. attribute:: link_encoding
                                            
                                            	Link Encoding
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: link_mtu
                                            
                                            	Link MTU size (bytes)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: link_switching_capability
                                            
                                            	Link Switching Capability
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: maximum_lsp_bw_per_priority
                                            
                                            	Maximum LSP bandwidth for each priority  (bytes/s)
                                            	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                            
                                            .. attribute:: minimum_lsp_bw
                                            
                                            	Minimum LSP bandwidth (bytes/s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__init__()

                                                self.yang_name = "link-sw-capability"
                                                self.yang_parent_name = "mpls-te-link"

                                                self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                                self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                                self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                                self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                                self.maximum_lsp_bw_per_priority = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("link_encoding",
                                                                "link_mtu",
                                                                "link_switching_capability",
                                                                "minimum_lsp_bw") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)


                                            class MaximumLspBwPerPriority(Entity):
                                                """
                                                Maximum LSP bandwidth for each priority
                                                
                                                (bytes/s)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte/s
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                                    self.yang_name = "maximum-lsp-bw-per-priority"
                                                    self.yang_parent_name = "link-sw-capability"

                                                    self.entry = YLeaf(YType.uint64, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "maximum-lsp-bw-per-priority" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.maximum_lsp_bw_per_priority:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.link_encoding.is_set or
                                                    self.link_mtu.is_set or
                                                    self.link_switching_capability.is_set or
                                                    self.minimum_lsp_bw.is_set)

                                            def has_operation(self):
                                                for c in self.maximum_lsp_bw_per_priority:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.link_encoding.yfilter != YFilter.not_set or
                                                    self.link_mtu.yfilter != YFilter.not_set or
                                                    self.link_switching_capability.yfilter != YFilter.not_set or
                                                    self.minimum_lsp_bw.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "link-sw-capability" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.link_encoding.is_set or self.link_encoding.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_encoding.get_name_leafdata())
                                                if (self.link_mtu.is_set or self.link_mtu.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_mtu.get_name_leafdata())
                                                if (self.link_switching_capability.is_set or self.link_switching_capability.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_switching_capability.get_name_leafdata())
                                                if (self.minimum_lsp_bw.is_set or self.minimum_lsp_bw.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minimum_lsp_bw.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "maximum-lsp-bw-per-priority"):
                                                    for c in self.maximum_lsp_bw_per_priority:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.maximum_lsp_bw_per_priority.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "maximum-lsp-bw-per-priority" or name == "link-encoding" or name == "link-mtu" or name == "link-switching-capability" or name == "minimum-lsp-bw"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "link-encoding"):
                                                    self.link_encoding = value
                                                    self.link_encoding.value_namespace = name_space
                                                    self.link_encoding.value_namespace_prefix = name_space_prefix
                                                if(value_path == "link-mtu"):
                                                    self.link_mtu = value
                                                    self.link_mtu.value_namespace = name_space
                                                    self.link_mtu.value_namespace_prefix = name_space_prefix
                                                if(value_path == "link-switching-capability"):
                                                    self.link_switching_capability = value
                                                    self.link_switching_capability.value_namespace = name_space
                                                    self.link_switching_capability.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minimum-lsp-bw"):
                                                    self.minimum_lsp_bw = value
                                                    self.minimum_lsp_bw.value_namespace = name_space
                                                    self.minimum_lsp_bw.value_namespace_prefix = name_space_prefix


                                        class ExtendedAdminGroupList(Entity):
                                            """
                                            Extended Admin Group
                                            
                                            .. attribute:: ext_admin_data
                                            
                                            	Value of Extended Admin Group
                                            	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                            
                                            .. attribute:: extended_admin_size
                                            
                                            	Size of the extended admin group
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                                self.yang_name = "extended-admin-group-list"
                                                self.yang_parent_name = "mpls-te-link"

                                                self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                                self.ext_admin_data = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("extended_admin_size") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)


                                            class ExtAdminData(Entity):
                                                """
                                                Value of Extended Admin Group
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                                    self.yang_name = "ext-admin-data"
                                                    self.yang_parent_name = "extended-admin-group-list"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ext-admin-data" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.ext_admin_data:
                                                    if (c.has_data()):
                                                        return True
                                                return self.extended_admin_size.is_set

                                            def has_operation(self):
                                                for c in self.ext_admin_data:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.extended_admin_size.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "extended-admin-group-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.extended_admin_size.is_set or self.extended_admin_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.extended_admin_size.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ext-admin-data"):
                                                    for c in self.ext_admin_data:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.ext_admin_data.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ext-admin-data" or name == "extended-admin-size"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "extended-admin-size"):
                                                    self.extended_admin_size = value
                                                    self.extended_admin_size.value_namespace = name_space
                                                    self.extended_admin_size.value_namespace_prefix = name_space_prefix


                                        class MplsteLinkOptTlv(Entity):
                                            """
                                            List of Optional TLVs
                                            
                                            .. attribute:: mplste_link_opt_tlv_len
                                            
                                            	Length of Opt TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mplste_link_opt_tlv_type
                                            
                                            	Type of Opt TLV
                                            	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                            
                                            .. attribute:: mplste_link_opt_tlv_value
                                            
                                            	Value of Opt TLV
                                            	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                                self.yang_name = "mplste-link-opt-tlv"
                                                self.yang_parent_name = "mpls-te-link"

                                                self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                                self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                                self.mplste_link_opt_tlv_value = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("mplste_link_opt_tlv_len",
                                                                "mplste_link_opt_tlv_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)


                                            class MplsteLinkOptTlvValue(Entity):
                                                """
                                                Value of Opt TLV
                                                
                                                .. attribute:: bctlv_value
                                                
                                                	Value of Bandwidth Constraints TLV
                                                	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                                
                                                .. attribute:: ixcdtlv_value
                                                
                                                	Value of IXCD TLV
                                                	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                                
                                                .. attribute:: opaque_tlv_type
                                                
                                                	OpaqueTLVType
                                                	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                                
                                                .. attribute:: srlgtlv_value
                                                
                                                	Value of SRLG TLV
                                                	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                                
                                                .. attribute:: unidtlv_value
                                                
                                                	Value of Uni Delay TLV
                                                	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                                    self.yang_name = "mplste-link-opt-tlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv"

                                                    self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                                    self.bctlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                    self.bctlv_value.parent = self
                                                    self._children_name_map["bctlv_value"] = "bctlv-value"
                                                    self._children_yang_names.add("bctlv-value")

                                                    self.ixcdtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                    self.ixcdtlv_value.parent = self
                                                    self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                    self._children_yang_names.add("ixcdtlv-value")

                                                    self.srlgtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                    self.srlgtlv_value.parent = self
                                                    self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                    self._children_yang_names.add("srlgtlv-value")

                                                    self.unidtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                    self.unidtlv_value.parent = self
                                                    self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                    self._children_yang_names.add("unidtlv-value")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("opaque_tlv_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)


                                                class BctlvValue(Entity):
                                                    """
                                                    Value of Bandwidth Constraints TLV
                                                    
                                                    .. attribute:: model_id
                                                    
                                                    	Allocation Model ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mplste_link_bc_bandwidth
                                                    
                                                    	Value of BC TLV
                                                    	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                                    
                                                    .. attribute:: num_b_cs
                                                    
                                                    	Number of BC TLVs
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                        self.yang_name = "bctlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                        self.model_id = YLeaf(YType.uint8, "model-id")

                                                        self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                        self.mplste_link_bc_bandwidth = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("model_id",
                                                                        "num_b_cs") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)


                                                    class MplsteLinkBcBandwidth(Entity):
                                                        """
                                                        Value of BC TLV
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                            self.yang_name = "mplste-link-bc-bandwidth"
                                                            self.yang_parent_name = "bctlv-value"

                                                            self.entry = YLeaf(YType.uint64, "entry")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("entry") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return self.entry.is_set

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.entry.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "mplste-link-bc-bandwidth" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "entry"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "entry"):
                                                                self.entry = value
                                                                self.entry.value_namespace = name_space
                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.mplste_link_bc_bandwidth:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.model_id.is_set or
                                                            self.num_b_cs.is_set)

                                                    def has_operation(self):
                                                        for c in self.mplste_link_bc_bandwidth:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.model_id.yfilter != YFilter.not_set or
                                                            self.num_b_cs.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "bctlv-value" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.model_id.is_set or self.model_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.model_id.get_name_leafdata())
                                                        if (self.num_b_cs.is_set or self.num_b_cs.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_b_cs.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "mplste-link-bc-bandwidth"):
                                                            for c in self.mplste_link_bc_bandwidth:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.mplste_link_bc_bandwidth.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "mplste-link-bc-bandwidth" or name == "model-id" or name == "num-b-cs"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "model-id"):
                                                            self.model_id = value
                                                            self.model_id.value_namespace = name_space
                                                            self.model_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-b-cs"):
                                                            self.num_b_cs = value
                                                            self.num_b_cs.value_namespace = name_space
                                                            self.num_b_cs.value_namespace_prefix = name_space_prefix


                                                class SrlgtlvValue(Entity):
                                                    """
                                                    Value of SRLG TLV
                                                    
                                                    .. attribute:: mplste_link_srlg_data
                                                    
                                                    	Value of SRLG TLV
                                                    	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                                    
                                                    .. attribute:: num_srl_gs
                                                    
                                                    	Number of SRLG TLVs
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: srlg_len
                                                    
                                                    	Length of SRLG TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                        self.yang_name = "srlgtlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                        self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                        self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                        self.mplste_link_srlg_data = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("num_srl_gs",
                                                                        "srlg_len") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)


                                                    class MplsteLinkSrlgData(Entity):
                                                        """
                                                        Value of SRLG TLV
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                            self.yang_name = "mplste-link-srlg-data"
                                                            self.yang_parent_name = "srlgtlv-value"

                                                            self.entry = YLeaf(YType.uint32, "entry")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("entry") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return self.entry.is_set

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.entry.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "mplste-link-srlg-data" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "entry"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "entry"):
                                                                self.entry = value
                                                                self.entry.value_namespace = name_space
                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.mplste_link_srlg_data:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.num_srl_gs.is_set or
                                                            self.srlg_len.is_set)

                                                    def has_operation(self):
                                                        for c in self.mplste_link_srlg_data:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.num_srl_gs.yfilter != YFilter.not_set or
                                                            self.srlg_len.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "srlgtlv-value" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.num_srl_gs.is_set or self.num_srl_gs.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_srl_gs.get_name_leafdata())
                                                        if (self.srlg_len.is_set or self.srlg_len.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.srlg_len.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "mplste-link-srlg-data"):
                                                            for c in self.mplste_link_srlg_data:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.mplste_link_srlg_data.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "mplste-link-srlg-data" or name == "num-srl-gs" or name == "srlg-len"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "num-srl-gs"):
                                                            self.num_srl_gs = value
                                                            self.num_srl_gs.value_namespace = name_space
                                                            self.num_srl_gs.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "srlg-len"):
                                                            self.srlg_len = value
                                                            self.srlg_len.value_namespace = name_space
                                                            self.srlg_len.value_namespace_prefix = name_space_prefix


                                                class IxcdtlvValue(Entity):
                                                    """
                                                    Value of IXCD TLV
                                                    
                                                    .. attribute:: fixed_scsi_count
                                                    
                                                    	Fixed SCSI count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flex_scsi_count
                                                    
                                                    	Flexible SCSI count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ixcd_switching_cap_type
                                                    
                                                    	Switching Cap type
                                                    	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                                    
                                                    .. attribute:: max_lspbw
                                                    
                                                    	Max LSP bandwidth array
                                                    	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                                    
                                                    .. attribute:: rile_len_code
                                                    
                                                    	Rile LenCode
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: switching_cap
                                                    
                                                    	SCap
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                        self.yang_name = "ixcdtlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                        self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                        self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                        self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                        self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                        self.ixcd_switching_cap_type = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                        self.ixcd_switching_cap_type.parent = self
                                                        self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                        self._children_yang_names.add("ixcd-switching-cap-type")

                                                        self.max_lspbw = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("fixed_scsi_count",
                                                                        "flex_scsi_count",
                                                                        "rile_len_code",
                                                                        "switching_cap") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)


                                                    class IxcdSwitchingCapType(Entity):
                                                        """
                                                        Switching Cap type
                                                        
                                                        .. attribute:: ixcdbw_sub_tlv
                                                        
                                                        	Sub TLVs
                                                        	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                        
                                                        .. attribute:: ixcdpsc_info
                                                        
                                                        	IXCD PSC information
                                                        	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                        
                                                        .. attribute:: switching_cap_type
                                                        
                                                        	SwitchingCapType
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                            self.yang_name = "ixcd-switching-cap-type"
                                                            self.yang_parent_name = "ixcdtlv-value"

                                                            self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                            self.ixcdbw_sub_tlv = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                            self.ixcdbw_sub_tlv.parent = self
                                                            self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                            self._children_yang_names.add("ixcdbw-sub-tlv")

                                                            self.ixcdpsc_info = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                            self.ixcdpsc_info.parent = self
                                                            self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                            self._children_yang_names.add("ixcdpsc-info")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("switching_cap_type") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)


                                                        class IxcdpscInfo(Entity):
                                                            """
                                                            IXCD PSC information
                                                            
                                                            .. attribute:: min_lsp_bandwidth
                                                            
                                                            	Min LSP bandwidth
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: psc_interface_mtu
                                                            
                                                            	 Interface MTU
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                                self.yang_name = "ixcdpsc-info"
                                                                self.yang_parent_name = "ixcd-switching-cap-type"

                                                                self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                                self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("min_lsp_bandwidth",
                                                                                "psc_interface_mtu") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)

                                                            def has_data(self):
                                                                return (
                                                                    self.min_lsp_bandwidth.is_set or
                                                                    self.psc_interface_mtu.is_set)

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.min_lsp_bandwidth.yfilter != YFilter.not_set or
                                                                    self.psc_interface_mtu.yfilter != YFilter.not_set)

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "ixcdpsc-info" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.min_lsp_bandwidth.is_set or self.min_lsp_bandwidth.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.min_lsp_bandwidth.get_name_leafdata())
                                                                if (self.psc_interface_mtu.is_set or self.psc_interface_mtu.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.psc_interface_mtu.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "min-lsp-bandwidth" or name == "psc-interface-mtu"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "min-lsp-bandwidth"):
                                                                    self.min_lsp_bandwidth = value
                                                                    self.min_lsp_bandwidth.value_namespace = name_space
                                                                    self.min_lsp_bandwidth.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "psc-interface-mtu"):
                                                                    self.psc_interface_mtu = value
                                                                    self.psc_interface_mtu.value_namespace = name_space
                                                                    self.psc_interface_mtu.value_namespace_prefix = name_space_prefix


                                                        class IxcdbwSubTlv(Entity):
                                                            """
                                                            Sub TLVs
                                                            
                                                            .. attribute:: arr_bw_sub_tlv
                                                            
                                                            	Array of sub tlvs
                                                            	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                                self.yang_name = "ixcdbw-sub-tlv"
                                                                self.yang_parent_name = "ixcd-switching-cap-type"

                                                                self.arr_bw_sub_tlv = YList(self)

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in () and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)


                                                            class ArrBwSubTlv(Entity):
                                                                """
                                                                Array of sub tlvs
                                                                
                                                                .. attribute:: bw_sub_tlv_length
                                                                
                                                                	Length of BW Sub TLV
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: bw_sub_tlv_type
                                                                
                                                                	Type of Sub TLV
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: bw_sub_tlv_value
                                                                
                                                                	Value of BW Sub TLV
                                                                	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-01-02'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                                    self.yang_name = "arr-bw-sub-tlv"
                                                                    self.yang_parent_name = "ixcdbw-sub-tlv"

                                                                    self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                                    self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                                    self.bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                    self.bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                    self._children_yang_names.add("bw-sub-tlv-value")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("bw_sub_tlv_length",
                                                                                    "bw_sub_tlv_type") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)


                                                                class BwSubTlvValue(Entity):
                                                                    """
                                                                    Value of BW Sub TLV
                                                                    
                                                                    .. attribute:: fixed_bw_sub_tlv_value
                                                                    
                                                                    	Value of Fixed Sub TLV
                                                                    	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                                    
                                                                    .. attribute:: flex_bw_sub_tlv_value
                                                                    
                                                                    	Value of Flex Sub TLV
                                                                    	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                                    
                                                                    .. attribute:: ixcdbw_sub_tlv_type
                                                                    
                                                                    	IXCDBWSubTLVType
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                        self.yang_name = "bw-sub-tlv-value"
                                                                        self.yang_parent_name = "arr-bw-sub-tlv"

                                                                        self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                        self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                        self.fixed_bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                        self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                        self.flex_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                        self.flex_bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                        self._children_yang_names.add("flex-bw-sub-tlv-value")

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in ("ixcdbw_sub_tlv_type") and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)


                                                                    class FixedBwSubTlvValue(Entity):
                                                                        """
                                                                        Value of Fixed Sub TLV
                                                                        
                                                                        .. attribute:: fixed_sub_tlv_value
                                                                        
                                                                        	Value of Fixed Sub TLV
                                                                        	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                        
                                                                        .. attribute:: unres_oduj_prio
                                                                        
                                                                        	Array of Unres Oduj Prio
                                                                        	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                            self.yang_name = "fixed-bw-sub-tlv-value"
                                                                            self.yang_parent_name = "bw-sub-tlv-value"

                                                                            self.fixed_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                            self.fixed_sub_tlv_value.parent = self
                                                                            self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                            self._children_yang_names.add("fixed-sub-tlv-value")

                                                                            self.unres_oduj_prio = YList(self)

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in () and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)


                                                                        class FixedSubTlvValue(Entity):
                                                                            """
                                                                            Value of Fixed Sub TLV
                                                                            
                                                                            .. attribute:: num_stages
                                                                            
                                                                            	Number of stages
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit0
                                                                            
                                                                            	Priority 0
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit1
                                                                            
                                                                            	Priority 1
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit2
                                                                            
                                                                            	Priority 2
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit3
                                                                            
                                                                            	Priority 3
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit4
                                                                            
                                                                            	Priority 4
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit5
                                                                            
                                                                            	Priority 5
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit6
                                                                            
                                                                            	Priority 6
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit7
                                                                            
                                                                            	Priority 7
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: res
                                                                            
                                                                            	Res
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: sbit
                                                                            
                                                                            	S Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: signal_type
                                                                            
                                                                            	Signal Type
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: stage
                                                                            
                                                                            	Array of Stages
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                            
                                                                            .. attribute:: tbit
                                                                            
                                                                            	T Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: tsg
                                                                            
                                                                            	TSG
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-01-02'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                                self.yang_name = "fixed-sub-tlv-value"
                                                                                self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                                self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                                self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                                self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                                self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                                self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                                self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                                self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                                self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                                self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                                self.res = YLeaf(YType.uint8, "res")

                                                                                self.sbit = YLeaf(YType.uint8, "sbit")

                                                                                self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                                self.stage = YLeaf(YType.str, "stage")

                                                                                self.tbit = YLeaf(YType.uint8, "tbit")

                                                                                self.tsg = YLeaf(YType.uint8, "tsg")

                                                                            def __setattr__(self, name, value):
                                                                                self._check_monkey_patching_error(name, value)
                                                                                with _handle_type_error():
                                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                            "Please use list append or extend method."
                                                                                                            .format(value))
                                                                                    if isinstance(value, Enum.YLeaf):
                                                                                        value = value.name
                                                                                    if name in ("num_stages",
                                                                                                "priority_bit0",
                                                                                                "priority_bit1",
                                                                                                "priority_bit2",
                                                                                                "priority_bit3",
                                                                                                "priority_bit4",
                                                                                                "priority_bit5",
                                                                                                "priority_bit6",
                                                                                                "priority_bit7",
                                                                                                "res",
                                                                                                "sbit",
                                                                                                "signal_type",
                                                                                                "stage",
                                                                                                "tbit",
                                                                                                "tsg") and name in self.__dict__:
                                                                                        if isinstance(value, YLeaf):
                                                                                            self.__dict__[name].set(value.get())
                                                                                        elif isinstance(value, YLeafList):
                                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)
                                                                                        else:
                                                                                            self.__dict__[name].set(value)
                                                                                    else:
                                                                                        if hasattr(value, "parent") and name != "parent":
                                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                                value.parent = self
                                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                                value.parent = self
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)

                                                                            def has_data(self):
                                                                                return (
                                                                                    self.num_stages.is_set or
                                                                                    self.priority_bit0.is_set or
                                                                                    self.priority_bit1.is_set or
                                                                                    self.priority_bit2.is_set or
                                                                                    self.priority_bit3.is_set or
                                                                                    self.priority_bit4.is_set or
                                                                                    self.priority_bit5.is_set or
                                                                                    self.priority_bit6.is_set or
                                                                                    self.priority_bit7.is_set or
                                                                                    self.res.is_set or
                                                                                    self.sbit.is_set or
                                                                                    self.signal_type.is_set or
                                                                                    self.stage.is_set or
                                                                                    self.tbit.is_set or
                                                                                    self.tsg.is_set)

                                                                            def has_operation(self):
                                                                                return (
                                                                                    self.yfilter != YFilter.not_set or
                                                                                    self.num_stages.yfilter != YFilter.not_set or
                                                                                    self.priority_bit0.yfilter != YFilter.not_set or
                                                                                    self.priority_bit1.yfilter != YFilter.not_set or
                                                                                    self.priority_bit2.yfilter != YFilter.not_set or
                                                                                    self.priority_bit3.yfilter != YFilter.not_set or
                                                                                    self.priority_bit4.yfilter != YFilter.not_set or
                                                                                    self.priority_bit5.yfilter != YFilter.not_set or
                                                                                    self.priority_bit6.yfilter != YFilter.not_set or
                                                                                    self.priority_bit7.yfilter != YFilter.not_set or
                                                                                    self.res.yfilter != YFilter.not_set or
                                                                                    self.sbit.yfilter != YFilter.not_set or
                                                                                    self.signal_type.yfilter != YFilter.not_set or
                                                                                    self.stage.yfilter != YFilter.not_set or
                                                                                    self.tbit.yfilter != YFilter.not_set or
                                                                                    self.tsg.yfilter != YFilter.not_set)

                                                                            def get_segment_path(self):
                                                                                path_buffer = ""
                                                                                path_buffer = "fixed-sub-tlv-value" + path_buffer

                                                                                return path_buffer

                                                                            def get_entity_path(self, ancestor):
                                                                                path_buffer = ""
                                                                                if (ancestor is None):
                                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                                else:
                                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                                leaf_name_data = LeafDataList()
                                                                                if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                                if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                                if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                                if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                                if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                                if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                                if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                                if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                                if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                                if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.res.get_name_leafdata())
                                                                                if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                                if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                                if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.stage.get_name_leafdata())
                                                                                if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                                if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                                return entity_path

                                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                                if child is not None:
                                                                                    return child

                                                                                return None

                                                                            def has_leaf_or_child_of_name(self, name):
                                                                                if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                                    return True
                                                                                return False

                                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                                if(value_path == "num-stages"):
                                                                                    self.num_stages = value
                                                                                    self.num_stages.value_namespace = name_space
                                                                                    self.num_stages.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit0"):
                                                                                    self.priority_bit0 = value
                                                                                    self.priority_bit0.value_namespace = name_space
                                                                                    self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit1"):
                                                                                    self.priority_bit1 = value
                                                                                    self.priority_bit1.value_namespace = name_space
                                                                                    self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit2"):
                                                                                    self.priority_bit2 = value
                                                                                    self.priority_bit2.value_namespace = name_space
                                                                                    self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit3"):
                                                                                    self.priority_bit3 = value
                                                                                    self.priority_bit3.value_namespace = name_space
                                                                                    self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit4"):
                                                                                    self.priority_bit4 = value
                                                                                    self.priority_bit4.value_namespace = name_space
                                                                                    self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit5"):
                                                                                    self.priority_bit5 = value
                                                                                    self.priority_bit5.value_namespace = name_space
                                                                                    self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit6"):
                                                                                    self.priority_bit6 = value
                                                                                    self.priority_bit6.value_namespace = name_space
                                                                                    self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit7"):
                                                                                    self.priority_bit7 = value
                                                                                    self.priority_bit7.value_namespace = name_space
                                                                                    self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "res"):
                                                                                    self.res = value
                                                                                    self.res.value_namespace = name_space
                                                                                    self.res.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "sbit"):
                                                                                    self.sbit = value
                                                                                    self.sbit.value_namespace = name_space
                                                                                    self.sbit.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "signal-type"):
                                                                                    self.signal_type = value
                                                                                    self.signal_type.value_namespace = name_space
                                                                                    self.signal_type.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "stage"):
                                                                                    self.stage = value
                                                                                    self.stage.value_namespace = name_space
                                                                                    self.stage.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "tbit"):
                                                                                    self.tbit = value
                                                                                    self.tbit.value_namespace = name_space
                                                                                    self.tbit.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "tsg"):
                                                                                    self.tsg = value
                                                                                    self.tsg.value_namespace = name_space
                                                                                    self.tsg.value_namespace_prefix = name_space_prefix


                                                                        class UnresOdujPrio(Entity):
                                                                            """
                                                                            Array of Unres Oduj Prio
                                                                            
                                                                            .. attribute:: entry
                                                                            
                                                                            	
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-01-02'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                                self.yang_name = "unres-oduj-prio"
                                                                                self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                                self.entry = YLeaf(YType.uint32, "entry")

                                                                            def __setattr__(self, name, value):
                                                                                self._check_monkey_patching_error(name, value)
                                                                                with _handle_type_error():
                                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                            "Please use list append or extend method."
                                                                                                            .format(value))
                                                                                    if isinstance(value, Enum.YLeaf):
                                                                                        value = value.name
                                                                                    if name in ("entry") and name in self.__dict__:
                                                                                        if isinstance(value, YLeaf):
                                                                                            self.__dict__[name].set(value.get())
                                                                                        elif isinstance(value, YLeafList):
                                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)
                                                                                        else:
                                                                                            self.__dict__[name].set(value)
                                                                                    else:
                                                                                        if hasattr(value, "parent") and name != "parent":
                                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                                value.parent = self
                                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                                value.parent = self
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)

                                                                            def has_data(self):
                                                                                return self.entry.is_set

                                                                            def has_operation(self):
                                                                                return (
                                                                                    self.yfilter != YFilter.not_set or
                                                                                    self.entry.yfilter != YFilter.not_set)

                                                                            def get_segment_path(self):
                                                                                path_buffer = ""
                                                                                path_buffer = "unres-oduj-prio" + path_buffer

                                                                                return path_buffer

                                                                            def get_entity_path(self, ancestor):
                                                                                path_buffer = ""
                                                                                if (ancestor is None):
                                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                                else:
                                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                                leaf_name_data = LeafDataList()
                                                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                                return entity_path

                                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                                if child is not None:
                                                                                    return child

                                                                                return None

                                                                            def has_leaf_or_child_of_name(self, name):
                                                                                if(name == "entry"):
                                                                                    return True
                                                                                return False

                                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                                if(value_path == "entry"):
                                                                                    self.entry = value
                                                                                    self.entry.value_namespace = name_space
                                                                                    self.entry.value_namespace_prefix = name_space_prefix

                                                                        def has_data(self):
                                                                            for c in self.unres_oduj_prio:
                                                                                if (c.has_data()):
                                                                                    return True
                                                                            return (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_data())

                                                                        def has_operation(self):
                                                                            for c in self.unres_oduj_prio:
                                                                                if (c.has_operation()):
                                                                                    return True
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_operation()))

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "fixed-bw-sub-tlv-value" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            if (child_yang_name == "fixed-sub-tlv-value"):
                                                                                if (self.fixed_sub_tlv_value is None):
                                                                                    self.fixed_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                                    self.fixed_sub_tlv_value.parent = self
                                                                                    self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                                return self.fixed_sub_tlv_value

                                                                            if (child_yang_name == "unres-oduj-prio"):
                                                                                for c in self.unres_oduj_prio:
                                                                                    segment = c.get_segment_path()
                                                                                    if (segment_path == segment):
                                                                                        return c
                                                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio()
                                                                                c.parent = self
                                                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                                                self._local_refs[local_reference_key] = c
                                                                                self.unres_oduj_prio.append(c)
                                                                                return c

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "fixed-sub-tlv-value" or name == "unres-oduj-prio"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            pass


                                                                    class FlexBwSubTlvValue(Entity):
                                                                        """
                                                                        Value of Flex Sub TLV
                                                                        
                                                                        .. attribute:: flex_sub_tlv_value_common
                                                                        
                                                                        	Flex Sub TLV Value
                                                                        	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                        
                                                                        .. attribute:: max_lspbw
                                                                        
                                                                        	Max LSP BW Array
                                                                        	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                        
                                                                        .. attribute:: unres_lspbw
                                                                        
                                                                        	Array of Unres LSP BW
                                                                        	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                            self.yang_name = "flex-bw-sub-tlv-value"
                                                                            self.yang_parent_name = "bw-sub-tlv-value"

                                                                            self.flex_sub_tlv_value_common = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                            self.flex_sub_tlv_value_common.parent = self
                                                                            self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                            self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                            self.max_lspbw = YList(self)
                                                                            self.unres_lspbw = YList(self)

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in () and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)


                                                                        class FlexSubTlvValueCommon(Entity):
                                                                            """
                                                                            Flex Sub TLV Value
                                                                            
                                                                            .. attribute:: num_stages
                                                                            
                                                                            	Number of stages
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit0
                                                                            
                                                                            	Priority 0
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit1
                                                                            
                                                                            	Priority 1
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit2
                                                                            
                                                                            	Priority 2
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit3
                                                                            
                                                                            	Priority 3
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit4
                                                                            
                                                                            	Priority 4
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit5
                                                                            
                                                                            	Priority 5
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit6
                                                                            
                                                                            	Priority 6
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit7
                                                                            
                                                                            	Priority 7
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: res
                                                                            
                                                                            	Res
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: sbit
                                                                            
                                                                            	S Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: signal_type
                                                                            
                                                                            	Signal Type
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: stage
                                                                            
                                                                            	Array of Stages
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                            
                                                                            .. attribute:: tbit
                                                                            
                                                                            	T Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: tsg
                                                                            
                                                                            	TSG
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-01-02'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                                self.yang_name = "flex-sub-tlv-value-common"
                                                                                self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                                self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                                self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                                self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                                self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                                self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                                self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                                self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                                self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                                self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                                self.res = YLeaf(YType.uint8, "res")

                                                                                self.sbit = YLeaf(YType.uint8, "sbit")

                                                                                self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                                self.stage = YLeaf(YType.str, "stage")

                                                                                self.tbit = YLeaf(YType.uint8, "tbit")

                                                                                self.tsg = YLeaf(YType.uint8, "tsg")

                                                                            def __setattr__(self, name, value):
                                                                                self._check_monkey_patching_error(name, value)
                                                                                with _handle_type_error():
                                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                            "Please use list append or extend method."
                                                                                                            .format(value))
                                                                                    if isinstance(value, Enum.YLeaf):
                                                                                        value = value.name
                                                                                    if name in ("num_stages",
                                                                                                "priority_bit0",
                                                                                                "priority_bit1",
                                                                                                "priority_bit2",
                                                                                                "priority_bit3",
                                                                                                "priority_bit4",
                                                                                                "priority_bit5",
                                                                                                "priority_bit6",
                                                                                                "priority_bit7",
                                                                                                "res",
                                                                                                "sbit",
                                                                                                "signal_type",
                                                                                                "stage",
                                                                                                "tbit",
                                                                                                "tsg") and name in self.__dict__:
                                                                                        if isinstance(value, YLeaf):
                                                                                            self.__dict__[name].set(value.get())
                                                                                        elif isinstance(value, YLeafList):
                                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)
                                                                                        else:
                                                                                            self.__dict__[name].set(value)
                                                                                    else:
                                                                                        if hasattr(value, "parent") and name != "parent":
                                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                                value.parent = self
                                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                                value.parent = self
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)

                                                                            def has_data(self):
                                                                                return (
                                                                                    self.num_stages.is_set or
                                                                                    self.priority_bit0.is_set or
                                                                                    self.priority_bit1.is_set or
                                                                                    self.priority_bit2.is_set or
                                                                                    self.priority_bit3.is_set or
                                                                                    self.priority_bit4.is_set or
                                                                                    self.priority_bit5.is_set or
                                                                                    self.priority_bit6.is_set or
                                                                                    self.priority_bit7.is_set or
                                                                                    self.res.is_set or
                                                                                    self.sbit.is_set or
                                                                                    self.signal_type.is_set or
                                                                                    self.stage.is_set or
                                                                                    self.tbit.is_set or
                                                                                    self.tsg.is_set)

                                                                            def has_operation(self):
                                                                                return (
                                                                                    self.yfilter != YFilter.not_set or
                                                                                    self.num_stages.yfilter != YFilter.not_set or
                                                                                    self.priority_bit0.yfilter != YFilter.not_set or
                                                                                    self.priority_bit1.yfilter != YFilter.not_set or
                                                                                    self.priority_bit2.yfilter != YFilter.not_set or
                                                                                    self.priority_bit3.yfilter != YFilter.not_set or
                                                                                    self.priority_bit4.yfilter != YFilter.not_set or
                                                                                    self.priority_bit5.yfilter != YFilter.not_set or
                                                                                    self.priority_bit6.yfilter != YFilter.not_set or
                                                                                    self.priority_bit7.yfilter != YFilter.not_set or
                                                                                    self.res.yfilter != YFilter.not_set or
                                                                                    self.sbit.yfilter != YFilter.not_set or
                                                                                    self.signal_type.yfilter != YFilter.not_set or
                                                                                    self.stage.yfilter != YFilter.not_set or
                                                                                    self.tbit.yfilter != YFilter.not_set or
                                                                                    self.tsg.yfilter != YFilter.not_set)

                                                                            def get_segment_path(self):
                                                                                path_buffer = ""
                                                                                path_buffer = "flex-sub-tlv-value-common" + path_buffer

                                                                                return path_buffer

                                                                            def get_entity_path(self, ancestor):
                                                                                path_buffer = ""
                                                                                if (ancestor is None):
                                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                                else:
                                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                                leaf_name_data = LeafDataList()
                                                                                if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                                if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                                if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                                if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                                if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                                if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                                if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                                if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                                if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                                if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.res.get_name_leafdata())
                                                                                if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                                if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                                if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.stage.get_name_leafdata())
                                                                                if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                                if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                                return entity_path

                                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                                if child is not None:
                                                                                    return child

                                                                                return None

                                                                            def has_leaf_or_child_of_name(self, name):
                                                                                if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                                    return True
                                                                                return False

                                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                                if(value_path == "num-stages"):
                                                                                    self.num_stages = value
                                                                                    self.num_stages.value_namespace = name_space
                                                                                    self.num_stages.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit0"):
                                                                                    self.priority_bit0 = value
                                                                                    self.priority_bit0.value_namespace = name_space
                                                                                    self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit1"):
                                                                                    self.priority_bit1 = value
                                                                                    self.priority_bit1.value_namespace = name_space
                                                                                    self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit2"):
                                                                                    self.priority_bit2 = value
                                                                                    self.priority_bit2.value_namespace = name_space
                                                                                    self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit3"):
                                                                                    self.priority_bit3 = value
                                                                                    self.priority_bit3.value_namespace = name_space
                                                                                    self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit4"):
                                                                                    self.priority_bit4 = value
                                                                                    self.priority_bit4.value_namespace = name_space
                                                                                    self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit5"):
                                                                                    self.priority_bit5 = value
                                                                                    self.priority_bit5.value_namespace = name_space
                                                                                    self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit6"):
                                                                                    self.priority_bit6 = value
                                                                                    self.priority_bit6.value_namespace = name_space
                                                                                    self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "priority-bit7"):
                                                                                    self.priority_bit7 = value
                                                                                    self.priority_bit7.value_namespace = name_space
                                                                                    self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "res"):
                                                                                    self.res = value
                                                                                    self.res.value_namespace = name_space
                                                                                    self.res.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "sbit"):
                                                                                    self.sbit = value
                                                                                    self.sbit.value_namespace = name_space
                                                                                    self.sbit.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "signal-type"):
                                                                                    self.signal_type = value
                                                                                    self.signal_type.value_namespace = name_space
                                                                                    self.signal_type.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "stage"):
                                                                                    self.stage = value
                                                                                    self.stage.value_namespace = name_space
                                                                                    self.stage.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "tbit"):
                                                                                    self.tbit = value
                                                                                    self.tbit.value_namespace = name_space
                                                                                    self.tbit.value_namespace_prefix = name_space_prefix
                                                                                if(value_path == "tsg"):
                                                                                    self.tsg = value
                                                                                    self.tsg.value_namespace = name_space
                                                                                    self.tsg.value_namespace_prefix = name_space_prefix


                                                                        class UnresLspbw(Entity):
                                                                            """
                                                                            Array of Unres LSP BW
                                                                            
                                                                            .. attribute:: entry
                                                                            
                                                                            	
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..18446744073709551615
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-01-02'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                                self.yang_name = "unres-lspbw"
                                                                                self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                                self.entry = YLeaf(YType.uint64, "entry")

                                                                            def __setattr__(self, name, value):
                                                                                self._check_monkey_patching_error(name, value)
                                                                                with _handle_type_error():
                                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                            "Please use list append or extend method."
                                                                                                            .format(value))
                                                                                    if isinstance(value, Enum.YLeaf):
                                                                                        value = value.name
                                                                                    if name in ("entry") and name in self.__dict__:
                                                                                        if isinstance(value, YLeaf):
                                                                                            self.__dict__[name].set(value.get())
                                                                                        elif isinstance(value, YLeafList):
                                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)
                                                                                        else:
                                                                                            self.__dict__[name].set(value)
                                                                                    else:
                                                                                        if hasattr(value, "parent") and name != "parent":
                                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                                value.parent = self
                                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                                value.parent = self
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)

                                                                            def has_data(self):
                                                                                return self.entry.is_set

                                                                            def has_operation(self):
                                                                                return (
                                                                                    self.yfilter != YFilter.not_set or
                                                                                    self.entry.yfilter != YFilter.not_set)

                                                                            def get_segment_path(self):
                                                                                path_buffer = ""
                                                                                path_buffer = "unres-lspbw" + path_buffer

                                                                                return path_buffer

                                                                            def get_entity_path(self, ancestor):
                                                                                path_buffer = ""
                                                                                if (ancestor is None):
                                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                                else:
                                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                                leaf_name_data = LeafDataList()
                                                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                                return entity_path

                                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                                if child is not None:
                                                                                    return child

                                                                                return None

                                                                            def has_leaf_or_child_of_name(self, name):
                                                                                if(name == "entry"):
                                                                                    return True
                                                                                return False

                                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                                if(value_path == "entry"):
                                                                                    self.entry = value
                                                                                    self.entry.value_namespace = name_space
                                                                                    self.entry.value_namespace_prefix = name_space_prefix


                                                                        class MaxLspbw(Entity):
                                                                            """
                                                                            Max LSP BW Array
                                                                            
                                                                            .. attribute:: entry
                                                                            
                                                                            	
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..18446744073709551615
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-01-02'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                                self.yang_name = "max-lspbw"
                                                                                self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                                self.entry = YLeaf(YType.uint64, "entry")

                                                                            def __setattr__(self, name, value):
                                                                                self._check_monkey_patching_error(name, value)
                                                                                with _handle_type_error():
                                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                            "Please use list append or extend method."
                                                                                                            .format(value))
                                                                                    if isinstance(value, Enum.YLeaf):
                                                                                        value = value.name
                                                                                    if name in ("entry") and name in self.__dict__:
                                                                                        if isinstance(value, YLeaf):
                                                                                            self.__dict__[name].set(value.get())
                                                                                        elif isinstance(value, YLeafList):
                                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                                        else:
                                                                                            self.__dict__[name].set(value)
                                                                                    else:
                                                                                        if hasattr(value, "parent") and name != "parent":
                                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                                value.parent = self
                                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                                value.parent = self
                                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)

                                                                            def has_data(self):
                                                                                return self.entry.is_set

                                                                            def has_operation(self):
                                                                                return (
                                                                                    self.yfilter != YFilter.not_set or
                                                                                    self.entry.yfilter != YFilter.not_set)

                                                                            def get_segment_path(self):
                                                                                path_buffer = ""
                                                                                path_buffer = "max-lspbw" + path_buffer

                                                                                return path_buffer

                                                                            def get_entity_path(self, ancestor):
                                                                                path_buffer = ""
                                                                                if (ancestor is None):
                                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                                else:
                                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                                leaf_name_data = LeafDataList()
                                                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                                return entity_path

                                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                                if child is not None:
                                                                                    return child

                                                                                return None

                                                                            def has_leaf_or_child_of_name(self, name):
                                                                                if(name == "entry"):
                                                                                    return True
                                                                                return False

                                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                                if(value_path == "entry"):
                                                                                    self.entry = value
                                                                                    self.entry.value_namespace = name_space
                                                                                    self.entry.value_namespace_prefix = name_space_prefix

                                                                        def has_data(self):
                                                                            for c in self.max_lspbw:
                                                                                if (c.has_data()):
                                                                                    return True
                                                                            for c in self.unres_lspbw:
                                                                                if (c.has_data()):
                                                                                    return True
                                                                            return (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_data())

                                                                        def has_operation(self):
                                                                            for c in self.max_lspbw:
                                                                                if (c.has_operation()):
                                                                                    return True
                                                                            for c in self.unres_lspbw:
                                                                                if (c.has_operation()):
                                                                                    return True
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_operation()))

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "flex-bw-sub-tlv-value" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            if (child_yang_name == "flex-sub-tlv-value-common"):
                                                                                if (self.flex_sub_tlv_value_common is None):
                                                                                    self.flex_sub_tlv_value_common = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                                    self.flex_sub_tlv_value_common.parent = self
                                                                                    self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                                return self.flex_sub_tlv_value_common

                                                                            if (child_yang_name == "max-lspbw"):
                                                                                for c in self.max_lspbw:
                                                                                    segment = c.get_segment_path()
                                                                                    if (segment_path == segment):
                                                                                        return c
                                                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw()
                                                                                c.parent = self
                                                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                                                self._local_refs[local_reference_key] = c
                                                                                self.max_lspbw.append(c)
                                                                                return c

                                                                            if (child_yang_name == "unres-lspbw"):
                                                                                for c in self.unres_lspbw:
                                                                                    segment = c.get_segment_path()
                                                                                    if (segment_path == segment):
                                                                                        return c
                                                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw()
                                                                                c.parent = self
                                                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                                                self._local_refs[local_reference_key] = c
                                                                                self.unres_lspbw.append(c)
                                                                                return c

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "flex-sub-tlv-value-common" or name == "max-lspbw" or name == "unres-lspbw"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            pass

                                                                    def has_data(self):
                                                                        return (
                                                                            self.ixcdbw_sub_tlv_type.is_set or
                                                                            (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_data()) or
                                                                            (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_data()))

                                                                    def has_operation(self):
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                            (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_operation()) or
                                                                            (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_operation()))

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "bw-sub-tlv-value" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()
                                                                        if (self.ixcdbw_sub_tlv_type.is_set or self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.ixcdbw_sub_tlv_type.get_name_leafdata())

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        if (child_yang_name == "fixed-bw-sub-tlv-value"):
                                                                            if (self.fixed_bw_sub_tlv_value is None):
                                                                                self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                                self.fixed_bw_sub_tlv_value.parent = self
                                                                                self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                            return self.fixed_bw_sub_tlv_value

                                                                        if (child_yang_name == "flex-bw-sub-tlv-value"):
                                                                            if (self.flex_bw_sub_tlv_value is None):
                                                                                self.flex_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                                self.flex_bw_sub_tlv_value.parent = self
                                                                                self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                            return self.flex_bw_sub_tlv_value

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "fixed-bw-sub-tlv-value" or name == "flex-bw-sub-tlv-value" or name == "ixcdbw-sub-tlv-type"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        if(value_path == "ixcdbw-sub-tlv-type"):
                                                                            self.ixcdbw_sub_tlv_type = value
                                                                            self.ixcdbw_sub_tlv_type.value_namespace = name_space
                                                                            self.ixcdbw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                                def has_data(self):
                                                                    return (
                                                                        self.bw_sub_tlv_length.is_set or
                                                                        self.bw_sub_tlv_type.is_set or
                                                                        (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_data()))

                                                                def has_operation(self):
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.bw_sub_tlv_length.yfilter != YFilter.not_set or
                                                                        self.bw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                        (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_operation()))

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "arr-bw-sub-tlv" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.bw_sub_tlv_length.is_set or self.bw_sub_tlv_length.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.bw_sub_tlv_length.get_name_leafdata())
                                                                    if (self.bw_sub_tlv_type.is_set or self.bw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.bw_sub_tlv_type.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    if (child_yang_name == "bw-sub-tlv-value"):
                                                                        if (self.bw_sub_tlv_value is None):
                                                                            self.bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                            self.bw_sub_tlv_value.parent = self
                                                                            self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                        return self.bw_sub_tlv_value

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "bw-sub-tlv-value" or name == "bw-sub-tlv-length" or name == "bw-sub-tlv-type"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "bw-sub-tlv-length"):
                                                                        self.bw_sub_tlv_length = value
                                                                        self.bw_sub_tlv_length.value_namespace = name_space
                                                                        self.bw_sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "bw-sub-tlv-type"):
                                                                        self.bw_sub_tlv_type = value
                                                                        self.bw_sub_tlv_type.value_namespace = name_space
                                                                        self.bw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                for c in self.arr_bw_sub_tlv:
                                                                    if (c.has_data()):
                                                                        return True
                                                                return False

                                                            def has_operation(self):
                                                                for c in self.arr_bw_sub_tlv:
                                                                    if (c.has_operation()):
                                                                        return True
                                                                return self.yfilter != YFilter.not_set

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "ixcdbw-sub-tlv" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "arr-bw-sub-tlv"):
                                                                    for c in self.arr_bw_sub_tlv:
                                                                        segment = c.get_segment_path()
                                                                        if (segment_path == segment):
                                                                            return c
                                                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv()
                                                                    c.parent = self
                                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                                    self._local_refs[local_reference_key] = c
                                                                    self.arr_bw_sub_tlv.append(c)
                                                                    return c

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "arr-bw-sub-tlv"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                pass

                                                        def has_data(self):
                                                            return (
                                                                self.switching_cap_type.is_set or
                                                                (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_data()) or
                                                                (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.switching_cap_type.yfilter != YFilter.not_set or
                                                                (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_operation()) or
                                                                (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ixcd-switching-cap-type" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.switching_cap_type.is_set or self.switching_cap_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.switching_cap_type.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "ixcdbw-sub-tlv"):
                                                                if (self.ixcdbw_sub_tlv is None):
                                                                    self.ixcdbw_sub_tlv = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                                    self.ixcdbw_sub_tlv.parent = self
                                                                    self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                                return self.ixcdbw_sub_tlv

                                                            if (child_yang_name == "ixcdpsc-info"):
                                                                if (self.ixcdpsc_info is None):
                                                                    self.ixcdpsc_info = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                                    self.ixcdpsc_info.parent = self
                                                                    self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                                return self.ixcdpsc_info

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "ixcdbw-sub-tlv" or name == "ixcdpsc-info" or name == "switching-cap-type"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "switching-cap-type"):
                                                                self.switching_cap_type = value
                                                                self.switching_cap_type.value_namespace = name_space
                                                                self.switching_cap_type.value_namespace_prefix = name_space_prefix


                                                    class MaxLspbw(Entity):
                                                        """
                                                        Max LSP bandwidth array
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-9223372036854775808..9223372036854775807
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                            self.yang_name = "max-lspbw"
                                                            self.yang_parent_name = "ixcdtlv-value"

                                                            self.entry = YLeaf(YType.int64, "entry")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("entry") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return self.entry.is_set

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.entry.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "max-lspbw" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "entry"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "entry"):
                                                                self.entry = value
                                                                self.entry.value_namespace = name_space
                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.max_lspbw:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.fixed_scsi_count.is_set or
                                                            self.flex_scsi_count.is_set or
                                                            self.rile_len_code.is_set or
                                                            self.switching_cap.is_set or
                                                            (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_data()))

                                                    def has_operation(self):
                                                        for c in self.max_lspbw:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.fixed_scsi_count.yfilter != YFilter.not_set or
                                                            self.flex_scsi_count.yfilter != YFilter.not_set or
                                                            self.rile_len_code.yfilter != YFilter.not_set or
                                                            self.switching_cap.yfilter != YFilter.not_set or
                                                            (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_operation()))

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ixcdtlv-value" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.fixed_scsi_count.is_set or self.fixed_scsi_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.fixed_scsi_count.get_name_leafdata())
                                                        if (self.flex_scsi_count.is_set or self.flex_scsi_count.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.flex_scsi_count.get_name_leafdata())
                                                        if (self.rile_len_code.is_set or self.rile_len_code.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rile_len_code.get_name_leafdata())
                                                        if (self.switching_cap.is_set or self.switching_cap.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.switching_cap.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ixcd-switching-cap-type"):
                                                            if (self.ixcd_switching_cap_type is None):
                                                                self.ixcd_switching_cap_type = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                                self.ixcd_switching_cap_type.parent = self
                                                                self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                            return self.ixcd_switching_cap_type

                                                        if (child_yang_name == "max-lspbw"):
                                                            for c in self.max_lspbw:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.max_lspbw.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ixcd-switching-cap-type" or name == "max-lspbw" or name == "fixed-scsi-count" or name == "flex-scsi-count" or name == "rile-len-code" or name == "switching-cap"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "fixed-scsi-count"):
                                                            self.fixed_scsi_count = value
                                                            self.fixed_scsi_count.value_namespace = name_space
                                                            self.fixed_scsi_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "flex-scsi-count"):
                                                            self.flex_scsi_count = value
                                                            self.flex_scsi_count.value_namespace = name_space
                                                            self.flex_scsi_count.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rile-len-code"):
                                                            self.rile_len_code = value
                                                            self.rile_len_code.value_namespace = name_space
                                                            self.rile_len_code.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "switching-cap"):
                                                            self.switching_cap = value
                                                            self.switching_cap.value_namespace = name_space
                                                            self.switching_cap.value_namespace_prefix = name_space_prefix


                                                class UnidtlvValue(Entity):
                                                    """
                                                    Value of Uni Delay TLV
                                                    
                                                    .. attribute:: uni_dir_delay
                                                    
                                                    	Uni Dir Delay
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                        self.yang_name = "unidtlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                        self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("uni_dir_delay") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.uni_dir_delay.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.uni_dir_delay.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "unidtlv-value" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.uni_dir_delay.is_set or self.uni_dir_delay.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.uni_dir_delay.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "uni-dir-delay"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "uni-dir-delay"):
                                                            self.uni_dir_delay = value
                                                            self.uni_dir_delay.value_namespace = name_space
                                                            self.uni_dir_delay.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.opaque_tlv_type.is_set or
                                                        (self.bctlv_value is not None and self.bctlv_value.has_data()) or
                                                        (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_data()) or
                                                        (self.srlgtlv_value is not None and self.srlgtlv_value.has_data()) or
                                                        (self.unidtlv_value is not None and self.unidtlv_value.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.opaque_tlv_type.yfilter != YFilter.not_set or
                                                        (self.bctlv_value is not None and self.bctlv_value.has_operation()) or
                                                        (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_operation()) or
                                                        (self.srlgtlv_value is not None and self.srlgtlv_value.has_operation()) or
                                                        (self.unidtlv_value is not None and self.unidtlv_value.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "mplste-link-opt-tlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.opaque_tlv_type.is_set or self.opaque_tlv_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.opaque_tlv_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "bctlv-value"):
                                                        if (self.bctlv_value is None):
                                                            self.bctlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                            self.bctlv_value.parent = self
                                                            self._children_name_map["bctlv_value"] = "bctlv-value"
                                                        return self.bctlv_value

                                                    if (child_yang_name == "ixcdtlv-value"):
                                                        if (self.ixcdtlv_value is None):
                                                            self.ixcdtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                            self.ixcdtlv_value.parent = self
                                                            self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                        return self.ixcdtlv_value

                                                    if (child_yang_name == "srlgtlv-value"):
                                                        if (self.srlgtlv_value is None):
                                                            self.srlgtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                            self.srlgtlv_value.parent = self
                                                            self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                        return self.srlgtlv_value

                                                    if (child_yang_name == "unidtlv-value"):
                                                        if (self.unidtlv_value is None):
                                                            self.unidtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                            self.unidtlv_value.parent = self
                                                            self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                        return self.unidtlv_value

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bctlv-value" or name == "ixcdtlv-value" or name == "srlgtlv-value" or name == "unidtlv-value" or name == "opaque-tlv-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "opaque-tlv-type"):
                                                        self.opaque_tlv_type = value
                                                        self.opaque_tlv_type.value_namespace = name_space
                                                        self.opaque_tlv_type.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.mplste_link_opt_tlv_value:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.mplste_link_opt_tlv_len.is_set or
                                                    self.mplste_link_opt_tlv_type.is_set)

                                            def has_operation(self):
                                                for c in self.mplste_link_opt_tlv_value:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set or
                                                    self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mplste-link-opt-tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.mplste_link_opt_tlv_len.is_set or self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mplste_link_opt_tlv_len.get_name_leafdata())
                                                if (self.mplste_link_opt_tlv_type.is_set or self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mplste_link_opt_tlv_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "mplste-link-opt-tlv-value"):
                                                    for c in self.mplste_link_opt_tlv_value:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.mplste_link_opt_tlv_value.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "mplste-link-opt-tlv-value" or name == "mplste-link-opt-tlv-len" or name == "mplste-link-opt-tlv-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "mplste-link-opt-tlv-len"):
                                                    self.mplste_link_opt_tlv_len = value
                                                    self.mplste_link_opt_tlv_len.value_namespace = name_space
                                                    self.mplste_link_opt_tlv_len.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mplste-link-opt-tlv-type"):
                                                    self.mplste_link_opt_tlv_type = value
                                                    self.mplste_link_opt_tlv_type.value_namespace = name_space
                                                    self.mplste_link_opt_tlv_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.mplste_link_opt_tlv:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.affinity.is_set or
                                                self.dste_allocation_model_id.is_set or
                                                self.dste_in_use.is_set or
                                                self.fragment_id.is_set or
                                                self.igp_metric.is_set or
                                                self.input_interface_id.is_set or
                                                self.link_address.is_set or
                                                self.maximum_link_bw.is_set or
                                                self.maximum_link_reservable_bw.is_set or
                                                self.maximum_link_sub_reservable_bw.is_set or
                                                self.mpls_link_instance.is_set or
                                                self.mpls_link_type.is_set or
                                                self.neighbor_ip_address.is_set or
                                                self.neighbor_system_id.is_set or
                                                self.new_link.is_set or
                                                self.number_of_optional_tl_vs.is_set or
                                                self.output_interface_id.is_set or
                                                self.priority_count.is_set or
                                                self.te_metric.is_set or
                                                (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_data()) or
                                                (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_data()) or
                                                (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_data()) or
                                                (self.link_sw_capability is not None and self.link_sw_capability.has_data()) or
                                                (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_data()))

                                        def has_operation(self):
                                            for c in self.mplste_link_opt_tlv:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.affinity.yfilter != YFilter.not_set or
                                                self.dste_allocation_model_id.yfilter != YFilter.not_set or
                                                self.dste_in_use.yfilter != YFilter.not_set or
                                                self.fragment_id.yfilter != YFilter.not_set or
                                                self.igp_metric.yfilter != YFilter.not_set or
                                                self.input_interface_id.yfilter != YFilter.not_set or
                                                self.link_address.yfilter != YFilter.not_set or
                                                self.maximum_link_bw.yfilter != YFilter.not_set or
                                                self.maximum_link_reservable_bw.yfilter != YFilter.not_set or
                                                self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set or
                                                self.mpls_link_instance.yfilter != YFilter.not_set or
                                                self.mpls_link_type.yfilter != YFilter.not_set or
                                                self.neighbor_ip_address.yfilter != YFilter.not_set or
                                                self.neighbor_system_id.yfilter != YFilter.not_set or
                                                self.new_link.yfilter != YFilter.not_set or
                                                self.number_of_optional_tl_vs.yfilter != YFilter.not_set or
                                                self.output_interface_id.yfilter != YFilter.not_set or
                                                self.priority_count.yfilter != YFilter.not_set or
                                                self.te_metric.yfilter != YFilter.not_set or
                                                (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_operation()) or
                                                (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_operation()) or
                                                (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_operation()) or
                                                (self.link_sw_capability is not None and self.link_sw_capability.has_operation()) or
                                                (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mpls-te-link" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.affinity.is_set or self.affinity.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.affinity.get_name_leafdata())
                                            if (self.dste_allocation_model_id.is_set or self.dste_allocation_model_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dste_allocation_model_id.get_name_leafdata())
                                            if (self.dste_in_use.is_set or self.dste_in_use.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dste_in_use.get_name_leafdata())
                                            if (self.fragment_id.is_set or self.fragment_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fragment_id.get_name_leafdata())
                                            if (self.igp_metric.is_set or self.igp_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igp_metric.get_name_leafdata())
                                            if (self.input_interface_id.is_set or self.input_interface_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.input_interface_id.get_name_leafdata())
                                            if (self.link_address.is_set or self.link_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_address.get_name_leafdata())
                                            if (self.maximum_link_bw.is_set or self.maximum_link_bw.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_link_bw.get_name_leafdata())
                                            if (self.maximum_link_reservable_bw.is_set or self.maximum_link_reservable_bw.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_link_reservable_bw.get_name_leafdata())
                                            if (self.maximum_link_sub_reservable_bw.is_set or self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_link_sub_reservable_bw.get_name_leafdata())
                                            if (self.mpls_link_instance.is_set or self.mpls_link_instance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mpls_link_instance.get_name_leafdata())
                                            if (self.mpls_link_type.is_set or self.mpls_link_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mpls_link_type.get_name_leafdata())
                                            if (self.neighbor_ip_address.is_set or self.neighbor_ip_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_ip_address.get_name_leafdata())
                                            if (self.neighbor_system_id.is_set or self.neighbor_system_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_system_id.get_name_leafdata())
                                            if (self.new_link.is_set or self.new_link.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.new_link.get_name_leafdata())
                                            if (self.number_of_optional_tl_vs.is_set or self.number_of_optional_tl_vs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.number_of_optional_tl_vs.get_name_leafdata())
                                            if (self.output_interface_id.is_set or self.output_interface_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.output_interface_id.get_name_leafdata())
                                            if (self.priority_count.is_set or self.priority_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.priority_count.get_name_leafdata())
                                            if (self.te_metric.is_set or self.te_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.te_metric.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "extended-admin-group-list"):
                                                if (self.extended_admin_group_list is None):
                                                    self.extended_admin_group_list = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                                    self.extended_admin_group_list.parent = self
                                                    self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                                return self.extended_admin_group_list

                                            if (child_yang_name == "global-unreserve-bw-per-priority"):
                                                if (self.global_unreserve_bw_per_priority is None):
                                                    self.global_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                                    self.global_unreserve_bw_per_priority.parent = self
                                                    self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                                return self.global_unreserve_bw_per_priority

                                            if (child_yang_name == "link-protocol-priority-capability"):
                                                if (self.link_protocol_priority_capability is None):
                                                    self.link_protocol_priority_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                                    self.link_protocol_priority_capability.parent = self
                                                    self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                                return self.link_protocol_priority_capability

                                            if (child_yang_name == "link-sw-capability"):
                                                if (self.link_sw_capability is None):
                                                    self.link_sw_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                                    self.link_sw_capability.parent = self
                                                    self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                                return self.link_sw_capability

                                            if (child_yang_name == "mplste-link-opt-tlv"):
                                                for c in self.mplste_link_opt_tlv:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.mplste_link_opt_tlv.append(c)
                                                return c

                                            if (child_yang_name == "sub-pool-unreserve-bw-per-priority"):
                                                if (self.sub_pool_unreserve_bw_per_priority is None):
                                                    self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                                    self.sub_pool_unreserve_bw_per_priority.parent = self
                                                    self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                                return self.sub_pool_unreserve_bw_per_priority

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "extended-admin-group-list" or name == "global-unreserve-bw-per-priority" or name == "link-protocol-priority-capability" or name == "link-sw-capability" or name == "mplste-link-opt-tlv" or name == "sub-pool-unreserve-bw-per-priority" or name == "affinity" or name == "dste-allocation-model-id" or name == "dste-in-use" or name == "fragment-id" or name == "igp-metric" or name == "input-interface-id" or name == "link-address" or name == "maximum-link-bw" or name == "maximum-link-reservable-bw" or name == "maximum-link-sub-reservable-bw" or name == "mpls-link-instance" or name == "mpls-link-type" or name == "neighbor-ip-address" or name == "neighbor-system-id" or name == "new-link" or name == "number-of-optional-tl-vs" or name == "output-interface-id" or name == "priority-count" or name == "te-metric"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "affinity"):
                                                self.affinity = value
                                                self.affinity.value_namespace = name_space
                                                self.affinity.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dste-allocation-model-id"):
                                                self.dste_allocation_model_id = value
                                                self.dste_allocation_model_id.value_namespace = name_space
                                                self.dste_allocation_model_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dste-in-use"):
                                                self.dste_in_use = value
                                                self.dste_in_use.value_namespace = name_space
                                                self.dste_in_use.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fragment-id"):
                                                self.fragment_id = value
                                                self.fragment_id.value_namespace = name_space
                                                self.fragment_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igp-metric"):
                                                self.igp_metric = value
                                                self.igp_metric.value_namespace = name_space
                                                self.igp_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "input-interface-id"):
                                                self.input_interface_id = value
                                                self.input_interface_id.value_namespace = name_space
                                                self.input_interface_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-address"):
                                                self.link_address = value
                                                self.link_address.value_namespace = name_space
                                                self.link_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-link-bw"):
                                                self.maximum_link_bw = value
                                                self.maximum_link_bw.value_namespace = name_space
                                                self.maximum_link_bw.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-link-reservable-bw"):
                                                self.maximum_link_reservable_bw = value
                                                self.maximum_link_reservable_bw.value_namespace = name_space
                                                self.maximum_link_reservable_bw.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-link-sub-reservable-bw"):
                                                self.maximum_link_sub_reservable_bw = value
                                                self.maximum_link_sub_reservable_bw.value_namespace = name_space
                                                self.maximum_link_sub_reservable_bw.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mpls-link-instance"):
                                                self.mpls_link_instance = value
                                                self.mpls_link_instance.value_namespace = name_space
                                                self.mpls_link_instance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mpls-link-type"):
                                                self.mpls_link_type = value
                                                self.mpls_link_type.value_namespace = name_space
                                                self.mpls_link_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-ip-address"):
                                                self.neighbor_ip_address = value
                                                self.neighbor_ip_address.value_namespace = name_space
                                                self.neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-system-id"):
                                                self.neighbor_system_id = value
                                                self.neighbor_system_id.value_namespace = name_space
                                                self.neighbor_system_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "new-link"):
                                                self.new_link = value
                                                self.new_link.value_namespace = name_space
                                                self.new_link.value_namespace_prefix = name_space_prefix
                                            if(value_path == "number-of-optional-tl-vs"):
                                                self.number_of_optional_tl_vs = value
                                                self.number_of_optional_tl_vs.value_namespace = name_space
                                                self.number_of_optional_tl_vs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "output-interface-id"):
                                                self.output_interface_id = value
                                                self.output_interface_id.value_namespace = name_space
                                                self.output_interface_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "priority-count"):
                                                self.priority_count = value
                                                self.priority_count.value_namespace = name_space
                                                self.priority_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "te-metric"):
                                                self.te_metric = value
                                                self.te_metric.value_namespace = name_space
                                                self.te_metric.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.mpls_te_link:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.dste_model_id.is_set or
                                            self.fragment_id.is_set or
                                            self.fragment_instance.is_set or
                                            self.same_fragment_count.is_set)

                                    def has_operation(self):
                                        for c in self.mpls_te_link:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dste_model_id.yfilter != YFilter.not_set or
                                            self.fragment_id.yfilter != YFilter.not_set or
                                            self.fragment_instance.yfilter != YFilter.not_set or
                                            self.same_fragment_count.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls-te-fragment" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dste_model_id.is_set or self.dste_model_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dste_model_id.get_name_leafdata())
                                        if (self.fragment_id.is_set or self.fragment_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fragment_id.get_name_leafdata())
                                        if (self.fragment_instance.is_set or self.fragment_instance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fragment_instance.get_name_leafdata())
                                        if (self.same_fragment_count.is_set or self.same_fragment_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.same_fragment_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "mpls-te-link"):
                                            for c in self.mpls_te_link:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.mpls_te_link.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mpls-te-link" or name == "dste-model-id" or name == "fragment-id" or name == "fragment-instance" or name == "same-fragment-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dste-model-id"):
                                            self.dste_model_id = value
                                            self.dste_model_id.value_namespace = name_space
                                            self.dste_model_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fragment-id"):
                                            self.fragment_id = value
                                            self.fragment_id.value_namespace = name_space
                                            self.fragment_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fragment-instance"):
                                            self.fragment_instance = value
                                            self.fragment_instance.value_namespace = name_space
                                            self.fragment_instance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "same-fragment-count"):
                                            self.same_fragment_count = value
                                            self.same_fragment_count.value_namespace = name_space
                                            self.same_fragment_count.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.mpls_te_fragment:
                                        if (c.has_data()):
                                            return True
                                    for c in self.mpls_te_link:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.area_id.is_set or
                                        self.mpls_te_area_id.is_set or
                                        self.mpls_te_area_instance.is_set or
                                        self.mpls_te_enabled.is_set or
                                        self.mpls_te_initialized.is_set or
                                        self.mpls_te_next_fragment_id.is_set or
                                        self.mpls_te_router_address.is_set or
                                        self.mpls_te_router_id.is_set or
                                        self.spacious_fragment.is_set)

                                def has_operation(self):
                                    for c in self.mpls_te_fragment:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.mpls_te_link:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.mpls_te_area_id.yfilter != YFilter.not_set or
                                        self.mpls_te_area_instance.yfilter != YFilter.not_set or
                                        self.mpls_te_enabled.yfilter != YFilter.not_set or
                                        self.mpls_te_initialized.yfilter != YFilter.not_set or
                                        self.mpls_te_next_fragment_id.yfilter != YFilter.not_set or
                                        self.mpls_te_router_address.yfilter != YFilter.not_set or
                                        self.mpls_te_router_id.yfilter != YFilter.not_set or
                                        self.spacious_fragment.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mpls-te-fragment" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.mpls_te_area_id.is_set or self.mpls_te_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_area_id.get_name_leafdata())
                                    if (self.mpls_te_area_instance.is_set or self.mpls_te_area_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_area_instance.get_name_leafdata())
                                    if (self.mpls_te_enabled.is_set or self.mpls_te_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_enabled.get_name_leafdata())
                                    if (self.mpls_te_initialized.is_set or self.mpls_te_initialized.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_initialized.get_name_leafdata())
                                    if (self.mpls_te_next_fragment_id.is_set or self.mpls_te_next_fragment_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_next_fragment_id.get_name_leafdata())
                                    if (self.mpls_te_router_address.is_set or self.mpls_te_router_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_router_address.get_name_leafdata())
                                    if (self.mpls_te_router_id.is_set or self.mpls_te_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_te_router_id.get_name_leafdata())
                                    if (self.spacious_fragment.is_set or self.spacious_fragment.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spacious_fragment.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "mpls-te-fragment"):
                                        for c in self.mpls_te_fragment:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.mpls_te_fragment.append(c)
                                        return c

                                    if (child_yang_name == "mpls-te-link"):
                                        for c in self.mpls_te_link:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.mpls_te_link.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mpls-te-fragment" or name == "mpls-te-link" or name == "area-id" or name == "mpls-te-area-id" or name == "mpls-te-area-instance" or name == "mpls-te-enabled" or name == "mpls-te-initialized" or name == "mpls-te-next-fragment-id" or name == "mpls-te-router-address" or name == "mpls-te-router-id" or name == "spacious-fragment"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-area-id"):
                                        self.mpls_te_area_id = value
                                        self.mpls_te_area_id.value_namespace = name_space
                                        self.mpls_te_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-area-instance"):
                                        self.mpls_te_area_instance = value
                                        self.mpls_te_area_instance.value_namespace = name_space
                                        self.mpls_te_area_instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-enabled"):
                                        self.mpls_te_enabled = value
                                        self.mpls_te_enabled.value_namespace = name_space
                                        self.mpls_te_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-initialized"):
                                        self.mpls_te_initialized = value
                                        self.mpls_te_initialized.value_namespace = name_space
                                        self.mpls_te_initialized.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-next-fragment-id"):
                                        self.mpls_te_next_fragment_id = value
                                        self.mpls_te_next_fragment_id.value_namespace = name_space
                                        self.mpls_te_next_fragment_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-router-address"):
                                        self.mpls_te_router_address = value
                                        self.mpls_te_router_address.value_namespace = name_space
                                        self.mpls_te_router_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-te-router-id"):
                                        self.mpls_te_router_id = value
                                        self.mpls_te_router_id.value_namespace = name_space
                                        self.mpls_te_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spacious-fragment"):
                                        self.spacious_fragment = value
                                        self.spacious_fragment.value_namespace = name_space
                                        self.spacious_fragment.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.mpls_te_fragment:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.mpls_te_fragment:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mpls-te-fragments" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mpls-te-fragment"):
                                    for c in self.mpls_te_fragment:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.mpls_te_fragment.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mpls-te-fragment"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.mpls_te_fragments is not None and self.mpls_te_fragments.has_data()) or
                                (self.mpls_te_links is not None and self.mpls_te_links.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.mpls_te_fragments is not None and self.mpls_te_fragments.has_operation()) or
                                (self.mpls_te_links is not None and self.mpls_te_links.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mpls-te" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mpls-te-fragments"):
                                if (self.mpls_te_fragments is None):
                                    self.mpls_te_fragments = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments()
                                    self.mpls_te_fragments.parent = self
                                    self._children_name_map["mpls_te_fragments"] = "mpls-te-fragments"
                                return self.mpls_te_fragments

                            if (child_yang_name == "mpls-te-links"):
                                if (self.mpls_te_links is None):
                                    self.mpls_te_links = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks()
                                    self.mpls_te_links.parent = self
                                    self._children_name_map["mpls_te_links"] = "mpls-te-links"
                                return self.mpls_te_links

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mpls-te-fragments" or name == "mpls-te-links"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Statistics(Entity):
                        """
                        Container for Statistics
                        
                        .. attribute:: frr_stats
                        
                        	OSPF fast\-reroute statistics
                        	**type**\:   :py:class:`FrrStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.FrrStats>`
                        
                        .. attribute:: interface_stats_entries
                        
                        	Statistics innformation Interface table
                        	**type**\:   :py:class:`InterfaceStatsEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries>`
                        
                        .. attribute:: issu_stats
                        
                        	OSPF ISSU statistics
                        	**type**\:   :py:class:`IssuStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats>`
                        
                        .. attribute:: nsr_pl_stats
                        
                        	OSPF NSR packet library statistics
                        	**type**\:   :py:class:`NsrPlStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats>`
                        
                        .. attribute:: nsr_stats
                        
                        	OSPF NSR thread statistics
                        	**type**\:   :py:class:`NsrStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats>`
                        
                        .. attribute:: protocol_stats
                        
                        	OSPF Protocol statistics
                        	**type**\:   :py:class:`ProtocolStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.ProtocolStats>`
                        
                        .. attribute:: raw_io_stats
                        
                        	OSPF RAW IO statistics
                        	**type**\:   :py:class:`RawIoStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RawIoStats>`
                        
                        .. attribute:: rib_batch_stats
                        
                        	Stats concerning RIB route updates using the Batching API
                        	**type**\:   :py:class:`RibBatchStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats>`
                        
                        .. attribute:: rib_thread_stats
                        
                        	OSPF RIB thread statistics
                        	**type**\:   :py:class:`RibThreadStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats>`
                        
                        .. attribute:: spf_stats
                        
                        	OSPF SPF statistics
                        	**type**\:   :py:class:`SpfStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats>`
                        
                        .. attribute:: te_stats
                        
                        	OSPF TE IO statistics
                        	**type**\:   :py:class:`TeStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.TeStats>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "vrf"

                            self.frr_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.FrrStats()
                            self.frr_stats.parent = self
                            self._children_name_map["frr_stats"] = "frr-stats"
                            self._children_yang_names.add("frr-stats")

                            self.interface_stats_entries = Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries()
                            self.interface_stats_entries.parent = self
                            self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                            self._children_yang_names.add("interface-stats-entries")

                            self.issu_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats()
                            self.issu_stats.parent = self
                            self._children_name_map["issu_stats"] = "issu-stats"
                            self._children_yang_names.add("issu-stats")

                            self.nsr_pl_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats()
                            self.nsr_pl_stats.parent = self
                            self._children_name_map["nsr_pl_stats"] = "nsr-pl-stats"
                            self._children_yang_names.add("nsr-pl-stats")

                            self.nsr_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats()
                            self.nsr_stats.parent = self
                            self._children_name_map["nsr_stats"] = "nsr-stats"
                            self._children_yang_names.add("nsr-stats")

                            self.protocol_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.ProtocolStats()
                            self.protocol_stats.parent = self
                            self._children_name_map["protocol_stats"] = "protocol-stats"
                            self._children_yang_names.add("protocol-stats")

                            self.raw_io_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RawIoStats()
                            self.raw_io_stats.parent = self
                            self._children_name_map["raw_io_stats"] = "raw-io-stats"
                            self._children_yang_names.add("raw-io-stats")

                            self.rib_batch_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats()
                            self.rib_batch_stats.parent = self
                            self._children_name_map["rib_batch_stats"] = "rib-batch-stats"
                            self._children_yang_names.add("rib-batch-stats")

                            self.rib_thread_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats()
                            self.rib_thread_stats.parent = self
                            self._children_name_map["rib_thread_stats"] = "rib-thread-stats"
                            self._children_yang_names.add("rib-thread-stats")

                            self.spf_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats()
                            self.spf_stats.parent = self
                            self._children_name_map["spf_stats"] = "spf-stats"
                            self._children_yang_names.add("spf-stats")

                            self.te_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.TeStats()
                            self.te_stats.parent = self
                            self._children_name_map["te_stats"] = "te-stats"
                            self._children_yang_names.add("te-stats")


                        class SpfStats(Entity):
                            """
                            OSPF SPF statistics
                            
                            .. attribute:: os_ex_runtime
                            
                            	os ex runtime
                            	**type**\: list of    :py:class:`OsExRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime>`
                            
                            .. attribute:: os_runtime
                            
                            	os runtime
                            	**type**\: list of    :py:class:`OsRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime>`
                            
                            .. attribute:: os_sum_runtime
                            
                            	os sum runtime
                            	**type**\: list of    :py:class:`OsSumRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime>`
                            
                            .. attribute:: runtime
                            
                            	runtime
                            	**type**\: list of    :py:class:`Runtime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime>`
                            
                            .. attribute:: spf_header
                            
                            	spf header
                            	**type**\:   :py:class:`SpfHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats, self).__init__()

                                self.yang_name = "spf-stats"
                                self.yang_parent_name = "statistics"

                                self.spf_header = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader()
                                self.spf_header.parent = self
                                self._children_name_map["spf_header"] = "spf-header"
                                self._children_yang_names.add("spf-header")

                                self.os_ex_runtime = YList(self)
                                self.os_runtime = YList(self)
                                self.os_sum_runtime = YList(self)
                                self.runtime = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats, self).__setattr__(name, value)


                            class SpfHeader(Entity):
                                """
                                spf header
                                
                                .. attribute:: area_summ
                                
                                	area summ
                                	**type**\: list of    :py:class:`AreaSumm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader.AreaSumm>`
                                
                                .. attribute:: router_id
                                
                                	router id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: spf_count
                                
                                	spf count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader, self).__init__()

                                    self.yang_name = "spf-header"
                                    self.yang_parent_name = "spf-stats"

                                    self.router_id = YLeaf(YType.str, "router-id")

                                    self.spf_count = YLeaf(YType.uint32, "spf-count")

                                    self.area_summ = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("router_id",
                                                    "spf_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader, self).__setattr__(name, value)


                                class AreaSumm(Entity):
                                    """
                                    area summ
                                    
                                    .. attribute:: area_id
                                    
                                    	area id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_count
                                    
                                    	spf count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader.AreaSumm, self).__init__()

                                        self.yang_name = "area-summ"
                                        self.yang_parent_name = "spf-header"

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.spf_count = YLeaf(YType.uint32, "spf-count")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("area_id",
                                                        "spf_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader.AreaSumm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader.AreaSumm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.area_id.is_set or
                                            self.spf_count.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.area_id.yfilter != YFilter.not_set or
                                            self.spf_count.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "area-summ" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id.get_name_leafdata())
                                        if (self.spf_count.is_set or self.spf_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "area-id" or name == "spf-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "area-id"):
                                            self.area_id = value
                                            self.area_id.value_namespace = name_space
                                            self.area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spf-count"):
                                            self.spf_count = value
                                            self.spf_count.value_namespace = name_space
                                            self.spf_count.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.area_summ:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.router_id.is_set or
                                        self.spf_count.is_set)

                                def has_operation(self):
                                    for c in self.area_summ:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.router_id.yfilter != YFilter.not_set or
                                        self.spf_count.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "spf-header" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.router_id.get_name_leafdata())
                                    if (self.spf_count.is_set or self.spf_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spf_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "area-summ"):
                                        for c in self.area_summ:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader.AreaSumm()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.area_summ.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "area-summ" or name == "router-id" or name == "spf-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "router-id"):
                                        self.router_id = value
                                        self.router_id.value_namespace = name_space
                                        self.router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spf-count"):
                                        self.spf_count = value
                                        self.spf_count.value_namespace = name_space
                                        self.spf_count.value_namespace_prefix = name_space_prefix


                            class OsRuntime(Entity):
                                """
                                os runtime
                                
                                .. attribute:: si_area_id_str
                                
                                	si area id str
                                	**type**\:  str
                                
                                .. attribute:: si_change_flags
                                
                                	si change flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: si_duration
                                
                                	si duration
                                	**type**\:   :py:class:`SiDuration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiDuration>`
                                
                                .. attribute:: si_start_time
                                
                                	si start time
                                	**type**\:   :py:class:`SiStartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiStartTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime, self).__init__()

                                    self.yang_name = "os-runtime"
                                    self.yang_parent_name = "spf-stats"

                                    self.si_area_id_str = YLeaf(YType.str, "si-area-id-str")

                                    self.si_change_flags = YLeaf(YType.uint16, "si-change-flags")

                                    self.si_duration = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiDuration()
                                    self.si_duration.parent = self
                                    self._children_name_map["si_duration"] = "si-duration"
                                    self._children_yang_names.add("si-duration")

                                    self.si_start_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiStartTime()
                                    self.si_start_time.parent = self
                                    self._children_name_map["si_start_time"] = "si-start-time"
                                    self._children_yang_names.add("si-start-time")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("si_area_id_str",
                                                    "si_change_flags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime, self).__setattr__(name, value)


                                class SiStartTime(Entity):
                                    """
                                    si start time
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiStartTime, self).__init__()

                                        self.yang_name = "si-start-time"
                                        self.yang_parent_name = "os-runtime"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiStartTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiStartTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "si-start-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix


                                class SiDuration(Entity):
                                    """
                                    si duration
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiDuration, self).__init__()

                                        self.yang_name = "si-duration"
                                        self.yang_parent_name = "os-runtime"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiDuration, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiDuration, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "si-duration" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.si_area_id_str.is_set or
                                        self.si_change_flags.is_set or
                                        (self.si_duration is not None and self.si_duration.has_data()) or
                                        (self.si_start_time is not None and self.si_start_time.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.si_area_id_str.yfilter != YFilter.not_set or
                                        self.si_change_flags.yfilter != YFilter.not_set or
                                        (self.si_duration is not None and self.si_duration.has_operation()) or
                                        (self.si_start_time is not None and self.si_start_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "os-runtime" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.si_area_id_str.is_set or self.si_area_id_str.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.si_area_id_str.get_name_leafdata())
                                    if (self.si_change_flags.is_set or self.si_change_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.si_change_flags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "si-duration"):
                                        if (self.si_duration is None):
                                            self.si_duration = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiDuration()
                                            self.si_duration.parent = self
                                            self._children_name_map["si_duration"] = "si-duration"
                                        return self.si_duration

                                    if (child_yang_name == "si-start-time"):
                                        if (self.si_start_time is None):
                                            self.si_start_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiStartTime()
                                            self.si_start_time.parent = self
                                            self._children_name_map["si_start_time"] = "si-start-time"
                                        return self.si_start_time

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "si-duration" or name == "si-start-time" or name == "si-area-id-str" or name == "si-change-flags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "si-area-id-str"):
                                        self.si_area_id_str = value
                                        self.si_area_id_str.value_namespace = name_space
                                        self.si_area_id_str.value_namespace_prefix = name_space_prefix
                                    if(value_path == "si-change-flags"):
                                        self.si_change_flags = value
                                        self.si_change_flags.value_namespace = name_space
                                        self.si_change_flags.value_namespace_prefix = name_space_prefix


                            class OsSumRuntime(Entity):
                                """
                                os sum runtime
                                
                                .. attribute:: sp_adv_rtr_id
                                
                                	sp adv rtr id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_dest_addr
                                
                                	sp dest addr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_dest_count
                                
                                	sp dest count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_duration
                                
                                	sp duration
                                	**type**\:   :py:class:`SpDuration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpDuration>`
                                
                                .. attribute:: sp_start_time
                                
                                	sp start time
                                	**type**\:   :py:class:`SpStartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpStartTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime, self).__init__()

                                    self.yang_name = "os-sum-runtime"
                                    self.yang_parent_name = "spf-stats"

                                    self.sp_adv_rtr_id = YLeaf(YType.uint32, "sp-adv-rtr-id")

                                    self.sp_dest_addr = YLeaf(YType.uint32, "sp-dest-addr")

                                    self.sp_dest_count = YLeaf(YType.uint32, "sp-dest-count")

                                    self.sp_duration = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpDuration()
                                    self.sp_duration.parent = self
                                    self._children_name_map["sp_duration"] = "sp-duration"
                                    self._children_yang_names.add("sp-duration")

                                    self.sp_start_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpStartTime()
                                    self.sp_start_time.parent = self
                                    self._children_name_map["sp_start_time"] = "sp-start-time"
                                    self._children_yang_names.add("sp-start-time")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("sp_adv_rtr_id",
                                                    "sp_dest_addr",
                                                    "sp_dest_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime, self).__setattr__(name, value)


                                class SpStartTime(Entity):
                                    """
                                    sp start time
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpStartTime, self).__init__()

                                        self.yang_name = "sp-start-time"
                                        self.yang_parent_name = "os-sum-runtime"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpStartTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpStartTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sp-start-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix


                                class SpDuration(Entity):
                                    """
                                    sp duration
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpDuration, self).__init__()

                                        self.yang_name = "sp-duration"
                                        self.yang_parent_name = "os-sum-runtime"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpDuration, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpDuration, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sp-duration" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.sp_adv_rtr_id.is_set or
                                        self.sp_dest_addr.is_set or
                                        self.sp_dest_count.is_set or
                                        (self.sp_duration is not None and self.sp_duration.has_data()) or
                                        (self.sp_start_time is not None and self.sp_start_time.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.sp_adv_rtr_id.yfilter != YFilter.not_set or
                                        self.sp_dest_addr.yfilter != YFilter.not_set or
                                        self.sp_dest_count.yfilter != YFilter.not_set or
                                        (self.sp_duration is not None and self.sp_duration.has_operation()) or
                                        (self.sp_start_time is not None and self.sp_start_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "os-sum-runtime" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.sp_adv_rtr_id.is_set or self.sp_adv_rtr_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sp_adv_rtr_id.get_name_leafdata())
                                    if (self.sp_dest_addr.is_set or self.sp_dest_addr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sp_dest_addr.get_name_leafdata())
                                    if (self.sp_dest_count.is_set or self.sp_dest_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sp_dest_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sp-duration"):
                                        if (self.sp_duration is None):
                                            self.sp_duration = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpDuration()
                                            self.sp_duration.parent = self
                                            self._children_name_map["sp_duration"] = "sp-duration"
                                        return self.sp_duration

                                    if (child_yang_name == "sp-start-time"):
                                        if (self.sp_start_time is None):
                                            self.sp_start_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpStartTime()
                                            self.sp_start_time.parent = self
                                            self._children_name_map["sp_start_time"] = "sp-start-time"
                                        return self.sp_start_time

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sp-duration" or name == "sp-start-time" or name == "sp-adv-rtr-id" or name == "sp-dest-addr" or name == "sp-dest-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "sp-adv-rtr-id"):
                                        self.sp_adv_rtr_id = value
                                        self.sp_adv_rtr_id.value_namespace = name_space
                                        self.sp_adv_rtr_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sp-dest-addr"):
                                        self.sp_dest_addr = value
                                        self.sp_dest_addr.value_namespace = name_space
                                        self.sp_dest_addr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sp-dest-count"):
                                        self.sp_dest_count = value
                                        self.sp_dest_count.value_namespace = name_space
                                        self.sp_dest_count.value_namespace_prefix = name_space_prefix


                            class OsExRuntime(Entity):
                                """
                                os ex runtime
                                
                                .. attribute:: sp_adv_rtr_id
                                
                                	sp adv rtr id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_dest_addr
                                
                                	sp dest addr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_dest_count
                                
                                	sp dest count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_duration
                                
                                	sp duration
                                	**type**\:   :py:class:`SpDuration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpDuration>`
                                
                                .. attribute:: sp_start_time
                                
                                	sp start time
                                	**type**\:   :py:class:`SpStartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpStartTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime, self).__init__()

                                    self.yang_name = "os-ex-runtime"
                                    self.yang_parent_name = "spf-stats"

                                    self.sp_adv_rtr_id = YLeaf(YType.uint32, "sp-adv-rtr-id")

                                    self.sp_dest_addr = YLeaf(YType.uint32, "sp-dest-addr")

                                    self.sp_dest_count = YLeaf(YType.uint32, "sp-dest-count")

                                    self.sp_duration = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpDuration()
                                    self.sp_duration.parent = self
                                    self._children_name_map["sp_duration"] = "sp-duration"
                                    self._children_yang_names.add("sp-duration")

                                    self.sp_start_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpStartTime()
                                    self.sp_start_time.parent = self
                                    self._children_name_map["sp_start_time"] = "sp-start-time"
                                    self._children_yang_names.add("sp-start-time")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("sp_adv_rtr_id",
                                                    "sp_dest_addr",
                                                    "sp_dest_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime, self).__setattr__(name, value)


                                class SpStartTime(Entity):
                                    """
                                    sp start time
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpStartTime, self).__init__()

                                        self.yang_name = "sp-start-time"
                                        self.yang_parent_name = "os-ex-runtime"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpStartTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpStartTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sp-start-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix


                                class SpDuration(Entity):
                                    """
                                    sp duration
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpDuration, self).__init__()

                                        self.yang_name = "sp-duration"
                                        self.yang_parent_name = "os-ex-runtime"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpDuration, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpDuration, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sp-duration" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.sp_adv_rtr_id.is_set or
                                        self.sp_dest_addr.is_set or
                                        self.sp_dest_count.is_set or
                                        (self.sp_duration is not None and self.sp_duration.has_data()) or
                                        (self.sp_start_time is not None and self.sp_start_time.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.sp_adv_rtr_id.yfilter != YFilter.not_set or
                                        self.sp_dest_addr.yfilter != YFilter.not_set or
                                        self.sp_dest_count.yfilter != YFilter.not_set or
                                        (self.sp_duration is not None and self.sp_duration.has_operation()) or
                                        (self.sp_start_time is not None and self.sp_start_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "os-ex-runtime" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.sp_adv_rtr_id.is_set or self.sp_adv_rtr_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sp_adv_rtr_id.get_name_leafdata())
                                    if (self.sp_dest_addr.is_set or self.sp_dest_addr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sp_dest_addr.get_name_leafdata())
                                    if (self.sp_dest_count.is_set or self.sp_dest_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sp_dest_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sp-duration"):
                                        if (self.sp_duration is None):
                                            self.sp_duration = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpDuration()
                                            self.sp_duration.parent = self
                                            self._children_name_map["sp_duration"] = "sp-duration"
                                        return self.sp_duration

                                    if (child_yang_name == "sp-start-time"):
                                        if (self.sp_start_time is None):
                                            self.sp_start_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpStartTime()
                                            self.sp_start_time.parent = self
                                            self._children_name_map["sp_start_time"] = "sp-start-time"
                                        return self.sp_start_time

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sp-duration" or name == "sp-start-time" or name == "sp-adv-rtr-id" or name == "sp-dest-addr" or name == "sp-dest-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "sp-adv-rtr-id"):
                                        self.sp_adv_rtr_id = value
                                        self.sp_adv_rtr_id.value_namespace = name_space
                                        self.sp_adv_rtr_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sp-dest-addr"):
                                        self.sp_dest_addr = value
                                        self.sp_dest_addr.value_namespace = name_space
                                        self.sp_dest_addr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sp-dest-count"):
                                        self.sp_dest_count = value
                                        self.sp_dest_count.value_namespace = name_space
                                        self.sp_dest_count.value_namespace_prefix = name_space_prefix


                            class Runtime(Entity):
                                """
                                runtime
                                
                                .. attribute:: area_stat
                                
                                	area stat
                                	**type**\: list of    :py:class:`AreaStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat>`
                                
                                .. attribute:: gbl_spf_time
                                
                                	gbl spf time
                                	**type**\:   :py:class:`GblSpfTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.GblSpfTime>`
                                
                                .. attribute:: lsa_change_cnt
                                
                                	lsa change cnt
                                	**type**\:  int
                                
                                	**range:** \-32768..32767
                                
                                .. attribute:: lsa_info
                                
                                	lsa info
                                	**type**\: list of    :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.LsaInfo>`
                                
                                .. attribute:: spf_start_time
                                
                                	spf start time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime, self).__init__()

                                    self.yang_name = "runtime"
                                    self.yang_parent_name = "spf-stats"

                                    self.lsa_change_cnt = YLeaf(YType.int16, "lsa-change-cnt")

                                    self.spf_start_time = YLeaf(YType.uint32, "spf-start-time")

                                    self.gbl_spf_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.GblSpfTime()
                                    self.gbl_spf_time.parent = self
                                    self._children_name_map["gbl_spf_time"] = "gbl-spf-time"
                                    self._children_yang_names.add("gbl-spf-time")

                                    self.area_stat = YList(self)
                                    self.lsa_info = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("lsa_change_cnt",
                                                    "spf_start_time") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime, self).__setattr__(name, value)


                                class GblSpfTime(Entity):
                                    """
                                    gbl spf time
                                    
                                    .. attribute:: spf_dijkstra
                                    
                                    	spf dijkstra
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_ext_prefix
                                    
                                    	spf ext prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_ext_prefix_del
                                    
                                    	spf ext prefix del
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_inter_prefix
                                    
                                    	spf inter prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_inter_prefix_del
                                    
                                    	spf inter prefix del
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_intra_prefix
                                    
                                    	spf intra prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_intra_prefix_del
                                    
                                    	spf intra prefix del
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.GblSpfTime, self).__init__()

                                        self.yang_name = "gbl-spf-time"
                                        self.yang_parent_name = "runtime"

                                        self.spf_dijkstra = YLeaf(YType.uint32, "spf-dijkstra")

                                        self.spf_ext_prefix = YLeaf(YType.uint32, "spf-ext-prefix")

                                        self.spf_ext_prefix_del = YLeaf(YType.uint32, "spf-ext-prefix-del")

                                        self.spf_inter_prefix = YLeaf(YType.uint32, "spf-inter-prefix")

                                        self.spf_inter_prefix_del = YLeaf(YType.uint32, "spf-inter-prefix-del")

                                        self.spf_intra_prefix = YLeaf(YType.uint32, "spf-intra-prefix")

                                        self.spf_intra_prefix_del = YLeaf(YType.uint32, "spf-intra-prefix-del")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("spf_dijkstra",
                                                        "spf_ext_prefix",
                                                        "spf_ext_prefix_del",
                                                        "spf_inter_prefix",
                                                        "spf_inter_prefix_del",
                                                        "spf_intra_prefix",
                                                        "spf_intra_prefix_del") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.GblSpfTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.GblSpfTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.spf_dijkstra.is_set or
                                            self.spf_ext_prefix.is_set or
                                            self.spf_ext_prefix_del.is_set or
                                            self.spf_inter_prefix.is_set or
                                            self.spf_inter_prefix_del.is_set or
                                            self.spf_intra_prefix.is_set or
                                            self.spf_intra_prefix_del.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.spf_dijkstra.yfilter != YFilter.not_set or
                                            self.spf_ext_prefix.yfilter != YFilter.not_set or
                                            self.spf_ext_prefix_del.yfilter != YFilter.not_set or
                                            self.spf_inter_prefix.yfilter != YFilter.not_set or
                                            self.spf_inter_prefix_del.yfilter != YFilter.not_set or
                                            self.spf_intra_prefix.yfilter != YFilter.not_set or
                                            self.spf_intra_prefix_del.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "gbl-spf-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.spf_dijkstra.is_set or self.spf_dijkstra.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_dijkstra.get_name_leafdata())
                                        if (self.spf_ext_prefix.is_set or self.spf_ext_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_ext_prefix.get_name_leafdata())
                                        if (self.spf_ext_prefix_del.is_set or self.spf_ext_prefix_del.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_ext_prefix_del.get_name_leafdata())
                                        if (self.spf_inter_prefix.is_set or self.spf_inter_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_inter_prefix.get_name_leafdata())
                                        if (self.spf_inter_prefix_del.is_set or self.spf_inter_prefix_del.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_inter_prefix_del.get_name_leafdata())
                                        if (self.spf_intra_prefix.is_set or self.spf_intra_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_intra_prefix.get_name_leafdata())
                                        if (self.spf_intra_prefix_del.is_set or self.spf_intra_prefix_del.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_intra_prefix_del.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "spf-dijkstra" or name == "spf-ext-prefix" or name == "spf-ext-prefix-del" or name == "spf-inter-prefix" or name == "spf-inter-prefix-del" or name == "spf-intra-prefix" or name == "spf-intra-prefix-del"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "spf-dijkstra"):
                                            self.spf_dijkstra = value
                                            self.spf_dijkstra.value_namespace = name_space
                                            self.spf_dijkstra.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spf-ext-prefix"):
                                            self.spf_ext_prefix = value
                                            self.spf_ext_prefix.value_namespace = name_space
                                            self.spf_ext_prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spf-ext-prefix-del"):
                                            self.spf_ext_prefix_del = value
                                            self.spf_ext_prefix_del.value_namespace = name_space
                                            self.spf_ext_prefix_del.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spf-inter-prefix"):
                                            self.spf_inter_prefix = value
                                            self.spf_inter_prefix.value_namespace = name_space
                                            self.spf_inter_prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spf-inter-prefix-del"):
                                            self.spf_inter_prefix_del = value
                                            self.spf_inter_prefix_del.value_namespace = name_space
                                            self.spf_inter_prefix_del.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spf-intra-prefix"):
                                            self.spf_intra_prefix = value
                                            self.spf_intra_prefix.value_namespace = name_space
                                            self.spf_intra_prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spf-intra-prefix-del"):
                                            self.spf_intra_prefix_del = value
                                            self.spf_intra_prefix_del.value_namespace = name_space
                                            self.spf_intra_prefix_del.value_namespace_prefix = name_space_prefix


                                class LsaInfo(Entity):
                                    """
                                    lsa info
                                    
                                    .. attribute:: adv_rtr
                                    
                                    	adv rtr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: area_id
                                    
                                    	area id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flush
                                    
                                    	flush
                                    	**type**\:  bool
                                    
                                    .. attribute:: id
                                    
                                    	id
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.LsaInfo, self).__init__()

                                        self.yang_name = "lsa-info"
                                        self.yang_parent_name = "runtime"

                                        self.adv_rtr = YLeaf(YType.str, "adv-rtr")

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.flush = YLeaf(YType.boolean, "flush")

                                        self.id = YLeaf(YType.str, "id")

                                        self.type = YLeaf(YType.uint8, "type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("adv_rtr",
                                                        "area_id",
                                                        "flush",
                                                        "id",
                                                        "type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.LsaInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.LsaInfo, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.adv_rtr.is_set or
                                            self.area_id.is_set or
                                            self.flush.is_set or
                                            self.id.is_set or
                                            self.type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.adv_rtr.yfilter != YFilter.not_set or
                                            self.area_id.yfilter != YFilter.not_set or
                                            self.flush.yfilter != YFilter.not_set or
                                            self.id.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lsa-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.adv_rtr.is_set or self.adv_rtr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.adv_rtr.get_name_leafdata())
                                        if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id.get_name_leafdata())
                                        if (self.flush.is_set or self.flush.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flush.get_name_leafdata())
                                        if (self.id.is_set or self.id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.id.get_name_leafdata())
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "adv-rtr" or name == "area-id" or name == "flush" or name == "id" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "adv-rtr"):
                                            self.adv_rtr = value
                                            self.adv_rtr.value_namespace = name_space
                                            self.adv_rtr.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-id"):
                                            self.area_id = value
                                            self.area_id.value_namespace = name_space
                                            self.area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flush"):
                                            self.flush = value
                                            self.flush.value_namespace = name_space
                                            self.flush.value_namespace_prefix = name_space_prefix
                                        if(value_path == "id"):
                                            self.id = value
                                            self.id.value_namespace = name_space
                                            self.id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix


                                class AreaStat(Entity):
                                    """
                                    area stat
                                    
                                    .. attribute:: area_id
                                    
                                    	area id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_type_cnt
                                    
                                    	lsa type cnt
                                    	**type**\: list of    :py:class:`LsaTypeCnt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt>`
                                    
                                    .. attribute:: spf_time
                                    
                                    	spf time
                                    	**type**\:   :py:class:`SpfTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat, self).__init__()

                                        self.yang_name = "area-stat"
                                        self.yang_parent_name = "runtime"

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.spf_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime()
                                        self.spf_time.parent = self
                                        self._children_name_map["spf_time"] = "spf-time"
                                        self._children_yang_names.add("spf-time")

                                        self.lsa_type_cnt = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("area_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat, self).__setattr__(name, value)


                                    class SpfTime(Entity):
                                        """
                                        spf time
                                        
                                        .. attribute:: spf_dijkstra
                                        
                                        	spf dijkstra
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: spf_ext_prefix
                                        
                                        	spf ext prefix
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: spf_ext_prefix_del
                                        
                                        	spf ext prefix del
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: spf_inter_prefix
                                        
                                        	spf inter prefix
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: spf_inter_prefix_del
                                        
                                        	spf inter prefix del
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: spf_intra_prefix
                                        
                                        	spf intra prefix
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: spf_intra_prefix_del
                                        
                                        	spf intra prefix del
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime, self).__init__()

                                            self.yang_name = "spf-time"
                                            self.yang_parent_name = "area-stat"

                                            self.spf_dijkstra = YLeaf(YType.uint32, "spf-dijkstra")

                                            self.spf_ext_prefix = YLeaf(YType.uint32, "spf-ext-prefix")

                                            self.spf_ext_prefix_del = YLeaf(YType.uint32, "spf-ext-prefix-del")

                                            self.spf_inter_prefix = YLeaf(YType.uint32, "spf-inter-prefix")

                                            self.spf_inter_prefix_del = YLeaf(YType.uint32, "spf-inter-prefix-del")

                                            self.spf_intra_prefix = YLeaf(YType.uint32, "spf-intra-prefix")

                                            self.spf_intra_prefix_del = YLeaf(YType.uint32, "spf-intra-prefix-del")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("spf_dijkstra",
                                                            "spf_ext_prefix",
                                                            "spf_ext_prefix_del",
                                                            "spf_inter_prefix",
                                                            "spf_inter_prefix_del",
                                                            "spf_intra_prefix",
                                                            "spf_intra_prefix_del") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.spf_dijkstra.is_set or
                                                self.spf_ext_prefix.is_set or
                                                self.spf_ext_prefix_del.is_set or
                                                self.spf_inter_prefix.is_set or
                                                self.spf_inter_prefix_del.is_set or
                                                self.spf_intra_prefix.is_set or
                                                self.spf_intra_prefix_del.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.spf_dijkstra.yfilter != YFilter.not_set or
                                                self.spf_ext_prefix.yfilter != YFilter.not_set or
                                                self.spf_ext_prefix_del.yfilter != YFilter.not_set or
                                                self.spf_inter_prefix.yfilter != YFilter.not_set or
                                                self.spf_inter_prefix_del.yfilter != YFilter.not_set or
                                                self.spf_intra_prefix.yfilter != YFilter.not_set or
                                                self.spf_intra_prefix_del.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "spf-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.spf_dijkstra.is_set or self.spf_dijkstra.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.spf_dijkstra.get_name_leafdata())
                                            if (self.spf_ext_prefix.is_set or self.spf_ext_prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.spf_ext_prefix.get_name_leafdata())
                                            if (self.spf_ext_prefix_del.is_set or self.spf_ext_prefix_del.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.spf_ext_prefix_del.get_name_leafdata())
                                            if (self.spf_inter_prefix.is_set or self.spf_inter_prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.spf_inter_prefix.get_name_leafdata())
                                            if (self.spf_inter_prefix_del.is_set or self.spf_inter_prefix_del.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.spf_inter_prefix_del.get_name_leafdata())
                                            if (self.spf_intra_prefix.is_set or self.spf_intra_prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.spf_intra_prefix.get_name_leafdata())
                                            if (self.spf_intra_prefix_del.is_set or self.spf_intra_prefix_del.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.spf_intra_prefix_del.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "spf-dijkstra" or name == "spf-ext-prefix" or name == "spf-ext-prefix-del" or name == "spf-inter-prefix" or name == "spf-inter-prefix-del" or name == "spf-intra-prefix" or name == "spf-intra-prefix-del"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "spf-dijkstra"):
                                                self.spf_dijkstra = value
                                                self.spf_dijkstra.value_namespace = name_space
                                                self.spf_dijkstra.value_namespace_prefix = name_space_prefix
                                            if(value_path == "spf-ext-prefix"):
                                                self.spf_ext_prefix = value
                                                self.spf_ext_prefix.value_namespace = name_space
                                                self.spf_ext_prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "spf-ext-prefix-del"):
                                                self.spf_ext_prefix_del = value
                                                self.spf_ext_prefix_del.value_namespace = name_space
                                                self.spf_ext_prefix_del.value_namespace_prefix = name_space_prefix
                                            if(value_path == "spf-inter-prefix"):
                                                self.spf_inter_prefix = value
                                                self.spf_inter_prefix.value_namespace = name_space
                                                self.spf_inter_prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "spf-inter-prefix-del"):
                                                self.spf_inter_prefix_del = value
                                                self.spf_inter_prefix_del.value_namespace = name_space
                                                self.spf_inter_prefix_del.value_namespace_prefix = name_space_prefix
                                            if(value_path == "spf-intra-prefix"):
                                                self.spf_intra_prefix = value
                                                self.spf_intra_prefix.value_namespace = name_space
                                                self.spf_intra_prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "spf-intra-prefix-del"):
                                                self.spf_intra_prefix_del = value
                                                self.spf_intra_prefix_del.value_namespace = name_space
                                                self.spf_intra_prefix_del.value_namespace_prefix = name_space_prefix


                                    class LsaTypeCnt(Entity):
                                        """
                                        lsa type cnt
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt, self).__init__()

                                            self.yang_name = "lsa-type-cnt"
                                            self.yang_parent_name = "area-stat"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "lsa-type-cnt" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.lsa_type_cnt:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.area_id.is_set or
                                            (self.spf_time is not None and self.spf_time.has_data()))

                                    def has_operation(self):
                                        for c in self.lsa_type_cnt:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.area_id.yfilter != YFilter.not_set or
                                            (self.spf_time is not None and self.spf_time.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "area-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "lsa-type-cnt"):
                                            for c in self.lsa_type_cnt:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.lsa_type_cnt.append(c)
                                            return c

                                        if (child_yang_name == "spf-time"):
                                            if (self.spf_time is None):
                                                self.spf_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime()
                                                self.spf_time.parent = self
                                                self._children_name_map["spf_time"] = "spf-time"
                                            return self.spf_time

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lsa-type-cnt" or name == "spf-time" or name == "area-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "area-id"):
                                            self.area_id = value
                                            self.area_id.value_namespace = name_space
                                            self.area_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.area_stat:
                                        if (c.has_data()):
                                            return True
                                    for c in self.lsa_info:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.lsa_change_cnt.is_set or
                                        self.spf_start_time.is_set or
                                        (self.gbl_spf_time is not None and self.gbl_spf_time.has_data()))

                                def has_operation(self):
                                    for c in self.area_stat:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.lsa_info:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.lsa_change_cnt.yfilter != YFilter.not_set or
                                        self.spf_start_time.yfilter != YFilter.not_set or
                                        (self.gbl_spf_time is not None and self.gbl_spf_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "runtime" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.lsa_change_cnt.is_set or self.lsa_change_cnt.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_change_cnt.get_name_leafdata())
                                    if (self.spf_start_time.is_set or self.spf_start_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spf_start_time.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "area-stat"):
                                        for c in self.area_stat:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.area_stat.append(c)
                                        return c

                                    if (child_yang_name == "gbl-spf-time"):
                                        if (self.gbl_spf_time is None):
                                            self.gbl_spf_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.GblSpfTime()
                                            self.gbl_spf_time.parent = self
                                            self._children_name_map["gbl_spf_time"] = "gbl-spf-time"
                                        return self.gbl_spf_time

                                    if (child_yang_name == "lsa-info"):
                                        for c in self.lsa_info:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.LsaInfo()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.lsa_info.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "area-stat" or name == "gbl-spf-time" or name == "lsa-info" or name == "lsa-change-cnt" or name == "spf-start-time"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "lsa-change-cnt"):
                                        self.lsa_change_cnt = value
                                        self.lsa_change_cnt.value_namespace = name_space
                                        self.lsa_change_cnt.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spf-start-time"):
                                        self.spf_start_time = value
                                        self.spf_start_time.value_namespace = name_space
                                        self.spf_start_time.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.os_ex_runtime:
                                    if (c.has_data()):
                                        return True
                                for c in self.os_runtime:
                                    if (c.has_data()):
                                        return True
                                for c in self.os_sum_runtime:
                                    if (c.has_data()):
                                        return True
                                for c in self.runtime:
                                    if (c.has_data()):
                                        return True
                                return (self.spf_header is not None and self.spf_header.has_data())

                            def has_operation(self):
                                for c in self.os_ex_runtime:
                                    if (c.has_operation()):
                                        return True
                                for c in self.os_runtime:
                                    if (c.has_operation()):
                                        return True
                                for c in self.os_sum_runtime:
                                    if (c.has_operation()):
                                        return True
                                for c in self.runtime:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.spf_header is not None and self.spf_header.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "spf-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "os-ex-runtime"):
                                    for c in self.os_ex_runtime:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.os_ex_runtime.append(c)
                                    return c

                                if (child_yang_name == "os-runtime"):
                                    for c in self.os_runtime:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.os_runtime.append(c)
                                    return c

                                if (child_yang_name == "os-sum-runtime"):
                                    for c in self.os_sum_runtime:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.os_sum_runtime.append(c)
                                    return c

                                if (child_yang_name == "runtime"):
                                    for c in self.runtime:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.runtime.append(c)
                                    return c

                                if (child_yang_name == "spf-header"):
                                    if (self.spf_header is None):
                                        self.spf_header = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader()
                                        self.spf_header.parent = self
                                        self._children_name_map["spf_header"] = "spf-header"
                                    return self.spf_header

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "os-ex-runtime" or name == "os-runtime" or name == "os-sum-runtime" or name == "runtime" or name == "spf-header"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class RibBatchStats(Entity):
                            """
                            Stats concerning RIB route updates using the
                            Batching API
                            
                            .. attribute:: priority_batch
                            
                            	priority batch
                            	**type**\: list of    :py:class:`PriorityBatch <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats.PriorityBatch>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats, self).__init__()

                                self.yang_name = "rib-batch-stats"
                                self.yang_parent_name = "statistics"

                                self.priority_batch = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats, self).__setattr__(name, value)


                            class PriorityBatch(Entity):
                                """
                                priority batch
                                
                                .. attribute:: batches_sent
                                
                                	batches sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lfas_add
                                
                                	lfas add
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lfas_del
                                
                                	lfas del
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lfas_pending
                                
                                	lfas pending
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lfas_sent
                                
                                	lfas sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_routes
                                
                                	max routes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: paths_add
                                
                                	paths add
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: paths_add_errs
                                
                                	paths add errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: paths_del
                                
                                	paths del
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: paths_del_errs
                                
                                	paths del errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: paths_pending
                                
                                	paths pending
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: paths_sent
                                
                                	paths sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: priority_level
                                
                                	priority level
                                	**type**\:  str
                                
                                	**length:** 0..40
                                
                                .. attribute:: routes_pending
                                
                                	routes pending
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: routes_sent
                                
                                	routes sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats.PriorityBatch, self).__init__()

                                    self.yang_name = "priority-batch"
                                    self.yang_parent_name = "rib-batch-stats"

                                    self.batches_sent = YLeaf(YType.uint32, "batches-sent")

                                    self.lfas_add = YLeaf(YType.uint32, "lfas-add")

                                    self.lfas_del = YLeaf(YType.uint32, "lfas-del")

                                    self.lfas_pending = YLeaf(YType.uint32, "lfas-pending")

                                    self.lfas_sent = YLeaf(YType.uint32, "lfas-sent")

                                    self.max_routes = YLeaf(YType.uint32, "max-routes")

                                    self.paths_add = YLeaf(YType.uint32, "paths-add")

                                    self.paths_add_errs = YLeaf(YType.uint32, "paths-add-errs")

                                    self.paths_del = YLeaf(YType.uint32, "paths-del")

                                    self.paths_del_errs = YLeaf(YType.uint32, "paths-del-errs")

                                    self.paths_pending = YLeaf(YType.uint32, "paths-pending")

                                    self.paths_sent = YLeaf(YType.uint32, "paths-sent")

                                    self.priority_level = YLeaf(YType.str, "priority-level")

                                    self.routes_pending = YLeaf(YType.uint32, "routes-pending")

                                    self.routes_sent = YLeaf(YType.uint32, "routes-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("batches_sent",
                                                    "lfas_add",
                                                    "lfas_del",
                                                    "lfas_pending",
                                                    "lfas_sent",
                                                    "max_routes",
                                                    "paths_add",
                                                    "paths_add_errs",
                                                    "paths_del",
                                                    "paths_del_errs",
                                                    "paths_pending",
                                                    "paths_sent",
                                                    "priority_level",
                                                    "routes_pending",
                                                    "routes_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats.PriorityBatch, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats.PriorityBatch, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.batches_sent.is_set or
                                        self.lfas_add.is_set or
                                        self.lfas_del.is_set or
                                        self.lfas_pending.is_set or
                                        self.lfas_sent.is_set or
                                        self.max_routes.is_set or
                                        self.paths_add.is_set or
                                        self.paths_add_errs.is_set or
                                        self.paths_del.is_set or
                                        self.paths_del_errs.is_set or
                                        self.paths_pending.is_set or
                                        self.paths_sent.is_set or
                                        self.priority_level.is_set or
                                        self.routes_pending.is_set or
                                        self.routes_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.batches_sent.yfilter != YFilter.not_set or
                                        self.lfas_add.yfilter != YFilter.not_set or
                                        self.lfas_del.yfilter != YFilter.not_set or
                                        self.lfas_pending.yfilter != YFilter.not_set or
                                        self.lfas_sent.yfilter != YFilter.not_set or
                                        self.max_routes.yfilter != YFilter.not_set or
                                        self.paths_add.yfilter != YFilter.not_set or
                                        self.paths_add_errs.yfilter != YFilter.not_set or
                                        self.paths_del.yfilter != YFilter.not_set or
                                        self.paths_del_errs.yfilter != YFilter.not_set or
                                        self.paths_pending.yfilter != YFilter.not_set or
                                        self.paths_sent.yfilter != YFilter.not_set or
                                        self.priority_level.yfilter != YFilter.not_set or
                                        self.routes_pending.yfilter != YFilter.not_set or
                                        self.routes_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "priority-batch" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.batches_sent.is_set or self.batches_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.batches_sent.get_name_leafdata())
                                    if (self.lfas_add.is_set or self.lfas_add.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lfas_add.get_name_leafdata())
                                    if (self.lfas_del.is_set or self.lfas_del.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lfas_del.get_name_leafdata())
                                    if (self.lfas_pending.is_set or self.lfas_pending.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lfas_pending.get_name_leafdata())
                                    if (self.lfas_sent.is_set or self.lfas_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lfas_sent.get_name_leafdata())
                                    if (self.max_routes.is_set or self.max_routes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.max_routes.get_name_leafdata())
                                    if (self.paths_add.is_set or self.paths_add.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.paths_add.get_name_leafdata())
                                    if (self.paths_add_errs.is_set or self.paths_add_errs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.paths_add_errs.get_name_leafdata())
                                    if (self.paths_del.is_set or self.paths_del.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.paths_del.get_name_leafdata())
                                    if (self.paths_del_errs.is_set or self.paths_del_errs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.paths_del_errs.get_name_leafdata())
                                    if (self.paths_pending.is_set or self.paths_pending.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.paths_pending.get_name_leafdata())
                                    if (self.paths_sent.is_set or self.paths_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.paths_sent.get_name_leafdata())
                                    if (self.priority_level.is_set or self.priority_level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.priority_level.get_name_leafdata())
                                    if (self.routes_pending.is_set or self.routes_pending.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.routes_pending.get_name_leafdata())
                                    if (self.routes_sent.is_set or self.routes_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.routes_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "batches-sent" or name == "lfas-add" or name == "lfas-del" or name == "lfas-pending" or name == "lfas-sent" or name == "max-routes" or name == "paths-add" or name == "paths-add-errs" or name == "paths-del" or name == "paths-del-errs" or name == "paths-pending" or name == "paths-sent" or name == "priority-level" or name == "routes-pending" or name == "routes-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "batches-sent"):
                                        self.batches_sent = value
                                        self.batches_sent.value_namespace = name_space
                                        self.batches_sent.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lfas-add"):
                                        self.lfas_add = value
                                        self.lfas_add.value_namespace = name_space
                                        self.lfas_add.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lfas-del"):
                                        self.lfas_del = value
                                        self.lfas_del.value_namespace = name_space
                                        self.lfas_del.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lfas-pending"):
                                        self.lfas_pending = value
                                        self.lfas_pending.value_namespace = name_space
                                        self.lfas_pending.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lfas-sent"):
                                        self.lfas_sent = value
                                        self.lfas_sent.value_namespace = name_space
                                        self.lfas_sent.value_namespace_prefix = name_space_prefix
                                    if(value_path == "max-routes"):
                                        self.max_routes = value
                                        self.max_routes.value_namespace = name_space
                                        self.max_routes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "paths-add"):
                                        self.paths_add = value
                                        self.paths_add.value_namespace = name_space
                                        self.paths_add.value_namespace_prefix = name_space_prefix
                                    if(value_path == "paths-add-errs"):
                                        self.paths_add_errs = value
                                        self.paths_add_errs.value_namespace = name_space
                                        self.paths_add_errs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "paths-del"):
                                        self.paths_del = value
                                        self.paths_del.value_namespace = name_space
                                        self.paths_del.value_namespace_prefix = name_space_prefix
                                    if(value_path == "paths-del-errs"):
                                        self.paths_del_errs = value
                                        self.paths_del_errs.value_namespace = name_space
                                        self.paths_del_errs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "paths-pending"):
                                        self.paths_pending = value
                                        self.paths_pending.value_namespace = name_space
                                        self.paths_pending.value_namespace_prefix = name_space_prefix
                                    if(value_path == "paths-sent"):
                                        self.paths_sent = value
                                        self.paths_sent.value_namespace = name_space
                                        self.paths_sent.value_namespace_prefix = name_space_prefix
                                    if(value_path == "priority-level"):
                                        self.priority_level = value
                                        self.priority_level.value_namespace = name_space
                                        self.priority_level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "routes-pending"):
                                        self.routes_pending = value
                                        self.routes_pending.value_namespace = name_space
                                        self.routes_pending.value_namespace_prefix = name_space_prefix
                                    if(value_path == "routes-sent"):
                                        self.routes_sent = value
                                        self.routes_sent.value_namespace = name_space
                                        self.routes_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.priority_batch:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.priority_batch:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rib-batch-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "priority-batch"):
                                    for c in self.priority_batch:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats.PriorityBatch()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.priority_batch.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "priority-batch"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class IssuStats(Entity):
                            """
                            OSPF ISSU statistics
                            
                            .. attribute:: nsr_conn_to_active_attempts
                            
                            	nsr conn to active attempts
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_closes
                            
                            	nsr conn to active closes
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_errors
                            
                            	nsr conn to active errors
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_fails
                            
                            	nsr conn to active fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_opens
                            
                            	nsr conn to active opens
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_fsm_state
                            
                            	nsr fsm state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_intf_seq_no
                            
                            	nsr intf seq no
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_lsa_init_sync_pend_count
                            
                            	nsr lsa init sync pend count
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_lsa_qad_mdata_count
                            
                            	nsr lsa qad mdata count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_lsa_qad_qid
                            
                            	nsr lsa qad qid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_mtu
                            
                            	nsr mtu
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nbr_init_sync_pend_count
                            
                            	nsr nbr init sync pend count
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_nbr_qad_mdata_count
                            
                            	nsr nbr qad mdata count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nbr_qad_qid
                            
                            	nsr nbr qad qid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nbr_seq_no
                            
                            	nsr nbr seq no
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nodeid
                            
                            	nsr nodeid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_peer_nodeid
                            
                            	nsr peer nodeid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_peer_version
                            
                            	nsr peer version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_rev
                            
                            	nsr rev
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_rtr_thd_sched
                            
                            	nsr rtr thd sched
                            	**type**\:   :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched>`
                            
                            .. attribute:: nsr_thd_sched
                            
                            	nsr thd sched
                            	**type**\:   :py:class:`NsrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched>`
                            
                            .. attribute:: nsr_tmr_quant
                            
                            	nsr tmr quant
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_version
                            
                            	nsr version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats, self).__init__()

                                self.yang_name = "issu-stats"
                                self.yang_parent_name = "statistics"

                                self.nsr_conn_to_active_attempts = YLeaf(YType.uint64, "nsr-conn-to-active-attempts")

                                self.nsr_conn_to_active_closes = YLeaf(YType.uint64, "nsr-conn-to-active-closes")

                                self.nsr_conn_to_active_errors = YLeaf(YType.uint64, "nsr-conn-to-active-errors")

                                self.nsr_conn_to_active_fails = YLeaf(YType.uint64, "nsr-conn-to-active-fails")

                                self.nsr_conn_to_active_opens = YLeaf(YType.uint64, "nsr-conn-to-active-opens")

                                self.nsr_fsm_state = YLeaf(YType.int32, "nsr-fsm-state")

                                self.nsr_intf_seq_no = YLeaf(YType.uint32, "nsr-intf-seq-no")

                                self.nsr_lsa_init_sync_pend_count = YLeaf(YType.int32, "nsr-lsa-init-sync-pend-count")

                                self.nsr_lsa_qad_mdata_count = YLeaf(YType.uint32, "nsr-lsa-qad-mdata-count")

                                self.nsr_lsa_qad_qid = YLeaf(YType.uint32, "nsr-lsa-qad-qid")

                                self.nsr_mtu = YLeaf(YType.uint32, "nsr-mtu")

                                self.nsr_nbr_init_sync_pend_count = YLeaf(YType.int32, "nsr-nbr-init-sync-pend-count")

                                self.nsr_nbr_qad_mdata_count = YLeaf(YType.uint32, "nsr-nbr-qad-mdata-count")

                                self.nsr_nbr_qad_qid = YLeaf(YType.uint32, "nsr-nbr-qad-qid")

                                self.nsr_nbr_seq_no = YLeaf(YType.uint32, "nsr-nbr-seq-no")

                                self.nsr_nodeid = YLeaf(YType.uint32, "nsr-nodeid")

                                self.nsr_peer_nodeid = YLeaf(YType.uint32, "nsr-peer-nodeid")

                                self.nsr_peer_version = YLeaf(YType.uint32, "nsr-peer-version")

                                self.nsr_rev = YLeaf(YType.int32, "nsr-rev")

                                self.nsr_tmr_quant = YLeaf(YType.int32, "nsr-tmr-quant")

                                self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                                self.nsr_rtr_thd_sched = Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched()
                                self.nsr_rtr_thd_sched.parent = self
                                self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                                self._children_yang_names.add("nsr-rtr-thd-sched")

                                self.nsr_thd_sched = Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched()
                                self.nsr_thd_sched.parent = self
                                self._children_name_map["nsr_thd_sched"] = "nsr-thd-sched"
                                self._children_yang_names.add("nsr-thd-sched")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nsr_conn_to_active_attempts",
                                                "nsr_conn_to_active_closes",
                                                "nsr_conn_to_active_errors",
                                                "nsr_conn_to_active_fails",
                                                "nsr_conn_to_active_opens",
                                                "nsr_fsm_state",
                                                "nsr_intf_seq_no",
                                                "nsr_lsa_init_sync_pend_count",
                                                "nsr_lsa_qad_mdata_count",
                                                "nsr_lsa_qad_qid",
                                                "nsr_mtu",
                                                "nsr_nbr_init_sync_pend_count",
                                                "nsr_nbr_qad_mdata_count",
                                                "nsr_nbr_qad_qid",
                                                "nsr_nbr_seq_no",
                                                "nsr_nodeid",
                                                "nsr_peer_nodeid",
                                                "nsr_peer_version",
                                                "nsr_rev",
                                                "nsr_tmr_quant",
                                                "nsr_version") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats, self).__setattr__(name, value)


                            class NsrThdSched(Entity):
                                """
                                nsr thd sched
                                
                                .. attribute:: nsr_bad_pulses_rx
                                
                                	nsr bad pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_in_q
                                
                                	nsr events in q
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_events_rx
                                
                                	nsr events rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_tx
                                
                                	nsr events tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_good_pulses_rx
                                
                                	nsr good pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pri
                                
                                	nsr pri
                                	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched.NsrPri>`
                                
                                .. attribute:: nsr_pulse_quant
                                
                                	nsr pulse quant
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: nsr_pulse_tx_fails
                                
                                	nsr pulse tx fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pulses_tx
                                
                                	nsr pulses tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched, self).__init__()

                                    self.yang_name = "nsr-thd-sched"
                                    self.yang_parent_name = "issu-stats"

                                    self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                    self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                    self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                    self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                    self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                    self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                    self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                    self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                    self.nsr_pri = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nsr_bad_pulses_rx",
                                                    "nsr_events_in_q",
                                                    "nsr_events_rx",
                                                    "nsr_events_tx",
                                                    "nsr_good_pulses_rx",
                                                    "nsr_pulse_quant",
                                                    "nsr_pulse_tx_fails",
                                                    "nsr_pulses_tx") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched, self).__setattr__(name, value)


                                class NsrPri(Entity):
                                    """
                                    nsr pri
                                    
                                    .. attribute:: nsr_sched_enq_fails
                                    
                                    	nsr sched enq fails
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_deqd
                                    
                                    	nsr sched evs deqd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_in_q
                                    
                                    	nsr sched evs in q
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_evs_qd
                                    
                                    	nsr sched evs qd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_max_evs
                                    
                                    	nsr sched max evs
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_peak_q_len
                                    
                                    	nsr sched peak q len
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_pri
                                    
                                    	nsr sched pri
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sched_quant
                                    
                                    	nsr sched quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nsr_sched_remain_quant
                                    
                                    	nsr sched remain quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched.NsrPri, self).__init__()

                                        self.yang_name = "nsr-pri"
                                        self.yang_parent_name = "nsr-thd-sched"

                                        self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                        self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                        self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                        self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                        self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                        self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                        self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                        self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                        self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nsr_sched_enq_fails",
                                                        "nsr_sched_evs_deqd",
                                                        "nsr_sched_evs_in_q",
                                                        "nsr_sched_evs_qd",
                                                        "nsr_sched_max_evs",
                                                        "nsr_sched_peak_q_len",
                                                        "nsr_sched_pri",
                                                        "nsr_sched_quant",
                                                        "nsr_sched_remain_quant") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched.NsrPri, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched.NsrPri, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nsr_sched_enq_fails.is_set or
                                            self.nsr_sched_evs_deqd.is_set or
                                            self.nsr_sched_evs_in_q.is_set or
                                            self.nsr_sched_evs_qd.is_set or
                                            self.nsr_sched_max_evs.is_set or
                                            self.nsr_sched_peak_q_len.is_set or
                                            self.nsr_sched_pri.is_set or
                                            self.nsr_sched_quant.is_set or
                                            self.nsr_sched_remain_quant.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nsr_sched_enq_fails.yfilter != YFilter.not_set or
                                            self.nsr_sched_evs_deqd.yfilter != YFilter.not_set or
                                            self.nsr_sched_evs_in_q.yfilter != YFilter.not_set or
                                            self.nsr_sched_evs_qd.yfilter != YFilter.not_set or
                                            self.nsr_sched_max_evs.yfilter != YFilter.not_set or
                                            self.nsr_sched_peak_q_len.yfilter != YFilter.not_set or
                                            self.nsr_sched_pri.yfilter != YFilter.not_set or
                                            self.nsr_sched_quant.yfilter != YFilter.not_set or
                                            self.nsr_sched_remain_quant.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "nsr-pri" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nsr_sched_enq_fails.is_set or self.nsr_sched_enq_fails.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_enq_fails.get_name_leafdata())
                                        if (self.nsr_sched_evs_deqd.is_set or self.nsr_sched_evs_deqd.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_evs_deqd.get_name_leafdata())
                                        if (self.nsr_sched_evs_in_q.is_set or self.nsr_sched_evs_in_q.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_evs_in_q.get_name_leafdata())
                                        if (self.nsr_sched_evs_qd.is_set or self.nsr_sched_evs_qd.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_evs_qd.get_name_leafdata())
                                        if (self.nsr_sched_max_evs.is_set or self.nsr_sched_max_evs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_max_evs.get_name_leafdata())
                                        if (self.nsr_sched_peak_q_len.is_set or self.nsr_sched_peak_q_len.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_peak_q_len.get_name_leafdata())
                                        if (self.nsr_sched_pri.is_set or self.nsr_sched_pri.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_pri.get_name_leafdata())
                                        if (self.nsr_sched_quant.is_set or self.nsr_sched_quant.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_quant.get_name_leafdata())
                                        if (self.nsr_sched_remain_quant.is_set or self.nsr_sched_remain_quant.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_remain_quant.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nsr-sched-enq-fails" or name == "nsr-sched-evs-deqd" or name == "nsr-sched-evs-in-q" or name == "nsr-sched-evs-qd" or name == "nsr-sched-max-evs" or name == "nsr-sched-peak-q-len" or name == "nsr-sched-pri" or name == "nsr-sched-quant" or name == "nsr-sched-remain-quant"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nsr-sched-enq-fails"):
                                            self.nsr_sched_enq_fails = value
                                            self.nsr_sched_enq_fails.value_namespace = name_space
                                            self.nsr_sched_enq_fails.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-evs-deqd"):
                                            self.nsr_sched_evs_deqd = value
                                            self.nsr_sched_evs_deqd.value_namespace = name_space
                                            self.nsr_sched_evs_deqd.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-evs-in-q"):
                                            self.nsr_sched_evs_in_q = value
                                            self.nsr_sched_evs_in_q.value_namespace = name_space
                                            self.nsr_sched_evs_in_q.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-evs-qd"):
                                            self.nsr_sched_evs_qd = value
                                            self.nsr_sched_evs_qd.value_namespace = name_space
                                            self.nsr_sched_evs_qd.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-max-evs"):
                                            self.nsr_sched_max_evs = value
                                            self.nsr_sched_max_evs.value_namespace = name_space
                                            self.nsr_sched_max_evs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-peak-q-len"):
                                            self.nsr_sched_peak_q_len = value
                                            self.nsr_sched_peak_q_len.value_namespace = name_space
                                            self.nsr_sched_peak_q_len.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-pri"):
                                            self.nsr_sched_pri = value
                                            self.nsr_sched_pri.value_namespace = name_space
                                            self.nsr_sched_pri.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-quant"):
                                            self.nsr_sched_quant = value
                                            self.nsr_sched_quant.value_namespace = name_space
                                            self.nsr_sched_quant.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-remain-quant"):
                                            self.nsr_sched_remain_quant = value
                                            self.nsr_sched_remain_quant.value_namespace = name_space
                                            self.nsr_sched_remain_quant.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.nsr_pri:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.nsr_bad_pulses_rx.is_set or
                                        self.nsr_events_in_q.is_set or
                                        self.nsr_events_rx.is_set or
                                        self.nsr_events_tx.is_set or
                                        self.nsr_good_pulses_rx.is_set or
                                        self.nsr_pulse_quant.is_set or
                                        self.nsr_pulse_tx_fails.is_set or
                                        self.nsr_pulses_tx.is_set)

                                def has_operation(self):
                                    for c in self.nsr_pri:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nsr_bad_pulses_rx.yfilter != YFilter.not_set or
                                        self.nsr_events_in_q.yfilter != YFilter.not_set or
                                        self.nsr_events_rx.yfilter != YFilter.not_set or
                                        self.nsr_events_tx.yfilter != YFilter.not_set or
                                        self.nsr_good_pulses_rx.yfilter != YFilter.not_set or
                                        self.nsr_pulse_quant.yfilter != YFilter.not_set or
                                        self.nsr_pulse_tx_fails.yfilter != YFilter.not_set or
                                        self.nsr_pulses_tx.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "nsr-thd-sched" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nsr_bad_pulses_rx.is_set or self.nsr_bad_pulses_rx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_bad_pulses_rx.get_name_leafdata())
                                    if (self.nsr_events_in_q.is_set or self.nsr_events_in_q.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_events_in_q.get_name_leafdata())
                                    if (self.nsr_events_rx.is_set or self.nsr_events_rx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_events_rx.get_name_leafdata())
                                    if (self.nsr_events_tx.is_set or self.nsr_events_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_events_tx.get_name_leafdata())
                                    if (self.nsr_good_pulses_rx.is_set or self.nsr_good_pulses_rx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_good_pulses_rx.get_name_leafdata())
                                    if (self.nsr_pulse_quant.is_set or self.nsr_pulse_quant.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_pulse_quant.get_name_leafdata())
                                    if (self.nsr_pulse_tx_fails.is_set or self.nsr_pulse_tx_fails.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_pulse_tx_fails.get_name_leafdata())
                                    if (self.nsr_pulses_tx.is_set or self.nsr_pulses_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_pulses_tx.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "nsr-pri"):
                                        for c in self.nsr_pri:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched.NsrPri()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.nsr_pri.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nsr-pri" or name == "nsr-bad-pulses-rx" or name == "nsr-events-in-q" or name == "nsr-events-rx" or name == "nsr-events-tx" or name == "nsr-good-pulses-rx" or name == "nsr-pulse-quant" or name == "nsr-pulse-tx-fails" or name == "nsr-pulses-tx"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nsr-bad-pulses-rx"):
                                        self.nsr_bad_pulses_rx = value
                                        self.nsr_bad_pulses_rx.value_namespace = name_space
                                        self.nsr_bad_pulses_rx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-events-in-q"):
                                        self.nsr_events_in_q = value
                                        self.nsr_events_in_q.value_namespace = name_space
                                        self.nsr_events_in_q.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-events-rx"):
                                        self.nsr_events_rx = value
                                        self.nsr_events_rx.value_namespace = name_space
                                        self.nsr_events_rx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-events-tx"):
                                        self.nsr_events_tx = value
                                        self.nsr_events_tx.value_namespace = name_space
                                        self.nsr_events_tx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-good-pulses-rx"):
                                        self.nsr_good_pulses_rx = value
                                        self.nsr_good_pulses_rx.value_namespace = name_space
                                        self.nsr_good_pulses_rx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-pulse-quant"):
                                        self.nsr_pulse_quant = value
                                        self.nsr_pulse_quant.value_namespace = name_space
                                        self.nsr_pulse_quant.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-pulse-tx-fails"):
                                        self.nsr_pulse_tx_fails = value
                                        self.nsr_pulse_tx_fails.value_namespace = name_space
                                        self.nsr_pulse_tx_fails.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-pulses-tx"):
                                        self.nsr_pulses_tx = value
                                        self.nsr_pulses_tx.value_namespace = name_space
                                        self.nsr_pulses_tx.value_namespace_prefix = name_space_prefix


                            class NsrRtrThdSched(Entity):
                                """
                                nsr rtr thd sched
                                
                                .. attribute:: nsr_bad_pulses_rx
                                
                                	nsr bad pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_in_q
                                
                                	nsr events in q
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_events_rx
                                
                                	nsr events rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_tx
                                
                                	nsr events tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_good_pulses_rx
                                
                                	nsr good pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pri
                                
                                	nsr pri
                                	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri>`
                                
                                .. attribute:: nsr_pulse_quant
                                
                                	nsr pulse quant
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: nsr_pulse_tx_fails
                                
                                	nsr pulse tx fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pulses_tx
                                
                                	nsr pulses tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched, self).__init__()

                                    self.yang_name = "nsr-rtr-thd-sched"
                                    self.yang_parent_name = "issu-stats"

                                    self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                    self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                    self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                    self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                    self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                    self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                    self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                    self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                    self.nsr_pri = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nsr_bad_pulses_rx",
                                                    "nsr_events_in_q",
                                                    "nsr_events_rx",
                                                    "nsr_events_tx",
                                                    "nsr_good_pulses_rx",
                                                    "nsr_pulse_quant",
                                                    "nsr_pulse_tx_fails",
                                                    "nsr_pulses_tx") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched, self).__setattr__(name, value)


                                class NsrPri(Entity):
                                    """
                                    nsr pri
                                    
                                    .. attribute:: nsr_sched_enq_fails
                                    
                                    	nsr sched enq fails
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_deqd
                                    
                                    	nsr sched evs deqd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_in_q
                                    
                                    	nsr sched evs in q
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_evs_qd
                                    
                                    	nsr sched evs qd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_max_evs
                                    
                                    	nsr sched max evs
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_peak_q_len
                                    
                                    	nsr sched peak q len
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_pri
                                    
                                    	nsr sched pri
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sched_quant
                                    
                                    	nsr sched quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nsr_sched_remain_quant
                                    
                                    	nsr sched remain quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri, self).__init__()

                                        self.yang_name = "nsr-pri"
                                        self.yang_parent_name = "nsr-rtr-thd-sched"

                                        self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                        self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                        self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                        self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                        self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                        self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                        self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                        self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                        self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nsr_sched_enq_fails",
                                                        "nsr_sched_evs_deqd",
                                                        "nsr_sched_evs_in_q",
                                                        "nsr_sched_evs_qd",
                                                        "nsr_sched_max_evs",
                                                        "nsr_sched_peak_q_len",
                                                        "nsr_sched_pri",
                                                        "nsr_sched_quant",
                                                        "nsr_sched_remain_quant") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nsr_sched_enq_fails.is_set or
                                            self.nsr_sched_evs_deqd.is_set or
                                            self.nsr_sched_evs_in_q.is_set or
                                            self.nsr_sched_evs_qd.is_set or
                                            self.nsr_sched_max_evs.is_set or
                                            self.nsr_sched_peak_q_len.is_set or
                                            self.nsr_sched_pri.is_set or
                                            self.nsr_sched_quant.is_set or
                                            self.nsr_sched_remain_quant.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nsr_sched_enq_fails.yfilter != YFilter.not_set or
                                            self.nsr_sched_evs_deqd.yfilter != YFilter.not_set or
                                            self.nsr_sched_evs_in_q.yfilter != YFilter.not_set or
                                            self.nsr_sched_evs_qd.yfilter != YFilter.not_set or
                                            self.nsr_sched_max_evs.yfilter != YFilter.not_set or
                                            self.nsr_sched_peak_q_len.yfilter != YFilter.not_set or
                                            self.nsr_sched_pri.yfilter != YFilter.not_set or
                                            self.nsr_sched_quant.yfilter != YFilter.not_set or
                                            self.nsr_sched_remain_quant.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "nsr-pri" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nsr_sched_enq_fails.is_set or self.nsr_sched_enq_fails.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_enq_fails.get_name_leafdata())
                                        if (self.nsr_sched_evs_deqd.is_set or self.nsr_sched_evs_deqd.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_evs_deqd.get_name_leafdata())
                                        if (self.nsr_sched_evs_in_q.is_set or self.nsr_sched_evs_in_q.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_evs_in_q.get_name_leafdata())
                                        if (self.nsr_sched_evs_qd.is_set or self.nsr_sched_evs_qd.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_evs_qd.get_name_leafdata())
                                        if (self.nsr_sched_max_evs.is_set or self.nsr_sched_max_evs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_max_evs.get_name_leafdata())
                                        if (self.nsr_sched_peak_q_len.is_set or self.nsr_sched_peak_q_len.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_peak_q_len.get_name_leafdata())
                                        if (self.nsr_sched_pri.is_set or self.nsr_sched_pri.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_pri.get_name_leafdata())
                                        if (self.nsr_sched_quant.is_set or self.nsr_sched_quant.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_quant.get_name_leafdata())
                                        if (self.nsr_sched_remain_quant.is_set or self.nsr_sched_remain_quant.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_remain_quant.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nsr-sched-enq-fails" or name == "nsr-sched-evs-deqd" or name == "nsr-sched-evs-in-q" or name == "nsr-sched-evs-qd" or name == "nsr-sched-max-evs" or name == "nsr-sched-peak-q-len" or name == "nsr-sched-pri" or name == "nsr-sched-quant" or name == "nsr-sched-remain-quant"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nsr-sched-enq-fails"):
                                            self.nsr_sched_enq_fails = value
                                            self.nsr_sched_enq_fails.value_namespace = name_space
                                            self.nsr_sched_enq_fails.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-evs-deqd"):
                                            self.nsr_sched_evs_deqd = value
                                            self.nsr_sched_evs_deqd.value_namespace = name_space
                                            self.nsr_sched_evs_deqd.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-evs-in-q"):
                                            self.nsr_sched_evs_in_q = value
                                            self.nsr_sched_evs_in_q.value_namespace = name_space
                                            self.nsr_sched_evs_in_q.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-evs-qd"):
                                            self.nsr_sched_evs_qd = value
                                            self.nsr_sched_evs_qd.value_namespace = name_space
                                            self.nsr_sched_evs_qd.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-max-evs"):
                                            self.nsr_sched_max_evs = value
                                            self.nsr_sched_max_evs.value_namespace = name_space
                                            self.nsr_sched_max_evs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-peak-q-len"):
                                            self.nsr_sched_peak_q_len = value
                                            self.nsr_sched_peak_q_len.value_namespace = name_space
                                            self.nsr_sched_peak_q_len.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-pri"):
                                            self.nsr_sched_pri = value
                                            self.nsr_sched_pri.value_namespace = name_space
                                            self.nsr_sched_pri.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-quant"):
                                            self.nsr_sched_quant = value
                                            self.nsr_sched_quant.value_namespace = name_space
                                            self.nsr_sched_quant.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-remain-quant"):
                                            self.nsr_sched_remain_quant = value
                                            self.nsr_sched_remain_quant.value_namespace = name_space
                                            self.nsr_sched_remain_quant.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.nsr_pri:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.nsr_bad_pulses_rx.is_set or
                                        self.nsr_events_in_q.is_set or
                                        self.nsr_events_rx.is_set or
                                        self.nsr_events_tx.is_set or
                                        self.nsr_good_pulses_rx.is_set or
                                        self.nsr_pulse_quant.is_set or
                                        self.nsr_pulse_tx_fails.is_set or
                                        self.nsr_pulses_tx.is_set)

                                def has_operation(self):
                                    for c in self.nsr_pri:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nsr_bad_pulses_rx.yfilter != YFilter.not_set or
                                        self.nsr_events_in_q.yfilter != YFilter.not_set or
                                        self.nsr_events_rx.yfilter != YFilter.not_set or
                                        self.nsr_events_tx.yfilter != YFilter.not_set or
                                        self.nsr_good_pulses_rx.yfilter != YFilter.not_set or
                                        self.nsr_pulse_quant.yfilter != YFilter.not_set or
                                        self.nsr_pulse_tx_fails.yfilter != YFilter.not_set or
                                        self.nsr_pulses_tx.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "nsr-rtr-thd-sched" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nsr_bad_pulses_rx.is_set or self.nsr_bad_pulses_rx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_bad_pulses_rx.get_name_leafdata())
                                    if (self.nsr_events_in_q.is_set or self.nsr_events_in_q.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_events_in_q.get_name_leafdata())
                                    if (self.nsr_events_rx.is_set or self.nsr_events_rx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_events_rx.get_name_leafdata())
                                    if (self.nsr_events_tx.is_set or self.nsr_events_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_events_tx.get_name_leafdata())
                                    if (self.nsr_good_pulses_rx.is_set or self.nsr_good_pulses_rx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_good_pulses_rx.get_name_leafdata())
                                    if (self.nsr_pulse_quant.is_set or self.nsr_pulse_quant.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_pulse_quant.get_name_leafdata())
                                    if (self.nsr_pulse_tx_fails.is_set or self.nsr_pulse_tx_fails.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_pulse_tx_fails.get_name_leafdata())
                                    if (self.nsr_pulses_tx.is_set or self.nsr_pulses_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_pulses_tx.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "nsr-pri"):
                                        for c in self.nsr_pri:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.nsr_pri.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nsr-pri" or name == "nsr-bad-pulses-rx" or name == "nsr-events-in-q" or name == "nsr-events-rx" or name == "nsr-events-tx" or name == "nsr-good-pulses-rx" or name == "nsr-pulse-quant" or name == "nsr-pulse-tx-fails" or name == "nsr-pulses-tx"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nsr-bad-pulses-rx"):
                                        self.nsr_bad_pulses_rx = value
                                        self.nsr_bad_pulses_rx.value_namespace = name_space
                                        self.nsr_bad_pulses_rx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-events-in-q"):
                                        self.nsr_events_in_q = value
                                        self.nsr_events_in_q.value_namespace = name_space
                                        self.nsr_events_in_q.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-events-rx"):
                                        self.nsr_events_rx = value
                                        self.nsr_events_rx.value_namespace = name_space
                                        self.nsr_events_rx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-events-tx"):
                                        self.nsr_events_tx = value
                                        self.nsr_events_tx.value_namespace = name_space
                                        self.nsr_events_tx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-good-pulses-rx"):
                                        self.nsr_good_pulses_rx = value
                                        self.nsr_good_pulses_rx.value_namespace = name_space
                                        self.nsr_good_pulses_rx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-pulse-quant"):
                                        self.nsr_pulse_quant = value
                                        self.nsr_pulse_quant.value_namespace = name_space
                                        self.nsr_pulse_quant.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-pulse-tx-fails"):
                                        self.nsr_pulse_tx_fails = value
                                        self.nsr_pulse_tx_fails.value_namespace = name_space
                                        self.nsr_pulse_tx_fails.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-pulses-tx"):
                                        self.nsr_pulses_tx = value
                                        self.nsr_pulses_tx.value_namespace = name_space
                                        self.nsr_pulses_tx.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.nsr_conn_to_active_attempts.is_set or
                                    self.nsr_conn_to_active_closes.is_set or
                                    self.nsr_conn_to_active_errors.is_set or
                                    self.nsr_conn_to_active_fails.is_set or
                                    self.nsr_conn_to_active_opens.is_set or
                                    self.nsr_fsm_state.is_set or
                                    self.nsr_intf_seq_no.is_set or
                                    self.nsr_lsa_init_sync_pend_count.is_set or
                                    self.nsr_lsa_qad_mdata_count.is_set or
                                    self.nsr_lsa_qad_qid.is_set or
                                    self.nsr_mtu.is_set or
                                    self.nsr_nbr_init_sync_pend_count.is_set or
                                    self.nsr_nbr_qad_mdata_count.is_set or
                                    self.nsr_nbr_qad_qid.is_set or
                                    self.nsr_nbr_seq_no.is_set or
                                    self.nsr_nodeid.is_set or
                                    self.nsr_peer_nodeid.is_set or
                                    self.nsr_peer_version.is_set or
                                    self.nsr_rev.is_set or
                                    self.nsr_tmr_quant.is_set or
                                    self.nsr_version.is_set or
                                    (self.nsr_rtr_thd_sched is not None and self.nsr_rtr_thd_sched.has_data()) or
                                    (self.nsr_thd_sched is not None and self.nsr_thd_sched.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nsr_conn_to_active_attempts.yfilter != YFilter.not_set or
                                    self.nsr_conn_to_active_closes.yfilter != YFilter.not_set or
                                    self.nsr_conn_to_active_errors.yfilter != YFilter.not_set or
                                    self.nsr_conn_to_active_fails.yfilter != YFilter.not_set or
                                    self.nsr_conn_to_active_opens.yfilter != YFilter.not_set or
                                    self.nsr_fsm_state.yfilter != YFilter.not_set or
                                    self.nsr_intf_seq_no.yfilter != YFilter.not_set or
                                    self.nsr_lsa_init_sync_pend_count.yfilter != YFilter.not_set or
                                    self.nsr_lsa_qad_mdata_count.yfilter != YFilter.not_set or
                                    self.nsr_lsa_qad_qid.yfilter != YFilter.not_set or
                                    self.nsr_mtu.yfilter != YFilter.not_set or
                                    self.nsr_nbr_init_sync_pend_count.yfilter != YFilter.not_set or
                                    self.nsr_nbr_qad_mdata_count.yfilter != YFilter.not_set or
                                    self.nsr_nbr_qad_qid.yfilter != YFilter.not_set or
                                    self.nsr_nbr_seq_no.yfilter != YFilter.not_set or
                                    self.nsr_nodeid.yfilter != YFilter.not_set or
                                    self.nsr_peer_nodeid.yfilter != YFilter.not_set or
                                    self.nsr_peer_version.yfilter != YFilter.not_set or
                                    self.nsr_rev.yfilter != YFilter.not_set or
                                    self.nsr_tmr_quant.yfilter != YFilter.not_set or
                                    self.nsr_version.yfilter != YFilter.not_set or
                                    (self.nsr_rtr_thd_sched is not None and self.nsr_rtr_thd_sched.has_operation()) or
                                    (self.nsr_thd_sched is not None and self.nsr_thd_sched.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "issu-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nsr_conn_to_active_attempts.is_set or self.nsr_conn_to_active_attempts.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_conn_to_active_attempts.get_name_leafdata())
                                if (self.nsr_conn_to_active_closes.is_set or self.nsr_conn_to_active_closes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_conn_to_active_closes.get_name_leafdata())
                                if (self.nsr_conn_to_active_errors.is_set or self.nsr_conn_to_active_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_conn_to_active_errors.get_name_leafdata())
                                if (self.nsr_conn_to_active_fails.is_set or self.nsr_conn_to_active_fails.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_conn_to_active_fails.get_name_leafdata())
                                if (self.nsr_conn_to_active_opens.is_set or self.nsr_conn_to_active_opens.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_conn_to_active_opens.get_name_leafdata())
                                if (self.nsr_fsm_state.is_set or self.nsr_fsm_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_fsm_state.get_name_leafdata())
                                if (self.nsr_intf_seq_no.is_set or self.nsr_intf_seq_no.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_intf_seq_no.get_name_leafdata())
                                if (self.nsr_lsa_init_sync_pend_count.is_set or self.nsr_lsa_init_sync_pend_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_lsa_init_sync_pend_count.get_name_leafdata())
                                if (self.nsr_lsa_qad_mdata_count.is_set or self.nsr_lsa_qad_mdata_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_lsa_qad_mdata_count.get_name_leafdata())
                                if (self.nsr_lsa_qad_qid.is_set or self.nsr_lsa_qad_qid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_lsa_qad_qid.get_name_leafdata())
                                if (self.nsr_mtu.is_set or self.nsr_mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_mtu.get_name_leafdata())
                                if (self.nsr_nbr_init_sync_pend_count.is_set or self.nsr_nbr_init_sync_pend_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_nbr_init_sync_pend_count.get_name_leafdata())
                                if (self.nsr_nbr_qad_mdata_count.is_set or self.nsr_nbr_qad_mdata_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_nbr_qad_mdata_count.get_name_leafdata())
                                if (self.nsr_nbr_qad_qid.is_set or self.nsr_nbr_qad_qid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_nbr_qad_qid.get_name_leafdata())
                                if (self.nsr_nbr_seq_no.is_set or self.nsr_nbr_seq_no.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_nbr_seq_no.get_name_leafdata())
                                if (self.nsr_nodeid.is_set or self.nsr_nodeid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_nodeid.get_name_leafdata())
                                if (self.nsr_peer_nodeid.is_set or self.nsr_peer_nodeid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_peer_nodeid.get_name_leafdata())
                                if (self.nsr_peer_version.is_set or self.nsr_peer_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_peer_version.get_name_leafdata())
                                if (self.nsr_rev.is_set or self.nsr_rev.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_rev.get_name_leafdata())
                                if (self.nsr_tmr_quant.is_set or self.nsr_tmr_quant.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_tmr_quant.get_name_leafdata())
                                if (self.nsr_version.is_set or self.nsr_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_version.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "nsr-rtr-thd-sched"):
                                    if (self.nsr_rtr_thd_sched is None):
                                        self.nsr_rtr_thd_sched = Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched()
                                        self.nsr_rtr_thd_sched.parent = self
                                        self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                                    return self.nsr_rtr_thd_sched

                                if (child_yang_name == "nsr-thd-sched"):
                                    if (self.nsr_thd_sched is None):
                                        self.nsr_thd_sched = Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched()
                                        self.nsr_thd_sched.parent = self
                                        self._children_name_map["nsr_thd_sched"] = "nsr-thd-sched"
                                    return self.nsr_thd_sched

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nsr-rtr-thd-sched" or name == "nsr-thd-sched" or name == "nsr-conn-to-active-attempts" or name == "nsr-conn-to-active-closes" or name == "nsr-conn-to-active-errors" or name == "nsr-conn-to-active-fails" or name == "nsr-conn-to-active-opens" or name == "nsr-fsm-state" or name == "nsr-intf-seq-no" or name == "nsr-lsa-init-sync-pend-count" or name == "nsr-lsa-qad-mdata-count" or name == "nsr-lsa-qad-qid" or name == "nsr-mtu" or name == "nsr-nbr-init-sync-pend-count" or name == "nsr-nbr-qad-mdata-count" or name == "nsr-nbr-qad-qid" or name == "nsr-nbr-seq-no" or name == "nsr-nodeid" or name == "nsr-peer-nodeid" or name == "nsr-peer-version" or name == "nsr-rev" or name == "nsr-tmr-quant" or name == "nsr-version"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nsr-conn-to-active-attempts"):
                                    self.nsr_conn_to_active_attempts = value
                                    self.nsr_conn_to_active_attempts.value_namespace = name_space
                                    self.nsr_conn_to_active_attempts.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-conn-to-active-closes"):
                                    self.nsr_conn_to_active_closes = value
                                    self.nsr_conn_to_active_closes.value_namespace = name_space
                                    self.nsr_conn_to_active_closes.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-conn-to-active-errors"):
                                    self.nsr_conn_to_active_errors = value
                                    self.nsr_conn_to_active_errors.value_namespace = name_space
                                    self.nsr_conn_to_active_errors.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-conn-to-active-fails"):
                                    self.nsr_conn_to_active_fails = value
                                    self.nsr_conn_to_active_fails.value_namespace = name_space
                                    self.nsr_conn_to_active_fails.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-conn-to-active-opens"):
                                    self.nsr_conn_to_active_opens = value
                                    self.nsr_conn_to_active_opens.value_namespace = name_space
                                    self.nsr_conn_to_active_opens.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-fsm-state"):
                                    self.nsr_fsm_state = value
                                    self.nsr_fsm_state.value_namespace = name_space
                                    self.nsr_fsm_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-intf-seq-no"):
                                    self.nsr_intf_seq_no = value
                                    self.nsr_intf_seq_no.value_namespace = name_space
                                    self.nsr_intf_seq_no.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-lsa-init-sync-pend-count"):
                                    self.nsr_lsa_init_sync_pend_count = value
                                    self.nsr_lsa_init_sync_pend_count.value_namespace = name_space
                                    self.nsr_lsa_init_sync_pend_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-lsa-qad-mdata-count"):
                                    self.nsr_lsa_qad_mdata_count = value
                                    self.nsr_lsa_qad_mdata_count.value_namespace = name_space
                                    self.nsr_lsa_qad_mdata_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-lsa-qad-qid"):
                                    self.nsr_lsa_qad_qid = value
                                    self.nsr_lsa_qad_qid.value_namespace = name_space
                                    self.nsr_lsa_qad_qid.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-mtu"):
                                    self.nsr_mtu = value
                                    self.nsr_mtu.value_namespace = name_space
                                    self.nsr_mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-nbr-init-sync-pend-count"):
                                    self.nsr_nbr_init_sync_pend_count = value
                                    self.nsr_nbr_init_sync_pend_count.value_namespace = name_space
                                    self.nsr_nbr_init_sync_pend_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-nbr-qad-mdata-count"):
                                    self.nsr_nbr_qad_mdata_count = value
                                    self.nsr_nbr_qad_mdata_count.value_namespace = name_space
                                    self.nsr_nbr_qad_mdata_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-nbr-qad-qid"):
                                    self.nsr_nbr_qad_qid = value
                                    self.nsr_nbr_qad_qid.value_namespace = name_space
                                    self.nsr_nbr_qad_qid.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-nbr-seq-no"):
                                    self.nsr_nbr_seq_no = value
                                    self.nsr_nbr_seq_no.value_namespace = name_space
                                    self.nsr_nbr_seq_no.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-nodeid"):
                                    self.nsr_nodeid = value
                                    self.nsr_nodeid.value_namespace = name_space
                                    self.nsr_nodeid.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-peer-nodeid"):
                                    self.nsr_peer_nodeid = value
                                    self.nsr_peer_nodeid.value_namespace = name_space
                                    self.nsr_peer_nodeid.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-peer-version"):
                                    self.nsr_peer_version = value
                                    self.nsr_peer_version.value_namespace = name_space
                                    self.nsr_peer_version.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-rev"):
                                    self.nsr_rev = value
                                    self.nsr_rev.value_namespace = name_space
                                    self.nsr_rev.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-tmr-quant"):
                                    self.nsr_tmr_quant = value
                                    self.nsr_tmr_quant.value_namespace = name_space
                                    self.nsr_tmr_quant.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-version"):
                                    self.nsr_version = value
                                    self.nsr_version.value_namespace = name_space
                                    self.nsr_version.value_namespace_prefix = name_space_prefix


                        class RibThreadStats(Entity):
                            """
                            OSPF RIB thread statistics
                            
                            .. attribute:: internalwq
                            
                            	internalwq
                            	**type**\:   :py:class:`Internalwq <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq>`
                            
                            .. attribute:: ribqueue
                            
                            	ribqueue
                            	**type**\: list of    :py:class:`Ribqueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats, self).__init__()

                                self.yang_name = "rib-thread-stats"
                                self.yang_parent_name = "statistics"

                                self.internalwq = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq()
                                self.internalwq.parent = self
                                self._children_name_map["internalwq"] = "internalwq"
                                self._children_yang_names.add("internalwq")

                                self.ribqueue = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats, self).__setattr__(name, value)


                            class Internalwq(Entity):
                                """
                                internalwq
                                
                                .. attribute:: priority_level
                                
                                	priority level
                                	**type**\:  str
                                
                                	**length:** 0..40
                                
                                .. attribute:: rib_base_clock
                                
                                	rib base clock
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: rib_base_time
                                
                                	rib base time
                                	**type**\:   :py:class:`RibBaseTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq.RibBaseTime>`
                                
                                .. attribute:: rib_dequeue_errs
                                
                                	rib dequeue errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_drop_after
                                
                                	rib drop after
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_drop_before
                                
                                	rib drop before
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_drop_conn
                                
                                	rib drop conn
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_empty_batches
                                
                                	rib empty batches
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_pfx_limit_errs
                                
                                	rib pfx limit errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_pkts_sent
                                
                                	rib pkts sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_queue_errs
                                
                                	rib queue errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_send_errs
                                
                                	rib send errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_signals
                                
                                	rib signals
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_table_not_created
                                
                                	rib table not created
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_version
                                
                                	rib version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wq_dqtime
                                
                                	wq dqtime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: wq_len_cur
                                
                                	wq len cur
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: wq_len_max
                                
                                	wq len max
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: wq_thread_active
                                
                                	wq thread active
                                	**type**\:  bool
                                
                                .. attribute:: wq_total_dequeued
                                
                                	wq total dequeued
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wq_total_queued
                                
                                	wq total queued
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wqe_qtime
                                
                                	wqe qtime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq, self).__init__()

                                    self.yang_name = "internalwq"
                                    self.yang_parent_name = "rib-thread-stats"

                                    self.priority_level = YLeaf(YType.str, "priority-level")

                                    self.rib_base_clock = YLeaf(YType.uint64, "rib-base-clock")

                                    self.rib_dequeue_errs = YLeaf(YType.uint32, "rib-dequeue-errs")

                                    self.rib_drop_after = YLeaf(YType.uint32, "rib-drop-after")

                                    self.rib_drop_before = YLeaf(YType.uint32, "rib-drop-before")

                                    self.rib_drop_conn = YLeaf(YType.uint32, "rib-drop-conn")

                                    self.rib_empty_batches = YLeaf(YType.uint32, "rib-empty-batches")

                                    self.rib_pfx_limit_errs = YLeaf(YType.uint32, "rib-pfx-limit-errs")

                                    self.rib_pkts_sent = YLeaf(YType.uint32, "rib-pkts-sent")

                                    self.rib_queue_errs = YLeaf(YType.uint32, "rib-queue-errs")

                                    self.rib_send_errs = YLeaf(YType.uint32, "rib-send-errs")

                                    self.rib_signals = YLeaf(YType.uint32, "rib-signals")

                                    self.rib_table_not_created = YLeaf(YType.uint32, "rib-table-not-created")

                                    self.rib_version = YLeaf(YType.uint32, "rib-version")

                                    self.wq_dqtime = YLeaf(YType.uint64, "wq-dqtime")

                                    self.wq_len_cur = YLeaf(YType.int32, "wq-len-cur")

                                    self.wq_len_max = YLeaf(YType.int32, "wq-len-max")

                                    self.wq_thread_active = YLeaf(YType.boolean, "wq-thread-active")

                                    self.wq_total_dequeued = YLeaf(YType.uint32, "wq-total-dequeued")

                                    self.wq_total_queued = YLeaf(YType.uint32, "wq-total-queued")

                                    self.wqe_qtime = YLeaf(YType.uint64, "wqe-qtime")

                                    self.rib_base_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq.RibBaseTime()
                                    self.rib_base_time.parent = self
                                    self._children_name_map["rib_base_time"] = "rib-base-time"
                                    self._children_yang_names.add("rib-base-time")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("priority_level",
                                                    "rib_base_clock",
                                                    "rib_dequeue_errs",
                                                    "rib_drop_after",
                                                    "rib_drop_before",
                                                    "rib_drop_conn",
                                                    "rib_empty_batches",
                                                    "rib_pfx_limit_errs",
                                                    "rib_pkts_sent",
                                                    "rib_queue_errs",
                                                    "rib_send_errs",
                                                    "rib_signals",
                                                    "rib_table_not_created",
                                                    "rib_version",
                                                    "wq_dqtime",
                                                    "wq_len_cur",
                                                    "wq_len_max",
                                                    "wq_thread_active",
                                                    "wq_total_dequeued",
                                                    "wq_total_queued",
                                                    "wqe_qtime") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq, self).__setattr__(name, value)


                                class RibBaseTime(Entity):
                                    """
                                    rib base time
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq.RibBaseTime, self).__init__()

                                        self.yang_name = "rib-base-time"
                                        self.yang_parent_name = "internalwq"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq.RibBaseTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq.RibBaseTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rib-base-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.priority_level.is_set or
                                        self.rib_base_clock.is_set or
                                        self.rib_dequeue_errs.is_set or
                                        self.rib_drop_after.is_set or
                                        self.rib_drop_before.is_set or
                                        self.rib_drop_conn.is_set or
                                        self.rib_empty_batches.is_set or
                                        self.rib_pfx_limit_errs.is_set or
                                        self.rib_pkts_sent.is_set or
                                        self.rib_queue_errs.is_set or
                                        self.rib_send_errs.is_set or
                                        self.rib_signals.is_set or
                                        self.rib_table_not_created.is_set or
                                        self.rib_version.is_set or
                                        self.wq_dqtime.is_set or
                                        self.wq_len_cur.is_set or
                                        self.wq_len_max.is_set or
                                        self.wq_thread_active.is_set or
                                        self.wq_total_dequeued.is_set or
                                        self.wq_total_queued.is_set or
                                        self.wqe_qtime.is_set or
                                        (self.rib_base_time is not None and self.rib_base_time.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.priority_level.yfilter != YFilter.not_set or
                                        self.rib_base_clock.yfilter != YFilter.not_set or
                                        self.rib_dequeue_errs.yfilter != YFilter.not_set or
                                        self.rib_drop_after.yfilter != YFilter.not_set or
                                        self.rib_drop_before.yfilter != YFilter.not_set or
                                        self.rib_drop_conn.yfilter != YFilter.not_set or
                                        self.rib_empty_batches.yfilter != YFilter.not_set or
                                        self.rib_pfx_limit_errs.yfilter != YFilter.not_set or
                                        self.rib_pkts_sent.yfilter != YFilter.not_set or
                                        self.rib_queue_errs.yfilter != YFilter.not_set or
                                        self.rib_send_errs.yfilter != YFilter.not_set or
                                        self.rib_signals.yfilter != YFilter.not_set or
                                        self.rib_table_not_created.yfilter != YFilter.not_set or
                                        self.rib_version.yfilter != YFilter.not_set or
                                        self.wq_dqtime.yfilter != YFilter.not_set or
                                        self.wq_len_cur.yfilter != YFilter.not_set or
                                        self.wq_len_max.yfilter != YFilter.not_set or
                                        self.wq_thread_active.yfilter != YFilter.not_set or
                                        self.wq_total_dequeued.yfilter != YFilter.not_set or
                                        self.wq_total_queued.yfilter != YFilter.not_set or
                                        self.wqe_qtime.yfilter != YFilter.not_set or
                                        (self.rib_base_time is not None and self.rib_base_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "internalwq" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.priority_level.is_set or self.priority_level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.priority_level.get_name_leafdata())
                                    if (self.rib_base_clock.is_set or self.rib_base_clock.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_base_clock.get_name_leafdata())
                                    if (self.rib_dequeue_errs.is_set or self.rib_dequeue_errs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_dequeue_errs.get_name_leafdata())
                                    if (self.rib_drop_after.is_set or self.rib_drop_after.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_drop_after.get_name_leafdata())
                                    if (self.rib_drop_before.is_set or self.rib_drop_before.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_drop_before.get_name_leafdata())
                                    if (self.rib_drop_conn.is_set or self.rib_drop_conn.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_drop_conn.get_name_leafdata())
                                    if (self.rib_empty_batches.is_set or self.rib_empty_batches.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_empty_batches.get_name_leafdata())
                                    if (self.rib_pfx_limit_errs.is_set or self.rib_pfx_limit_errs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_pfx_limit_errs.get_name_leafdata())
                                    if (self.rib_pkts_sent.is_set or self.rib_pkts_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_pkts_sent.get_name_leafdata())
                                    if (self.rib_queue_errs.is_set or self.rib_queue_errs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_queue_errs.get_name_leafdata())
                                    if (self.rib_send_errs.is_set or self.rib_send_errs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_send_errs.get_name_leafdata())
                                    if (self.rib_signals.is_set or self.rib_signals.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_signals.get_name_leafdata())
                                    if (self.rib_table_not_created.is_set or self.rib_table_not_created.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_table_not_created.get_name_leafdata())
                                    if (self.rib_version.is_set or self.rib_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_version.get_name_leafdata())
                                    if (self.wq_dqtime.is_set or self.wq_dqtime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wq_dqtime.get_name_leafdata())
                                    if (self.wq_len_cur.is_set or self.wq_len_cur.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wq_len_cur.get_name_leafdata())
                                    if (self.wq_len_max.is_set or self.wq_len_max.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wq_len_max.get_name_leafdata())
                                    if (self.wq_thread_active.is_set or self.wq_thread_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wq_thread_active.get_name_leafdata())
                                    if (self.wq_total_dequeued.is_set or self.wq_total_dequeued.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wq_total_dequeued.get_name_leafdata())
                                    if (self.wq_total_queued.is_set or self.wq_total_queued.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wq_total_queued.get_name_leafdata())
                                    if (self.wqe_qtime.is_set or self.wqe_qtime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wqe_qtime.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rib-base-time"):
                                        if (self.rib_base_time is None):
                                            self.rib_base_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq.RibBaseTime()
                                            self.rib_base_time.parent = self
                                            self._children_name_map["rib_base_time"] = "rib-base-time"
                                        return self.rib_base_time

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rib-base-time" or name == "priority-level" or name == "rib-base-clock" or name == "rib-dequeue-errs" or name == "rib-drop-after" or name == "rib-drop-before" or name == "rib-drop-conn" or name == "rib-empty-batches" or name == "rib-pfx-limit-errs" or name == "rib-pkts-sent" or name == "rib-queue-errs" or name == "rib-send-errs" or name == "rib-signals" or name == "rib-table-not-created" or name == "rib-version" or name == "wq-dqtime" or name == "wq-len-cur" or name == "wq-len-max" or name == "wq-thread-active" or name == "wq-total-dequeued" or name == "wq-total-queued" or name == "wqe-qtime"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "priority-level"):
                                        self.priority_level = value
                                        self.priority_level.value_namespace = name_space
                                        self.priority_level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-base-clock"):
                                        self.rib_base_clock = value
                                        self.rib_base_clock.value_namespace = name_space
                                        self.rib_base_clock.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-dequeue-errs"):
                                        self.rib_dequeue_errs = value
                                        self.rib_dequeue_errs.value_namespace = name_space
                                        self.rib_dequeue_errs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-drop-after"):
                                        self.rib_drop_after = value
                                        self.rib_drop_after.value_namespace = name_space
                                        self.rib_drop_after.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-drop-before"):
                                        self.rib_drop_before = value
                                        self.rib_drop_before.value_namespace = name_space
                                        self.rib_drop_before.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-drop-conn"):
                                        self.rib_drop_conn = value
                                        self.rib_drop_conn.value_namespace = name_space
                                        self.rib_drop_conn.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-empty-batches"):
                                        self.rib_empty_batches = value
                                        self.rib_empty_batches.value_namespace = name_space
                                        self.rib_empty_batches.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-pfx-limit-errs"):
                                        self.rib_pfx_limit_errs = value
                                        self.rib_pfx_limit_errs.value_namespace = name_space
                                        self.rib_pfx_limit_errs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-pkts-sent"):
                                        self.rib_pkts_sent = value
                                        self.rib_pkts_sent.value_namespace = name_space
                                        self.rib_pkts_sent.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-queue-errs"):
                                        self.rib_queue_errs = value
                                        self.rib_queue_errs.value_namespace = name_space
                                        self.rib_queue_errs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-send-errs"):
                                        self.rib_send_errs = value
                                        self.rib_send_errs.value_namespace = name_space
                                        self.rib_send_errs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-signals"):
                                        self.rib_signals = value
                                        self.rib_signals.value_namespace = name_space
                                        self.rib_signals.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-table-not-created"):
                                        self.rib_table_not_created = value
                                        self.rib_table_not_created.value_namespace = name_space
                                        self.rib_table_not_created.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-version"):
                                        self.rib_version = value
                                        self.rib_version.value_namespace = name_space
                                        self.rib_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wq-dqtime"):
                                        self.wq_dqtime = value
                                        self.wq_dqtime.value_namespace = name_space
                                        self.wq_dqtime.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wq-len-cur"):
                                        self.wq_len_cur = value
                                        self.wq_len_cur.value_namespace = name_space
                                        self.wq_len_cur.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wq-len-max"):
                                        self.wq_len_max = value
                                        self.wq_len_max.value_namespace = name_space
                                        self.wq_len_max.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wq-thread-active"):
                                        self.wq_thread_active = value
                                        self.wq_thread_active.value_namespace = name_space
                                        self.wq_thread_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wq-total-dequeued"):
                                        self.wq_total_dequeued = value
                                        self.wq_total_dequeued.value_namespace = name_space
                                        self.wq_total_dequeued.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wq-total-queued"):
                                        self.wq_total_queued = value
                                        self.wq_total_queued.value_namespace = name_space
                                        self.wq_total_queued.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wqe-qtime"):
                                        self.wqe_qtime = value
                                        self.wqe_qtime.value_namespace = name_space
                                        self.wqe_qtime.value_namespace_prefix = name_space_prefix


                            class Ribqueue(Entity):
                                """
                                ribqueue
                                
                                .. attribute:: priority_level
                                
                                	priority level
                                	**type**\:  str
                                
                                	**length:** 0..40
                                
                                .. attribute:: rib_base_clock
                                
                                	rib base clock
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: rib_base_time
                                
                                	rib base time
                                	**type**\:   :py:class:`RibBaseTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime>`
                                
                                .. attribute:: rib_dequeue_errs
                                
                                	rib dequeue errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_drop_after
                                
                                	rib drop after
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_drop_before
                                
                                	rib drop before
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_drop_conn
                                
                                	rib drop conn
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_empty_batches
                                
                                	rib empty batches
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_pfx_limit_errs
                                
                                	rib pfx limit errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_pkts_sent
                                
                                	rib pkts sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_queue_errs
                                
                                	rib queue errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_send_errs
                                
                                	rib send errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_signals
                                
                                	rib signals
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_table_not_created
                                
                                	rib table not created
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_version
                                
                                	rib version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wq_dqtime
                                
                                	wq dqtime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: wq_len_cur
                                
                                	wq len cur
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: wq_len_max
                                
                                	wq len max
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: wq_thread_active
                                
                                	wq thread active
                                	**type**\:  bool
                                
                                .. attribute:: wq_total_dequeued
                                
                                	wq total dequeued
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wq_total_queued
                                
                                	wq total queued
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wqe_qtime
                                
                                	wqe qtime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue, self).__init__()

                                    self.yang_name = "ribqueue"
                                    self.yang_parent_name = "rib-thread-stats"

                                    self.priority_level = YLeaf(YType.str, "priority-level")

                                    self.rib_base_clock = YLeaf(YType.uint64, "rib-base-clock")

                                    self.rib_dequeue_errs = YLeaf(YType.uint32, "rib-dequeue-errs")

                                    self.rib_drop_after = YLeaf(YType.uint32, "rib-drop-after")

                                    self.rib_drop_before = YLeaf(YType.uint32, "rib-drop-before")

                                    self.rib_drop_conn = YLeaf(YType.uint32, "rib-drop-conn")

                                    self.rib_empty_batches = YLeaf(YType.uint32, "rib-empty-batches")

                                    self.rib_pfx_limit_errs = YLeaf(YType.uint32, "rib-pfx-limit-errs")

                                    self.rib_pkts_sent = YLeaf(YType.uint32, "rib-pkts-sent")

                                    self.rib_queue_errs = YLeaf(YType.uint32, "rib-queue-errs")

                                    self.rib_send_errs = YLeaf(YType.uint32, "rib-send-errs")

                                    self.rib_signals = YLeaf(YType.uint32, "rib-signals")

                                    self.rib_table_not_created = YLeaf(YType.uint32, "rib-table-not-created")

                                    self.rib_version = YLeaf(YType.uint32, "rib-version")

                                    self.wq_dqtime = YLeaf(YType.uint64, "wq-dqtime")

                                    self.wq_len_cur = YLeaf(YType.int32, "wq-len-cur")

                                    self.wq_len_max = YLeaf(YType.int32, "wq-len-max")

                                    self.wq_thread_active = YLeaf(YType.boolean, "wq-thread-active")

                                    self.wq_total_dequeued = YLeaf(YType.uint32, "wq-total-dequeued")

                                    self.wq_total_queued = YLeaf(YType.uint32, "wq-total-queued")

                                    self.wqe_qtime = YLeaf(YType.uint64, "wqe-qtime")

                                    self.rib_base_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime()
                                    self.rib_base_time.parent = self
                                    self._children_name_map["rib_base_time"] = "rib-base-time"
                                    self._children_yang_names.add("rib-base-time")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("priority_level",
                                                    "rib_base_clock",
                                                    "rib_dequeue_errs",
                                                    "rib_drop_after",
                                                    "rib_drop_before",
                                                    "rib_drop_conn",
                                                    "rib_empty_batches",
                                                    "rib_pfx_limit_errs",
                                                    "rib_pkts_sent",
                                                    "rib_queue_errs",
                                                    "rib_send_errs",
                                                    "rib_signals",
                                                    "rib_table_not_created",
                                                    "rib_version",
                                                    "wq_dqtime",
                                                    "wq_len_cur",
                                                    "wq_len_max",
                                                    "wq_thread_active",
                                                    "wq_total_dequeued",
                                                    "wq_total_queued",
                                                    "wqe_qtime") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue, self).__setattr__(name, value)


                                class RibBaseTime(Entity):
                                    """
                                    rib base time
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime, self).__init__()

                                        self.yang_name = "rib-base-time"
                                        self.yang_parent_name = "ribqueue"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rib-base-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.priority_level.is_set or
                                        self.rib_base_clock.is_set or
                                        self.rib_dequeue_errs.is_set or
                                        self.rib_drop_after.is_set or
                                        self.rib_drop_before.is_set or
                                        self.rib_drop_conn.is_set or
                                        self.rib_empty_batches.is_set or
                                        self.rib_pfx_limit_errs.is_set or
                                        self.rib_pkts_sent.is_set or
                                        self.rib_queue_errs.is_set or
                                        self.rib_send_errs.is_set or
                                        self.rib_signals.is_set or
                                        self.rib_table_not_created.is_set or
                                        self.rib_version.is_set or
                                        self.wq_dqtime.is_set or
                                        self.wq_len_cur.is_set or
                                        self.wq_len_max.is_set or
                                        self.wq_thread_active.is_set or
                                        self.wq_total_dequeued.is_set or
                                        self.wq_total_queued.is_set or
                                        self.wqe_qtime.is_set or
                                        (self.rib_base_time is not None and self.rib_base_time.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.priority_level.yfilter != YFilter.not_set or
                                        self.rib_base_clock.yfilter != YFilter.not_set or
                                        self.rib_dequeue_errs.yfilter != YFilter.not_set or
                                        self.rib_drop_after.yfilter != YFilter.not_set or
                                        self.rib_drop_before.yfilter != YFilter.not_set or
                                        self.rib_drop_conn.yfilter != YFilter.not_set or
                                        self.rib_empty_batches.yfilter != YFilter.not_set or
                                        self.rib_pfx_limit_errs.yfilter != YFilter.not_set or
                                        self.rib_pkts_sent.yfilter != YFilter.not_set or
                                        self.rib_queue_errs.yfilter != YFilter.not_set or
                                        self.rib_send_errs.yfilter != YFilter.not_set or
                                        self.rib_signals.yfilter != YFilter.not_set or
                                        self.rib_table_not_created.yfilter != YFilter.not_set or
                                        self.rib_version.yfilter != YFilter.not_set or
                                        self.wq_dqtime.yfilter != YFilter.not_set or
                                        self.wq_len_cur.yfilter != YFilter.not_set or
                                        self.wq_len_max.yfilter != YFilter.not_set or
                                        self.wq_thread_active.yfilter != YFilter.not_set or
                                        self.wq_total_dequeued.yfilter != YFilter.not_set or
                                        self.wq_total_queued.yfilter != YFilter.not_set or
                                        self.wqe_qtime.yfilter != YFilter.not_set or
                                        (self.rib_base_time is not None and self.rib_base_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ribqueue" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.priority_level.is_set or self.priority_level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.priority_level.get_name_leafdata())
                                    if (self.rib_base_clock.is_set or self.rib_base_clock.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_base_clock.get_name_leafdata())
                                    if (self.rib_dequeue_errs.is_set or self.rib_dequeue_errs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_dequeue_errs.get_name_leafdata())
                                    if (self.rib_drop_after.is_set or self.rib_drop_after.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_drop_after.get_name_leafdata())
                                    if (self.rib_drop_before.is_set or self.rib_drop_before.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_drop_before.get_name_leafdata())
                                    if (self.rib_drop_conn.is_set or self.rib_drop_conn.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_drop_conn.get_name_leafdata())
                                    if (self.rib_empty_batches.is_set or self.rib_empty_batches.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_empty_batches.get_name_leafdata())
                                    if (self.rib_pfx_limit_errs.is_set or self.rib_pfx_limit_errs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_pfx_limit_errs.get_name_leafdata())
                                    if (self.rib_pkts_sent.is_set or self.rib_pkts_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_pkts_sent.get_name_leafdata())
                                    if (self.rib_queue_errs.is_set or self.rib_queue_errs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_queue_errs.get_name_leafdata())
                                    if (self.rib_send_errs.is_set or self.rib_send_errs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_send_errs.get_name_leafdata())
                                    if (self.rib_signals.is_set or self.rib_signals.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_signals.get_name_leafdata())
                                    if (self.rib_table_not_created.is_set or self.rib_table_not_created.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_table_not_created.get_name_leafdata())
                                    if (self.rib_version.is_set or self.rib_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rib_version.get_name_leafdata())
                                    if (self.wq_dqtime.is_set or self.wq_dqtime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wq_dqtime.get_name_leafdata())
                                    if (self.wq_len_cur.is_set or self.wq_len_cur.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wq_len_cur.get_name_leafdata())
                                    if (self.wq_len_max.is_set or self.wq_len_max.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wq_len_max.get_name_leafdata())
                                    if (self.wq_thread_active.is_set or self.wq_thread_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wq_thread_active.get_name_leafdata())
                                    if (self.wq_total_dequeued.is_set or self.wq_total_dequeued.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wq_total_dequeued.get_name_leafdata())
                                    if (self.wq_total_queued.is_set or self.wq_total_queued.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wq_total_queued.get_name_leafdata())
                                    if (self.wqe_qtime.is_set or self.wqe_qtime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wqe_qtime.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rib-base-time"):
                                        if (self.rib_base_time is None):
                                            self.rib_base_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime()
                                            self.rib_base_time.parent = self
                                            self._children_name_map["rib_base_time"] = "rib-base-time"
                                        return self.rib_base_time

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rib-base-time" or name == "priority-level" or name == "rib-base-clock" or name == "rib-dequeue-errs" or name == "rib-drop-after" or name == "rib-drop-before" or name == "rib-drop-conn" or name == "rib-empty-batches" or name == "rib-pfx-limit-errs" or name == "rib-pkts-sent" or name == "rib-queue-errs" or name == "rib-send-errs" or name == "rib-signals" or name == "rib-table-not-created" or name == "rib-version" or name == "wq-dqtime" or name == "wq-len-cur" or name == "wq-len-max" or name == "wq-thread-active" or name == "wq-total-dequeued" or name == "wq-total-queued" or name == "wqe-qtime"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "priority-level"):
                                        self.priority_level = value
                                        self.priority_level.value_namespace = name_space
                                        self.priority_level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-base-clock"):
                                        self.rib_base_clock = value
                                        self.rib_base_clock.value_namespace = name_space
                                        self.rib_base_clock.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-dequeue-errs"):
                                        self.rib_dequeue_errs = value
                                        self.rib_dequeue_errs.value_namespace = name_space
                                        self.rib_dequeue_errs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-drop-after"):
                                        self.rib_drop_after = value
                                        self.rib_drop_after.value_namespace = name_space
                                        self.rib_drop_after.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-drop-before"):
                                        self.rib_drop_before = value
                                        self.rib_drop_before.value_namespace = name_space
                                        self.rib_drop_before.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-drop-conn"):
                                        self.rib_drop_conn = value
                                        self.rib_drop_conn.value_namespace = name_space
                                        self.rib_drop_conn.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-empty-batches"):
                                        self.rib_empty_batches = value
                                        self.rib_empty_batches.value_namespace = name_space
                                        self.rib_empty_batches.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-pfx-limit-errs"):
                                        self.rib_pfx_limit_errs = value
                                        self.rib_pfx_limit_errs.value_namespace = name_space
                                        self.rib_pfx_limit_errs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-pkts-sent"):
                                        self.rib_pkts_sent = value
                                        self.rib_pkts_sent.value_namespace = name_space
                                        self.rib_pkts_sent.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-queue-errs"):
                                        self.rib_queue_errs = value
                                        self.rib_queue_errs.value_namespace = name_space
                                        self.rib_queue_errs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-send-errs"):
                                        self.rib_send_errs = value
                                        self.rib_send_errs.value_namespace = name_space
                                        self.rib_send_errs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-signals"):
                                        self.rib_signals = value
                                        self.rib_signals.value_namespace = name_space
                                        self.rib_signals.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-table-not-created"):
                                        self.rib_table_not_created = value
                                        self.rib_table_not_created.value_namespace = name_space
                                        self.rib_table_not_created.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rib-version"):
                                        self.rib_version = value
                                        self.rib_version.value_namespace = name_space
                                        self.rib_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wq-dqtime"):
                                        self.wq_dqtime = value
                                        self.wq_dqtime.value_namespace = name_space
                                        self.wq_dqtime.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wq-len-cur"):
                                        self.wq_len_cur = value
                                        self.wq_len_cur.value_namespace = name_space
                                        self.wq_len_cur.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wq-len-max"):
                                        self.wq_len_max = value
                                        self.wq_len_max.value_namespace = name_space
                                        self.wq_len_max.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wq-thread-active"):
                                        self.wq_thread_active = value
                                        self.wq_thread_active.value_namespace = name_space
                                        self.wq_thread_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wq-total-dequeued"):
                                        self.wq_total_dequeued = value
                                        self.wq_total_dequeued.value_namespace = name_space
                                        self.wq_total_dequeued.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wq-total-queued"):
                                        self.wq_total_queued = value
                                        self.wq_total_queued.value_namespace = name_space
                                        self.wq_total_queued.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wqe-qtime"):
                                        self.wqe_qtime = value
                                        self.wqe_qtime.value_namespace = name_space
                                        self.wqe_qtime.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.ribqueue:
                                    if (c.has_data()):
                                        return True
                                return (self.internalwq is not None and self.internalwq.has_data())

                            def has_operation(self):
                                for c in self.ribqueue:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.internalwq is not None and self.internalwq.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rib-thread-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "internalwq"):
                                    if (self.internalwq is None):
                                        self.internalwq = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq()
                                        self.internalwq.parent = self
                                        self._children_name_map["internalwq"] = "internalwq"
                                    return self.internalwq

                                if (child_yang_name == "ribqueue"):
                                    for c in self.ribqueue:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.ribqueue.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "internalwq" or name == "ribqueue"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class NsrPlStats(Entity):
                            """
                            OSPF NSR packet library statistics
                            
                            .. attribute:: ncd_pri
                            
                            	ncd pri
                            	**type**\: list of    :py:class:`NcdPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats, self).__init__()

                                self.yang_name = "nsr-pl-stats"
                                self.yang_parent_name = "statistics"

                                self.ncd_pri = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats, self).__setattr__(name, value)


                            class NcdPri(Entity):
                                """
                                ncd pri
                                
                                .. attribute:: num_recv
                                
                                	Total recvd
                                	**type**\: list of    :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecv>`
                                
                                .. attribute:: num_recv_drop
                                
                                	Recv Errors/drops
                                	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop>`
                                
                                .. attribute:: num_sent
                                
                                	Total sent
                                	**type**\: list of    :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSent>`
                                
                                .. attribute:: num_sent_drop
                                
                                	Sent Error/drops
                                	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri, self).__init__()

                                    self.yang_name = "ncd-pri"
                                    self.yang_parent_name = "nsr-pl-stats"

                                    self.num_recv = YList(self)
                                    self.num_recv_drop = YList(self)
                                    self.num_sent = YList(self)
                                    self.num_sent_drop = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri, self).__setattr__(name, value)


                                class NumSent(Entity):
                                    """
                                    Total sent
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSent, self).__init__()

                                        self.yang_name = "num-sent"
                                        self.yang_parent_name = "ncd-pri"

                                        self.entry = YLeaf(YType.uint64, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSent, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSent, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "num-sent" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix


                                class NumRecv(Entity):
                                    """
                                    Total recvd
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecv, self).__init__()

                                        self.yang_name = "num-recv"
                                        self.yang_parent_name = "ncd-pri"

                                        self.entry = YLeaf(YType.uint64, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "num-recv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix


                                class NumSentDrop(Entity):
                                    """
                                    Sent Error/drops
                                    
                                    .. attribute:: nsr_pl_send_drop_array
                                    
                                    	nsr pl send drop array
                                    	**type**\: list of    :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop, self).__init__()

                                        self.yang_name = "num-sent-drop"
                                        self.yang_parent_name = "ncd-pri"

                                        self.nsr_pl_send_drop_array = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop, self).__setattr__(name, value)


                                    class NsrPlSendDropArray(Entity):
                                        """
                                        nsr pl send drop array
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray, self).__init__()

                                            self.yang_name = "nsr-pl-send-drop-array"
                                            self.yang_parent_name = "num-sent-drop"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "nsr-pl-send-drop-array" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.nsr_pl_send_drop_array:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.nsr_pl_send_drop_array:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "num-sent-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "nsr-pl-send-drop-array"):
                                            for c in self.nsr_pl_send_drop_array:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.nsr_pl_send_drop_array.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nsr-pl-send-drop-array"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class NumRecvDrop(Entity):
                                    """
                                    Recv Errors/drops
                                    
                                    .. attribute:: nsr_pl_recv_drop_array
                                    
                                    	nsr pl recv drop array
                                    	**type**\: list of    :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop, self).__init__()

                                        self.yang_name = "num-recv-drop"
                                        self.yang_parent_name = "ncd-pri"

                                        self.nsr_pl_recv_drop_array = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop, self).__setattr__(name, value)


                                    class NsrPlRecvDropArray(Entity):
                                        """
                                        nsr pl recv drop array
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray, self).__init__()

                                            self.yang_name = "nsr-pl-recv-drop-array"
                                            self.yang_parent_name = "num-recv-drop"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "nsr-pl-recv-drop-array" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.nsr_pl_recv_drop_array:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.nsr_pl_recv_drop_array:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "num-recv-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "nsr-pl-recv-drop-array"):
                                            for c in self.nsr_pl_recv_drop_array:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.nsr_pl_recv_drop_array.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nsr-pl-recv-drop-array"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    for c in self.num_recv:
                                        if (c.has_data()):
                                            return True
                                    for c in self.num_recv_drop:
                                        if (c.has_data()):
                                            return True
                                    for c in self.num_sent:
                                        if (c.has_data()):
                                            return True
                                    for c in self.num_sent_drop:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.num_recv:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.num_recv_drop:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.num_sent:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.num_sent_drop:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ncd-pri" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "num-recv"):
                                        for c in self.num_recv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.num_recv.append(c)
                                        return c

                                    if (child_yang_name == "num-recv-drop"):
                                        for c in self.num_recv_drop:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.num_recv_drop.append(c)
                                        return c

                                    if (child_yang_name == "num-sent"):
                                        for c in self.num_sent:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSent()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.num_sent.append(c)
                                        return c

                                    if (child_yang_name == "num-sent-drop"):
                                        for c in self.num_sent_drop:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.num_sent_drop.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "num-recv" or name == "num-recv-drop" or name == "num-sent" or name == "num-sent-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                for c in self.ncd_pri:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.ncd_pri:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nsr-pl-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ncd-pri"):
                                    for c in self.ncd_pri:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.ncd_pri.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ncd-pri"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class NsrStats(Entity):
                            """
                            OSPF NSR thread statistics
                            
                            .. attribute:: nsr_conn_to_active_attempts
                            
                            	nsr conn to active attempts
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_closes
                            
                            	nsr conn to active closes
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_errors
                            
                            	nsr conn to active errors
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_fails
                            
                            	nsr conn to active fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_opens
                            
                            	nsr conn to active opens
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_fsm_state
                            
                            	nsr fsm state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_intf_seq_no
                            
                            	nsr intf seq no
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_lsa_init_sync_pend_count
                            
                            	nsr lsa init sync pend count
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_lsa_qad_mdata_count
                            
                            	nsr lsa qad mdata count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_lsa_qad_qid
                            
                            	nsr lsa qad qid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_mtu
                            
                            	nsr mtu
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nbr_init_sync_pend_count
                            
                            	nsr nbr init sync pend count
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_nbr_qad_mdata_count
                            
                            	nsr nbr qad mdata count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nbr_qad_qid
                            
                            	nsr nbr qad qid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nbr_seq_no
                            
                            	nsr nbr seq no
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nodeid
                            
                            	nsr nodeid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_peer_nodeid
                            
                            	nsr peer nodeid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_peer_version
                            
                            	nsr peer version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_rev
                            
                            	nsr rev
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_rtr_thd_sched
                            
                            	nsr rtr thd sched
                            	**type**\:   :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched>`
                            
                            .. attribute:: nsr_thd_sched
                            
                            	nsr thd sched
                            	**type**\:   :py:class:`NsrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched>`
                            
                            .. attribute:: nsr_tmr_quant
                            
                            	nsr tmr quant
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_version
                            
                            	nsr version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats, self).__init__()

                                self.yang_name = "nsr-stats"
                                self.yang_parent_name = "statistics"

                                self.nsr_conn_to_active_attempts = YLeaf(YType.uint64, "nsr-conn-to-active-attempts")

                                self.nsr_conn_to_active_closes = YLeaf(YType.uint64, "nsr-conn-to-active-closes")

                                self.nsr_conn_to_active_errors = YLeaf(YType.uint64, "nsr-conn-to-active-errors")

                                self.nsr_conn_to_active_fails = YLeaf(YType.uint64, "nsr-conn-to-active-fails")

                                self.nsr_conn_to_active_opens = YLeaf(YType.uint64, "nsr-conn-to-active-opens")

                                self.nsr_fsm_state = YLeaf(YType.int32, "nsr-fsm-state")

                                self.nsr_intf_seq_no = YLeaf(YType.uint32, "nsr-intf-seq-no")

                                self.nsr_lsa_init_sync_pend_count = YLeaf(YType.int32, "nsr-lsa-init-sync-pend-count")

                                self.nsr_lsa_qad_mdata_count = YLeaf(YType.uint32, "nsr-lsa-qad-mdata-count")

                                self.nsr_lsa_qad_qid = YLeaf(YType.uint32, "nsr-lsa-qad-qid")

                                self.nsr_mtu = YLeaf(YType.uint32, "nsr-mtu")

                                self.nsr_nbr_init_sync_pend_count = YLeaf(YType.int32, "nsr-nbr-init-sync-pend-count")

                                self.nsr_nbr_qad_mdata_count = YLeaf(YType.uint32, "nsr-nbr-qad-mdata-count")

                                self.nsr_nbr_qad_qid = YLeaf(YType.uint32, "nsr-nbr-qad-qid")

                                self.nsr_nbr_seq_no = YLeaf(YType.uint32, "nsr-nbr-seq-no")

                                self.nsr_nodeid = YLeaf(YType.uint32, "nsr-nodeid")

                                self.nsr_peer_nodeid = YLeaf(YType.uint32, "nsr-peer-nodeid")

                                self.nsr_peer_version = YLeaf(YType.uint32, "nsr-peer-version")

                                self.nsr_rev = YLeaf(YType.int32, "nsr-rev")

                                self.nsr_tmr_quant = YLeaf(YType.int32, "nsr-tmr-quant")

                                self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                                self.nsr_rtr_thd_sched = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched()
                                self.nsr_rtr_thd_sched.parent = self
                                self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                                self._children_yang_names.add("nsr-rtr-thd-sched")

                                self.nsr_thd_sched = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched()
                                self.nsr_thd_sched.parent = self
                                self._children_name_map["nsr_thd_sched"] = "nsr-thd-sched"
                                self._children_yang_names.add("nsr-thd-sched")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nsr_conn_to_active_attempts",
                                                "nsr_conn_to_active_closes",
                                                "nsr_conn_to_active_errors",
                                                "nsr_conn_to_active_fails",
                                                "nsr_conn_to_active_opens",
                                                "nsr_fsm_state",
                                                "nsr_intf_seq_no",
                                                "nsr_lsa_init_sync_pend_count",
                                                "nsr_lsa_qad_mdata_count",
                                                "nsr_lsa_qad_qid",
                                                "nsr_mtu",
                                                "nsr_nbr_init_sync_pend_count",
                                                "nsr_nbr_qad_mdata_count",
                                                "nsr_nbr_qad_qid",
                                                "nsr_nbr_seq_no",
                                                "nsr_nodeid",
                                                "nsr_peer_nodeid",
                                                "nsr_peer_version",
                                                "nsr_rev",
                                                "nsr_tmr_quant",
                                                "nsr_version") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats, self).__setattr__(name, value)


                            class NsrThdSched(Entity):
                                """
                                nsr thd sched
                                
                                .. attribute:: nsr_bad_pulses_rx
                                
                                	nsr bad pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_in_q
                                
                                	nsr events in q
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_events_rx
                                
                                	nsr events rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_tx
                                
                                	nsr events tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_good_pulses_rx
                                
                                	nsr good pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pri
                                
                                	nsr pri
                                	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched.NsrPri>`
                                
                                .. attribute:: nsr_pulse_quant
                                
                                	nsr pulse quant
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: nsr_pulse_tx_fails
                                
                                	nsr pulse tx fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pulses_tx
                                
                                	nsr pulses tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched, self).__init__()

                                    self.yang_name = "nsr-thd-sched"
                                    self.yang_parent_name = "nsr-stats"

                                    self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                    self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                    self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                    self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                    self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                    self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                    self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                    self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                    self.nsr_pri = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nsr_bad_pulses_rx",
                                                    "nsr_events_in_q",
                                                    "nsr_events_rx",
                                                    "nsr_events_tx",
                                                    "nsr_good_pulses_rx",
                                                    "nsr_pulse_quant",
                                                    "nsr_pulse_tx_fails",
                                                    "nsr_pulses_tx") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched, self).__setattr__(name, value)


                                class NsrPri(Entity):
                                    """
                                    nsr pri
                                    
                                    .. attribute:: nsr_sched_enq_fails
                                    
                                    	nsr sched enq fails
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_deqd
                                    
                                    	nsr sched evs deqd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_in_q
                                    
                                    	nsr sched evs in q
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_evs_qd
                                    
                                    	nsr sched evs qd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_max_evs
                                    
                                    	nsr sched max evs
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_peak_q_len
                                    
                                    	nsr sched peak q len
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_pri
                                    
                                    	nsr sched pri
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sched_quant
                                    
                                    	nsr sched quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nsr_sched_remain_quant
                                    
                                    	nsr sched remain quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched.NsrPri, self).__init__()

                                        self.yang_name = "nsr-pri"
                                        self.yang_parent_name = "nsr-thd-sched"

                                        self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                        self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                        self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                        self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                        self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                        self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                        self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                        self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                        self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nsr_sched_enq_fails",
                                                        "nsr_sched_evs_deqd",
                                                        "nsr_sched_evs_in_q",
                                                        "nsr_sched_evs_qd",
                                                        "nsr_sched_max_evs",
                                                        "nsr_sched_peak_q_len",
                                                        "nsr_sched_pri",
                                                        "nsr_sched_quant",
                                                        "nsr_sched_remain_quant") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched.NsrPri, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched.NsrPri, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nsr_sched_enq_fails.is_set or
                                            self.nsr_sched_evs_deqd.is_set or
                                            self.nsr_sched_evs_in_q.is_set or
                                            self.nsr_sched_evs_qd.is_set or
                                            self.nsr_sched_max_evs.is_set or
                                            self.nsr_sched_peak_q_len.is_set or
                                            self.nsr_sched_pri.is_set or
                                            self.nsr_sched_quant.is_set or
                                            self.nsr_sched_remain_quant.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nsr_sched_enq_fails.yfilter != YFilter.not_set or
                                            self.nsr_sched_evs_deqd.yfilter != YFilter.not_set or
                                            self.nsr_sched_evs_in_q.yfilter != YFilter.not_set or
                                            self.nsr_sched_evs_qd.yfilter != YFilter.not_set or
                                            self.nsr_sched_max_evs.yfilter != YFilter.not_set or
                                            self.nsr_sched_peak_q_len.yfilter != YFilter.not_set or
                                            self.nsr_sched_pri.yfilter != YFilter.not_set or
                                            self.nsr_sched_quant.yfilter != YFilter.not_set or
                                            self.nsr_sched_remain_quant.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "nsr-pri" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nsr_sched_enq_fails.is_set or self.nsr_sched_enq_fails.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_enq_fails.get_name_leafdata())
                                        if (self.nsr_sched_evs_deqd.is_set or self.nsr_sched_evs_deqd.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_evs_deqd.get_name_leafdata())
                                        if (self.nsr_sched_evs_in_q.is_set or self.nsr_sched_evs_in_q.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_evs_in_q.get_name_leafdata())
                                        if (self.nsr_sched_evs_qd.is_set or self.nsr_sched_evs_qd.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_evs_qd.get_name_leafdata())
                                        if (self.nsr_sched_max_evs.is_set or self.nsr_sched_max_evs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_max_evs.get_name_leafdata())
                                        if (self.nsr_sched_peak_q_len.is_set or self.nsr_sched_peak_q_len.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_peak_q_len.get_name_leafdata())
                                        if (self.nsr_sched_pri.is_set or self.nsr_sched_pri.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_pri.get_name_leafdata())
                                        if (self.nsr_sched_quant.is_set or self.nsr_sched_quant.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_quant.get_name_leafdata())
                                        if (self.nsr_sched_remain_quant.is_set or self.nsr_sched_remain_quant.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_remain_quant.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nsr-sched-enq-fails" or name == "nsr-sched-evs-deqd" or name == "nsr-sched-evs-in-q" or name == "nsr-sched-evs-qd" or name == "nsr-sched-max-evs" or name == "nsr-sched-peak-q-len" or name == "nsr-sched-pri" or name == "nsr-sched-quant" or name == "nsr-sched-remain-quant"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nsr-sched-enq-fails"):
                                            self.nsr_sched_enq_fails = value
                                            self.nsr_sched_enq_fails.value_namespace = name_space
                                            self.nsr_sched_enq_fails.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-evs-deqd"):
                                            self.nsr_sched_evs_deqd = value
                                            self.nsr_sched_evs_deqd.value_namespace = name_space
                                            self.nsr_sched_evs_deqd.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-evs-in-q"):
                                            self.nsr_sched_evs_in_q = value
                                            self.nsr_sched_evs_in_q.value_namespace = name_space
                                            self.nsr_sched_evs_in_q.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-evs-qd"):
                                            self.nsr_sched_evs_qd = value
                                            self.nsr_sched_evs_qd.value_namespace = name_space
                                            self.nsr_sched_evs_qd.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-max-evs"):
                                            self.nsr_sched_max_evs = value
                                            self.nsr_sched_max_evs.value_namespace = name_space
                                            self.nsr_sched_max_evs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-peak-q-len"):
                                            self.nsr_sched_peak_q_len = value
                                            self.nsr_sched_peak_q_len.value_namespace = name_space
                                            self.nsr_sched_peak_q_len.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-pri"):
                                            self.nsr_sched_pri = value
                                            self.nsr_sched_pri.value_namespace = name_space
                                            self.nsr_sched_pri.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-quant"):
                                            self.nsr_sched_quant = value
                                            self.nsr_sched_quant.value_namespace = name_space
                                            self.nsr_sched_quant.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-remain-quant"):
                                            self.nsr_sched_remain_quant = value
                                            self.nsr_sched_remain_quant.value_namespace = name_space
                                            self.nsr_sched_remain_quant.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.nsr_pri:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.nsr_bad_pulses_rx.is_set or
                                        self.nsr_events_in_q.is_set or
                                        self.nsr_events_rx.is_set or
                                        self.nsr_events_tx.is_set or
                                        self.nsr_good_pulses_rx.is_set or
                                        self.nsr_pulse_quant.is_set or
                                        self.nsr_pulse_tx_fails.is_set or
                                        self.nsr_pulses_tx.is_set)

                                def has_operation(self):
                                    for c in self.nsr_pri:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nsr_bad_pulses_rx.yfilter != YFilter.not_set or
                                        self.nsr_events_in_q.yfilter != YFilter.not_set or
                                        self.nsr_events_rx.yfilter != YFilter.not_set or
                                        self.nsr_events_tx.yfilter != YFilter.not_set or
                                        self.nsr_good_pulses_rx.yfilter != YFilter.not_set or
                                        self.nsr_pulse_quant.yfilter != YFilter.not_set or
                                        self.nsr_pulse_tx_fails.yfilter != YFilter.not_set or
                                        self.nsr_pulses_tx.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "nsr-thd-sched" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nsr_bad_pulses_rx.is_set or self.nsr_bad_pulses_rx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_bad_pulses_rx.get_name_leafdata())
                                    if (self.nsr_events_in_q.is_set or self.nsr_events_in_q.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_events_in_q.get_name_leafdata())
                                    if (self.nsr_events_rx.is_set or self.nsr_events_rx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_events_rx.get_name_leafdata())
                                    if (self.nsr_events_tx.is_set or self.nsr_events_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_events_tx.get_name_leafdata())
                                    if (self.nsr_good_pulses_rx.is_set or self.nsr_good_pulses_rx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_good_pulses_rx.get_name_leafdata())
                                    if (self.nsr_pulse_quant.is_set or self.nsr_pulse_quant.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_pulse_quant.get_name_leafdata())
                                    if (self.nsr_pulse_tx_fails.is_set or self.nsr_pulse_tx_fails.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_pulse_tx_fails.get_name_leafdata())
                                    if (self.nsr_pulses_tx.is_set or self.nsr_pulses_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_pulses_tx.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "nsr-pri"):
                                        for c in self.nsr_pri:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched.NsrPri()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.nsr_pri.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nsr-pri" or name == "nsr-bad-pulses-rx" or name == "nsr-events-in-q" or name == "nsr-events-rx" or name == "nsr-events-tx" or name == "nsr-good-pulses-rx" or name == "nsr-pulse-quant" or name == "nsr-pulse-tx-fails" or name == "nsr-pulses-tx"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nsr-bad-pulses-rx"):
                                        self.nsr_bad_pulses_rx = value
                                        self.nsr_bad_pulses_rx.value_namespace = name_space
                                        self.nsr_bad_pulses_rx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-events-in-q"):
                                        self.nsr_events_in_q = value
                                        self.nsr_events_in_q.value_namespace = name_space
                                        self.nsr_events_in_q.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-events-rx"):
                                        self.nsr_events_rx = value
                                        self.nsr_events_rx.value_namespace = name_space
                                        self.nsr_events_rx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-events-tx"):
                                        self.nsr_events_tx = value
                                        self.nsr_events_tx.value_namespace = name_space
                                        self.nsr_events_tx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-good-pulses-rx"):
                                        self.nsr_good_pulses_rx = value
                                        self.nsr_good_pulses_rx.value_namespace = name_space
                                        self.nsr_good_pulses_rx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-pulse-quant"):
                                        self.nsr_pulse_quant = value
                                        self.nsr_pulse_quant.value_namespace = name_space
                                        self.nsr_pulse_quant.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-pulse-tx-fails"):
                                        self.nsr_pulse_tx_fails = value
                                        self.nsr_pulse_tx_fails.value_namespace = name_space
                                        self.nsr_pulse_tx_fails.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-pulses-tx"):
                                        self.nsr_pulses_tx = value
                                        self.nsr_pulses_tx.value_namespace = name_space
                                        self.nsr_pulses_tx.value_namespace_prefix = name_space_prefix


                            class NsrRtrThdSched(Entity):
                                """
                                nsr rtr thd sched
                                
                                .. attribute:: nsr_bad_pulses_rx
                                
                                	nsr bad pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_in_q
                                
                                	nsr events in q
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_events_rx
                                
                                	nsr events rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_tx
                                
                                	nsr events tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_good_pulses_rx
                                
                                	nsr good pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pri
                                
                                	nsr pri
                                	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri>`
                                
                                .. attribute:: nsr_pulse_quant
                                
                                	nsr pulse quant
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: nsr_pulse_tx_fails
                                
                                	nsr pulse tx fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pulses_tx
                                
                                	nsr pulses tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched, self).__init__()

                                    self.yang_name = "nsr-rtr-thd-sched"
                                    self.yang_parent_name = "nsr-stats"

                                    self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                    self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                    self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                    self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                    self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                    self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                    self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                    self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                    self.nsr_pri = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nsr_bad_pulses_rx",
                                                    "nsr_events_in_q",
                                                    "nsr_events_rx",
                                                    "nsr_events_tx",
                                                    "nsr_good_pulses_rx",
                                                    "nsr_pulse_quant",
                                                    "nsr_pulse_tx_fails",
                                                    "nsr_pulses_tx") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched, self).__setattr__(name, value)


                                class NsrPri(Entity):
                                    """
                                    nsr pri
                                    
                                    .. attribute:: nsr_sched_enq_fails
                                    
                                    	nsr sched enq fails
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_deqd
                                    
                                    	nsr sched evs deqd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_in_q
                                    
                                    	nsr sched evs in q
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_evs_qd
                                    
                                    	nsr sched evs qd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_max_evs
                                    
                                    	nsr sched max evs
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_peak_q_len
                                    
                                    	nsr sched peak q len
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_pri
                                    
                                    	nsr sched pri
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sched_quant
                                    
                                    	nsr sched quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nsr_sched_remain_quant
                                    
                                    	nsr sched remain quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri, self).__init__()

                                        self.yang_name = "nsr-pri"
                                        self.yang_parent_name = "nsr-rtr-thd-sched"

                                        self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                        self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                        self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                        self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                        self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                        self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                        self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                        self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                        self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nsr_sched_enq_fails",
                                                        "nsr_sched_evs_deqd",
                                                        "nsr_sched_evs_in_q",
                                                        "nsr_sched_evs_qd",
                                                        "nsr_sched_max_evs",
                                                        "nsr_sched_peak_q_len",
                                                        "nsr_sched_pri",
                                                        "nsr_sched_quant",
                                                        "nsr_sched_remain_quant") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nsr_sched_enq_fails.is_set or
                                            self.nsr_sched_evs_deqd.is_set or
                                            self.nsr_sched_evs_in_q.is_set or
                                            self.nsr_sched_evs_qd.is_set or
                                            self.nsr_sched_max_evs.is_set or
                                            self.nsr_sched_peak_q_len.is_set or
                                            self.nsr_sched_pri.is_set or
                                            self.nsr_sched_quant.is_set or
                                            self.nsr_sched_remain_quant.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nsr_sched_enq_fails.yfilter != YFilter.not_set or
                                            self.nsr_sched_evs_deqd.yfilter != YFilter.not_set or
                                            self.nsr_sched_evs_in_q.yfilter != YFilter.not_set or
                                            self.nsr_sched_evs_qd.yfilter != YFilter.not_set or
                                            self.nsr_sched_max_evs.yfilter != YFilter.not_set or
                                            self.nsr_sched_peak_q_len.yfilter != YFilter.not_set or
                                            self.nsr_sched_pri.yfilter != YFilter.not_set or
                                            self.nsr_sched_quant.yfilter != YFilter.not_set or
                                            self.nsr_sched_remain_quant.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "nsr-pri" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nsr_sched_enq_fails.is_set or self.nsr_sched_enq_fails.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_enq_fails.get_name_leafdata())
                                        if (self.nsr_sched_evs_deqd.is_set or self.nsr_sched_evs_deqd.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_evs_deqd.get_name_leafdata())
                                        if (self.nsr_sched_evs_in_q.is_set or self.nsr_sched_evs_in_q.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_evs_in_q.get_name_leafdata())
                                        if (self.nsr_sched_evs_qd.is_set or self.nsr_sched_evs_qd.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_evs_qd.get_name_leafdata())
                                        if (self.nsr_sched_max_evs.is_set or self.nsr_sched_max_evs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_max_evs.get_name_leafdata())
                                        if (self.nsr_sched_peak_q_len.is_set or self.nsr_sched_peak_q_len.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_peak_q_len.get_name_leafdata())
                                        if (self.nsr_sched_pri.is_set or self.nsr_sched_pri.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_pri.get_name_leafdata())
                                        if (self.nsr_sched_quant.is_set or self.nsr_sched_quant.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_quant.get_name_leafdata())
                                        if (self.nsr_sched_remain_quant.is_set or self.nsr_sched_remain_quant.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_sched_remain_quant.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nsr-sched-enq-fails" or name == "nsr-sched-evs-deqd" or name == "nsr-sched-evs-in-q" or name == "nsr-sched-evs-qd" or name == "nsr-sched-max-evs" or name == "nsr-sched-peak-q-len" or name == "nsr-sched-pri" or name == "nsr-sched-quant" or name == "nsr-sched-remain-quant"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nsr-sched-enq-fails"):
                                            self.nsr_sched_enq_fails = value
                                            self.nsr_sched_enq_fails.value_namespace = name_space
                                            self.nsr_sched_enq_fails.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-evs-deqd"):
                                            self.nsr_sched_evs_deqd = value
                                            self.nsr_sched_evs_deqd.value_namespace = name_space
                                            self.nsr_sched_evs_deqd.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-evs-in-q"):
                                            self.nsr_sched_evs_in_q = value
                                            self.nsr_sched_evs_in_q.value_namespace = name_space
                                            self.nsr_sched_evs_in_q.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-evs-qd"):
                                            self.nsr_sched_evs_qd = value
                                            self.nsr_sched_evs_qd.value_namespace = name_space
                                            self.nsr_sched_evs_qd.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-max-evs"):
                                            self.nsr_sched_max_evs = value
                                            self.nsr_sched_max_evs.value_namespace = name_space
                                            self.nsr_sched_max_evs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-peak-q-len"):
                                            self.nsr_sched_peak_q_len = value
                                            self.nsr_sched_peak_q_len.value_namespace = name_space
                                            self.nsr_sched_peak_q_len.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-pri"):
                                            self.nsr_sched_pri = value
                                            self.nsr_sched_pri.value_namespace = name_space
                                            self.nsr_sched_pri.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-quant"):
                                            self.nsr_sched_quant = value
                                            self.nsr_sched_quant.value_namespace = name_space
                                            self.nsr_sched_quant.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-sched-remain-quant"):
                                            self.nsr_sched_remain_quant = value
                                            self.nsr_sched_remain_quant.value_namespace = name_space
                                            self.nsr_sched_remain_quant.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.nsr_pri:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.nsr_bad_pulses_rx.is_set or
                                        self.nsr_events_in_q.is_set or
                                        self.nsr_events_rx.is_set or
                                        self.nsr_events_tx.is_set or
                                        self.nsr_good_pulses_rx.is_set or
                                        self.nsr_pulse_quant.is_set or
                                        self.nsr_pulse_tx_fails.is_set or
                                        self.nsr_pulses_tx.is_set)

                                def has_operation(self):
                                    for c in self.nsr_pri:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nsr_bad_pulses_rx.yfilter != YFilter.not_set or
                                        self.nsr_events_in_q.yfilter != YFilter.not_set or
                                        self.nsr_events_rx.yfilter != YFilter.not_set or
                                        self.nsr_events_tx.yfilter != YFilter.not_set or
                                        self.nsr_good_pulses_rx.yfilter != YFilter.not_set or
                                        self.nsr_pulse_quant.yfilter != YFilter.not_set or
                                        self.nsr_pulse_tx_fails.yfilter != YFilter.not_set or
                                        self.nsr_pulses_tx.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "nsr-rtr-thd-sched" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nsr_bad_pulses_rx.is_set or self.nsr_bad_pulses_rx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_bad_pulses_rx.get_name_leafdata())
                                    if (self.nsr_events_in_q.is_set or self.nsr_events_in_q.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_events_in_q.get_name_leafdata())
                                    if (self.nsr_events_rx.is_set or self.nsr_events_rx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_events_rx.get_name_leafdata())
                                    if (self.nsr_events_tx.is_set or self.nsr_events_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_events_tx.get_name_leafdata())
                                    if (self.nsr_good_pulses_rx.is_set or self.nsr_good_pulses_rx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_good_pulses_rx.get_name_leafdata())
                                    if (self.nsr_pulse_quant.is_set or self.nsr_pulse_quant.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_pulse_quant.get_name_leafdata())
                                    if (self.nsr_pulse_tx_fails.is_set or self.nsr_pulse_tx_fails.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_pulse_tx_fails.get_name_leafdata())
                                    if (self.nsr_pulses_tx.is_set or self.nsr_pulses_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_pulses_tx.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "nsr-pri"):
                                        for c in self.nsr_pri:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.nsr_pri.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nsr-pri" or name == "nsr-bad-pulses-rx" or name == "nsr-events-in-q" or name == "nsr-events-rx" or name == "nsr-events-tx" or name == "nsr-good-pulses-rx" or name == "nsr-pulse-quant" or name == "nsr-pulse-tx-fails" or name == "nsr-pulses-tx"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nsr-bad-pulses-rx"):
                                        self.nsr_bad_pulses_rx = value
                                        self.nsr_bad_pulses_rx.value_namespace = name_space
                                        self.nsr_bad_pulses_rx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-events-in-q"):
                                        self.nsr_events_in_q = value
                                        self.nsr_events_in_q.value_namespace = name_space
                                        self.nsr_events_in_q.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-events-rx"):
                                        self.nsr_events_rx = value
                                        self.nsr_events_rx.value_namespace = name_space
                                        self.nsr_events_rx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-events-tx"):
                                        self.nsr_events_tx = value
                                        self.nsr_events_tx.value_namespace = name_space
                                        self.nsr_events_tx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-good-pulses-rx"):
                                        self.nsr_good_pulses_rx = value
                                        self.nsr_good_pulses_rx.value_namespace = name_space
                                        self.nsr_good_pulses_rx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-pulse-quant"):
                                        self.nsr_pulse_quant = value
                                        self.nsr_pulse_quant.value_namespace = name_space
                                        self.nsr_pulse_quant.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-pulse-tx-fails"):
                                        self.nsr_pulse_tx_fails = value
                                        self.nsr_pulse_tx_fails.value_namespace = name_space
                                        self.nsr_pulse_tx_fails.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-pulses-tx"):
                                        self.nsr_pulses_tx = value
                                        self.nsr_pulses_tx.value_namespace = name_space
                                        self.nsr_pulses_tx.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.nsr_conn_to_active_attempts.is_set or
                                    self.nsr_conn_to_active_closes.is_set or
                                    self.nsr_conn_to_active_errors.is_set or
                                    self.nsr_conn_to_active_fails.is_set or
                                    self.nsr_conn_to_active_opens.is_set or
                                    self.nsr_fsm_state.is_set or
                                    self.nsr_intf_seq_no.is_set or
                                    self.nsr_lsa_init_sync_pend_count.is_set or
                                    self.nsr_lsa_qad_mdata_count.is_set or
                                    self.nsr_lsa_qad_qid.is_set or
                                    self.nsr_mtu.is_set or
                                    self.nsr_nbr_init_sync_pend_count.is_set or
                                    self.nsr_nbr_qad_mdata_count.is_set or
                                    self.nsr_nbr_qad_qid.is_set or
                                    self.nsr_nbr_seq_no.is_set or
                                    self.nsr_nodeid.is_set or
                                    self.nsr_peer_nodeid.is_set or
                                    self.nsr_peer_version.is_set or
                                    self.nsr_rev.is_set or
                                    self.nsr_tmr_quant.is_set or
                                    self.nsr_version.is_set or
                                    (self.nsr_rtr_thd_sched is not None and self.nsr_rtr_thd_sched.has_data()) or
                                    (self.nsr_thd_sched is not None and self.nsr_thd_sched.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nsr_conn_to_active_attempts.yfilter != YFilter.not_set or
                                    self.nsr_conn_to_active_closes.yfilter != YFilter.not_set or
                                    self.nsr_conn_to_active_errors.yfilter != YFilter.not_set or
                                    self.nsr_conn_to_active_fails.yfilter != YFilter.not_set or
                                    self.nsr_conn_to_active_opens.yfilter != YFilter.not_set or
                                    self.nsr_fsm_state.yfilter != YFilter.not_set or
                                    self.nsr_intf_seq_no.yfilter != YFilter.not_set or
                                    self.nsr_lsa_init_sync_pend_count.yfilter != YFilter.not_set or
                                    self.nsr_lsa_qad_mdata_count.yfilter != YFilter.not_set or
                                    self.nsr_lsa_qad_qid.yfilter != YFilter.not_set or
                                    self.nsr_mtu.yfilter != YFilter.not_set or
                                    self.nsr_nbr_init_sync_pend_count.yfilter != YFilter.not_set or
                                    self.nsr_nbr_qad_mdata_count.yfilter != YFilter.not_set or
                                    self.nsr_nbr_qad_qid.yfilter != YFilter.not_set or
                                    self.nsr_nbr_seq_no.yfilter != YFilter.not_set or
                                    self.nsr_nodeid.yfilter != YFilter.not_set or
                                    self.nsr_peer_nodeid.yfilter != YFilter.not_set or
                                    self.nsr_peer_version.yfilter != YFilter.not_set or
                                    self.nsr_rev.yfilter != YFilter.not_set or
                                    self.nsr_tmr_quant.yfilter != YFilter.not_set or
                                    self.nsr_version.yfilter != YFilter.not_set or
                                    (self.nsr_rtr_thd_sched is not None and self.nsr_rtr_thd_sched.has_operation()) or
                                    (self.nsr_thd_sched is not None and self.nsr_thd_sched.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nsr-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nsr_conn_to_active_attempts.is_set or self.nsr_conn_to_active_attempts.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_conn_to_active_attempts.get_name_leafdata())
                                if (self.nsr_conn_to_active_closes.is_set or self.nsr_conn_to_active_closes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_conn_to_active_closes.get_name_leafdata())
                                if (self.nsr_conn_to_active_errors.is_set or self.nsr_conn_to_active_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_conn_to_active_errors.get_name_leafdata())
                                if (self.nsr_conn_to_active_fails.is_set or self.nsr_conn_to_active_fails.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_conn_to_active_fails.get_name_leafdata())
                                if (self.nsr_conn_to_active_opens.is_set or self.nsr_conn_to_active_opens.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_conn_to_active_opens.get_name_leafdata())
                                if (self.nsr_fsm_state.is_set or self.nsr_fsm_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_fsm_state.get_name_leafdata())
                                if (self.nsr_intf_seq_no.is_set or self.nsr_intf_seq_no.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_intf_seq_no.get_name_leafdata())
                                if (self.nsr_lsa_init_sync_pend_count.is_set or self.nsr_lsa_init_sync_pend_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_lsa_init_sync_pend_count.get_name_leafdata())
                                if (self.nsr_lsa_qad_mdata_count.is_set or self.nsr_lsa_qad_mdata_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_lsa_qad_mdata_count.get_name_leafdata())
                                if (self.nsr_lsa_qad_qid.is_set or self.nsr_lsa_qad_qid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_lsa_qad_qid.get_name_leafdata())
                                if (self.nsr_mtu.is_set or self.nsr_mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_mtu.get_name_leafdata())
                                if (self.nsr_nbr_init_sync_pend_count.is_set or self.nsr_nbr_init_sync_pend_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_nbr_init_sync_pend_count.get_name_leafdata())
                                if (self.nsr_nbr_qad_mdata_count.is_set or self.nsr_nbr_qad_mdata_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_nbr_qad_mdata_count.get_name_leafdata())
                                if (self.nsr_nbr_qad_qid.is_set or self.nsr_nbr_qad_qid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_nbr_qad_qid.get_name_leafdata())
                                if (self.nsr_nbr_seq_no.is_set or self.nsr_nbr_seq_no.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_nbr_seq_no.get_name_leafdata())
                                if (self.nsr_nodeid.is_set or self.nsr_nodeid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_nodeid.get_name_leafdata())
                                if (self.nsr_peer_nodeid.is_set or self.nsr_peer_nodeid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_peer_nodeid.get_name_leafdata())
                                if (self.nsr_peer_version.is_set or self.nsr_peer_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_peer_version.get_name_leafdata())
                                if (self.nsr_rev.is_set or self.nsr_rev.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_rev.get_name_leafdata())
                                if (self.nsr_tmr_quant.is_set or self.nsr_tmr_quant.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_tmr_quant.get_name_leafdata())
                                if (self.nsr_version.is_set or self.nsr_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_version.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "nsr-rtr-thd-sched"):
                                    if (self.nsr_rtr_thd_sched is None):
                                        self.nsr_rtr_thd_sched = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched()
                                        self.nsr_rtr_thd_sched.parent = self
                                        self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                                    return self.nsr_rtr_thd_sched

                                if (child_yang_name == "nsr-thd-sched"):
                                    if (self.nsr_thd_sched is None):
                                        self.nsr_thd_sched = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched()
                                        self.nsr_thd_sched.parent = self
                                        self._children_name_map["nsr_thd_sched"] = "nsr-thd-sched"
                                    return self.nsr_thd_sched

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nsr-rtr-thd-sched" or name == "nsr-thd-sched" or name == "nsr-conn-to-active-attempts" or name == "nsr-conn-to-active-closes" or name == "nsr-conn-to-active-errors" or name == "nsr-conn-to-active-fails" or name == "nsr-conn-to-active-opens" or name == "nsr-fsm-state" or name == "nsr-intf-seq-no" or name == "nsr-lsa-init-sync-pend-count" or name == "nsr-lsa-qad-mdata-count" or name == "nsr-lsa-qad-qid" or name == "nsr-mtu" or name == "nsr-nbr-init-sync-pend-count" or name == "nsr-nbr-qad-mdata-count" or name == "nsr-nbr-qad-qid" or name == "nsr-nbr-seq-no" or name == "nsr-nodeid" or name == "nsr-peer-nodeid" or name == "nsr-peer-version" or name == "nsr-rev" or name == "nsr-tmr-quant" or name == "nsr-version"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nsr-conn-to-active-attempts"):
                                    self.nsr_conn_to_active_attempts = value
                                    self.nsr_conn_to_active_attempts.value_namespace = name_space
                                    self.nsr_conn_to_active_attempts.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-conn-to-active-closes"):
                                    self.nsr_conn_to_active_closes = value
                                    self.nsr_conn_to_active_closes.value_namespace = name_space
                                    self.nsr_conn_to_active_closes.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-conn-to-active-errors"):
                                    self.nsr_conn_to_active_errors = value
                                    self.nsr_conn_to_active_errors.value_namespace = name_space
                                    self.nsr_conn_to_active_errors.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-conn-to-active-fails"):
                                    self.nsr_conn_to_active_fails = value
                                    self.nsr_conn_to_active_fails.value_namespace = name_space
                                    self.nsr_conn_to_active_fails.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-conn-to-active-opens"):
                                    self.nsr_conn_to_active_opens = value
                                    self.nsr_conn_to_active_opens.value_namespace = name_space
                                    self.nsr_conn_to_active_opens.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-fsm-state"):
                                    self.nsr_fsm_state = value
                                    self.nsr_fsm_state.value_namespace = name_space
                                    self.nsr_fsm_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-intf-seq-no"):
                                    self.nsr_intf_seq_no = value
                                    self.nsr_intf_seq_no.value_namespace = name_space
                                    self.nsr_intf_seq_no.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-lsa-init-sync-pend-count"):
                                    self.nsr_lsa_init_sync_pend_count = value
                                    self.nsr_lsa_init_sync_pend_count.value_namespace = name_space
                                    self.nsr_lsa_init_sync_pend_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-lsa-qad-mdata-count"):
                                    self.nsr_lsa_qad_mdata_count = value
                                    self.nsr_lsa_qad_mdata_count.value_namespace = name_space
                                    self.nsr_lsa_qad_mdata_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-lsa-qad-qid"):
                                    self.nsr_lsa_qad_qid = value
                                    self.nsr_lsa_qad_qid.value_namespace = name_space
                                    self.nsr_lsa_qad_qid.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-mtu"):
                                    self.nsr_mtu = value
                                    self.nsr_mtu.value_namespace = name_space
                                    self.nsr_mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-nbr-init-sync-pend-count"):
                                    self.nsr_nbr_init_sync_pend_count = value
                                    self.nsr_nbr_init_sync_pend_count.value_namespace = name_space
                                    self.nsr_nbr_init_sync_pend_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-nbr-qad-mdata-count"):
                                    self.nsr_nbr_qad_mdata_count = value
                                    self.nsr_nbr_qad_mdata_count.value_namespace = name_space
                                    self.nsr_nbr_qad_mdata_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-nbr-qad-qid"):
                                    self.nsr_nbr_qad_qid = value
                                    self.nsr_nbr_qad_qid.value_namespace = name_space
                                    self.nsr_nbr_qad_qid.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-nbr-seq-no"):
                                    self.nsr_nbr_seq_no = value
                                    self.nsr_nbr_seq_no.value_namespace = name_space
                                    self.nsr_nbr_seq_no.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-nodeid"):
                                    self.nsr_nodeid = value
                                    self.nsr_nodeid.value_namespace = name_space
                                    self.nsr_nodeid.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-peer-nodeid"):
                                    self.nsr_peer_nodeid = value
                                    self.nsr_peer_nodeid.value_namespace = name_space
                                    self.nsr_peer_nodeid.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-peer-version"):
                                    self.nsr_peer_version = value
                                    self.nsr_peer_version.value_namespace = name_space
                                    self.nsr_peer_version.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-rev"):
                                    self.nsr_rev = value
                                    self.nsr_rev.value_namespace = name_space
                                    self.nsr_rev.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-tmr-quant"):
                                    self.nsr_tmr_quant = value
                                    self.nsr_tmr_quant.value_namespace = name_space
                                    self.nsr_tmr_quant.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-version"):
                                    self.nsr_version = value
                                    self.nsr_version.value_namespace = name_space
                                    self.nsr_version.value_namespace_prefix = name_space_prefix


                        class FrrStats(Entity):
                            """
                            OSPF fast\-reroute statistics
                            
                            .. attribute:: fs_paths
                            
                            	Number of IPFRR paths
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fs_paths_eligible
                            
                            	Number of paths enabled for protection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fs_paths_protected
                            
                            	Number of paths protected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.FrrStats, self).__init__()

                                self.yang_name = "frr-stats"
                                self.yang_parent_name = "statistics"

                                self.fs_paths = YLeaf(YType.uint32, "fs-paths")

                                self.fs_paths_eligible = YLeaf(YType.uint32, "fs-paths-eligible")

                                self.fs_paths_protected = YLeaf(YType.uint32, "fs-paths-protected")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fs_paths",
                                                "fs_paths_eligible",
                                                "fs_paths_protected") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.FrrStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.FrrStats, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.fs_paths.is_set or
                                    self.fs_paths_eligible.is_set or
                                    self.fs_paths_protected.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fs_paths.yfilter != YFilter.not_set or
                                    self.fs_paths_eligible.yfilter != YFilter.not_set or
                                    self.fs_paths_protected.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "frr-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fs_paths.is_set or self.fs_paths.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fs_paths.get_name_leafdata())
                                if (self.fs_paths_eligible.is_set or self.fs_paths_eligible.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fs_paths_eligible.get_name_leafdata())
                                if (self.fs_paths_protected.is_set or self.fs_paths_protected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fs_paths_protected.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "fs-paths" or name == "fs-paths-eligible" or name == "fs-paths-protected"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fs-paths"):
                                    self.fs_paths = value
                                    self.fs_paths.value_namespace = name_space
                                    self.fs_paths.value_namespace_prefix = name_space_prefix
                                if(value_path == "fs-paths-eligible"):
                                    self.fs_paths_eligible = value
                                    self.fs_paths_eligible.value_namespace = name_space
                                    self.fs_paths_eligible.value_namespace_prefix = name_space_prefix
                                if(value_path == "fs-paths-protected"):
                                    self.fs_paths_protected = value
                                    self.fs_paths_protected.value_namespace = name_space
                                    self.fs_paths_protected.value_namespace_prefix = name_space_prefix


                        class TeStats(Entity):
                            """
                            OSPF TE IO statistics
                            
                            .. attribute:: adj_changes
                            
                            	adj changes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adj_gets
                            
                            	adj gets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: control_batch_reads
                            
                            	control batch reads
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: control_batch_writes
                            
                            	control batch writes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: control_disconnects
                            
                            	control disconnects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: data_trans_completes
                            
                            	data trans completes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fragment_announces
                            
                            	fragment announces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fragment_deletes
                            
                            	fragment deletes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_batch_reads
                            
                            	link batch reads
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_batch_writes
                            
                            	link batch writes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_floods
                            
                            	link floods
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_fragment_floods
                            
                            	link fragment floods
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsp_gets
                            
                            	lsp gets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_br_lkup_num_dests
                            
                            	pce br lkup num dests
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_br_lookup
                            
                            	pce br lookup
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_br_resp_fails
                            
                            	pce br resp fails
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_flood
                            
                            	pce flood
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_get
                            
                            	pce get
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_listen
                            
                            	pce listen
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_node_announce_batches
                            
                            	pce node announce batches
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_node_delete_batches
                            
                            	pce node delete batches
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_node_send_fails
                            
                            	pce node send fails
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_num_node_announce
                            
                            	pce num node announce
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_num_node_delete
                            
                            	pce num node delete
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_stoplisten
                            
                            	pce stoplisten
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sr_num_area_enabled
                            
                            	sr num area enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_connected
                            
                            	te connected
                            	**type**\:  bool
                            
                            .. attribute:: te_disconnects
                            
                            	te disconnects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_sr_idt_sent
                            
                            	te sr idt sent
                            	**type**\:  bool
                            
                            .. attribute:: te_sr_path_reg_idt_recvd
                            
                            	te sr path reg idt recvd
                            	**type**\:  bool
                            
                            .. attribute:: total_tunnels
                            
                            	total tunnels
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_announces
                            
                            	tunnel announces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.TeStats, self).__init__()

                                self.yang_name = "te-stats"
                                self.yang_parent_name = "statistics"

                                self.adj_changes = YLeaf(YType.uint32, "adj-changes")

                                self.adj_gets = YLeaf(YType.uint32, "adj-gets")

                                self.control_batch_reads = YLeaf(YType.uint32, "control-batch-reads")

                                self.control_batch_writes = YLeaf(YType.uint32, "control-batch-writes")

                                self.control_disconnects = YLeaf(YType.uint32, "control-disconnects")

                                self.data_trans_completes = YLeaf(YType.uint32, "data-trans-completes")

                                self.fragment_announces = YLeaf(YType.uint32, "fragment-announces")

                                self.fragment_deletes = YLeaf(YType.uint32, "fragment-deletes")

                                self.link_batch_reads = YLeaf(YType.uint32, "link-batch-reads")

                                self.link_batch_writes = YLeaf(YType.uint32, "link-batch-writes")

                                self.link_floods = YLeaf(YType.uint32, "link-floods")

                                self.link_fragment_floods = YLeaf(YType.uint32, "link-fragment-floods")

                                self.lsp_gets = YLeaf(YType.uint32, "lsp-gets")

                                self.pce_br_lkup_num_dests = YLeaf(YType.uint32, "pce-br-lkup-num-dests")

                                self.pce_br_lookup = YLeaf(YType.uint32, "pce-br-lookup")

                                self.pce_br_resp_fails = YLeaf(YType.uint32, "pce-br-resp-fails")

                                self.pce_flood = YLeaf(YType.uint32, "pce-flood")

                                self.pce_get = YLeaf(YType.uint32, "pce-get")

                                self.pce_listen = YLeaf(YType.uint32, "pce-listen")

                                self.pce_node_announce_batches = YLeaf(YType.uint32, "pce-node-announce-batches")

                                self.pce_node_delete_batches = YLeaf(YType.uint32, "pce-node-delete-batches")

                                self.pce_node_send_fails = YLeaf(YType.uint32, "pce-node-send-fails")

                                self.pce_num_node_announce = YLeaf(YType.uint32, "pce-num-node-announce")

                                self.pce_num_node_delete = YLeaf(YType.uint32, "pce-num-node-delete")

                                self.pce_stoplisten = YLeaf(YType.uint32, "pce-stoplisten")

                                self.sr_num_area_enabled = YLeaf(YType.uint32, "sr-num-area-enabled")

                                self.te_connected = YLeaf(YType.boolean, "te-connected")

                                self.te_disconnects = YLeaf(YType.uint32, "te-disconnects")

                                self.te_sr_idt_sent = YLeaf(YType.boolean, "te-sr-idt-sent")

                                self.te_sr_path_reg_idt_recvd = YLeaf(YType.boolean, "te-sr-path-reg-idt-recvd")

                                self.total_tunnels = YLeaf(YType.uint32, "total-tunnels")

                                self.tunnel_announces = YLeaf(YType.uint32, "tunnel-announces")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("adj_changes",
                                                "adj_gets",
                                                "control_batch_reads",
                                                "control_batch_writes",
                                                "control_disconnects",
                                                "data_trans_completes",
                                                "fragment_announces",
                                                "fragment_deletes",
                                                "link_batch_reads",
                                                "link_batch_writes",
                                                "link_floods",
                                                "link_fragment_floods",
                                                "lsp_gets",
                                                "pce_br_lkup_num_dests",
                                                "pce_br_lookup",
                                                "pce_br_resp_fails",
                                                "pce_flood",
                                                "pce_get",
                                                "pce_listen",
                                                "pce_node_announce_batches",
                                                "pce_node_delete_batches",
                                                "pce_node_send_fails",
                                                "pce_num_node_announce",
                                                "pce_num_node_delete",
                                                "pce_stoplisten",
                                                "sr_num_area_enabled",
                                                "te_connected",
                                                "te_disconnects",
                                                "te_sr_idt_sent",
                                                "te_sr_path_reg_idt_recvd",
                                                "total_tunnels",
                                                "tunnel_announces") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.TeStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.TeStats, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.adj_changes.is_set or
                                    self.adj_gets.is_set or
                                    self.control_batch_reads.is_set or
                                    self.control_batch_writes.is_set or
                                    self.control_disconnects.is_set or
                                    self.data_trans_completes.is_set or
                                    self.fragment_announces.is_set or
                                    self.fragment_deletes.is_set or
                                    self.link_batch_reads.is_set or
                                    self.link_batch_writes.is_set or
                                    self.link_floods.is_set or
                                    self.link_fragment_floods.is_set or
                                    self.lsp_gets.is_set or
                                    self.pce_br_lkup_num_dests.is_set or
                                    self.pce_br_lookup.is_set or
                                    self.pce_br_resp_fails.is_set or
                                    self.pce_flood.is_set or
                                    self.pce_get.is_set or
                                    self.pce_listen.is_set or
                                    self.pce_node_announce_batches.is_set or
                                    self.pce_node_delete_batches.is_set or
                                    self.pce_node_send_fails.is_set or
                                    self.pce_num_node_announce.is_set or
                                    self.pce_num_node_delete.is_set or
                                    self.pce_stoplisten.is_set or
                                    self.sr_num_area_enabled.is_set or
                                    self.te_connected.is_set or
                                    self.te_disconnects.is_set or
                                    self.te_sr_idt_sent.is_set or
                                    self.te_sr_path_reg_idt_recvd.is_set or
                                    self.total_tunnels.is_set or
                                    self.tunnel_announces.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.adj_changes.yfilter != YFilter.not_set or
                                    self.adj_gets.yfilter != YFilter.not_set or
                                    self.control_batch_reads.yfilter != YFilter.not_set or
                                    self.control_batch_writes.yfilter != YFilter.not_set or
                                    self.control_disconnects.yfilter != YFilter.not_set or
                                    self.data_trans_completes.yfilter != YFilter.not_set or
                                    self.fragment_announces.yfilter != YFilter.not_set or
                                    self.fragment_deletes.yfilter != YFilter.not_set or
                                    self.link_batch_reads.yfilter != YFilter.not_set or
                                    self.link_batch_writes.yfilter != YFilter.not_set or
                                    self.link_floods.yfilter != YFilter.not_set or
                                    self.link_fragment_floods.yfilter != YFilter.not_set or
                                    self.lsp_gets.yfilter != YFilter.not_set or
                                    self.pce_br_lkup_num_dests.yfilter != YFilter.not_set or
                                    self.pce_br_lookup.yfilter != YFilter.not_set or
                                    self.pce_br_resp_fails.yfilter != YFilter.not_set or
                                    self.pce_flood.yfilter != YFilter.not_set or
                                    self.pce_get.yfilter != YFilter.not_set or
                                    self.pce_listen.yfilter != YFilter.not_set or
                                    self.pce_node_announce_batches.yfilter != YFilter.not_set or
                                    self.pce_node_delete_batches.yfilter != YFilter.not_set or
                                    self.pce_node_send_fails.yfilter != YFilter.not_set or
                                    self.pce_num_node_announce.yfilter != YFilter.not_set or
                                    self.pce_num_node_delete.yfilter != YFilter.not_set or
                                    self.pce_stoplisten.yfilter != YFilter.not_set or
                                    self.sr_num_area_enabled.yfilter != YFilter.not_set or
                                    self.te_connected.yfilter != YFilter.not_set or
                                    self.te_disconnects.yfilter != YFilter.not_set or
                                    self.te_sr_idt_sent.yfilter != YFilter.not_set or
                                    self.te_sr_path_reg_idt_recvd.yfilter != YFilter.not_set or
                                    self.total_tunnels.yfilter != YFilter.not_set or
                                    self.tunnel_announces.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "te-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.adj_changes.is_set or self.adj_changes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adj_changes.get_name_leafdata())
                                if (self.adj_gets.is_set or self.adj_gets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adj_gets.get_name_leafdata())
                                if (self.control_batch_reads.is_set or self.control_batch_reads.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.control_batch_reads.get_name_leafdata())
                                if (self.control_batch_writes.is_set or self.control_batch_writes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.control_batch_writes.get_name_leafdata())
                                if (self.control_disconnects.is_set or self.control_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.control_disconnects.get_name_leafdata())
                                if (self.data_trans_completes.is_set or self.data_trans_completes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.data_trans_completes.get_name_leafdata())
                                if (self.fragment_announces.is_set or self.fragment_announces.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fragment_announces.get_name_leafdata())
                                if (self.fragment_deletes.is_set or self.fragment_deletes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fragment_deletes.get_name_leafdata())
                                if (self.link_batch_reads.is_set or self.link_batch_reads.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.link_batch_reads.get_name_leafdata())
                                if (self.link_batch_writes.is_set or self.link_batch_writes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.link_batch_writes.get_name_leafdata())
                                if (self.link_floods.is_set or self.link_floods.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.link_floods.get_name_leafdata())
                                if (self.link_fragment_floods.is_set or self.link_fragment_floods.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.link_fragment_floods.get_name_leafdata())
                                if (self.lsp_gets.is_set or self.lsp_gets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsp_gets.get_name_leafdata())
                                if (self.pce_br_lkup_num_dests.is_set or self.pce_br_lkup_num_dests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce_br_lkup_num_dests.get_name_leafdata())
                                if (self.pce_br_lookup.is_set or self.pce_br_lookup.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce_br_lookup.get_name_leafdata())
                                if (self.pce_br_resp_fails.is_set or self.pce_br_resp_fails.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce_br_resp_fails.get_name_leafdata())
                                if (self.pce_flood.is_set or self.pce_flood.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce_flood.get_name_leafdata())
                                if (self.pce_get.is_set or self.pce_get.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce_get.get_name_leafdata())
                                if (self.pce_listen.is_set or self.pce_listen.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce_listen.get_name_leafdata())
                                if (self.pce_node_announce_batches.is_set or self.pce_node_announce_batches.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce_node_announce_batches.get_name_leafdata())
                                if (self.pce_node_delete_batches.is_set or self.pce_node_delete_batches.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce_node_delete_batches.get_name_leafdata())
                                if (self.pce_node_send_fails.is_set or self.pce_node_send_fails.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce_node_send_fails.get_name_leafdata())
                                if (self.pce_num_node_announce.is_set or self.pce_num_node_announce.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce_num_node_announce.get_name_leafdata())
                                if (self.pce_num_node_delete.is_set or self.pce_num_node_delete.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce_num_node_delete.get_name_leafdata())
                                if (self.pce_stoplisten.is_set or self.pce_stoplisten.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce_stoplisten.get_name_leafdata())
                                if (self.sr_num_area_enabled.is_set or self.sr_num_area_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sr_num_area_enabled.get_name_leafdata())
                                if (self.te_connected.is_set or self.te_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_connected.get_name_leafdata())
                                if (self.te_disconnects.is_set or self.te_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_disconnects.get_name_leafdata())
                                if (self.te_sr_idt_sent.is_set or self.te_sr_idt_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_sr_idt_sent.get_name_leafdata())
                                if (self.te_sr_path_reg_idt_recvd.is_set or self.te_sr_path_reg_idt_recvd.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_sr_path_reg_idt_recvd.get_name_leafdata())
                                if (self.total_tunnels.is_set or self.total_tunnels.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total_tunnels.get_name_leafdata())
                                if (self.tunnel_announces.is_set or self.tunnel_announces.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_announces.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "adj-changes" or name == "adj-gets" or name == "control-batch-reads" or name == "control-batch-writes" or name == "control-disconnects" or name == "data-trans-completes" or name == "fragment-announces" or name == "fragment-deletes" or name == "link-batch-reads" or name == "link-batch-writes" or name == "link-floods" or name == "link-fragment-floods" or name == "lsp-gets" or name == "pce-br-lkup-num-dests" or name == "pce-br-lookup" or name == "pce-br-resp-fails" or name == "pce-flood" or name == "pce-get" or name == "pce-listen" or name == "pce-node-announce-batches" or name == "pce-node-delete-batches" or name == "pce-node-send-fails" or name == "pce-num-node-announce" or name == "pce-num-node-delete" or name == "pce-stoplisten" or name == "sr-num-area-enabled" or name == "te-connected" or name == "te-disconnects" or name == "te-sr-idt-sent" or name == "te-sr-path-reg-idt-recvd" or name == "total-tunnels" or name == "tunnel-announces"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "adj-changes"):
                                    self.adj_changes = value
                                    self.adj_changes.value_namespace = name_space
                                    self.adj_changes.value_namespace_prefix = name_space_prefix
                                if(value_path == "adj-gets"):
                                    self.adj_gets = value
                                    self.adj_gets.value_namespace = name_space
                                    self.adj_gets.value_namespace_prefix = name_space_prefix
                                if(value_path == "control-batch-reads"):
                                    self.control_batch_reads = value
                                    self.control_batch_reads.value_namespace = name_space
                                    self.control_batch_reads.value_namespace_prefix = name_space_prefix
                                if(value_path == "control-batch-writes"):
                                    self.control_batch_writes = value
                                    self.control_batch_writes.value_namespace = name_space
                                    self.control_batch_writes.value_namespace_prefix = name_space_prefix
                                if(value_path == "control-disconnects"):
                                    self.control_disconnects = value
                                    self.control_disconnects.value_namespace = name_space
                                    self.control_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "data-trans-completes"):
                                    self.data_trans_completes = value
                                    self.data_trans_completes.value_namespace = name_space
                                    self.data_trans_completes.value_namespace_prefix = name_space_prefix
                                if(value_path == "fragment-announces"):
                                    self.fragment_announces = value
                                    self.fragment_announces.value_namespace = name_space
                                    self.fragment_announces.value_namespace_prefix = name_space_prefix
                                if(value_path == "fragment-deletes"):
                                    self.fragment_deletes = value
                                    self.fragment_deletes.value_namespace = name_space
                                    self.fragment_deletes.value_namespace_prefix = name_space_prefix
                                if(value_path == "link-batch-reads"):
                                    self.link_batch_reads = value
                                    self.link_batch_reads.value_namespace = name_space
                                    self.link_batch_reads.value_namespace_prefix = name_space_prefix
                                if(value_path == "link-batch-writes"):
                                    self.link_batch_writes = value
                                    self.link_batch_writes.value_namespace = name_space
                                    self.link_batch_writes.value_namespace_prefix = name_space_prefix
                                if(value_path == "link-floods"):
                                    self.link_floods = value
                                    self.link_floods.value_namespace = name_space
                                    self.link_floods.value_namespace_prefix = name_space_prefix
                                if(value_path == "link-fragment-floods"):
                                    self.link_fragment_floods = value
                                    self.link_fragment_floods.value_namespace = name_space
                                    self.link_fragment_floods.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsp-gets"):
                                    self.lsp_gets = value
                                    self.lsp_gets.value_namespace = name_space
                                    self.lsp_gets.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce-br-lkup-num-dests"):
                                    self.pce_br_lkup_num_dests = value
                                    self.pce_br_lkup_num_dests.value_namespace = name_space
                                    self.pce_br_lkup_num_dests.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce-br-lookup"):
                                    self.pce_br_lookup = value
                                    self.pce_br_lookup.value_namespace = name_space
                                    self.pce_br_lookup.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce-br-resp-fails"):
                                    self.pce_br_resp_fails = value
                                    self.pce_br_resp_fails.value_namespace = name_space
                                    self.pce_br_resp_fails.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce-flood"):
                                    self.pce_flood = value
                                    self.pce_flood.value_namespace = name_space
                                    self.pce_flood.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce-get"):
                                    self.pce_get = value
                                    self.pce_get.value_namespace = name_space
                                    self.pce_get.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce-listen"):
                                    self.pce_listen = value
                                    self.pce_listen.value_namespace = name_space
                                    self.pce_listen.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce-node-announce-batches"):
                                    self.pce_node_announce_batches = value
                                    self.pce_node_announce_batches.value_namespace = name_space
                                    self.pce_node_announce_batches.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce-node-delete-batches"):
                                    self.pce_node_delete_batches = value
                                    self.pce_node_delete_batches.value_namespace = name_space
                                    self.pce_node_delete_batches.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce-node-send-fails"):
                                    self.pce_node_send_fails = value
                                    self.pce_node_send_fails.value_namespace = name_space
                                    self.pce_node_send_fails.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce-num-node-announce"):
                                    self.pce_num_node_announce = value
                                    self.pce_num_node_announce.value_namespace = name_space
                                    self.pce_num_node_announce.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce-num-node-delete"):
                                    self.pce_num_node_delete = value
                                    self.pce_num_node_delete.value_namespace = name_space
                                    self.pce_num_node_delete.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce-stoplisten"):
                                    self.pce_stoplisten = value
                                    self.pce_stoplisten.value_namespace = name_space
                                    self.pce_stoplisten.value_namespace_prefix = name_space_prefix
                                if(value_path == "sr-num-area-enabled"):
                                    self.sr_num_area_enabled = value
                                    self.sr_num_area_enabled.value_namespace = name_space
                                    self.sr_num_area_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-connected"):
                                    self.te_connected = value
                                    self.te_connected.value_namespace = name_space
                                    self.te_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-disconnects"):
                                    self.te_disconnects = value
                                    self.te_disconnects.value_namespace = name_space
                                    self.te_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-sr-idt-sent"):
                                    self.te_sr_idt_sent = value
                                    self.te_sr_idt_sent.value_namespace = name_space
                                    self.te_sr_idt_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-sr-path-reg-idt-recvd"):
                                    self.te_sr_path_reg_idt_recvd = value
                                    self.te_sr_path_reg_idt_recvd.value_namespace = name_space
                                    self.te_sr_path_reg_idt_recvd.value_namespace_prefix = name_space_prefix
                                if(value_path == "total-tunnels"):
                                    self.total_tunnels = value
                                    self.total_tunnels.value_namespace = name_space
                                    self.total_tunnels.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-announces"):
                                    self.tunnel_announces = value
                                    self.tunnel_announces.value_namespace = name_space
                                    self.tunnel_announces.value_namespace_prefix = name_space_prefix


                        class ProtocolStats(Entity):
                            """
                            OSPF Protocol statistics
                            
                            .. attribute:: checksumerr
                            
                            	checksumerr
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: h_input_ack
                            
                            	h input ack
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: h_input_dbdes
                            
                            	h input dbdes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: h_input_lsupd
                            
                            	h input lsupd
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: h_input_req
                            
                            	h input req
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_ack
                            
                            	input ack
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_ack_lsa
                            
                            	input ack lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_autherr
                            
                            	input autherr
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_dbdes
                            
                            	input dbdes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_dbdes_lsa
                            
                            	input dbdes lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_hello
                            
                            	input hello
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_lsupd
                            
                            	input lsupd
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_lsupd_lsa
                            
                            	input lsupd lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_req
                            
                            	input req
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_req_lsa
                            
                            	input req lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inputs
                            
                            	inputs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_ack
                            
                            	output ack
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_ack_lsa
                            
                            	output ack lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_autherr
                            
                            	output autherr
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_dbdes
                            
                            	output dbdes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_dbdes_lsa
                            
                            	output dbdes lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_hello
                            
                            	output hello
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_lsupd
                            
                            	output lsupd
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_lsupd_lsa
                            
                            	output lsupd lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_req
                            
                            	output req
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_req_lsa
                            
                            	output req lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: outputs
                            
                            	outputs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.ProtocolStats, self).__init__()

                                self.yang_name = "protocol-stats"
                                self.yang_parent_name = "statistics"

                                self.checksumerr = YLeaf(YType.uint32, "checksumerr")

                                self.h_input_ack = YLeaf(YType.uint32, "h-input-ack")

                                self.h_input_dbdes = YLeaf(YType.uint32, "h-input-dbdes")

                                self.h_input_lsupd = YLeaf(YType.uint32, "h-input-lsupd")

                                self.h_input_req = YLeaf(YType.uint32, "h-input-req")

                                self.input_ack = YLeaf(YType.uint32, "input-ack")

                                self.input_ack_lsa = YLeaf(YType.uint32, "input-ack-lsa")

                                self.input_autherr = YLeaf(YType.uint32, "input-autherr")

                                self.input_dbdes = YLeaf(YType.uint32, "input-dbdes")

                                self.input_dbdes_lsa = YLeaf(YType.uint32, "input-dbdes-lsa")

                                self.input_hello = YLeaf(YType.uint32, "input-hello")

                                self.input_lsupd = YLeaf(YType.uint32, "input-lsupd")

                                self.input_lsupd_lsa = YLeaf(YType.uint32, "input-lsupd-lsa")

                                self.input_req = YLeaf(YType.uint32, "input-req")

                                self.input_req_lsa = YLeaf(YType.uint32, "input-req-lsa")

                                self.inputs = YLeaf(YType.uint32, "inputs")

                                self.output_ack = YLeaf(YType.uint32, "output-ack")

                                self.output_ack_lsa = YLeaf(YType.uint32, "output-ack-lsa")

                                self.output_autherr = YLeaf(YType.uint32, "output-autherr")

                                self.output_dbdes = YLeaf(YType.uint32, "output-dbdes")

                                self.output_dbdes_lsa = YLeaf(YType.uint32, "output-dbdes-lsa")

                                self.output_hello = YLeaf(YType.uint32, "output-hello")

                                self.output_lsupd = YLeaf(YType.uint32, "output-lsupd")

                                self.output_lsupd_lsa = YLeaf(YType.uint32, "output-lsupd-lsa")

                                self.output_req = YLeaf(YType.uint32, "output-req")

                                self.output_req_lsa = YLeaf(YType.uint32, "output-req-lsa")

                                self.outputs = YLeaf(YType.uint32, "outputs")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("checksumerr",
                                                "h_input_ack",
                                                "h_input_dbdes",
                                                "h_input_lsupd",
                                                "h_input_req",
                                                "input_ack",
                                                "input_ack_lsa",
                                                "input_autherr",
                                                "input_dbdes",
                                                "input_dbdes_lsa",
                                                "input_hello",
                                                "input_lsupd",
                                                "input_lsupd_lsa",
                                                "input_req",
                                                "input_req_lsa",
                                                "inputs",
                                                "output_ack",
                                                "output_ack_lsa",
                                                "output_autherr",
                                                "output_dbdes",
                                                "output_dbdes_lsa",
                                                "output_hello",
                                                "output_lsupd",
                                                "output_lsupd_lsa",
                                                "output_req",
                                                "output_req_lsa",
                                                "outputs") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.ProtocolStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.ProtocolStats, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.checksumerr.is_set or
                                    self.h_input_ack.is_set or
                                    self.h_input_dbdes.is_set or
                                    self.h_input_lsupd.is_set or
                                    self.h_input_req.is_set or
                                    self.input_ack.is_set or
                                    self.input_ack_lsa.is_set or
                                    self.input_autherr.is_set or
                                    self.input_dbdes.is_set or
                                    self.input_dbdes_lsa.is_set or
                                    self.input_hello.is_set or
                                    self.input_lsupd.is_set or
                                    self.input_lsupd_lsa.is_set or
                                    self.input_req.is_set or
                                    self.input_req_lsa.is_set or
                                    self.inputs.is_set or
                                    self.output_ack.is_set or
                                    self.output_ack_lsa.is_set or
                                    self.output_autherr.is_set or
                                    self.output_dbdes.is_set or
                                    self.output_dbdes_lsa.is_set or
                                    self.output_hello.is_set or
                                    self.output_lsupd.is_set or
                                    self.output_lsupd_lsa.is_set or
                                    self.output_req.is_set or
                                    self.output_req_lsa.is_set or
                                    self.outputs.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.checksumerr.yfilter != YFilter.not_set or
                                    self.h_input_ack.yfilter != YFilter.not_set or
                                    self.h_input_dbdes.yfilter != YFilter.not_set or
                                    self.h_input_lsupd.yfilter != YFilter.not_set or
                                    self.h_input_req.yfilter != YFilter.not_set or
                                    self.input_ack.yfilter != YFilter.not_set or
                                    self.input_ack_lsa.yfilter != YFilter.not_set or
                                    self.input_autherr.yfilter != YFilter.not_set or
                                    self.input_dbdes.yfilter != YFilter.not_set or
                                    self.input_dbdes_lsa.yfilter != YFilter.not_set or
                                    self.input_hello.yfilter != YFilter.not_set or
                                    self.input_lsupd.yfilter != YFilter.not_set or
                                    self.input_lsupd_lsa.yfilter != YFilter.not_set or
                                    self.input_req.yfilter != YFilter.not_set or
                                    self.input_req_lsa.yfilter != YFilter.not_set or
                                    self.inputs.yfilter != YFilter.not_set or
                                    self.output_ack.yfilter != YFilter.not_set or
                                    self.output_ack_lsa.yfilter != YFilter.not_set or
                                    self.output_autherr.yfilter != YFilter.not_set or
                                    self.output_dbdes.yfilter != YFilter.not_set or
                                    self.output_dbdes_lsa.yfilter != YFilter.not_set or
                                    self.output_hello.yfilter != YFilter.not_set or
                                    self.output_lsupd.yfilter != YFilter.not_set or
                                    self.output_lsupd_lsa.yfilter != YFilter.not_set or
                                    self.output_req.yfilter != YFilter.not_set or
                                    self.output_req_lsa.yfilter != YFilter.not_set or
                                    self.outputs.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "protocol-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.checksumerr.is_set or self.checksumerr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.checksumerr.get_name_leafdata())
                                if (self.h_input_ack.is_set or self.h_input_ack.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.h_input_ack.get_name_leafdata())
                                if (self.h_input_dbdes.is_set or self.h_input_dbdes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.h_input_dbdes.get_name_leafdata())
                                if (self.h_input_lsupd.is_set or self.h_input_lsupd.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.h_input_lsupd.get_name_leafdata())
                                if (self.h_input_req.is_set or self.h_input_req.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.h_input_req.get_name_leafdata())
                                if (self.input_ack.is_set or self.input_ack.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.input_ack.get_name_leafdata())
                                if (self.input_ack_lsa.is_set or self.input_ack_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.input_ack_lsa.get_name_leafdata())
                                if (self.input_autherr.is_set or self.input_autherr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.input_autherr.get_name_leafdata())
                                if (self.input_dbdes.is_set or self.input_dbdes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.input_dbdes.get_name_leafdata())
                                if (self.input_dbdes_lsa.is_set or self.input_dbdes_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.input_dbdes_lsa.get_name_leafdata())
                                if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.input_hello.get_name_leafdata())
                                if (self.input_lsupd.is_set or self.input_lsupd.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.input_lsupd.get_name_leafdata())
                                if (self.input_lsupd_lsa.is_set or self.input_lsupd_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.input_lsupd_lsa.get_name_leafdata())
                                if (self.input_req.is_set or self.input_req.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.input_req.get_name_leafdata())
                                if (self.input_req_lsa.is_set or self.input_req_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.input_req_lsa.get_name_leafdata())
                                if (self.inputs.is_set or self.inputs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inputs.get_name_leafdata())
                                if (self.output_ack.is_set or self.output_ack.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.output_ack.get_name_leafdata())
                                if (self.output_ack_lsa.is_set or self.output_ack_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.output_ack_lsa.get_name_leafdata())
                                if (self.output_autherr.is_set or self.output_autherr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.output_autherr.get_name_leafdata())
                                if (self.output_dbdes.is_set or self.output_dbdes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.output_dbdes.get_name_leafdata())
                                if (self.output_dbdes_lsa.is_set or self.output_dbdes_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.output_dbdes_lsa.get_name_leafdata())
                                if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.output_hello.get_name_leafdata())
                                if (self.output_lsupd.is_set or self.output_lsupd.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.output_lsupd.get_name_leafdata())
                                if (self.output_lsupd_lsa.is_set or self.output_lsupd_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.output_lsupd_lsa.get_name_leafdata())
                                if (self.output_req.is_set or self.output_req.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.output_req.get_name_leafdata())
                                if (self.output_req_lsa.is_set or self.output_req_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.output_req_lsa.get_name_leafdata())
                                if (self.outputs.is_set or self.outputs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.outputs.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "checksumerr" or name == "h-input-ack" or name == "h-input-dbdes" or name == "h-input-lsupd" or name == "h-input-req" or name == "input-ack" or name == "input-ack-lsa" or name == "input-autherr" or name == "input-dbdes" or name == "input-dbdes-lsa" or name == "input-hello" or name == "input-lsupd" or name == "input-lsupd-lsa" or name == "input-req" or name == "input-req-lsa" or name == "inputs" or name == "output-ack" or name == "output-ack-lsa" or name == "output-autherr" or name == "output-dbdes" or name == "output-dbdes-lsa" or name == "output-hello" or name == "output-lsupd" or name == "output-lsupd-lsa" or name == "output-req" or name == "output-req-lsa" or name == "outputs"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "checksumerr"):
                                    self.checksumerr = value
                                    self.checksumerr.value_namespace = name_space
                                    self.checksumerr.value_namespace_prefix = name_space_prefix
                                if(value_path == "h-input-ack"):
                                    self.h_input_ack = value
                                    self.h_input_ack.value_namespace = name_space
                                    self.h_input_ack.value_namespace_prefix = name_space_prefix
                                if(value_path == "h-input-dbdes"):
                                    self.h_input_dbdes = value
                                    self.h_input_dbdes.value_namespace = name_space
                                    self.h_input_dbdes.value_namespace_prefix = name_space_prefix
                                if(value_path == "h-input-lsupd"):
                                    self.h_input_lsupd = value
                                    self.h_input_lsupd.value_namespace = name_space
                                    self.h_input_lsupd.value_namespace_prefix = name_space_prefix
                                if(value_path == "h-input-req"):
                                    self.h_input_req = value
                                    self.h_input_req.value_namespace = name_space
                                    self.h_input_req.value_namespace_prefix = name_space_prefix
                                if(value_path == "input-ack"):
                                    self.input_ack = value
                                    self.input_ack.value_namespace = name_space
                                    self.input_ack.value_namespace_prefix = name_space_prefix
                                if(value_path == "input-ack-lsa"):
                                    self.input_ack_lsa = value
                                    self.input_ack_lsa.value_namespace = name_space
                                    self.input_ack_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "input-autherr"):
                                    self.input_autherr = value
                                    self.input_autherr.value_namespace = name_space
                                    self.input_autherr.value_namespace_prefix = name_space_prefix
                                if(value_path == "input-dbdes"):
                                    self.input_dbdes = value
                                    self.input_dbdes.value_namespace = name_space
                                    self.input_dbdes.value_namespace_prefix = name_space_prefix
                                if(value_path == "input-dbdes-lsa"):
                                    self.input_dbdes_lsa = value
                                    self.input_dbdes_lsa.value_namespace = name_space
                                    self.input_dbdes_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "input-hello"):
                                    self.input_hello = value
                                    self.input_hello.value_namespace = name_space
                                    self.input_hello.value_namespace_prefix = name_space_prefix
                                if(value_path == "input-lsupd"):
                                    self.input_lsupd = value
                                    self.input_lsupd.value_namespace = name_space
                                    self.input_lsupd.value_namespace_prefix = name_space_prefix
                                if(value_path == "input-lsupd-lsa"):
                                    self.input_lsupd_lsa = value
                                    self.input_lsupd_lsa.value_namespace = name_space
                                    self.input_lsupd_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "input-req"):
                                    self.input_req = value
                                    self.input_req.value_namespace = name_space
                                    self.input_req.value_namespace_prefix = name_space_prefix
                                if(value_path == "input-req-lsa"):
                                    self.input_req_lsa = value
                                    self.input_req_lsa.value_namespace = name_space
                                    self.input_req_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "inputs"):
                                    self.inputs = value
                                    self.inputs.value_namespace = name_space
                                    self.inputs.value_namespace_prefix = name_space_prefix
                                if(value_path == "output-ack"):
                                    self.output_ack = value
                                    self.output_ack.value_namespace = name_space
                                    self.output_ack.value_namespace_prefix = name_space_prefix
                                if(value_path == "output-ack-lsa"):
                                    self.output_ack_lsa = value
                                    self.output_ack_lsa.value_namespace = name_space
                                    self.output_ack_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "output-autherr"):
                                    self.output_autherr = value
                                    self.output_autherr.value_namespace = name_space
                                    self.output_autherr.value_namespace_prefix = name_space_prefix
                                if(value_path == "output-dbdes"):
                                    self.output_dbdes = value
                                    self.output_dbdes.value_namespace = name_space
                                    self.output_dbdes.value_namespace_prefix = name_space_prefix
                                if(value_path == "output-dbdes-lsa"):
                                    self.output_dbdes_lsa = value
                                    self.output_dbdes_lsa.value_namespace = name_space
                                    self.output_dbdes_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "output-hello"):
                                    self.output_hello = value
                                    self.output_hello.value_namespace = name_space
                                    self.output_hello.value_namespace_prefix = name_space_prefix
                                if(value_path == "output-lsupd"):
                                    self.output_lsupd = value
                                    self.output_lsupd.value_namespace = name_space
                                    self.output_lsupd.value_namespace_prefix = name_space_prefix
                                if(value_path == "output-lsupd-lsa"):
                                    self.output_lsupd_lsa = value
                                    self.output_lsupd_lsa.value_namespace = name_space
                                    self.output_lsupd_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "output-req"):
                                    self.output_req = value
                                    self.output_req.value_namespace = name_space
                                    self.output_req.value_namespace_prefix = name_space_prefix
                                if(value_path == "output-req-lsa"):
                                    self.output_req_lsa = value
                                    self.output_req_lsa.value_namespace = name_space
                                    self.output_req_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "outputs"):
                                    self.outputs = value
                                    self.outputs.value_namespace = name_space
                                    self.outputs.value_namespace_prefix = name_space_prefix


                        class RawIoStats(Entity):
                            """
                            OSPF RAW IO statistics
                            
                            .. attribute:: disconnects
                            
                            	disconnects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: in_bytes_rcv
                            
                            	in bytes rcv
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: in_no_mem_discarded
                            
                            	in no mem discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: in_raw_event
                            
                            	in raw event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: in_rcv
                            
                            	in rcv
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: in_short_msg_discarded
                            
                            	in short msg discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: in_standby_discarded
                            
                            	in standby discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_not_ready_discarded
                            
                            	nsr not ready discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_bytes_sent
                            
                            	out bytes sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_ipv4_hdr_err_discarded
                            
                            	out ipv4 hdr err discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_no_conn_discarded
                            
                            	out no conn discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_no_pak_discarded
                            
                            	out no pak discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_null_src_discarded
                            
                            	out null src discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_send_pak_err_discarded
                            
                            	out send pak err discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_sent
                            
                            	out sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: raw_connected
                            
                            	raw connected
                            	**type**\:  bool
                            
                            .. attribute:: sl_raw_connected
                            
                            	sl raw connected
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RawIoStats, self).__init__()

                                self.yang_name = "raw-io-stats"
                                self.yang_parent_name = "statistics"

                                self.disconnects = YLeaf(YType.uint32, "disconnects")

                                self.in_bytes_rcv = YLeaf(YType.uint32, "in-bytes-rcv")

                                self.in_no_mem_discarded = YLeaf(YType.uint32, "in-no-mem-discarded")

                                self.in_raw_event = YLeaf(YType.uint32, "in-raw-event")

                                self.in_rcv = YLeaf(YType.uint32, "in-rcv")

                                self.in_short_msg_discarded = YLeaf(YType.uint32, "in-short-msg-discarded")

                                self.in_standby_discarded = YLeaf(YType.uint32, "in-standby-discarded")

                                self.nsr_not_ready_discarded = YLeaf(YType.uint32, "nsr-not-ready-discarded")

                                self.out_bytes_sent = YLeaf(YType.uint32, "out-bytes-sent")

                                self.out_ipv4_hdr_err_discarded = YLeaf(YType.uint32, "out-ipv4-hdr-err-discarded")

                                self.out_no_conn_discarded = YLeaf(YType.uint32, "out-no-conn-discarded")

                                self.out_no_pak_discarded = YLeaf(YType.uint32, "out-no-pak-discarded")

                                self.out_null_src_discarded = YLeaf(YType.uint32, "out-null-src-discarded")

                                self.out_send_pak_err_discarded = YLeaf(YType.uint32, "out-send-pak-err-discarded")

                                self.out_sent = YLeaf(YType.uint32, "out-sent")

                                self.raw_connected = YLeaf(YType.boolean, "raw-connected")

                                self.sl_raw_connected = YLeaf(YType.boolean, "sl-raw-connected")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("disconnects",
                                                "in_bytes_rcv",
                                                "in_no_mem_discarded",
                                                "in_raw_event",
                                                "in_rcv",
                                                "in_short_msg_discarded",
                                                "in_standby_discarded",
                                                "nsr_not_ready_discarded",
                                                "out_bytes_sent",
                                                "out_ipv4_hdr_err_discarded",
                                                "out_no_conn_discarded",
                                                "out_no_pak_discarded",
                                                "out_null_src_discarded",
                                                "out_send_pak_err_discarded",
                                                "out_sent",
                                                "raw_connected",
                                                "sl_raw_connected") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RawIoStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RawIoStats, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.disconnects.is_set or
                                    self.in_bytes_rcv.is_set or
                                    self.in_no_mem_discarded.is_set or
                                    self.in_raw_event.is_set or
                                    self.in_rcv.is_set or
                                    self.in_short_msg_discarded.is_set or
                                    self.in_standby_discarded.is_set or
                                    self.nsr_not_ready_discarded.is_set or
                                    self.out_bytes_sent.is_set or
                                    self.out_ipv4_hdr_err_discarded.is_set or
                                    self.out_no_conn_discarded.is_set or
                                    self.out_no_pak_discarded.is_set or
                                    self.out_null_src_discarded.is_set or
                                    self.out_send_pak_err_discarded.is_set or
                                    self.out_sent.is_set or
                                    self.raw_connected.is_set or
                                    self.sl_raw_connected.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.disconnects.yfilter != YFilter.not_set or
                                    self.in_bytes_rcv.yfilter != YFilter.not_set or
                                    self.in_no_mem_discarded.yfilter != YFilter.not_set or
                                    self.in_raw_event.yfilter != YFilter.not_set or
                                    self.in_rcv.yfilter != YFilter.not_set or
                                    self.in_short_msg_discarded.yfilter != YFilter.not_set or
                                    self.in_standby_discarded.yfilter != YFilter.not_set or
                                    self.nsr_not_ready_discarded.yfilter != YFilter.not_set or
                                    self.out_bytes_sent.yfilter != YFilter.not_set or
                                    self.out_ipv4_hdr_err_discarded.yfilter != YFilter.not_set or
                                    self.out_no_conn_discarded.yfilter != YFilter.not_set or
                                    self.out_no_pak_discarded.yfilter != YFilter.not_set or
                                    self.out_null_src_discarded.yfilter != YFilter.not_set or
                                    self.out_send_pak_err_discarded.yfilter != YFilter.not_set or
                                    self.out_sent.yfilter != YFilter.not_set or
                                    self.raw_connected.yfilter != YFilter.not_set or
                                    self.sl_raw_connected.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "raw-io-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.disconnects.is_set or self.disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disconnects.get_name_leafdata())
                                if (self.in_bytes_rcv.is_set or self.in_bytes_rcv.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.in_bytes_rcv.get_name_leafdata())
                                if (self.in_no_mem_discarded.is_set or self.in_no_mem_discarded.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.in_no_mem_discarded.get_name_leafdata())
                                if (self.in_raw_event.is_set or self.in_raw_event.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.in_raw_event.get_name_leafdata())
                                if (self.in_rcv.is_set or self.in_rcv.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.in_rcv.get_name_leafdata())
                                if (self.in_short_msg_discarded.is_set or self.in_short_msg_discarded.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.in_short_msg_discarded.get_name_leafdata())
                                if (self.in_standby_discarded.is_set or self.in_standby_discarded.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.in_standby_discarded.get_name_leafdata())
                                if (self.nsr_not_ready_discarded.is_set or self.nsr_not_ready_discarded.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_not_ready_discarded.get_name_leafdata())
                                if (self.out_bytes_sent.is_set or self.out_bytes_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_bytes_sent.get_name_leafdata())
                                if (self.out_ipv4_hdr_err_discarded.is_set or self.out_ipv4_hdr_err_discarded.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_ipv4_hdr_err_discarded.get_name_leafdata())
                                if (self.out_no_conn_discarded.is_set or self.out_no_conn_discarded.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_no_conn_discarded.get_name_leafdata())
                                if (self.out_no_pak_discarded.is_set or self.out_no_pak_discarded.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_no_pak_discarded.get_name_leafdata())
                                if (self.out_null_src_discarded.is_set or self.out_null_src_discarded.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_null_src_discarded.get_name_leafdata())
                                if (self.out_send_pak_err_discarded.is_set or self.out_send_pak_err_discarded.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_send_pak_err_discarded.get_name_leafdata())
                                if (self.out_sent.is_set or self.out_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_sent.get_name_leafdata())
                                if (self.raw_connected.is_set or self.raw_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.raw_connected.get_name_leafdata())
                                if (self.sl_raw_connected.is_set or self.sl_raw_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sl_raw_connected.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "disconnects" or name == "in-bytes-rcv" or name == "in-no-mem-discarded" or name == "in-raw-event" or name == "in-rcv" or name == "in-short-msg-discarded" or name == "in-standby-discarded" or name == "nsr-not-ready-discarded" or name == "out-bytes-sent" or name == "out-ipv4-hdr-err-discarded" or name == "out-no-conn-discarded" or name == "out-no-pak-discarded" or name == "out-null-src-discarded" or name == "out-send-pak-err-discarded" or name == "out-sent" or name == "raw-connected" or name == "sl-raw-connected"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "disconnects"):
                                    self.disconnects = value
                                    self.disconnects.value_namespace = name_space
                                    self.disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "in-bytes-rcv"):
                                    self.in_bytes_rcv = value
                                    self.in_bytes_rcv.value_namespace = name_space
                                    self.in_bytes_rcv.value_namespace_prefix = name_space_prefix
                                if(value_path == "in-no-mem-discarded"):
                                    self.in_no_mem_discarded = value
                                    self.in_no_mem_discarded.value_namespace = name_space
                                    self.in_no_mem_discarded.value_namespace_prefix = name_space_prefix
                                if(value_path == "in-raw-event"):
                                    self.in_raw_event = value
                                    self.in_raw_event.value_namespace = name_space
                                    self.in_raw_event.value_namespace_prefix = name_space_prefix
                                if(value_path == "in-rcv"):
                                    self.in_rcv = value
                                    self.in_rcv.value_namespace = name_space
                                    self.in_rcv.value_namespace_prefix = name_space_prefix
                                if(value_path == "in-short-msg-discarded"):
                                    self.in_short_msg_discarded = value
                                    self.in_short_msg_discarded.value_namespace = name_space
                                    self.in_short_msg_discarded.value_namespace_prefix = name_space_prefix
                                if(value_path == "in-standby-discarded"):
                                    self.in_standby_discarded = value
                                    self.in_standby_discarded.value_namespace = name_space
                                    self.in_standby_discarded.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-not-ready-discarded"):
                                    self.nsr_not_ready_discarded = value
                                    self.nsr_not_ready_discarded.value_namespace = name_space
                                    self.nsr_not_ready_discarded.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-bytes-sent"):
                                    self.out_bytes_sent = value
                                    self.out_bytes_sent.value_namespace = name_space
                                    self.out_bytes_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-ipv4-hdr-err-discarded"):
                                    self.out_ipv4_hdr_err_discarded = value
                                    self.out_ipv4_hdr_err_discarded.value_namespace = name_space
                                    self.out_ipv4_hdr_err_discarded.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-no-conn-discarded"):
                                    self.out_no_conn_discarded = value
                                    self.out_no_conn_discarded.value_namespace = name_space
                                    self.out_no_conn_discarded.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-no-pak-discarded"):
                                    self.out_no_pak_discarded = value
                                    self.out_no_pak_discarded.value_namespace = name_space
                                    self.out_no_pak_discarded.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-null-src-discarded"):
                                    self.out_null_src_discarded = value
                                    self.out_null_src_discarded.value_namespace = name_space
                                    self.out_null_src_discarded.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-send-pak-err-discarded"):
                                    self.out_send_pak_err_discarded = value
                                    self.out_send_pak_err_discarded.value_namespace = name_space
                                    self.out_send_pak_err_discarded.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-sent"):
                                    self.out_sent = value
                                    self.out_sent.value_namespace = name_space
                                    self.out_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "raw-connected"):
                                    self.raw_connected = value
                                    self.raw_connected.value_namespace = name_space
                                    self.raw_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "sl-raw-connected"):
                                    self.sl_raw_connected = value
                                    self.sl_raw_connected.value_namespace = name_space
                                    self.sl_raw_connected.value_namespace_prefix = name_space_prefix


                        class InterfaceStatsEntries(Entity):
                            """
                            Statistics innformation Interface table
                            
                            .. attribute:: interface_stats_entry
                            
                            	Statistics information for a specific interface
                            	**type**\: list of    :py:class:`InterfaceStatsEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries, self).__init__()

                                self.yang_name = "interface-stats-entries"
                                self.yang_parent_name = "statistics"

                                self.interface_stats_entry = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries, self).__setattr__(name, value)


                            class InterfaceStatsEntry(Entity):
                                """
                                Statistics information for a specific interface
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: handle
                                
                                	interface handle type
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: if_entry
                                
                                	interface entry
                                	**type**\: list of    :py:class:`IfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry>`
                                
                                .. attribute:: if_name_str
                                
                                	interface name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__init__()

                                    self.yang_name = "interface-stats-entry"
                                    self.yang_parent_name = "interface-stats-entries"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.handle = YLeaf(YType.str, "handle")

                                    self.if_name_str = YLeaf(YType.str, "if-name-str")

                                    self.if_entry = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "handle",
                                                    "if_name_str") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__setattr__(name, value)


                                class IfEntry(Entity):
                                    """
                                    interface entry
                                    
                                    .. attribute:: area_id
                                    
                                    	OSPF area id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_id_str
                                    
                                    	OSPF aread id string
                                    	**type**\:  str
                                    
                                    .. attribute:: if_stat
                                    
                                    	OSPF interface statistics
                                    	**type**\: list of    :py:class:`IfStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat>`
                                    
                                    .. attribute:: madj_intf
                                    
                                    	OSPF madj interface
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__init__()

                                        self.yang_name = "if-entry"
                                        self.yang_parent_name = "interface-stats-entry"

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.area_id_str = YLeaf(YType.str, "area-id-str")

                                        self.madj_intf = YLeaf(YType.boolean, "madj-intf")

                                        self.if_stat = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("area_id",
                                                        "area_id_str",
                                                        "madj_intf") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__setattr__(name, value)


                                    class IfStat(Entity):
                                        """
                                        OSPF interface statistics
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__init__()

                                            self.yang_name = "if-stat"
                                            self.yang_parent_name = "if-entry"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "if-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.if_stat:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.area_id.is_set or
                                            self.area_id_str.is_set or
                                            self.madj_intf.is_set)

                                    def has_operation(self):
                                        for c in self.if_stat:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.area_id.yfilter != YFilter.not_set or
                                            self.area_id_str.yfilter != YFilter.not_set or
                                            self.madj_intf.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "if-entry" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id.get_name_leafdata())
                                        if (self.area_id_str.is_set or self.area_id_str.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id_str.get_name_leafdata())
                                        if (self.madj_intf.is_set or self.madj_intf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.madj_intf.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "if-stat"):
                                            for c in self.if_stat:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.if_stat.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "if-stat" or name == "area-id" or name == "area-id-str" or name == "madj-intf"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "area-id"):
                                            self.area_id = value
                                            self.area_id.value_namespace = name_space
                                            self.area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-id-str"):
                                            self.area_id_str = value
                                            self.area_id_str.value_namespace = name_space
                                            self.area_id_str.value_namespace_prefix = name_space_prefix
                                        if(value_path == "madj-intf"):
                                            self.madj_intf = value
                                            self.madj_intf.value_namespace = name_space
                                            self.madj_intf.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.if_entry:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.interface_name.is_set or
                                        self.handle.is_set or
                                        self.if_name_str.is_set)

                                def has_operation(self):
                                    for c in self.if_entry:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.handle.yfilter != YFilter.not_set or
                                        self.if_name_str.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface-stats-entry" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.handle.is_set or self.handle.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.handle.get_name_leafdata())
                                    if (self.if_name_str.is_set or self.if_name_str.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.if_name_str.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "if-entry"):
                                        for c in self.if_entry:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.if_entry.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "if-entry" or name == "interface-name" or name == "handle" or name == "if-name-str"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "handle"):
                                        self.handle = value
                                        self.handle.value_namespace = name_space
                                        self.handle.value_namespace_prefix = name_space_prefix
                                    if(value_path == "if-name-str"):
                                        self.if_name_str = value
                                        self.if_name_str.value_namespace = name_space
                                        self.if_name_str.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface_stats_entry:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.interface_stats_entry:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-stats-entries" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface-stats-entry"):
                                    for c in self.interface_stats_entry:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface_stats_entry.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-stats-entry"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.frr_stats is not None and self.frr_stats.has_data()) or
                                (self.interface_stats_entries is not None and self.interface_stats_entries.has_data()) or
                                (self.issu_stats is not None and self.issu_stats.has_data()) or
                                (self.nsr_pl_stats is not None and self.nsr_pl_stats.has_data()) or
                                (self.nsr_stats is not None and self.nsr_stats.has_data()) or
                                (self.protocol_stats is not None and self.protocol_stats.has_data()) or
                                (self.raw_io_stats is not None and self.raw_io_stats.has_data()) or
                                (self.rib_batch_stats is not None and self.rib_batch_stats.has_data()) or
                                (self.rib_thread_stats is not None and self.rib_thread_stats.has_data()) or
                                (self.spf_stats is not None and self.spf_stats.has_data()) or
                                (self.te_stats is not None and self.te_stats.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.frr_stats is not None and self.frr_stats.has_operation()) or
                                (self.interface_stats_entries is not None and self.interface_stats_entries.has_operation()) or
                                (self.issu_stats is not None and self.issu_stats.has_operation()) or
                                (self.nsr_pl_stats is not None and self.nsr_pl_stats.has_operation()) or
                                (self.nsr_stats is not None and self.nsr_stats.has_operation()) or
                                (self.protocol_stats is not None and self.protocol_stats.has_operation()) or
                                (self.raw_io_stats is not None and self.raw_io_stats.has_operation()) or
                                (self.rib_batch_stats is not None and self.rib_batch_stats.has_operation()) or
                                (self.rib_thread_stats is not None and self.rib_thread_stats.has_operation()) or
                                (self.spf_stats is not None and self.spf_stats.has_operation()) or
                                (self.te_stats is not None and self.te_stats.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "frr-stats"):
                                if (self.frr_stats is None):
                                    self.frr_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.FrrStats()
                                    self.frr_stats.parent = self
                                    self._children_name_map["frr_stats"] = "frr-stats"
                                return self.frr_stats

                            if (child_yang_name == "interface-stats-entries"):
                                if (self.interface_stats_entries is None):
                                    self.interface_stats_entries = Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries()
                                    self.interface_stats_entries.parent = self
                                    self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                                return self.interface_stats_entries

                            if (child_yang_name == "issu-stats"):
                                if (self.issu_stats is None):
                                    self.issu_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats()
                                    self.issu_stats.parent = self
                                    self._children_name_map["issu_stats"] = "issu-stats"
                                return self.issu_stats

                            if (child_yang_name == "nsr-pl-stats"):
                                if (self.nsr_pl_stats is None):
                                    self.nsr_pl_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats()
                                    self.nsr_pl_stats.parent = self
                                    self._children_name_map["nsr_pl_stats"] = "nsr-pl-stats"
                                return self.nsr_pl_stats

                            if (child_yang_name == "nsr-stats"):
                                if (self.nsr_stats is None):
                                    self.nsr_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats()
                                    self.nsr_stats.parent = self
                                    self._children_name_map["nsr_stats"] = "nsr-stats"
                                return self.nsr_stats

                            if (child_yang_name == "protocol-stats"):
                                if (self.protocol_stats is None):
                                    self.protocol_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.ProtocolStats()
                                    self.protocol_stats.parent = self
                                    self._children_name_map["protocol_stats"] = "protocol-stats"
                                return self.protocol_stats

                            if (child_yang_name == "raw-io-stats"):
                                if (self.raw_io_stats is None):
                                    self.raw_io_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RawIoStats()
                                    self.raw_io_stats.parent = self
                                    self._children_name_map["raw_io_stats"] = "raw-io-stats"
                                return self.raw_io_stats

                            if (child_yang_name == "rib-batch-stats"):
                                if (self.rib_batch_stats is None):
                                    self.rib_batch_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats()
                                    self.rib_batch_stats.parent = self
                                    self._children_name_map["rib_batch_stats"] = "rib-batch-stats"
                                return self.rib_batch_stats

                            if (child_yang_name == "rib-thread-stats"):
                                if (self.rib_thread_stats is None):
                                    self.rib_thread_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats()
                                    self.rib_thread_stats.parent = self
                                    self._children_name_map["rib_thread_stats"] = "rib-thread-stats"
                                return self.rib_thread_stats

                            if (child_yang_name == "spf-stats"):
                                if (self.spf_stats is None):
                                    self.spf_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats()
                                    self.spf_stats.parent = self
                                    self._children_name_map["spf_stats"] = "spf-stats"
                                return self.spf_stats

                            if (child_yang_name == "te-stats"):
                                if (self.te_stats is None):
                                    self.te_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.TeStats()
                                    self.te_stats.parent = self
                                    self._children_name_map["te_stats"] = "te-stats"
                                return self.te_stats

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "frr-stats" or name == "interface-stats-entries" or name == "issu-stats" or name == "nsr-pl-stats" or name == "nsr-stats" or name == "protocol-stats" or name == "raw-io-stats" or name == "rib-batch-stats" or name == "rib-thread-stats" or name == "spf-stats" or name == "te-stats"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class AdjacencyInformation(Entity):
                        """
                        Container for OSPF Interfaces
                        
                        .. attribute:: neighbor_details
                        
                        	Neighbor detail table
                        	**type**\:   :py:class:`NeighborDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails>`
                        
                        .. attribute:: neighbors
                        
                        	Neighbor table
                        	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors>`
                        
                        .. attribute:: requests
                        
                        	Request List table
                        	**type**\:   :py:class:`Requests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests>`
                        
                        .. attribute:: retransmissions
                        
                        	Retransmission list table
                        	**type**\:   :py:class:`Retransmissions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation, self).__init__()

                            self.yang_name = "adjacency-information"
                            self.yang_parent_name = "vrf"

                            self.neighbor_details = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails()
                            self.neighbor_details.parent = self
                            self._children_name_map["neighbor_details"] = "neighbor-details"
                            self._children_yang_names.add("neighbor-details")

                            self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"
                            self._children_yang_names.add("neighbors")

                            self.requests = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests()
                            self.requests.parent = self
                            self._children_name_map["requests"] = "requests"
                            self._children_yang_names.add("requests")

                            self.retransmissions = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions()
                            self.retransmissions.parent = self
                            self._children_name_map["retransmissions"] = "retransmissions"
                            self._children_yang_names.add("retransmissions")


                        class Neighbors(Entity):
                            """
                            Neighbor table
                            
                            .. attribute:: neighbor
                            
                            	Neighbor information
                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors, self).__init__()

                                self.yang_name = "neighbors"
                                self.yang_parent_name = "adjacency-information"

                                self.neighbor = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors, self).__setattr__(name, value)


                            class Neighbor(Entity):
                                """
                                Neighbor information
                                
                                .. attribute:: dr_bdr_state
                                
                                	Designated Router state
                                	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_address_xr
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_information
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation>`
                                
                                .. attribute:: neighbor_dead_timer
                                
                                	Time until neighbor's dead timer expires (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_dr_priority
                                
                                	Neighbor's DR priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_interface_name
                                
                                	Interface via which the neighbor is seen
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: neighbor_madj_interface
                                
                                	Interface is MADJ
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_state
                                
                                	Neighbor's state
                                	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                
                                .. attribute:: neighbor_up_time
                                
                                	Amount of time since the adjacency is up (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "neighbors"

                                    self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                    self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                    self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                    self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                    self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                    self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                    self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                    self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation()
                                    self.neighbor_bfd_information.parent = self
                                    self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                    self._children_yang_names.add("neighbor-bfd-information")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dr_bdr_state",
                                                    "interface_name",
                                                    "neighbor_address",
                                                    "neighbor_address_xr",
                                                    "neighbor_dead_timer",
                                                    "neighbor_dr_priority",
                                                    "neighbor_id",
                                                    "neighbor_interface_name",
                                                    "neighbor_madj_interface",
                                                    "neighbor_state",
                                                    "neighbor_up_time") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor, self).__setattr__(name, value)


                                class NeighborBfdInformation(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation, self).__init__()

                                        self.yang_name = "neighbor-bfd-information"
                                        self.yang_parent_name = "neighbor"

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bfd_intf_enable_mode",
                                                        "bfd_status_flag") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bfd_intf_enable_mode.is_set or
                                            self.bfd_status_flag.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                            self.bfd_status_flag.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-bfd-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                        if (self.bfd_status_flag.is_set or self.bfd_status_flag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bfd_status_flag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bfd-intf-enable-mode" or name == "bfd-status-flag"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bfd-intf-enable-mode"):
                                            self.bfd_intf_enable_mode = value
                                            self.bfd_intf_enable_mode.value_namespace = name_space
                                            self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bfd-status-flag"):
                                            self.bfd_status_flag = value
                                            self.bfd_status_flag.value_namespace = name_space
                                            self.bfd_status_flag.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.dr_bdr_state.is_set or
                                        self.interface_name.is_set or
                                        self.neighbor_address.is_set or
                                        self.neighbor_address_xr.is_set or
                                        self.neighbor_dead_timer.is_set or
                                        self.neighbor_dr_priority.is_set or
                                        self.neighbor_id.is_set or
                                        self.neighbor_interface_name.is_set or
                                        self.neighbor_madj_interface.is_set or
                                        self.neighbor_state.is_set or
                                        self.neighbor_up_time.is_set or
                                        (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dr_bdr_state.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.neighbor_address.yfilter != YFilter.not_set or
                                        self.neighbor_address_xr.yfilter != YFilter.not_set or
                                        self.neighbor_dead_timer.yfilter != YFilter.not_set or
                                        self.neighbor_dr_priority.yfilter != YFilter.not_set or
                                        self.neighbor_id.yfilter != YFilter.not_set or
                                        self.neighbor_interface_name.yfilter != YFilter.not_set or
                                        self.neighbor_madj_interface.yfilter != YFilter.not_set or
                                        self.neighbor_state.yfilter != YFilter.not_set or
                                        self.neighbor_up_time.yfilter != YFilter.not_set or
                                        (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "neighbor" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dr_bdr_state.is_set or self.dr_bdr_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dr_bdr_state.get_name_leafdata())
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                    if (self.neighbor_address_xr.is_set or self.neighbor_address_xr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address_xr.get_name_leafdata())
                                    if (self.neighbor_dead_timer.is_set or self.neighbor_dead_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_dead_timer.get_name_leafdata())
                                    if (self.neighbor_dr_priority.is_set or self.neighbor_dr_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_dr_priority.get_name_leafdata())
                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                    if (self.neighbor_interface_name.is_set or self.neighbor_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_interface_name.get_name_leafdata())
                                    if (self.neighbor_madj_interface.is_set or self.neighbor_madj_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_madj_interface.get_name_leafdata())
                                    if (self.neighbor_state.is_set or self.neighbor_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_state.get_name_leafdata())
                                    if (self.neighbor_up_time.is_set or self.neighbor_up_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_up_time.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "neighbor-bfd-information"):
                                        if (self.neighbor_bfd_information is None):
                                            self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation()
                                            self.neighbor_bfd_information.parent = self
                                            self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                        return self.neighbor_bfd_information

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "neighbor-bfd-information" or name == "dr-bdr-state" or name == "interface-name" or name == "neighbor-address" or name == "neighbor-address-xr" or name == "neighbor-dead-timer" or name == "neighbor-dr-priority" or name == "neighbor-id" or name == "neighbor-interface-name" or name == "neighbor-madj-interface" or name == "neighbor-state" or name == "neighbor-up-time"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dr-bdr-state"):
                                        self.dr_bdr_state = value
                                        self.dr_bdr_state.value_namespace = name_space
                                        self.dr_bdr_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-address"):
                                        self.neighbor_address = value
                                        self.neighbor_address.value_namespace = name_space
                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-address-xr"):
                                        self.neighbor_address_xr = value
                                        self.neighbor_address_xr.value_namespace = name_space
                                        self.neighbor_address_xr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-dead-timer"):
                                        self.neighbor_dead_timer = value
                                        self.neighbor_dead_timer.value_namespace = name_space
                                        self.neighbor_dead_timer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-dr-priority"):
                                        self.neighbor_dr_priority = value
                                        self.neighbor_dr_priority.value_namespace = name_space
                                        self.neighbor_dr_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-id"):
                                        self.neighbor_id = value
                                        self.neighbor_id.value_namespace = name_space
                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-interface-name"):
                                        self.neighbor_interface_name = value
                                        self.neighbor_interface_name.value_namespace = name_space
                                        self.neighbor_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-madj-interface"):
                                        self.neighbor_madj_interface = value
                                        self.neighbor_madj_interface.value_namespace = name_space
                                        self.neighbor_madj_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-state"):
                                        self.neighbor_state = value
                                        self.neighbor_state.value_namespace = name_space
                                        self.neighbor_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-up-time"):
                                        self.neighbor_up_time = value
                                        self.neighbor_up_time.value_namespace = name_space
                                        self.neighbor_up_time.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.neighbor:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.neighbor:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbors" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "neighbor"):
                                    for c in self.neighbor:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.neighbor.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "neighbor"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Requests(Entity):
                            """
                            Request List table
                            
                            .. attribute:: request
                            
                            	Request list for a particular adjacency
                            	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests, self).__init__()

                                self.yang_name = "requests"
                                self.yang_parent_name = "adjacency-information"

                                self.request = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests, self).__setattr__(name, value)


                            class Request(Entity):
                                """
                                Request list for a particular adjacency
                                
                                .. attribute:: interface_name
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: request
                                
                                	List of request list entries
                                	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request.Request>`
                                
                                .. attribute:: request_interface_name
                                
                                	Request list interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: request_neighbor_address
                                
                                	Neighbor IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: request_neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request, self).__init__()

                                    self.yang_name = "request"
                                    self.yang_parent_name = "requests"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.request_interface_name = YLeaf(YType.str, "request-interface-name")

                                    self.request_neighbor_address = YLeaf(YType.str, "request-neighbor-address")

                                    self.request_neighbor_id = YLeaf(YType.str, "request-neighbor-id")

                                    self.request = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "neighbor_address",
                                                    "request_interface_name",
                                                    "request_neighbor_address",
                                                    "request_neighbor_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request, self).__setattr__(name, value)


                                class Request(Entity):
                                    """
                                    List of request list entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request.Request, self).__init__()

                                        self.yang_name = "request"
                                        self.yang_parent_name = "request"

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("header_advertising_router",
                                                        "header_ls_id",
                                                        "header_lsa_age",
                                                        "header_lsa_checksum",
                                                        "header_lsa_type",
                                                        "header_sequence_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request.Request, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request.Request, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.header_advertising_router.is_set or
                                            self.header_ls_id.is_set or
                                            self.header_lsa_age.is_set or
                                            self.header_lsa_checksum.is_set or
                                            self.header_lsa_type.is_set or
                                            self.header_sequence_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.header_advertising_router.yfilter != YFilter.not_set or
                                            self.header_ls_id.yfilter != YFilter.not_set or
                                            self.header_lsa_age.yfilter != YFilter.not_set or
                                            self.header_lsa_checksum.yfilter != YFilter.not_set or
                                            self.header_lsa_type.yfilter != YFilter.not_set or
                                            self.header_sequence_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "request" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                        if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                        if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                        if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                        if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                        if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "header-advertising-router"):
                                            self.header_advertising_router = value
                                            self.header_advertising_router.value_namespace = name_space
                                            self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-ls-id"):
                                            self.header_ls_id = value
                                            self.header_ls_id.value_namespace = name_space
                                            self.header_ls_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-age"):
                                            self.header_lsa_age = value
                                            self.header_lsa_age.value_namespace = name_space
                                            self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-checksum"):
                                            self.header_lsa_checksum = value
                                            self.header_lsa_checksum.value_namespace = name_space
                                            self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-type"):
                                            self.header_lsa_type = value
                                            self.header_lsa_type.value_namespace = name_space
                                            self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-sequence-number"):
                                            self.header_sequence_number = value
                                            self.header_sequence_number.value_namespace = name_space
                                            self.header_sequence_number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.request:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.interface_name.is_set or
                                        self.neighbor_address.is_set or
                                        self.request_interface_name.is_set or
                                        self.request_neighbor_address.is_set or
                                        self.request_neighbor_id.is_set)

                                def has_operation(self):
                                    for c in self.request:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.neighbor_address.yfilter != YFilter.not_set or
                                        self.request_interface_name.yfilter != YFilter.not_set or
                                        self.request_neighbor_address.yfilter != YFilter.not_set or
                                        self.request_neighbor_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "request" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                    if (self.request_interface_name.is_set or self.request_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.request_interface_name.get_name_leafdata())
                                    if (self.request_neighbor_address.is_set or self.request_neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.request_neighbor_address.get_name_leafdata())
                                    if (self.request_neighbor_id.is_set or self.request_neighbor_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.request_neighbor_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "request"):
                                        for c in self.request:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request.Request()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.request.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "request" or name == "interface-name" or name == "neighbor-address" or name == "request-interface-name" or name == "request-neighbor-address" or name == "request-neighbor-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-address"):
                                        self.neighbor_address = value
                                        self.neighbor_address.value_namespace = name_space
                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "request-interface-name"):
                                        self.request_interface_name = value
                                        self.request_interface_name.value_namespace = name_space
                                        self.request_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "request-neighbor-address"):
                                        self.request_neighbor_address = value
                                        self.request_neighbor_address.value_namespace = name_space
                                        self.request_neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "request-neighbor-id"):
                                        self.request_neighbor_id = value
                                        self.request_neighbor_id.value_namespace = name_space
                                        self.request_neighbor_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.request:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.request:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "requests" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "request"):
                                    for c in self.request:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.request.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "request"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Retransmissions(Entity):
                            """
                            Retransmission list table
                            
                            .. attribute:: retransmission
                            
                            	Retransmission list for a particular adjacency
                            	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions, self).__init__()

                                self.yang_name = "retransmissions"
                                self.yang_parent_name = "adjacency-information"

                                self.retransmission = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions, self).__setattr__(name, value)


                            class Retransmission(Entity):
                                """
                                Retransmission list for a particular adjacency
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_area_db
                                
                                	List of Area scope entries
                                	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb>`
                                
                                .. attribute:: retransmission_asdb
                                
                                	List of AS Scope entries
                                	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb>`
                                
                                .. attribute:: retransmission_count
                                
                                	Retransmission queue length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmission_interface_name
                                
                                	Retransmission list interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: retransmission_neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_neighbor_ip_address
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_timer
                                
                                	Amount of time remaining on retransmission timer (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission, self).__init__()

                                    self.yang_name = "retransmission"
                                    self.yang_parent_name = "retransmissions"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.retransmission_count = YLeaf(YType.uint32, "retransmission-count")

                                    self.retransmission_interface_name = YLeaf(YType.str, "retransmission-interface-name")

                                    self.retransmission_neighbor_id = YLeaf(YType.str, "retransmission-neighbor-id")

                                    self.retransmission_neighbor_ip_address = YLeaf(YType.str, "retransmission-neighbor-ip-address")

                                    self.retransmission_timer = YLeaf(YType.uint32, "retransmission-timer")

                                    self.retransmission_area_db = YList(self)
                                    self.retransmission_asdb = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "neighbor_address",
                                                    "retransmission_count",
                                                    "retransmission_interface_name",
                                                    "retransmission_neighbor_id",
                                                    "retransmission_neighbor_ip_address",
                                                    "retransmission_timer") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission, self).__setattr__(name, value)


                                class RetransmissionAreaDb(Entity):
                                    """
                                    List of Area scope entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb, self).__init__()

                                        self.yang_name = "retransmission-area-db"
                                        self.yang_parent_name = "retransmission"

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("header_advertising_router",
                                                        "header_ls_id",
                                                        "header_lsa_age",
                                                        "header_lsa_checksum",
                                                        "header_lsa_type",
                                                        "header_sequence_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.header_advertising_router.is_set or
                                            self.header_ls_id.is_set or
                                            self.header_lsa_age.is_set or
                                            self.header_lsa_checksum.is_set or
                                            self.header_lsa_type.is_set or
                                            self.header_sequence_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.header_advertising_router.yfilter != YFilter.not_set or
                                            self.header_ls_id.yfilter != YFilter.not_set or
                                            self.header_lsa_age.yfilter != YFilter.not_set or
                                            self.header_lsa_checksum.yfilter != YFilter.not_set or
                                            self.header_lsa_type.yfilter != YFilter.not_set or
                                            self.header_sequence_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "retransmission-area-db" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                        if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                        if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                        if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                        if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                        if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "header-advertising-router"):
                                            self.header_advertising_router = value
                                            self.header_advertising_router.value_namespace = name_space
                                            self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-ls-id"):
                                            self.header_ls_id = value
                                            self.header_ls_id.value_namespace = name_space
                                            self.header_ls_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-age"):
                                            self.header_lsa_age = value
                                            self.header_lsa_age.value_namespace = name_space
                                            self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-checksum"):
                                            self.header_lsa_checksum = value
                                            self.header_lsa_checksum.value_namespace = name_space
                                            self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-type"):
                                            self.header_lsa_type = value
                                            self.header_lsa_type.value_namespace = name_space
                                            self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-sequence-number"):
                                            self.header_sequence_number = value
                                            self.header_sequence_number.value_namespace = name_space
                                            self.header_sequence_number.value_namespace_prefix = name_space_prefix


                                class RetransmissionAsdb(Entity):
                                    """
                                    List of AS Scope entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb, self).__init__()

                                        self.yang_name = "retransmission-asdb"
                                        self.yang_parent_name = "retransmission"

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("header_advertising_router",
                                                        "header_ls_id",
                                                        "header_lsa_age",
                                                        "header_lsa_checksum",
                                                        "header_lsa_type",
                                                        "header_sequence_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.header_advertising_router.is_set or
                                            self.header_ls_id.is_set or
                                            self.header_lsa_age.is_set or
                                            self.header_lsa_checksum.is_set or
                                            self.header_lsa_type.is_set or
                                            self.header_sequence_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.header_advertising_router.yfilter != YFilter.not_set or
                                            self.header_ls_id.yfilter != YFilter.not_set or
                                            self.header_lsa_age.yfilter != YFilter.not_set or
                                            self.header_lsa_checksum.yfilter != YFilter.not_set or
                                            self.header_lsa_type.yfilter != YFilter.not_set or
                                            self.header_sequence_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "retransmission-asdb" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                        if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                        if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                        if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                        if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                        if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "header-advertising-router"):
                                            self.header_advertising_router = value
                                            self.header_advertising_router.value_namespace = name_space
                                            self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-ls-id"):
                                            self.header_ls_id = value
                                            self.header_ls_id.value_namespace = name_space
                                            self.header_ls_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-age"):
                                            self.header_lsa_age = value
                                            self.header_lsa_age.value_namespace = name_space
                                            self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-checksum"):
                                            self.header_lsa_checksum = value
                                            self.header_lsa_checksum.value_namespace = name_space
                                            self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-type"):
                                            self.header_lsa_type = value
                                            self.header_lsa_type.value_namespace = name_space
                                            self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-sequence-number"):
                                            self.header_sequence_number = value
                                            self.header_sequence_number.value_namespace = name_space
                                            self.header_sequence_number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.retransmission_area_db:
                                        if (c.has_data()):
                                            return True
                                    for c in self.retransmission_asdb:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.interface_name.is_set or
                                        self.neighbor_address.is_set or
                                        self.retransmission_count.is_set or
                                        self.retransmission_interface_name.is_set or
                                        self.retransmission_neighbor_id.is_set or
                                        self.retransmission_neighbor_ip_address.is_set or
                                        self.retransmission_timer.is_set)

                                def has_operation(self):
                                    for c in self.retransmission_area_db:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.retransmission_asdb:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.neighbor_address.yfilter != YFilter.not_set or
                                        self.retransmission_count.yfilter != YFilter.not_set or
                                        self.retransmission_interface_name.yfilter != YFilter.not_set or
                                        self.retransmission_neighbor_id.yfilter != YFilter.not_set or
                                        self.retransmission_neighbor_ip_address.yfilter != YFilter.not_set or
                                        self.retransmission_timer.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "retransmission" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                    if (self.retransmission_count.is_set or self.retransmission_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmission_count.get_name_leafdata())
                                    if (self.retransmission_interface_name.is_set or self.retransmission_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmission_interface_name.get_name_leafdata())
                                    if (self.retransmission_neighbor_id.is_set or self.retransmission_neighbor_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmission_neighbor_id.get_name_leafdata())
                                    if (self.retransmission_neighbor_ip_address.is_set or self.retransmission_neighbor_ip_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmission_neighbor_ip_address.get_name_leafdata())
                                    if (self.retransmission_timer.is_set or self.retransmission_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmission_timer.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "retransmission-area-db"):
                                        for c in self.retransmission_area_db:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.retransmission_area_db.append(c)
                                        return c

                                    if (child_yang_name == "retransmission-asdb"):
                                        for c in self.retransmission_asdb:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.retransmission_asdb.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "retransmission-area-db" or name == "retransmission-asdb" or name == "interface-name" or name == "neighbor-address" or name == "retransmission-count" or name == "retransmission-interface-name" or name == "retransmission-neighbor-id" or name == "retransmission-neighbor-ip-address" or name == "retransmission-timer"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-address"):
                                        self.neighbor_address = value
                                        self.neighbor_address.value_namespace = name_space
                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmission-count"):
                                        self.retransmission_count = value
                                        self.retransmission_count.value_namespace = name_space
                                        self.retransmission_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmission-interface-name"):
                                        self.retransmission_interface_name = value
                                        self.retransmission_interface_name.value_namespace = name_space
                                        self.retransmission_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmission-neighbor-id"):
                                        self.retransmission_neighbor_id = value
                                        self.retransmission_neighbor_id.value_namespace = name_space
                                        self.retransmission_neighbor_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmission-neighbor-ip-address"):
                                        self.retransmission_neighbor_ip_address = value
                                        self.retransmission_neighbor_ip_address.value_namespace = name_space
                                        self.retransmission_neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmission-timer"):
                                        self.retransmission_timer = value
                                        self.retransmission_timer.value_namespace = name_space
                                        self.retransmission_timer.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.retransmission:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.retransmission:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "retransmissions" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "retransmission"):
                                    for c in self.retransmission:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.retransmission.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "retransmission"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class NeighborDetails(Entity):
                            """
                            Neighbor detail table
                            
                            .. attribute:: neighbor_detail
                            
                            	A single neighbor's detail information
                            	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails, self).__init__()

                                self.yang_name = "neighbor-details"
                                self.yang_parent_name = "adjacency-information"

                                self.neighbor_detail = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails, self).__setattr__(name, value)


                            class NeighborDetail(Entity):
                                """
                                A single neighbor's detail information
                                
                                .. attribute:: adjacency_sid_label
                                
                                	SR Adjacency SID Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: adjacency_sid_protected
                                
                                	SR Adjacency SID Protected
                                	**type**\:  bool
                                
                                .. attribute:: adjacency_sid_unprotected_label
                                
                                	SR Adjacency SID Unprotected Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: interface_type
                                
                                	Interface type
                                	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                                
                                .. attribute:: last_oob_time
                                
                                	The amount of time in seconds since last time Out\-Of\-Band resynchronization was done with this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: lfa_interface
                                
                                	LFA Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: lfa_neighbor_id
                                
                                	LFA Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lfa_neighbor_revision
                                
                                	LFA Neighbor Revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lfa_next_hop
                                
                                	LFA Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_ack_list_count
                                
                                	Ack List Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_ack_list_high_watermark
                                
                                	Ack List High Watermark
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_area_id
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: neighbor_backup_designated_router_address
                                
                                	Address of backup designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_information
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation>`
                                
                                .. attribute:: neighbor_cost
                                
                                	Cost of path to this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_designated_router_address
                                
                                	Address of designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_filter
                                
                                	If true, filter outgoing LSAs
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_lls_option
                                
                                	This is a bitmask of Link Local signalling options received from the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_option
                                
                                	 This is bitmaks of neighbor's option field received
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_retransmission_information
                                
                                	Retransmission information with this neighbor
                                	**type**\:   :py:class:`NeighborRetransmissionInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation>`
                                
                                .. attribute:: neighbor_summary
                                
                                	Neighbor summary information
                                	**type**\:   :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary>`
                                
                                .. attribute:: next_poll_interval
                                
                                	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nsf_router_state
                                
                                	For cisco NSF, the router is either Requester or Receiver
                                	**type**\:   :py:class:`NsfRtr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NsfRtr>`
                                
                                .. attribute:: oob_resynchronization
                                
                                	Out\-Of\-Bound resynchronization in progress
                                	**type**\:  bool
                                
                                .. attribute:: pending_events
                                
                                	Number of pending events
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: poll_interval
                                
                                	Poll interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_change_count
                                
                                	Number of state changes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail, self).__init__()

                                    self.yang_name = "neighbor-detail"
                                    self.yang_parent_name = "neighbor-details"

                                    self.adjacency_sid_label = YLeaf(YType.uint32, "adjacency-sid-label")

                                    self.adjacency_sid_protected = YLeaf(YType.boolean, "adjacency-sid-protected")

                                    self.adjacency_sid_unprotected_label = YLeaf(YType.uint32, "adjacency-sid-unprotected-label")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                    self.last_oob_time = YLeaf(YType.uint32, "last-oob-time")

                                    self.lfa_interface = YLeaf(YType.str, "lfa-interface")

                                    self.lfa_neighbor_id = YLeaf(YType.str, "lfa-neighbor-id")

                                    self.lfa_neighbor_revision = YLeaf(YType.uint32, "lfa-neighbor-revision")

                                    self.lfa_next_hop = YLeaf(YType.str, "lfa-next-hop")

                                    self.neighbor_ack_list_count = YLeaf(YType.uint32, "neighbor-ack-list-count")

                                    self.neighbor_ack_list_high_watermark = YLeaf(YType.uint32, "neighbor-ack-list-high-watermark")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.neighbor_area_id = YLeaf(YType.str, "neighbor-area-id")

                                    self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                    self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                    self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                    self.neighbor_filter = YLeaf(YType.boolean, "neighbor-filter")

                                    self.neighbor_lls_option = YLeaf(YType.uint16, "neighbor-lls-option")

                                    self.neighbor_option = YLeaf(YType.uint8, "neighbor-option")

                                    self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                    self.nsf_router_state = YLeaf(YType.enumeration, "nsf-router-state")

                                    self.oob_resynchronization = YLeaf(YType.boolean, "oob-resynchronization")

                                    self.pending_events = YLeaf(YType.uint16, "pending-events")

                                    self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                    self.state_change_count = YLeaf(YType.uint16, "state-change-count")

                                    self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation()
                                    self.neighbor_bfd_information.parent = self
                                    self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                    self._children_yang_names.add("neighbor-bfd-information")

                                    self.neighbor_retransmission_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation()
                                    self.neighbor_retransmission_information.parent = self
                                    self._children_name_map["neighbor_retransmission_information"] = "neighbor-retransmission-information"
                                    self._children_yang_names.add("neighbor-retransmission-information")

                                    self.neighbor_summary = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary()
                                    self.neighbor_summary.parent = self
                                    self._children_name_map["neighbor_summary"] = "neighbor-summary"
                                    self._children_yang_names.add("neighbor-summary")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("adjacency_sid_label",
                                                    "adjacency_sid_protected",
                                                    "adjacency_sid_unprotected_label",
                                                    "interface_name",
                                                    "interface_type",
                                                    "last_oob_time",
                                                    "lfa_interface",
                                                    "lfa_neighbor_id",
                                                    "lfa_neighbor_revision",
                                                    "lfa_next_hop",
                                                    "neighbor_ack_list_count",
                                                    "neighbor_ack_list_high_watermark",
                                                    "neighbor_address",
                                                    "neighbor_area_id",
                                                    "neighbor_backup_designated_router_address",
                                                    "neighbor_cost",
                                                    "neighbor_designated_router_address",
                                                    "neighbor_filter",
                                                    "neighbor_lls_option",
                                                    "neighbor_option",
                                                    "next_poll_interval",
                                                    "nsf_router_state",
                                                    "oob_resynchronization",
                                                    "pending_events",
                                                    "poll_interval",
                                                    "state_change_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail, self).__setattr__(name, value)


                                class NeighborSummary(Entity):
                                    """
                                    Neighbor summary information
                                    
                                    .. attribute:: dr_bdr_state
                                    
                                    	Designated Router state
                                    	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bfd_information
                                    
                                    	Neighbor BFD information
                                    	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation>`
                                    
                                    .. attribute:: neighbor_dead_timer
                                    
                                    	Time until neighbor's dead timer expires (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_dr_priority
                                    
                                    	Neighbor's DR priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_id
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_interface_name
                                    
                                    	Interface via which the neighbor is seen
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: neighbor_madj_interface
                                    
                                    	Interface is MADJ
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_state
                                    
                                    	Neighbor's state
                                    	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                    
                                    .. attribute:: neighbor_up_time
                                    
                                    	Amount of time since the adjacency is up (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary, self).__init__()

                                        self.yang_name = "neighbor-summary"
                                        self.yang_parent_name = "neighbor-detail"

                                        self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                        self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                        self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                        self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                        self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                        self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                        self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                        self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                        self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                        self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation()
                                        self.neighbor_bfd_information.parent = self
                                        self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                        self._children_yang_names.add("neighbor-bfd-information")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dr_bdr_state",
                                                        "neighbor_address_xr",
                                                        "neighbor_dead_timer",
                                                        "neighbor_dr_priority",
                                                        "neighbor_id",
                                                        "neighbor_interface_name",
                                                        "neighbor_madj_interface",
                                                        "neighbor_state",
                                                        "neighbor_up_time") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary, self).__setattr__(name, value)


                                    class NeighborBfdInformation(Entity):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__init__()

                                            self.yang_name = "neighbor-bfd-information"
                                            self.yang_parent_name = "neighbor-summary"

                                            self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                            self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bfd_intf_enable_mode",
                                                            "bfd_status_flag") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bfd_intf_enable_mode.is_set or
                                                self.bfd_status_flag.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                                self.bfd_status_flag.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor-bfd-information" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                            if (self.bfd_status_flag.is_set or self.bfd_status_flag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_status_flag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bfd-intf-enable-mode" or name == "bfd-status-flag"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bfd-intf-enable-mode"):
                                                self.bfd_intf_enable_mode = value
                                                self.bfd_intf_enable_mode.value_namespace = name_space
                                                self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-status-flag"):
                                                self.bfd_status_flag = value
                                                self.bfd_status_flag.value_namespace = name_space
                                                self.bfd_status_flag.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.dr_bdr_state.is_set or
                                            self.neighbor_address_xr.is_set or
                                            self.neighbor_dead_timer.is_set or
                                            self.neighbor_dr_priority.is_set or
                                            self.neighbor_id.is_set or
                                            self.neighbor_interface_name.is_set or
                                            self.neighbor_madj_interface.is_set or
                                            self.neighbor_state.is_set or
                                            self.neighbor_up_time.is_set or
                                            (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dr_bdr_state.yfilter != YFilter.not_set or
                                            self.neighbor_address_xr.yfilter != YFilter.not_set or
                                            self.neighbor_dead_timer.yfilter != YFilter.not_set or
                                            self.neighbor_dr_priority.yfilter != YFilter.not_set or
                                            self.neighbor_id.yfilter != YFilter.not_set or
                                            self.neighbor_interface_name.yfilter != YFilter.not_set or
                                            self.neighbor_madj_interface.yfilter != YFilter.not_set or
                                            self.neighbor_state.yfilter != YFilter.not_set or
                                            self.neighbor_up_time.yfilter != YFilter.not_set or
                                            (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-summary" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dr_bdr_state.is_set or self.dr_bdr_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dr_bdr_state.get_name_leafdata())
                                        if (self.neighbor_address_xr.is_set or self.neighbor_address_xr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_address_xr.get_name_leafdata())
                                        if (self.neighbor_dead_timer.is_set or self.neighbor_dead_timer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_dead_timer.get_name_leafdata())
                                        if (self.neighbor_dr_priority.is_set or self.neighbor_dr_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_dr_priority.get_name_leafdata())
                                        if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                        if (self.neighbor_interface_name.is_set or self.neighbor_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_interface_name.get_name_leafdata())
                                        if (self.neighbor_madj_interface.is_set or self.neighbor_madj_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_madj_interface.get_name_leafdata())
                                        if (self.neighbor_state.is_set or self.neighbor_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_state.get_name_leafdata())
                                        if (self.neighbor_up_time.is_set or self.neighbor_up_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_up_time.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "neighbor-bfd-information"):
                                            if (self.neighbor_bfd_information is None):
                                                self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation()
                                                self.neighbor_bfd_information.parent = self
                                                self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                            return self.neighbor_bfd_information

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "neighbor-bfd-information" or name == "dr-bdr-state" or name == "neighbor-address-xr" or name == "neighbor-dead-timer" or name == "neighbor-dr-priority" or name == "neighbor-id" or name == "neighbor-interface-name" or name == "neighbor-madj-interface" or name == "neighbor-state" or name == "neighbor-up-time"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dr-bdr-state"):
                                            self.dr_bdr_state = value
                                            self.dr_bdr_state.value_namespace = name_space
                                            self.dr_bdr_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-address-xr"):
                                            self.neighbor_address_xr = value
                                            self.neighbor_address_xr.value_namespace = name_space
                                            self.neighbor_address_xr.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-dead-timer"):
                                            self.neighbor_dead_timer = value
                                            self.neighbor_dead_timer.value_namespace = name_space
                                            self.neighbor_dead_timer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-dr-priority"):
                                            self.neighbor_dr_priority = value
                                            self.neighbor_dr_priority.value_namespace = name_space
                                            self.neighbor_dr_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-id"):
                                            self.neighbor_id = value
                                            self.neighbor_id.value_namespace = name_space
                                            self.neighbor_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-interface-name"):
                                            self.neighbor_interface_name = value
                                            self.neighbor_interface_name.value_namespace = name_space
                                            self.neighbor_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-madj-interface"):
                                            self.neighbor_madj_interface = value
                                            self.neighbor_madj_interface.value_namespace = name_space
                                            self.neighbor_madj_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-state"):
                                            self.neighbor_state = value
                                            self.neighbor_state.value_namespace = name_space
                                            self.neighbor_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-up-time"):
                                            self.neighbor_up_time = value
                                            self.neighbor_up_time.value_namespace = name_space
                                            self.neighbor_up_time.value_namespace_prefix = name_space_prefix


                                class NeighborBfdInformation(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__init__()

                                        self.yang_name = "neighbor-bfd-information"
                                        self.yang_parent_name = "neighbor-detail"

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bfd_intf_enable_mode",
                                                        "bfd_status_flag") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bfd_intf_enable_mode.is_set or
                                            self.bfd_status_flag.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                            self.bfd_status_flag.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-bfd-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                        if (self.bfd_status_flag.is_set or self.bfd_status_flag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bfd_status_flag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bfd-intf-enable-mode" or name == "bfd-status-flag"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bfd-intf-enable-mode"):
                                            self.bfd_intf_enable_mode = value
                                            self.bfd_intf_enable_mode.value_namespace = name_space
                                            self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bfd-status-flag"):
                                            self.bfd_status_flag = value
                                            self.bfd_status_flag.value_namespace = name_space
                                            self.bfd_status_flag.value_namespace_prefix = name_space_prefix


                                class NeighborRetransmissionInformation(Entity):
                                    """
                                    Retransmission information with this neighbor
                                    
                                    .. attribute:: area_first_flood_information
                                    
                                    	First flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood_information_index
                                    
                                    	Index of the first flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_flooding_index
                                    
                                    	Area scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_information
                                    
                                    	Next flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_information_index
                                    
                                    	Index of next flood item for Area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_information
                                    
                                    	First flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_information_index
                                    
                                    	Index for first flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_flood_index
                                    
                                    	AS scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_information
                                    
                                    	Next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_information_index
                                    
                                    	Index of next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dbd_retransmission_count
                                    
                                    	Number of DBD retransmissions during last exchange
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dbd_retransmission_total_count
                                    
                                    	Total number of DBD retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_length
                                    
                                    	Number of LSAs sent in last retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_time
                                    
                                    	Last retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_retransmission_timer
                                    
                                    	Time until next LSA retransmission (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_length
                                    
                                    	Maximum number of LSAs sent in a retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_time
                                    
                                    	Maximum retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmission_count
                                    
                                    	Retransmission queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_retransmissions
                                    
                                    	Number of retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__init__()

                                        self.yang_name = "neighbor-retransmission-information"
                                        self.yang_parent_name = "neighbor-detail"

                                        self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                        self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                        self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                        self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                        self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                        self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                        self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                        self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                        self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                        self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                        self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                        self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                        self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                        self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                        self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                        self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                        self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                        self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                        self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("area_first_flood_information",
                                                        "area_first_flood_information_index",
                                                        "area_flooding_index",
                                                        "area_next_flood_information",
                                                        "area_next_flood_information_index",
                                                        "as_first_flood_information",
                                                        "as_first_flood_information_index",
                                                        "as_flood_index",
                                                        "as_next_flood_information",
                                                        "as_next_flood_information_index",
                                                        "dbd_retransmission_count",
                                                        "dbd_retransmission_total_count",
                                                        "last_retransmission_length",
                                                        "last_retransmission_time",
                                                        "lsa_retransmission_timer",
                                                        "maximum_retransmission_length",
                                                        "maximum_retransmission_time",
                                                        "neighbor_retransmission_count",
                                                        "number_of_retransmissions") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.area_first_flood_information.is_set or
                                            self.area_first_flood_information_index.is_set or
                                            self.area_flooding_index.is_set or
                                            self.area_next_flood_information.is_set or
                                            self.area_next_flood_information_index.is_set or
                                            self.as_first_flood_information.is_set or
                                            self.as_first_flood_information_index.is_set or
                                            self.as_flood_index.is_set or
                                            self.as_next_flood_information.is_set or
                                            self.as_next_flood_information_index.is_set or
                                            self.dbd_retransmission_count.is_set or
                                            self.dbd_retransmission_total_count.is_set or
                                            self.last_retransmission_length.is_set or
                                            self.last_retransmission_time.is_set or
                                            self.lsa_retransmission_timer.is_set or
                                            self.maximum_retransmission_length.is_set or
                                            self.maximum_retransmission_time.is_set or
                                            self.neighbor_retransmission_count.is_set or
                                            self.number_of_retransmissions.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.area_first_flood_information.yfilter != YFilter.not_set or
                                            self.area_first_flood_information_index.yfilter != YFilter.not_set or
                                            self.area_flooding_index.yfilter != YFilter.not_set or
                                            self.area_next_flood_information.yfilter != YFilter.not_set or
                                            self.area_next_flood_information_index.yfilter != YFilter.not_set or
                                            self.as_first_flood_information.yfilter != YFilter.not_set or
                                            self.as_first_flood_information_index.yfilter != YFilter.not_set or
                                            self.as_flood_index.yfilter != YFilter.not_set or
                                            self.as_next_flood_information.yfilter != YFilter.not_set or
                                            self.as_next_flood_information_index.yfilter != YFilter.not_set or
                                            self.dbd_retransmission_count.yfilter != YFilter.not_set or
                                            self.dbd_retransmission_total_count.yfilter != YFilter.not_set or
                                            self.last_retransmission_length.yfilter != YFilter.not_set or
                                            self.last_retransmission_time.yfilter != YFilter.not_set or
                                            self.lsa_retransmission_timer.yfilter != YFilter.not_set or
                                            self.maximum_retransmission_length.yfilter != YFilter.not_set or
                                            self.maximum_retransmission_time.yfilter != YFilter.not_set or
                                            self.neighbor_retransmission_count.yfilter != YFilter.not_set or
                                            self.number_of_retransmissions.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-retransmission-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.area_first_flood_information.is_set or self.area_first_flood_information.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_first_flood_information.get_name_leafdata())
                                        if (self.area_first_flood_information_index.is_set or self.area_first_flood_information_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_first_flood_information_index.get_name_leafdata())
                                        if (self.area_flooding_index.is_set or self.area_flooding_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_flooding_index.get_name_leafdata())
                                        if (self.area_next_flood_information.is_set or self.area_next_flood_information.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_next_flood_information.get_name_leafdata())
                                        if (self.area_next_flood_information_index.is_set or self.area_next_flood_information_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_next_flood_information_index.get_name_leafdata())
                                        if (self.as_first_flood_information.is_set or self.as_first_flood_information.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_first_flood_information.get_name_leafdata())
                                        if (self.as_first_flood_information_index.is_set or self.as_first_flood_information_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_first_flood_information_index.get_name_leafdata())
                                        if (self.as_flood_index.is_set or self.as_flood_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_flood_index.get_name_leafdata())
                                        if (self.as_next_flood_information.is_set or self.as_next_flood_information.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_next_flood_information.get_name_leafdata())
                                        if (self.as_next_flood_information_index.is_set or self.as_next_flood_information_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_next_flood_information_index.get_name_leafdata())
                                        if (self.dbd_retransmission_count.is_set or self.dbd_retransmission_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dbd_retransmission_count.get_name_leafdata())
                                        if (self.dbd_retransmission_total_count.is_set or self.dbd_retransmission_total_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dbd_retransmission_total_count.get_name_leafdata())
                                        if (self.last_retransmission_length.is_set or self.last_retransmission_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_retransmission_length.get_name_leafdata())
                                        if (self.last_retransmission_time.is_set or self.last_retransmission_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_retransmission_time.get_name_leafdata())
                                        if (self.lsa_retransmission_timer.is_set or self.lsa_retransmission_timer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_retransmission_timer.get_name_leafdata())
                                        if (self.maximum_retransmission_length.is_set or self.maximum_retransmission_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_retransmission_length.get_name_leafdata())
                                        if (self.maximum_retransmission_time.is_set or self.maximum_retransmission_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_retransmission_time.get_name_leafdata())
                                        if (self.neighbor_retransmission_count.is_set or self.neighbor_retransmission_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_retransmission_count.get_name_leafdata())
                                        if (self.number_of_retransmissions.is_set or self.number_of_retransmissions.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number_of_retransmissions.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "area-first-flood-information" or name == "area-first-flood-information-index" or name == "area-flooding-index" or name == "area-next-flood-information" or name == "area-next-flood-information-index" or name == "as-first-flood-information" or name == "as-first-flood-information-index" or name == "as-flood-index" or name == "as-next-flood-information" or name == "as-next-flood-information-index" or name == "dbd-retransmission-count" or name == "dbd-retransmission-total-count" or name == "last-retransmission-length" or name == "last-retransmission-time" or name == "lsa-retransmission-timer" or name == "maximum-retransmission-length" or name == "maximum-retransmission-time" or name == "neighbor-retransmission-count" or name == "number-of-retransmissions"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "area-first-flood-information"):
                                            self.area_first_flood_information = value
                                            self.area_first_flood_information.value_namespace = name_space
                                            self.area_first_flood_information.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-first-flood-information-index"):
                                            self.area_first_flood_information_index = value
                                            self.area_first_flood_information_index.value_namespace = name_space
                                            self.area_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-flooding-index"):
                                            self.area_flooding_index = value
                                            self.area_flooding_index.value_namespace = name_space
                                            self.area_flooding_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-next-flood-information"):
                                            self.area_next_flood_information = value
                                            self.area_next_flood_information.value_namespace = name_space
                                            self.area_next_flood_information.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-next-flood-information-index"):
                                            self.area_next_flood_information_index = value
                                            self.area_next_flood_information_index.value_namespace = name_space
                                            self.area_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-first-flood-information"):
                                            self.as_first_flood_information = value
                                            self.as_first_flood_information.value_namespace = name_space
                                            self.as_first_flood_information.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-first-flood-information-index"):
                                            self.as_first_flood_information_index = value
                                            self.as_first_flood_information_index.value_namespace = name_space
                                            self.as_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-flood-index"):
                                            self.as_flood_index = value
                                            self.as_flood_index.value_namespace = name_space
                                            self.as_flood_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-next-flood-information"):
                                            self.as_next_flood_information = value
                                            self.as_next_flood_information.value_namespace = name_space
                                            self.as_next_flood_information.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-next-flood-information-index"):
                                            self.as_next_flood_information_index = value
                                            self.as_next_flood_information_index.value_namespace = name_space
                                            self.as_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dbd-retransmission-count"):
                                            self.dbd_retransmission_count = value
                                            self.dbd_retransmission_count.value_namespace = name_space
                                            self.dbd_retransmission_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dbd-retransmission-total-count"):
                                            self.dbd_retransmission_total_count = value
                                            self.dbd_retransmission_total_count.value_namespace = name_space
                                            self.dbd_retransmission_total_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-retransmission-length"):
                                            self.last_retransmission_length = value
                                            self.last_retransmission_length.value_namespace = name_space
                                            self.last_retransmission_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-retransmission-time"):
                                            self.last_retransmission_time = value
                                            self.last_retransmission_time.value_namespace = name_space
                                            self.last_retransmission_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-retransmission-timer"):
                                            self.lsa_retransmission_timer = value
                                            self.lsa_retransmission_timer.value_namespace = name_space
                                            self.lsa_retransmission_timer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-retransmission-length"):
                                            self.maximum_retransmission_length = value
                                            self.maximum_retransmission_length.value_namespace = name_space
                                            self.maximum_retransmission_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-retransmission-time"):
                                            self.maximum_retransmission_time = value
                                            self.maximum_retransmission_time.value_namespace = name_space
                                            self.maximum_retransmission_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-retransmission-count"):
                                            self.neighbor_retransmission_count = value
                                            self.neighbor_retransmission_count.value_namespace = name_space
                                            self.neighbor_retransmission_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "number-of-retransmissions"):
                                            self.number_of_retransmissions = value
                                            self.number_of_retransmissions.value_namespace = name_space
                                            self.number_of_retransmissions.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.adjacency_sid_label.is_set or
                                        self.adjacency_sid_protected.is_set or
                                        self.adjacency_sid_unprotected_label.is_set or
                                        self.interface_name.is_set or
                                        self.interface_type.is_set or
                                        self.last_oob_time.is_set or
                                        self.lfa_interface.is_set or
                                        self.lfa_neighbor_id.is_set or
                                        self.lfa_neighbor_revision.is_set or
                                        self.lfa_next_hop.is_set or
                                        self.neighbor_ack_list_count.is_set or
                                        self.neighbor_ack_list_high_watermark.is_set or
                                        self.neighbor_address.is_set or
                                        self.neighbor_area_id.is_set or
                                        self.neighbor_backup_designated_router_address.is_set or
                                        self.neighbor_cost.is_set or
                                        self.neighbor_designated_router_address.is_set or
                                        self.neighbor_filter.is_set or
                                        self.neighbor_lls_option.is_set or
                                        self.neighbor_option.is_set or
                                        self.next_poll_interval.is_set or
                                        self.nsf_router_state.is_set or
                                        self.oob_resynchronization.is_set or
                                        self.pending_events.is_set or
                                        self.poll_interval.is_set or
                                        self.state_change_count.is_set or
                                        (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_data()) or
                                        (self.neighbor_retransmission_information is not None and self.neighbor_retransmission_information.has_data()) or
                                        (self.neighbor_summary is not None and self.neighbor_summary.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.adjacency_sid_label.yfilter != YFilter.not_set or
                                        self.adjacency_sid_protected.yfilter != YFilter.not_set or
                                        self.adjacency_sid_unprotected_label.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.interface_type.yfilter != YFilter.not_set or
                                        self.last_oob_time.yfilter != YFilter.not_set or
                                        self.lfa_interface.yfilter != YFilter.not_set or
                                        self.lfa_neighbor_id.yfilter != YFilter.not_set or
                                        self.lfa_neighbor_revision.yfilter != YFilter.not_set or
                                        self.lfa_next_hop.yfilter != YFilter.not_set or
                                        self.neighbor_ack_list_count.yfilter != YFilter.not_set or
                                        self.neighbor_ack_list_high_watermark.yfilter != YFilter.not_set or
                                        self.neighbor_address.yfilter != YFilter.not_set or
                                        self.neighbor_area_id.yfilter != YFilter.not_set or
                                        self.neighbor_backup_designated_router_address.yfilter != YFilter.not_set or
                                        self.neighbor_cost.yfilter != YFilter.not_set or
                                        self.neighbor_designated_router_address.yfilter != YFilter.not_set or
                                        self.neighbor_filter.yfilter != YFilter.not_set or
                                        self.neighbor_lls_option.yfilter != YFilter.not_set or
                                        self.neighbor_option.yfilter != YFilter.not_set or
                                        self.next_poll_interval.yfilter != YFilter.not_set or
                                        self.nsf_router_state.yfilter != YFilter.not_set or
                                        self.oob_resynchronization.yfilter != YFilter.not_set or
                                        self.pending_events.yfilter != YFilter.not_set or
                                        self.poll_interval.yfilter != YFilter.not_set or
                                        self.state_change_count.yfilter != YFilter.not_set or
                                        (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_operation()) or
                                        (self.neighbor_retransmission_information is not None and self.neighbor_retransmission_information.has_operation()) or
                                        (self.neighbor_summary is not None and self.neighbor_summary.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "neighbor-detail" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.adjacency_sid_label.is_set or self.adjacency_sid_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.adjacency_sid_label.get_name_leafdata())
                                    if (self.adjacency_sid_protected.is_set or self.adjacency_sid_protected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.adjacency_sid_protected.get_name_leafdata())
                                    if (self.adjacency_sid_unprotected_label.is_set or self.adjacency_sid_unprotected_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.adjacency_sid_unprotected_label.get_name_leafdata())
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.interface_type.is_set or self.interface_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_type.get_name_leafdata())
                                    if (self.last_oob_time.is_set or self.last_oob_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_oob_time.get_name_leafdata())
                                    if (self.lfa_interface.is_set or self.lfa_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lfa_interface.get_name_leafdata())
                                    if (self.lfa_neighbor_id.is_set or self.lfa_neighbor_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lfa_neighbor_id.get_name_leafdata())
                                    if (self.lfa_neighbor_revision.is_set or self.lfa_neighbor_revision.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lfa_neighbor_revision.get_name_leafdata())
                                    if (self.lfa_next_hop.is_set or self.lfa_next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lfa_next_hop.get_name_leafdata())
                                    if (self.neighbor_ack_list_count.is_set or self.neighbor_ack_list_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_ack_list_count.get_name_leafdata())
                                    if (self.neighbor_ack_list_high_watermark.is_set or self.neighbor_ack_list_high_watermark.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_ack_list_high_watermark.get_name_leafdata())
                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                    if (self.neighbor_area_id.is_set or self.neighbor_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_area_id.get_name_leafdata())
                                    if (self.neighbor_backup_designated_router_address.is_set or self.neighbor_backup_designated_router_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_backup_designated_router_address.get_name_leafdata())
                                    if (self.neighbor_cost.is_set or self.neighbor_cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_cost.get_name_leafdata())
                                    if (self.neighbor_designated_router_address.is_set or self.neighbor_designated_router_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_designated_router_address.get_name_leafdata())
                                    if (self.neighbor_filter.is_set or self.neighbor_filter.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_filter.get_name_leafdata())
                                    if (self.neighbor_lls_option.is_set or self.neighbor_lls_option.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_lls_option.get_name_leafdata())
                                    if (self.neighbor_option.is_set or self.neighbor_option.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_option.get_name_leafdata())
                                    if (self.next_poll_interval.is_set or self.next_poll_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_poll_interval.get_name_leafdata())
                                    if (self.nsf_router_state.is_set or self.nsf_router_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsf_router_state.get_name_leafdata())
                                    if (self.oob_resynchronization.is_set or self.oob_resynchronization.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.oob_resynchronization.get_name_leafdata())
                                    if (self.pending_events.is_set or self.pending_events.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pending_events.get_name_leafdata())
                                    if (self.poll_interval.is_set or self.poll_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.poll_interval.get_name_leafdata())
                                    if (self.state_change_count.is_set or self.state_change_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state_change_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "neighbor-bfd-information"):
                                        if (self.neighbor_bfd_information is None):
                                            self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation()
                                            self.neighbor_bfd_information.parent = self
                                            self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                        return self.neighbor_bfd_information

                                    if (child_yang_name == "neighbor-retransmission-information"):
                                        if (self.neighbor_retransmission_information is None):
                                            self.neighbor_retransmission_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation()
                                            self.neighbor_retransmission_information.parent = self
                                            self._children_name_map["neighbor_retransmission_information"] = "neighbor-retransmission-information"
                                        return self.neighbor_retransmission_information

                                    if (child_yang_name == "neighbor-summary"):
                                        if (self.neighbor_summary is None):
                                            self.neighbor_summary = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary()
                                            self.neighbor_summary.parent = self
                                            self._children_name_map["neighbor_summary"] = "neighbor-summary"
                                        return self.neighbor_summary

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "neighbor-bfd-information" or name == "neighbor-retransmission-information" or name == "neighbor-summary" or name == "adjacency-sid-label" or name == "adjacency-sid-protected" or name == "adjacency-sid-unprotected-label" or name == "interface-name" or name == "interface-type" or name == "last-oob-time" or name == "lfa-interface" or name == "lfa-neighbor-id" or name == "lfa-neighbor-revision" or name == "lfa-next-hop" or name == "neighbor-ack-list-count" or name == "neighbor-ack-list-high-watermark" or name == "neighbor-address" or name == "neighbor-area-id" or name == "neighbor-backup-designated-router-address" or name == "neighbor-cost" or name == "neighbor-designated-router-address" or name == "neighbor-filter" or name == "neighbor-lls-option" or name == "neighbor-option" or name == "next-poll-interval" or name == "nsf-router-state" or name == "oob-resynchronization" or name == "pending-events" or name == "poll-interval" or name == "state-change-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "adjacency-sid-label"):
                                        self.adjacency_sid_label = value
                                        self.adjacency_sid_label.value_namespace = name_space
                                        self.adjacency_sid_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "adjacency-sid-protected"):
                                        self.adjacency_sid_protected = value
                                        self.adjacency_sid_protected.value_namespace = name_space
                                        self.adjacency_sid_protected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "adjacency-sid-unprotected-label"):
                                        self.adjacency_sid_unprotected_label = value
                                        self.adjacency_sid_unprotected_label.value_namespace = name_space
                                        self.adjacency_sid_unprotected_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-type"):
                                        self.interface_type = value
                                        self.interface_type.value_namespace = name_space
                                        self.interface_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-oob-time"):
                                        self.last_oob_time = value
                                        self.last_oob_time.value_namespace = name_space
                                        self.last_oob_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lfa-interface"):
                                        self.lfa_interface = value
                                        self.lfa_interface.value_namespace = name_space
                                        self.lfa_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lfa-neighbor-id"):
                                        self.lfa_neighbor_id = value
                                        self.lfa_neighbor_id.value_namespace = name_space
                                        self.lfa_neighbor_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lfa-neighbor-revision"):
                                        self.lfa_neighbor_revision = value
                                        self.lfa_neighbor_revision.value_namespace = name_space
                                        self.lfa_neighbor_revision.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lfa-next-hop"):
                                        self.lfa_next_hop = value
                                        self.lfa_next_hop.value_namespace = name_space
                                        self.lfa_next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-ack-list-count"):
                                        self.neighbor_ack_list_count = value
                                        self.neighbor_ack_list_count.value_namespace = name_space
                                        self.neighbor_ack_list_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-ack-list-high-watermark"):
                                        self.neighbor_ack_list_high_watermark = value
                                        self.neighbor_ack_list_high_watermark.value_namespace = name_space
                                        self.neighbor_ack_list_high_watermark.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-address"):
                                        self.neighbor_address = value
                                        self.neighbor_address.value_namespace = name_space
                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-area-id"):
                                        self.neighbor_area_id = value
                                        self.neighbor_area_id.value_namespace = name_space
                                        self.neighbor_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-backup-designated-router-address"):
                                        self.neighbor_backup_designated_router_address = value
                                        self.neighbor_backup_designated_router_address.value_namespace = name_space
                                        self.neighbor_backup_designated_router_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-cost"):
                                        self.neighbor_cost = value
                                        self.neighbor_cost.value_namespace = name_space
                                        self.neighbor_cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-designated-router-address"):
                                        self.neighbor_designated_router_address = value
                                        self.neighbor_designated_router_address.value_namespace = name_space
                                        self.neighbor_designated_router_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-filter"):
                                        self.neighbor_filter = value
                                        self.neighbor_filter.value_namespace = name_space
                                        self.neighbor_filter.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-lls-option"):
                                        self.neighbor_lls_option = value
                                        self.neighbor_lls_option.value_namespace = name_space
                                        self.neighbor_lls_option.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-option"):
                                        self.neighbor_option = value
                                        self.neighbor_option.value_namespace = name_space
                                        self.neighbor_option.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-poll-interval"):
                                        self.next_poll_interval = value
                                        self.next_poll_interval.value_namespace = name_space
                                        self.next_poll_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsf-router-state"):
                                        self.nsf_router_state = value
                                        self.nsf_router_state.value_namespace = name_space
                                        self.nsf_router_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "oob-resynchronization"):
                                        self.oob_resynchronization = value
                                        self.oob_resynchronization.value_namespace = name_space
                                        self.oob_resynchronization.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pending-events"):
                                        self.pending_events = value
                                        self.pending_events.value_namespace = name_space
                                        self.pending_events.value_namespace_prefix = name_space_prefix
                                    if(value_path == "poll-interval"):
                                        self.poll_interval = value
                                        self.poll_interval.value_namespace = name_space
                                        self.poll_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state-change-count"):
                                        self.state_change_count = value
                                        self.state_change_count.value_namespace = name_space
                                        self.state_change_count.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.neighbor_detail:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.neighbor_detail:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbor-details" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "neighbor-detail"):
                                    for c in self.neighbor_detail:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.neighbor_detail.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "neighbor-detail"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.neighbor_details is not None and self.neighbor_details.has_data()) or
                                (self.neighbors is not None and self.neighbors.has_data()) or
                                (self.requests is not None and self.requests.has_data()) or
                                (self.retransmissions is not None and self.retransmissions.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.neighbor_details is not None and self.neighbor_details.has_operation()) or
                                (self.neighbors is not None and self.neighbors.has_operation()) or
                                (self.requests is not None and self.requests.has_operation()) or
                                (self.retransmissions is not None and self.retransmissions.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "adjacency-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "neighbor-details"):
                                if (self.neighbor_details is None):
                                    self.neighbor_details = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails()
                                    self.neighbor_details.parent = self
                                    self._children_name_map["neighbor_details"] = "neighbor-details"
                                return self.neighbor_details

                            if (child_yang_name == "neighbors"):
                                if (self.neighbors is None):
                                    self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors()
                                    self.neighbors.parent = self
                                    self._children_name_map["neighbors"] = "neighbors"
                                return self.neighbors

                            if (child_yang_name == "requests"):
                                if (self.requests is None):
                                    self.requests = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests()
                                    self.requests.parent = self
                                    self._children_name_map["requests"] = "requests"
                                return self.requests

                            if (child_yang_name == "retransmissions"):
                                if (self.retransmissions is None):
                                    self.retransmissions = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions()
                                    self.retransmissions.parent = self
                                    self._children_name_map["retransmissions"] = "retransmissions"
                                return self.retransmissions

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor-details" or name == "neighbors" or name == "requests" or name == "retransmissions"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class RouteInformation(Entity):
                        """
                        Container for OSPF routing tables
                        
                        .. attribute:: backup_routes
                        
                        	OSPF Route Table Including Backup Paths
                        	**type**\:   :py:class:`BackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes>`
                        
                        .. attribute:: connected_routes
                        
                        	OSPF Connected Route Table
                        	**type**\:   :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes>`
                        
                        .. attribute:: external_routes
                        
                        	OSPF External Route Table
                        	**type**\:   :py:class:`ExternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes>`
                        
                        .. attribute:: local_routes
                        
                        	OSPF Local Route Table
                        	**type**\:   :py:class:`LocalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes>`
                        
                        .. attribute:: multicast_intact_backup_routes
                        
                        	OSPF Route Table Including Multicast intact Backup Paths
                        	**type**\:   :py:class:`MulticastIntactBackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes>`
                        
                        .. attribute:: multicast_intact_route_table
                        
                        	OSPF Route Table including multicast\-intact routes
                        	**type**\:   :py:class:`MulticastIntactRouteTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable>`
                        
                        .. attribute:: route_areas
                        
                        	OSPF Area Route Table
                        	**type**\:   :py:class:`RouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas>`
                        
                        .. attribute:: route_table
                        
                        	OSPF Route Table
                        	**type**\:   :py:class:`RouteTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable>`
                        
                        .. attribute:: summary_information
                        
                        	OSPF route summary statistics
                        	**type**\:   :py:class:`SummaryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation, self).__init__()

                            self.yang_name = "route-information"
                            self.yang_parent_name = "vrf"

                            self.backup_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes()
                            self.backup_routes.parent = self
                            self._children_name_map["backup_routes"] = "backup-routes"
                            self._children_yang_names.add("backup-routes")

                            self.connected_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes()
                            self.connected_routes.parent = self
                            self._children_name_map["connected_routes"] = "connected-routes"
                            self._children_yang_names.add("connected-routes")

                            self.external_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes()
                            self.external_routes.parent = self
                            self._children_name_map["external_routes"] = "external-routes"
                            self._children_yang_names.add("external-routes")

                            self.local_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes()
                            self.local_routes.parent = self
                            self._children_name_map["local_routes"] = "local-routes"
                            self._children_yang_names.add("local-routes")

                            self.multicast_intact_backup_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes()
                            self.multicast_intact_backup_routes.parent = self
                            self._children_name_map["multicast_intact_backup_routes"] = "multicast-intact-backup-routes"
                            self._children_yang_names.add("multicast-intact-backup-routes")

                            self.multicast_intact_route_table = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable()
                            self.multicast_intact_route_table.parent = self
                            self._children_name_map["multicast_intact_route_table"] = "multicast-intact-route-table"
                            self._children_yang_names.add("multicast-intact-route-table")

                            self.route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas()
                            self.route_areas.parent = self
                            self._children_name_map["route_areas"] = "route-areas"
                            self._children_yang_names.add("route-areas")

                            self.route_table = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable()
                            self.route_table.parent = self
                            self._children_name_map["route_table"] = "route-table"
                            self._children_yang_names.add("route-table")

                            self.summary_information = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation()
                            self.summary_information.parent = self
                            self._children_name_map["summary_information"] = "summary-information"
                            self._children_yang_names.add("summary-information")


                        class BackupRoutes(Entity):
                            """
                            OSPF Route Table Including Backup Paths
                            
                            .. attribute:: backup_route
                            
                            	OSPF route including backup paths
                            	**type**\: list of    :py:class:`BackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes, self).__init__()

                                self.yang_name = "backup-routes"
                                self.yang_parent_name = "route-information"

                                self.backup_route = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes, self).__setattr__(name, value)


                            class BackupRoute(Entity):
                                """
                                OSPF route including backup paths
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute, self).__init__()

                                    self.yang_name = "backup-route"
                                    self.yang_parent_name = "backup-routes"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length",
                                                    "route_connected",
                                                    "route_metric",
                                                    "route_prefix",
                                                    "route_prefix_length",
                                                    "route_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute, self).__setattr__(name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "backup-route"

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("route_area_id",
                                                        "route_auto_excluded",
                                                        "route_forward_distance",
                                                        "route_rib_version",
                                                        "route_source",
                                                        "route_spf_priority",
                                                        "route_spf_version",
                                                        "route_srte_nbr_registered",
                                                        "route_srte_prefix_registered",
                                                        "route_te_metric") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo, self).__setattr__(name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-update-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-fail-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.route_area_id.is_set or
                                            self.route_auto_excluded.is_set or
                                            self.route_forward_distance.is_set or
                                            self.route_rib_version.is_set or
                                            self.route_source.is_set or
                                            self.route_spf_priority.is_set or
                                            self.route_spf_version.is_set or
                                            self.route_srte_nbr_registered.is_set or
                                            self.route_srte_prefix_registered.is_set or
                                            self.route_te_metric.is_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                            (self.route_update_time is not None and self.route_update_time.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.route_area_id.yfilter != YFilter.not_set or
                                            self.route_auto_excluded.yfilter != YFilter.not_set or
                                            self.route_forward_distance.yfilter != YFilter.not_set or
                                            self.route_rib_version.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            self.route_spf_priority.yfilter != YFilter.not_set or
                                            self.route_spf_version.yfilter != YFilter.not_set or
                                            self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                            self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                            self.route_te_metric.yfilter != YFilter.not_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                            (self.route_update_time is not None and self.route_update_time.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                        if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                        if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                        if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())
                                        if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                        if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                        if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                        if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                        if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-fail-time"):
                                            if (self.route_fail_time is None):
                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                            return self.route_fail_time

                                        if (child_yang_name == "route-update-time"):
                                            if (self.route_update_time is None):
                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                            return self.route_update_time

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "route-area-id"):
                                            self.route_area_id = value
                                            self.route_area_id.value_namespace = name_space
                                            self.route_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-auto-excluded"):
                                            self.route_auto_excluded = value
                                            self.route_auto_excluded.value_namespace = name_space
                                            self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-forward-distance"):
                                            self.route_forward_distance = value
                                            self.route_forward_distance.value_namespace = name_space
                                            self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-rib-version"):
                                            self.route_rib_version = value
                                            self.route_rib_version.value_namespace = name_space
                                            self.route_rib_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-priority"):
                                            self.route_spf_priority = value
                                            self.route_spf_priority.value_namespace = name_space
                                            self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-version"):
                                            self.route_spf_version = value
                                            self.route_spf_version.value_namespace = name_space
                                            self.route_spf_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-nbr-registered"):
                                            self.route_srte_nbr_registered = value
                                            self.route_srte_nbr_registered.value_namespace = name_space
                                            self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-prefix-registered"):
                                            self.route_srte_prefix_registered = value
                                            self.route_srte_prefix_registered.value_namespace = name_space
                                            self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-te-metric"):
                                            self.route_te_metric = value
                                            self.route_te_metric.value_namespace = name_space
                                            self.route_te_metric.value_namespace_prefix = name_space_prefix


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_backup_path
                                    
                                    	Backup Path Info
                                    	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath>`
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_id
                                    
                                    	Path ID of path
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "backup-route"

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.route_backup_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath()
                                        self.route_backup_path.parent = self
                                        self._children_name_map["route_backup_path"] = "route-backup-path"
                                        self._children_yang_names.add("route-backup-path")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lsa_type",
                                                        "route_interface_name",
                                                        "route_lsaid",
                                                        "route_metric",
                                                        "route_next_hop_address",
                                                        "route_path_id",
                                                        "route_path_is_mcast_intact",
                                                        "route_path_is_ucmp_path",
                                                        "route_source") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath, self).__setattr__(name, value)


                                    class RouteBackupPath(Entity):
                                        """
                                        Backup Path Info
                                        
                                        .. attribute:: backup_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: backup_remote_lfa
                                        
                                        	IP address of remote LFA
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: backup_repair
                                        
                                        	Backup Repair List
                                        	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair>`
                                        
                                        .. attribute:: backup_repair_list_size
                                        
                                        	Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: backup_route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: backup_route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: backup_route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: backup_tunnel_interface_name
                                        
                                        	Backup Tunnel Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: downstream
                                        
                                        	Downstream
                                        	**type**\:  bool
                                        
                                        .. attribute:: line_card_disjoint
                                        
                                        	Line Card Disjoint
                                        	**type**\:  bool
                                        
                                        .. attribute:: node_protect
                                        
                                        	Node Protect
                                        	**type**\:  bool
                                        
                                        .. attribute:: primary_path
                                        
                                        	Primary Path
                                        	**type**\:  bool
                                        
                                        .. attribute:: srlg_disjoint
                                        
                                        	SRLG Disjoint
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath, self).__init__()

                                            self.yang_name = "route-backup-path"
                                            self.yang_parent_name = "route-path"

                                            self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                            self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                            self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                            self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                            self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                            self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                            self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                            self.downstream = YLeaf(YType.boolean, "downstream")

                                            self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                            self.node_protect = YLeaf(YType.boolean, "node-protect")

                                            self.primary_path = YLeaf(YType.boolean, "primary-path")

                                            self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                            self.backup_repair = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("backup_metric",
                                                            "backup_remote_lfa",
                                                            "backup_repair_list_size",
                                                            "backup_route_interface_name",
                                                            "backup_route_next_hop_address",
                                                            "backup_route_source",
                                                            "backup_tunnel_interface_name",
                                                            "downstream",
                                                            "line_card_disjoint",
                                                            "node_protect",
                                                            "primary_path",
                                                            "srlg_disjoint") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath, self).__setattr__(name, value)


                                        class BackupRepair(Entity):
                                            """
                                            Backup Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                                self.yang_name = "backup-repair"
                                                self.yang_parent_name = "route-backup-path"

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("repair_element_id",
                                                                "repair_element_type",
                                                                "repair_label") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.repair_element_id.is_set or
                                                    self.repair_element_type.is_set or
                                                    self.repair_label.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.repair_element_id.yfilter != YFilter.not_set or
                                                    self.repair_element_type.yfilter != YFilter.not_set or
                                                    self.repair_label.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "backup-repair" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "repair-element-id"):
                                                    self.repair_element_id = value
                                                    self.repair_element_id.value_namespace = name_space
                                                    self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-element-type"):
                                                    self.repair_element_type = value
                                                    self.repair_element_type.value_namespace = name_space
                                                    self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-label"):
                                                    self.repair_label = value
                                                    self.repair_label.value_namespace = name_space
                                                    self.repair_label.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.backup_repair:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.backup_metric.is_set or
                                                self.backup_remote_lfa.is_set or
                                                self.backup_repair_list_size.is_set or
                                                self.backup_route_interface_name.is_set or
                                                self.backup_route_next_hop_address.is_set or
                                                self.backup_route_source.is_set or
                                                self.backup_tunnel_interface_name.is_set or
                                                self.downstream.is_set or
                                                self.line_card_disjoint.is_set or
                                                self.node_protect.is_set or
                                                self.primary_path.is_set or
                                                self.srlg_disjoint.is_set)

                                        def has_operation(self):
                                            for c in self.backup_repair:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.backup_metric.yfilter != YFilter.not_set or
                                                self.backup_remote_lfa.yfilter != YFilter.not_set or
                                                self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                self.backup_route_interface_name.yfilter != YFilter.not_set or
                                                self.backup_route_next_hop_address.yfilter != YFilter.not_set or
                                                self.backup_route_source.yfilter != YFilter.not_set or
                                                self.backup_tunnel_interface_name.yfilter != YFilter.not_set or
                                                self.downstream.yfilter != YFilter.not_set or
                                                self.line_card_disjoint.yfilter != YFilter.not_set or
                                                self.node_protect.yfilter != YFilter.not_set or
                                                self.primary_path.yfilter != YFilter.not_set or
                                                self.srlg_disjoint.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-backup-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.backup_metric.is_set or self.backup_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_metric.get_name_leafdata())
                                            if (self.backup_remote_lfa.is_set or self.backup_remote_lfa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_remote_lfa.get_name_leafdata())
                                            if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                            if (self.backup_route_interface_name.is_set or self.backup_route_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_route_interface_name.get_name_leafdata())
                                            if (self.backup_route_next_hop_address.is_set or self.backup_route_next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_route_next_hop_address.get_name_leafdata())
                                            if (self.backup_route_source.is_set or self.backup_route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_route_source.get_name_leafdata())
                                            if (self.backup_tunnel_interface_name.is_set or self.backup_tunnel_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_tunnel_interface_name.get_name_leafdata())
                                            if (self.downstream.is_set or self.downstream.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.downstream.get_name_leafdata())
                                            if (self.line_card_disjoint.is_set or self.line_card_disjoint.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.line_card_disjoint.get_name_leafdata())
                                            if (self.node_protect.is_set or self.node_protect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.node_protect.get_name_leafdata())
                                            if (self.primary_path.is_set or self.primary_path.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.primary_path.get_name_leafdata())
                                            if (self.srlg_disjoint.is_set or self.srlg_disjoint.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.srlg_disjoint.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "backup-repair"):
                                                for c in self.backup_repair:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.backup_repair.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "backup-repair" or name == "backup-metric" or name == "backup-remote-lfa" or name == "backup-repair-list-size" or name == "backup-route-interface-name" or name == "backup-route-next-hop-address" or name == "backup-route-source" or name == "backup-tunnel-interface-name" or name == "downstream" or name == "line-card-disjoint" or name == "node-protect" or name == "primary-path" or name == "srlg-disjoint"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "backup-metric"):
                                                self.backup_metric = value
                                                self.backup_metric.value_namespace = name_space
                                                self.backup_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "backup-remote-lfa"):
                                                self.backup_remote_lfa = value
                                                self.backup_remote_lfa.value_namespace = name_space
                                                self.backup_remote_lfa.value_namespace_prefix = name_space_prefix
                                            if(value_path == "backup-repair-list-size"):
                                                self.backup_repair_list_size = value
                                                self.backup_repair_list_size.value_namespace = name_space
                                                self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "backup-route-interface-name"):
                                                self.backup_route_interface_name = value
                                                self.backup_route_interface_name.value_namespace = name_space
                                                self.backup_route_interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "backup-route-next-hop-address"):
                                                self.backup_route_next_hop_address = value
                                                self.backup_route_next_hop_address.value_namespace = name_space
                                                self.backup_route_next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "backup-route-source"):
                                                self.backup_route_source = value
                                                self.backup_route_source.value_namespace = name_space
                                                self.backup_route_source.value_namespace_prefix = name_space_prefix
                                            if(value_path == "backup-tunnel-interface-name"):
                                                self.backup_tunnel_interface_name = value
                                                self.backup_tunnel_interface_name.value_namespace = name_space
                                                self.backup_tunnel_interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "downstream"):
                                                self.downstream = value
                                                self.downstream.value_namespace = name_space
                                                self.downstream.value_namespace_prefix = name_space_prefix
                                            if(value_path == "line-card-disjoint"):
                                                self.line_card_disjoint = value
                                                self.line_card_disjoint.value_namespace = name_space
                                                self.line_card_disjoint.value_namespace_prefix = name_space_prefix
                                            if(value_path == "node-protect"):
                                                self.node_protect = value
                                                self.node_protect.value_namespace = name_space
                                                self.node_protect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "primary-path"):
                                                self.primary_path = value
                                                self.primary_path.value_namespace = name_space
                                                self.primary_path.value_namespace_prefix = name_space_prefix
                                            if(value_path == "srlg-disjoint"):
                                                self.srlg_disjoint = value
                                                self.srlg_disjoint.value_namespace = name_space
                                                self.srlg_disjoint.value_namespace_prefix = name_space_prefix


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("microloop_repair_list_size",
                                                            "microloop_strict_spf",
                                                            "microloop_tunnel_interface_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("repair_element_id",
                                                                "repair_element_type",
                                                                "repair_label") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.repair_element_id.is_set or
                                                    self.repair_element_type.is_set or
                                                    self.repair_label.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.repair_element_id.yfilter != YFilter.not_set or
                                                    self.repair_element_type.yfilter != YFilter.not_set or
                                                    self.repair_label.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "microloop-repair" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "repair-element-id"):
                                                    self.repair_element_id = value
                                                    self.repair_element_id.value_namespace = name_space
                                                    self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-element-type"):
                                                    self.repair_element_type = value
                                                    self.repair_element_type.value_namespace = name_space
                                                    self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-label"):
                                                    self.repair_label = value
                                                    self.repair_label.value_namespace = name_space
                                                    self.repair_label.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.microloop_repair:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.microloop_repair_list_size.is_set or
                                                self.microloop_strict_spf.is_set or
                                                self.microloop_tunnel_interface_name.is_set)

                                        def has_operation(self):
                                            for c in self.microloop_repair:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                            if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                            if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "microloop-repair"):
                                                for c in self.microloop_repair:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.microloop_repair.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "microloop-repair-list-size"):
                                                self.microloop_repair_list_size = value
                                                self.microloop_repair_list_size.value_namespace = name_space
                                                self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-strict-spf"):
                                                self.microloop_strict_spf = value
                                                self.microloop_strict_spf.value_namespace = name_space
                                                self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-tunnel-interface-name"):
                                                self.microloop_tunnel_interface_name = value
                                                self.microloop_tunnel_interface_name.value_namespace = name_space
                                                self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.lsa_type.is_set or
                                            self.route_interface_name.is_set or
                                            self.route_lsaid.is_set or
                                            self.route_metric.is_set or
                                            self.route_next_hop_address.is_set or
                                            self.route_path_id.is_set or
                                            self.route_path_is_mcast_intact.is_set or
                                            self.route_path_is_ucmp_path.is_set or
                                            self.route_source.is_set or
                                            (self.route_backup_path is not None and self.route_backup_path.has_data()) or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lsa_type.yfilter != YFilter.not_set or
                                            self.route_interface_name.yfilter != YFilter.not_set or
                                            self.route_lsaid.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_next_hop_address.yfilter != YFilter.not_set or
                                            self.route_path_id.yfilter != YFilter.not_set or
                                            self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                            self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            (self.route_backup_path is not None and self.route_backup_path.has_operation()) or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                        if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                        if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                        if (self.route_path_id.is_set or self.route_path_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_id.get_name_leafdata())
                                        if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                        if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-backup-path"):
                                            if (self.route_backup_path is None):
                                                self.route_backup_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath()
                                                self.route_backup_path.parent = self
                                                self._children_name_map["route_backup_path"] = "route-backup-path"
                                            return self.route_backup_path

                                        if (child_yang_name == "sr-microloop-avoidance-path"):
                                            if (self.sr_microloop_avoidance_path is None):
                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            return self.sr_microloop_avoidance_path

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-backup-path" or name == "sr-microloop-avoidance-path" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-id" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lsa-type"):
                                            self.lsa_type = value
                                            self.lsa_type.value_namespace = name_space
                                            self.lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-interface-name"):
                                            self.route_interface_name = value
                                            self.route_interface_name.value_namespace = name_space
                                            self.route_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-lsaid"):
                                            self.route_lsaid = value
                                            self.route_lsaid.value_namespace = name_space
                                            self.route_lsaid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-next-hop-address"):
                                            self.route_next_hop_address = value
                                            self.route_next_hop_address.value_namespace = name_space
                                            self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-id"):
                                            self.route_path_id = value
                                            self.route_path_id.value_namespace = name_space
                                            self.route_path_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-mcast-intact"):
                                            self.route_path_is_mcast_intact = value
                                            self.route_path_is_mcast_intact.value_namespace = name_space
                                            self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-ucmp-path"):
                                            self.route_path_is_ucmp_path = value
                                            self.route_path_is_ucmp_path.value_namespace = name_space
                                            self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.route_path:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        self.route_connected.is_set or
                                        self.route_metric.is_set or
                                        self.route_prefix.is_set or
                                        self.route_prefix_length.is_set or
                                        self.route_type.is_set or
                                        (self.route_info is not None and self.route_info.has_data()))

                                def has_operation(self):
                                    for c in self.route_path:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        self.route_connected.yfilter != YFilter.not_set or
                                        self.route_metric.yfilter != YFilter.not_set or
                                        self.route_prefix.yfilter != YFilter.not_set or
                                        self.route_prefix_length.yfilter != YFilter.not_set or
                                        self.route_type.yfilter != YFilter.not_set or
                                        (self.route_info is not None and self.route_info.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "backup-route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                    if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_connected.get_name_leafdata())
                                    if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_metric.get_name_leafdata())
                                    if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                    if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-info"):
                                        if (self.route_info is None):
                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                        return self.route_info

                                    if (child_yang_name == "route-path"):
                                        for c in self.route_path:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.route_path.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-connected"):
                                        self.route_connected = value
                                        self.route_connected.value_namespace = name_space
                                        self.route_connected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-metric"):
                                        self.route_metric = value
                                        self.route_metric.value_namespace = name_space
                                        self.route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix"):
                                        self.route_prefix = value
                                        self.route_prefix.value_namespace = name_space
                                        self.route_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix-length"):
                                        self.route_prefix_length = value
                                        self.route_prefix_length.value_namespace = name_space
                                        self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-type"):
                                        self.route_type = value
                                        self.route_type.value_namespace = name_space
                                        self.route_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.backup_route:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.backup_route:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "backup-routes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "backup-route"):
                                    for c in self.backup_route:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.backup_route.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "backup-route"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class MulticastIntactRouteTable(Entity):
                            """
                            OSPF Route Table including multicast\-intact
                            routes
                            
                            .. attribute:: route
                            
                            	An OSPF route
                            	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable, self).__init__()

                                self.yang_name = "multicast-intact-route-table"
                                self.yang_parent_name = "route-information"

                                self.route = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable, self).__setattr__(name, value)


                            class Route(Entity):
                                """
                                An OSPF route
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route, self).__init__()

                                    self.yang_name = "route"
                                    self.yang_parent_name = "multicast-intact-route-table"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length",
                                                    "route_connected",
                                                    "route_metric",
                                                    "route_prefix",
                                                    "route_prefix_length",
                                                    "route_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route, self).__setattr__(name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "route"

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("route_area_id",
                                                        "route_auto_excluded",
                                                        "route_forward_distance",
                                                        "route_rib_version",
                                                        "route_source",
                                                        "route_spf_priority",
                                                        "route_spf_version",
                                                        "route_srte_nbr_registered",
                                                        "route_srte_prefix_registered",
                                                        "route_te_metric") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo, self).__setattr__(name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-update-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-fail-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.route_area_id.is_set or
                                            self.route_auto_excluded.is_set or
                                            self.route_forward_distance.is_set or
                                            self.route_rib_version.is_set or
                                            self.route_source.is_set or
                                            self.route_spf_priority.is_set or
                                            self.route_spf_version.is_set or
                                            self.route_srte_nbr_registered.is_set or
                                            self.route_srte_prefix_registered.is_set or
                                            self.route_te_metric.is_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                            (self.route_update_time is not None and self.route_update_time.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.route_area_id.yfilter != YFilter.not_set or
                                            self.route_auto_excluded.yfilter != YFilter.not_set or
                                            self.route_forward_distance.yfilter != YFilter.not_set or
                                            self.route_rib_version.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            self.route_spf_priority.yfilter != YFilter.not_set or
                                            self.route_spf_version.yfilter != YFilter.not_set or
                                            self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                            self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                            self.route_te_metric.yfilter != YFilter.not_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                            (self.route_update_time is not None and self.route_update_time.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                        if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                        if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                        if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())
                                        if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                        if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                        if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                        if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                        if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-fail-time"):
                                            if (self.route_fail_time is None):
                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                            return self.route_fail_time

                                        if (child_yang_name == "route-update-time"):
                                            if (self.route_update_time is None):
                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                            return self.route_update_time

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "route-area-id"):
                                            self.route_area_id = value
                                            self.route_area_id.value_namespace = name_space
                                            self.route_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-auto-excluded"):
                                            self.route_auto_excluded = value
                                            self.route_auto_excluded.value_namespace = name_space
                                            self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-forward-distance"):
                                            self.route_forward_distance = value
                                            self.route_forward_distance.value_namespace = name_space
                                            self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-rib-version"):
                                            self.route_rib_version = value
                                            self.route_rib_version.value_namespace = name_space
                                            self.route_rib_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-priority"):
                                            self.route_spf_priority = value
                                            self.route_spf_priority.value_namespace = name_space
                                            self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-version"):
                                            self.route_spf_version = value
                                            self.route_spf_version.value_namespace = name_space
                                            self.route_spf_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-nbr-registered"):
                                            self.route_srte_nbr_registered = value
                                            self.route_srte_nbr_registered.value_namespace = name_space
                                            self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-prefix-registered"):
                                            self.route_srte_prefix_registered = value
                                            self.route_srte_prefix_registered.value_namespace = name_space
                                            self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-te-metric"):
                                            self.route_te_metric = value
                                            self.route_te_metric.value_namespace = name_space
                                            self.route_te_metric.value_namespace_prefix = name_space_prefix


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: area_format
                                    
                                    	Area format IP or uint32
                                    	**type**\:  bool
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "route"

                                        self.area_format = YLeaf(YType.boolean, "area-format")

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("area_format",
                                                        "area_id",
                                                        "lsa_type",
                                                        "route_interface_name",
                                                        "route_lsaid",
                                                        "route_metric",
                                                        "route_next_hop_address",
                                                        "route_path_is_mcast_intact",
                                                        "route_path_is_ucmp_path",
                                                        "route_source") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath, self).__setattr__(name, value)


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("microloop_repair_list_size",
                                                            "microloop_strict_spf",
                                                            "microloop_tunnel_interface_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("repair_element_id",
                                                                "repair_element_type",
                                                                "repair_label") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.repair_element_id.is_set or
                                                    self.repair_element_type.is_set or
                                                    self.repair_label.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.repair_element_id.yfilter != YFilter.not_set or
                                                    self.repair_element_type.yfilter != YFilter.not_set or
                                                    self.repair_label.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "microloop-repair" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "repair-element-id"):
                                                    self.repair_element_id = value
                                                    self.repair_element_id.value_namespace = name_space
                                                    self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-element-type"):
                                                    self.repair_element_type = value
                                                    self.repair_element_type.value_namespace = name_space
                                                    self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-label"):
                                                    self.repair_label = value
                                                    self.repair_label.value_namespace = name_space
                                                    self.repair_label.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.microloop_repair:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.microloop_repair_list_size.is_set or
                                                self.microloop_strict_spf.is_set or
                                                self.microloop_tunnel_interface_name.is_set)

                                        def has_operation(self):
                                            for c in self.microloop_repair:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                            if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                            if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "microloop-repair"):
                                                for c in self.microloop_repair:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.microloop_repair.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "microloop-repair-list-size"):
                                                self.microloop_repair_list_size = value
                                                self.microloop_repair_list_size.value_namespace = name_space
                                                self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-strict-spf"):
                                                self.microloop_strict_spf = value
                                                self.microloop_strict_spf.value_namespace = name_space
                                                self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-tunnel-interface-name"):
                                                self.microloop_tunnel_interface_name = value
                                                self.microloop_tunnel_interface_name.value_namespace = name_space
                                                self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.area_format.is_set or
                                            self.area_id.is_set or
                                            self.lsa_type.is_set or
                                            self.route_interface_name.is_set or
                                            self.route_lsaid.is_set or
                                            self.route_metric.is_set or
                                            self.route_next_hop_address.is_set or
                                            self.route_path_is_mcast_intact.is_set or
                                            self.route_path_is_ucmp_path.is_set or
                                            self.route_source.is_set or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.area_format.yfilter != YFilter.not_set or
                                            self.area_id.yfilter != YFilter.not_set or
                                            self.lsa_type.yfilter != YFilter.not_set or
                                            self.route_interface_name.yfilter != YFilter.not_set or
                                            self.route_lsaid.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_next_hop_address.yfilter != YFilter.not_set or
                                            self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                            self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_format.get_name_leafdata())
                                        if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id.get_name_leafdata())
                                        if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                        if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                        if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                        if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                        if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "sr-microloop-avoidance-path"):
                                            if (self.sr_microloop_avoidance_path is None):
                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            return self.sr_microloop_avoidance_path

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "area-format"):
                                            self.area_format = value
                                            self.area_format.value_namespace = name_space
                                            self.area_format.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-id"):
                                            self.area_id = value
                                            self.area_id.value_namespace = name_space
                                            self.area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-type"):
                                            self.lsa_type = value
                                            self.lsa_type.value_namespace = name_space
                                            self.lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-interface-name"):
                                            self.route_interface_name = value
                                            self.route_interface_name.value_namespace = name_space
                                            self.route_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-lsaid"):
                                            self.route_lsaid = value
                                            self.route_lsaid.value_namespace = name_space
                                            self.route_lsaid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-next-hop-address"):
                                            self.route_next_hop_address = value
                                            self.route_next_hop_address.value_namespace = name_space
                                            self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-mcast-intact"):
                                            self.route_path_is_mcast_intact = value
                                            self.route_path_is_mcast_intact.value_namespace = name_space
                                            self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-ucmp-path"):
                                            self.route_path_is_ucmp_path = value
                                            self.route_path_is_ucmp_path.value_namespace = name_space
                                            self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.route_path:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        self.route_connected.is_set or
                                        self.route_metric.is_set or
                                        self.route_prefix.is_set or
                                        self.route_prefix_length.is_set or
                                        self.route_type.is_set or
                                        (self.route_info is not None and self.route_info.has_data()))

                                def has_operation(self):
                                    for c in self.route_path:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        self.route_connected.yfilter != YFilter.not_set or
                                        self.route_metric.yfilter != YFilter.not_set or
                                        self.route_prefix.yfilter != YFilter.not_set or
                                        self.route_prefix_length.yfilter != YFilter.not_set or
                                        self.route_type.yfilter != YFilter.not_set or
                                        (self.route_info is not None and self.route_info.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                    if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_connected.get_name_leafdata())
                                    if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_metric.get_name_leafdata())
                                    if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                    if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-info"):
                                        if (self.route_info is None):
                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                        return self.route_info

                                    if (child_yang_name == "route-path"):
                                        for c in self.route_path:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.route_path.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-connected"):
                                        self.route_connected = value
                                        self.route_connected.value_namespace = name_space
                                        self.route_connected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-metric"):
                                        self.route_metric = value
                                        self.route_metric.value_namespace = name_space
                                        self.route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix"):
                                        self.route_prefix = value
                                        self.route_prefix.value_namespace = name_space
                                        self.route_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix-length"):
                                        self.route_prefix_length = value
                                        self.route_prefix_length.value_namespace = name_space
                                        self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-type"):
                                        self.route_type = value
                                        self.route_type.value_namespace = name_space
                                        self.route_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.route:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.route:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "multicast-intact-route-table" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "route"):
                                    for c in self.route:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.route.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "route"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class MulticastIntactBackupRoutes(Entity):
                            """
                            OSPF Route Table Including Multicast intact
                            Backup Paths
                            
                            .. attribute:: multicast_intact_backup_route
                            
                            	OSPF route including multicast backup paths
                            	**type**\: list of    :py:class:`MulticastIntactBackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes, self).__init__()

                                self.yang_name = "multicast-intact-backup-routes"
                                self.yang_parent_name = "route-information"

                                self.multicast_intact_backup_route = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes, self).__setattr__(name, value)


                            class MulticastIntactBackupRoute(Entity):
                                """
                                OSPF route including multicast backup paths
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute, self).__init__()

                                    self.yang_name = "multicast-intact-backup-route"
                                    self.yang_parent_name = "multicast-intact-backup-routes"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length",
                                                    "route_connected",
                                                    "route_metric",
                                                    "route_prefix",
                                                    "route_prefix_length",
                                                    "route_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute, self).__setattr__(name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "multicast-intact-backup-route"

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("route_area_id",
                                                        "route_auto_excluded",
                                                        "route_forward_distance",
                                                        "route_rib_version",
                                                        "route_source",
                                                        "route_spf_priority",
                                                        "route_spf_version",
                                                        "route_srte_nbr_registered",
                                                        "route_srte_prefix_registered",
                                                        "route_te_metric") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo, self).__setattr__(name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-update-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-fail-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.route_area_id.is_set or
                                            self.route_auto_excluded.is_set or
                                            self.route_forward_distance.is_set or
                                            self.route_rib_version.is_set or
                                            self.route_source.is_set or
                                            self.route_spf_priority.is_set or
                                            self.route_spf_version.is_set or
                                            self.route_srte_nbr_registered.is_set or
                                            self.route_srte_prefix_registered.is_set or
                                            self.route_te_metric.is_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                            (self.route_update_time is not None and self.route_update_time.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.route_area_id.yfilter != YFilter.not_set or
                                            self.route_auto_excluded.yfilter != YFilter.not_set or
                                            self.route_forward_distance.yfilter != YFilter.not_set or
                                            self.route_rib_version.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            self.route_spf_priority.yfilter != YFilter.not_set or
                                            self.route_spf_version.yfilter != YFilter.not_set or
                                            self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                            self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                            self.route_te_metric.yfilter != YFilter.not_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                            (self.route_update_time is not None and self.route_update_time.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                        if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                        if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                        if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())
                                        if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                        if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                        if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                        if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                        if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-fail-time"):
                                            if (self.route_fail_time is None):
                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                            return self.route_fail_time

                                        if (child_yang_name == "route-update-time"):
                                            if (self.route_update_time is None):
                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                            return self.route_update_time

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "route-area-id"):
                                            self.route_area_id = value
                                            self.route_area_id.value_namespace = name_space
                                            self.route_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-auto-excluded"):
                                            self.route_auto_excluded = value
                                            self.route_auto_excluded.value_namespace = name_space
                                            self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-forward-distance"):
                                            self.route_forward_distance = value
                                            self.route_forward_distance.value_namespace = name_space
                                            self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-rib-version"):
                                            self.route_rib_version = value
                                            self.route_rib_version.value_namespace = name_space
                                            self.route_rib_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-priority"):
                                            self.route_spf_priority = value
                                            self.route_spf_priority.value_namespace = name_space
                                            self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-version"):
                                            self.route_spf_version = value
                                            self.route_spf_version.value_namespace = name_space
                                            self.route_spf_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-nbr-registered"):
                                            self.route_srte_nbr_registered = value
                                            self.route_srte_nbr_registered.value_namespace = name_space
                                            self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-prefix-registered"):
                                            self.route_srte_prefix_registered = value
                                            self.route_srte_prefix_registered.value_namespace = name_space
                                            self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-te-metric"):
                                            self.route_te_metric = value
                                            self.route_te_metric.value_namespace = name_space
                                            self.route_te_metric.value_namespace_prefix = name_space_prefix


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_backup_path
                                    
                                    	Backup Path Info
                                    	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath>`
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_id
                                    
                                    	Path ID of path
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "multicast-intact-backup-route"

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.route_backup_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath()
                                        self.route_backup_path.parent = self
                                        self._children_name_map["route_backup_path"] = "route-backup-path"
                                        self._children_yang_names.add("route-backup-path")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lsa_type",
                                                        "route_interface_name",
                                                        "route_lsaid",
                                                        "route_metric",
                                                        "route_next_hop_address",
                                                        "route_path_id",
                                                        "route_path_is_mcast_intact",
                                                        "route_path_is_ucmp_path",
                                                        "route_source") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath, self).__setattr__(name, value)


                                    class RouteBackupPath(Entity):
                                        """
                                        Backup Path Info
                                        
                                        .. attribute:: backup_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: backup_remote_lfa
                                        
                                        	IP address of remote LFA
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: backup_repair
                                        
                                        	Backup Repair List
                                        	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair>`
                                        
                                        .. attribute:: backup_repair_list_size
                                        
                                        	Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: backup_route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: backup_route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: backup_route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: backup_tunnel_interface_name
                                        
                                        	Backup Tunnel Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: downstream
                                        
                                        	Downstream
                                        	**type**\:  bool
                                        
                                        .. attribute:: line_card_disjoint
                                        
                                        	Line Card Disjoint
                                        	**type**\:  bool
                                        
                                        .. attribute:: node_protect
                                        
                                        	Node Protect
                                        	**type**\:  bool
                                        
                                        .. attribute:: primary_path
                                        
                                        	Primary Path
                                        	**type**\:  bool
                                        
                                        .. attribute:: srlg_disjoint
                                        
                                        	SRLG Disjoint
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath, self).__init__()

                                            self.yang_name = "route-backup-path"
                                            self.yang_parent_name = "route-path"

                                            self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                            self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                            self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                            self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                            self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                            self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                            self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                            self.downstream = YLeaf(YType.boolean, "downstream")

                                            self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                            self.node_protect = YLeaf(YType.boolean, "node-protect")

                                            self.primary_path = YLeaf(YType.boolean, "primary-path")

                                            self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                            self.backup_repair = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("backup_metric",
                                                            "backup_remote_lfa",
                                                            "backup_repair_list_size",
                                                            "backup_route_interface_name",
                                                            "backup_route_next_hop_address",
                                                            "backup_route_source",
                                                            "backup_tunnel_interface_name",
                                                            "downstream",
                                                            "line_card_disjoint",
                                                            "node_protect",
                                                            "primary_path",
                                                            "srlg_disjoint") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath, self).__setattr__(name, value)


                                        class BackupRepair(Entity):
                                            """
                                            Backup Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                                self.yang_name = "backup-repair"
                                                self.yang_parent_name = "route-backup-path"

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("repair_element_id",
                                                                "repair_element_type",
                                                                "repair_label") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.repair_element_id.is_set or
                                                    self.repair_element_type.is_set or
                                                    self.repair_label.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.repair_element_id.yfilter != YFilter.not_set or
                                                    self.repair_element_type.yfilter != YFilter.not_set or
                                                    self.repair_label.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "backup-repair" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "repair-element-id"):
                                                    self.repair_element_id = value
                                                    self.repair_element_id.value_namespace = name_space
                                                    self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-element-type"):
                                                    self.repair_element_type = value
                                                    self.repair_element_type.value_namespace = name_space
                                                    self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-label"):
                                                    self.repair_label = value
                                                    self.repair_label.value_namespace = name_space
                                                    self.repair_label.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.backup_repair:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.backup_metric.is_set or
                                                self.backup_remote_lfa.is_set or
                                                self.backup_repair_list_size.is_set or
                                                self.backup_route_interface_name.is_set or
                                                self.backup_route_next_hop_address.is_set or
                                                self.backup_route_source.is_set or
                                                self.backup_tunnel_interface_name.is_set or
                                                self.downstream.is_set or
                                                self.line_card_disjoint.is_set or
                                                self.node_protect.is_set or
                                                self.primary_path.is_set or
                                                self.srlg_disjoint.is_set)

                                        def has_operation(self):
                                            for c in self.backup_repair:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.backup_metric.yfilter != YFilter.not_set or
                                                self.backup_remote_lfa.yfilter != YFilter.not_set or
                                                self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                self.backup_route_interface_name.yfilter != YFilter.not_set or
                                                self.backup_route_next_hop_address.yfilter != YFilter.not_set or
                                                self.backup_route_source.yfilter != YFilter.not_set or
                                                self.backup_tunnel_interface_name.yfilter != YFilter.not_set or
                                                self.downstream.yfilter != YFilter.not_set or
                                                self.line_card_disjoint.yfilter != YFilter.not_set or
                                                self.node_protect.yfilter != YFilter.not_set or
                                                self.primary_path.yfilter != YFilter.not_set or
                                                self.srlg_disjoint.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-backup-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.backup_metric.is_set or self.backup_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_metric.get_name_leafdata())
                                            if (self.backup_remote_lfa.is_set or self.backup_remote_lfa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_remote_lfa.get_name_leafdata())
                                            if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                            if (self.backup_route_interface_name.is_set or self.backup_route_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_route_interface_name.get_name_leafdata())
                                            if (self.backup_route_next_hop_address.is_set or self.backup_route_next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_route_next_hop_address.get_name_leafdata())
                                            if (self.backup_route_source.is_set or self.backup_route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_route_source.get_name_leafdata())
                                            if (self.backup_tunnel_interface_name.is_set or self.backup_tunnel_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.backup_tunnel_interface_name.get_name_leafdata())
                                            if (self.downstream.is_set or self.downstream.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.downstream.get_name_leafdata())
                                            if (self.line_card_disjoint.is_set or self.line_card_disjoint.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.line_card_disjoint.get_name_leafdata())
                                            if (self.node_protect.is_set or self.node_protect.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.node_protect.get_name_leafdata())
                                            if (self.primary_path.is_set or self.primary_path.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.primary_path.get_name_leafdata())
                                            if (self.srlg_disjoint.is_set or self.srlg_disjoint.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.srlg_disjoint.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "backup-repair"):
                                                for c in self.backup_repair:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.backup_repair.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "backup-repair" or name == "backup-metric" or name == "backup-remote-lfa" or name == "backup-repair-list-size" or name == "backup-route-interface-name" or name == "backup-route-next-hop-address" or name == "backup-route-source" or name == "backup-tunnel-interface-name" or name == "downstream" or name == "line-card-disjoint" or name == "node-protect" or name == "primary-path" or name == "srlg-disjoint"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "backup-metric"):
                                                self.backup_metric = value
                                                self.backup_metric.value_namespace = name_space
                                                self.backup_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "backup-remote-lfa"):
                                                self.backup_remote_lfa = value
                                                self.backup_remote_lfa.value_namespace = name_space
                                                self.backup_remote_lfa.value_namespace_prefix = name_space_prefix
                                            if(value_path == "backup-repair-list-size"):
                                                self.backup_repair_list_size = value
                                                self.backup_repair_list_size.value_namespace = name_space
                                                self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "backup-route-interface-name"):
                                                self.backup_route_interface_name = value
                                                self.backup_route_interface_name.value_namespace = name_space
                                                self.backup_route_interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "backup-route-next-hop-address"):
                                                self.backup_route_next_hop_address = value
                                                self.backup_route_next_hop_address.value_namespace = name_space
                                                self.backup_route_next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "backup-route-source"):
                                                self.backup_route_source = value
                                                self.backup_route_source.value_namespace = name_space
                                                self.backup_route_source.value_namespace_prefix = name_space_prefix
                                            if(value_path == "backup-tunnel-interface-name"):
                                                self.backup_tunnel_interface_name = value
                                                self.backup_tunnel_interface_name.value_namespace = name_space
                                                self.backup_tunnel_interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "downstream"):
                                                self.downstream = value
                                                self.downstream.value_namespace = name_space
                                                self.downstream.value_namespace_prefix = name_space_prefix
                                            if(value_path == "line-card-disjoint"):
                                                self.line_card_disjoint = value
                                                self.line_card_disjoint.value_namespace = name_space
                                                self.line_card_disjoint.value_namespace_prefix = name_space_prefix
                                            if(value_path == "node-protect"):
                                                self.node_protect = value
                                                self.node_protect.value_namespace = name_space
                                                self.node_protect.value_namespace_prefix = name_space_prefix
                                            if(value_path == "primary-path"):
                                                self.primary_path = value
                                                self.primary_path.value_namespace = name_space
                                                self.primary_path.value_namespace_prefix = name_space_prefix
                                            if(value_path == "srlg-disjoint"):
                                                self.srlg_disjoint = value
                                                self.srlg_disjoint.value_namespace = name_space
                                                self.srlg_disjoint.value_namespace_prefix = name_space_prefix


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("microloop_repair_list_size",
                                                            "microloop_strict_spf",
                                                            "microloop_tunnel_interface_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("repair_element_id",
                                                                "repair_element_type",
                                                                "repair_label") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.repair_element_id.is_set or
                                                    self.repair_element_type.is_set or
                                                    self.repair_label.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.repair_element_id.yfilter != YFilter.not_set or
                                                    self.repair_element_type.yfilter != YFilter.not_set or
                                                    self.repair_label.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "microloop-repair" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "repair-element-id"):
                                                    self.repair_element_id = value
                                                    self.repair_element_id.value_namespace = name_space
                                                    self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-element-type"):
                                                    self.repair_element_type = value
                                                    self.repair_element_type.value_namespace = name_space
                                                    self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-label"):
                                                    self.repair_label = value
                                                    self.repair_label.value_namespace = name_space
                                                    self.repair_label.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.microloop_repair:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.microloop_repair_list_size.is_set or
                                                self.microloop_strict_spf.is_set or
                                                self.microloop_tunnel_interface_name.is_set)

                                        def has_operation(self):
                                            for c in self.microloop_repair:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                            if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                            if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "microloop-repair"):
                                                for c in self.microloop_repair:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.microloop_repair.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "microloop-repair-list-size"):
                                                self.microloop_repair_list_size = value
                                                self.microloop_repair_list_size.value_namespace = name_space
                                                self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-strict-spf"):
                                                self.microloop_strict_spf = value
                                                self.microloop_strict_spf.value_namespace = name_space
                                                self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-tunnel-interface-name"):
                                                self.microloop_tunnel_interface_name = value
                                                self.microloop_tunnel_interface_name.value_namespace = name_space
                                                self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.lsa_type.is_set or
                                            self.route_interface_name.is_set or
                                            self.route_lsaid.is_set or
                                            self.route_metric.is_set or
                                            self.route_next_hop_address.is_set or
                                            self.route_path_id.is_set or
                                            self.route_path_is_mcast_intact.is_set or
                                            self.route_path_is_ucmp_path.is_set or
                                            self.route_source.is_set or
                                            (self.route_backup_path is not None and self.route_backup_path.has_data()) or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lsa_type.yfilter != YFilter.not_set or
                                            self.route_interface_name.yfilter != YFilter.not_set or
                                            self.route_lsaid.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_next_hop_address.yfilter != YFilter.not_set or
                                            self.route_path_id.yfilter != YFilter.not_set or
                                            self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                            self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            (self.route_backup_path is not None and self.route_backup_path.has_operation()) or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                        if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                        if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                        if (self.route_path_id.is_set or self.route_path_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_id.get_name_leafdata())
                                        if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                        if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-backup-path"):
                                            if (self.route_backup_path is None):
                                                self.route_backup_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath()
                                                self.route_backup_path.parent = self
                                                self._children_name_map["route_backup_path"] = "route-backup-path"
                                            return self.route_backup_path

                                        if (child_yang_name == "sr-microloop-avoidance-path"):
                                            if (self.sr_microloop_avoidance_path is None):
                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            return self.sr_microloop_avoidance_path

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-backup-path" or name == "sr-microloop-avoidance-path" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-id" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lsa-type"):
                                            self.lsa_type = value
                                            self.lsa_type.value_namespace = name_space
                                            self.lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-interface-name"):
                                            self.route_interface_name = value
                                            self.route_interface_name.value_namespace = name_space
                                            self.route_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-lsaid"):
                                            self.route_lsaid = value
                                            self.route_lsaid.value_namespace = name_space
                                            self.route_lsaid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-next-hop-address"):
                                            self.route_next_hop_address = value
                                            self.route_next_hop_address.value_namespace = name_space
                                            self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-id"):
                                            self.route_path_id = value
                                            self.route_path_id.value_namespace = name_space
                                            self.route_path_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-mcast-intact"):
                                            self.route_path_is_mcast_intact = value
                                            self.route_path_is_mcast_intact.value_namespace = name_space
                                            self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-ucmp-path"):
                                            self.route_path_is_ucmp_path = value
                                            self.route_path_is_ucmp_path.value_namespace = name_space
                                            self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.route_path:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        self.route_connected.is_set or
                                        self.route_metric.is_set or
                                        self.route_prefix.is_set or
                                        self.route_prefix_length.is_set or
                                        self.route_type.is_set or
                                        (self.route_info is not None and self.route_info.has_data()))

                                def has_operation(self):
                                    for c in self.route_path:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        self.route_connected.yfilter != YFilter.not_set or
                                        self.route_metric.yfilter != YFilter.not_set or
                                        self.route_prefix.yfilter != YFilter.not_set or
                                        self.route_prefix_length.yfilter != YFilter.not_set or
                                        self.route_type.yfilter != YFilter.not_set or
                                        (self.route_info is not None and self.route_info.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast-intact-backup-route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                    if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_connected.get_name_leafdata())
                                    if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_metric.get_name_leafdata())
                                    if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                    if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-info"):
                                        if (self.route_info is None):
                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                        return self.route_info

                                    if (child_yang_name == "route-path"):
                                        for c in self.route_path:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.route_path.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-connected"):
                                        self.route_connected = value
                                        self.route_connected.value_namespace = name_space
                                        self.route_connected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-metric"):
                                        self.route_metric = value
                                        self.route_metric.value_namespace = name_space
                                        self.route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix"):
                                        self.route_prefix = value
                                        self.route_prefix.value_namespace = name_space
                                        self.route_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix-length"):
                                        self.route_prefix_length = value
                                        self.route_prefix_length.value_namespace = name_space
                                        self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-type"):
                                        self.route_type = value
                                        self.route_type.value_namespace = name_space
                                        self.route_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.multicast_intact_backup_route:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.multicast_intact_backup_route:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "multicast-intact-backup-routes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "multicast-intact-backup-route"):
                                    for c in self.multicast_intact_backup_route:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.multicast_intact_backup_route.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "multicast-intact-backup-route"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SummaryInformation(Entity):
                            """
                            OSPF route summary statistics
                            
                            .. attribute:: common
                            
                            	OSPF route summary Information
                            	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.Common>`
                            
                            .. attribute:: failure_address
                            
                            	Last failed address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: failure_time
                            
                            	Last time failed
                            	**type**\:   :py:class:`FailureTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.FailureTime>`
                            
                            .. attribute:: failures
                            
                            	RIB failure count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation, self).__init__()

                                self.yang_name = "summary-information"
                                self.yang_parent_name = "route-information"

                                self.failure_address = YLeaf(YType.str, "failure-address")

                                self.failures = YLeaf(YType.uint32, "failures")

                                self.common = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.Common()
                                self.common.parent = self
                                self._children_name_map["common"] = "common"
                                self._children_yang_names.add("common")

                                self.failure_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.FailureTime()
                                self.failure_time.parent = self
                                self._children_name_map["failure_time"] = "failure-time"
                                self._children_yang_names.add("failure-time")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("failure_address",
                                                "failures") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation, self).__setattr__(name, value)


                            class FailureTime(Entity):
                                """
                                Last time failed
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.FailureTime, self).__init__()

                                    self.yang_name = "failure-time"
                                    self.yang_parent_name = "summary-information"

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nanosecond",
                                                    "second") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.FailureTime, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.FailureTime, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nanosecond.is_set or
                                        self.second.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nanosecond.yfilter != YFilter.not_set or
                                        self.second.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "failure-time" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.second.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nanosecond" or name == "second"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nanosecond"):
                                        self.nanosecond = value
                                        self.nanosecond.value_namespace = name_space
                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                    if(value_path == "second"):
                                        self.second = value
                                        self.second.value_namespace = name_space
                                        self.second.value_namespace_prefix = name_space_prefix


                            class Common(Entity):
                                """
                                OSPF route summary Information
                                
                                .. attribute:: external_nssa_type1s
                                
                                	External NSSA type 1 count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_nssa_type2s
                                
                                	External NSSA type 2 count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_type1s
                                
                                	External type 1 count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_type2s
                                
                                	External type 2 count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_areas
                                
                                	Inter\-area count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_areas
                                
                                	Intra\-area count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total
                                
                                	Total count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.Common, self).__init__()

                                    self.yang_name = "common"
                                    self.yang_parent_name = "summary-information"

                                    self.external_nssa_type1s = YLeaf(YType.uint32, "external-nssa-type1s")

                                    self.external_nssa_type2s = YLeaf(YType.uint32, "external-nssa-type2s")

                                    self.external_type1s = YLeaf(YType.uint32, "external-type1s")

                                    self.external_type2s = YLeaf(YType.uint32, "external-type2s")

                                    self.inter_areas = YLeaf(YType.uint32, "inter-areas")

                                    self.intra_areas = YLeaf(YType.uint32, "intra-areas")

                                    self.total = YLeaf(YType.uint32, "total")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("external_nssa_type1s",
                                                    "external_nssa_type2s",
                                                    "external_type1s",
                                                    "external_type2s",
                                                    "inter_areas",
                                                    "intra_areas",
                                                    "total") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.Common, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.Common, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.external_nssa_type1s.is_set or
                                        self.external_nssa_type2s.is_set or
                                        self.external_type1s.is_set or
                                        self.external_type2s.is_set or
                                        self.inter_areas.is_set or
                                        self.intra_areas.is_set or
                                        self.total.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.external_nssa_type1s.yfilter != YFilter.not_set or
                                        self.external_nssa_type2s.yfilter != YFilter.not_set or
                                        self.external_type1s.yfilter != YFilter.not_set or
                                        self.external_type2s.yfilter != YFilter.not_set or
                                        self.inter_areas.yfilter != YFilter.not_set or
                                        self.intra_areas.yfilter != YFilter.not_set or
                                        self.total.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "common" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.external_nssa_type1s.is_set or self.external_nssa_type1s.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.external_nssa_type1s.get_name_leafdata())
                                    if (self.external_nssa_type2s.is_set or self.external_nssa_type2s.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.external_nssa_type2s.get_name_leafdata())
                                    if (self.external_type1s.is_set or self.external_type1s.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.external_type1s.get_name_leafdata())
                                    if (self.external_type2s.is_set or self.external_type2s.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.external_type2s.get_name_leafdata())
                                    if (self.inter_areas.is_set or self.inter_areas.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.inter_areas.get_name_leafdata())
                                    if (self.intra_areas.is_set or self.intra_areas.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.intra_areas.get_name_leafdata())
                                    if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.total.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "external-nssa-type1s" or name == "external-nssa-type2s" or name == "external-type1s" or name == "external-type2s" or name == "inter-areas" or name == "intra-areas" or name == "total"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "external-nssa-type1s"):
                                        self.external_nssa_type1s = value
                                        self.external_nssa_type1s.value_namespace = name_space
                                        self.external_nssa_type1s.value_namespace_prefix = name_space_prefix
                                    if(value_path == "external-nssa-type2s"):
                                        self.external_nssa_type2s = value
                                        self.external_nssa_type2s.value_namespace = name_space
                                        self.external_nssa_type2s.value_namespace_prefix = name_space_prefix
                                    if(value_path == "external-type1s"):
                                        self.external_type1s = value
                                        self.external_type1s.value_namespace = name_space
                                        self.external_type1s.value_namespace_prefix = name_space_prefix
                                    if(value_path == "external-type2s"):
                                        self.external_type2s = value
                                        self.external_type2s.value_namespace = name_space
                                        self.external_type2s.value_namespace_prefix = name_space_prefix
                                    if(value_path == "inter-areas"):
                                        self.inter_areas = value
                                        self.inter_areas.value_namespace = name_space
                                        self.inter_areas.value_namespace_prefix = name_space_prefix
                                    if(value_path == "intra-areas"):
                                        self.intra_areas = value
                                        self.intra_areas.value_namespace = name_space
                                        self.intra_areas.value_namespace_prefix = name_space_prefix
                                    if(value_path == "total"):
                                        self.total = value
                                        self.total.value_namespace = name_space
                                        self.total.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.failure_address.is_set or
                                    self.failures.is_set or
                                    (self.common is not None and self.common.has_data()) or
                                    (self.failure_time is not None and self.failure_time.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.failure_address.yfilter != YFilter.not_set or
                                    self.failures.yfilter != YFilter.not_set or
                                    (self.common is not None and self.common.has_operation()) or
                                    (self.failure_time is not None and self.failure_time.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "summary-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.failure_address.is_set or self.failure_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.failure_address.get_name_leafdata())
                                if (self.failures.is_set or self.failures.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.failures.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "common"):
                                    if (self.common is None):
                                        self.common = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.Common()
                                        self.common.parent = self
                                        self._children_name_map["common"] = "common"
                                    return self.common

                                if (child_yang_name == "failure-time"):
                                    if (self.failure_time is None):
                                        self.failure_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.FailureTime()
                                        self.failure_time.parent = self
                                        self._children_name_map["failure_time"] = "failure-time"
                                    return self.failure_time

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "common" or name == "failure-time" or name == "failure-address" or name == "failures"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "failure-address"):
                                    self.failure_address = value
                                    self.failure_address.value_namespace = name_space
                                    self.failure_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "failures"):
                                    self.failures = value
                                    self.failures.value_namespace = name_space
                                    self.failures.value_namespace_prefix = name_space_prefix


                        class ConnectedRoutes(Entity):
                            """
                            OSPF Connected Route Table
                            
                            .. attribute:: connected_route
                            
                            	Connected route
                            	**type**\: list of    :py:class:`ConnectedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes, self).__init__()

                                self.yang_name = "connected-routes"
                                self.yang_parent_name = "route-information"

                                self.connected_route = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes, self).__setattr__(name, value)


                            class ConnectedRoute(Entity):
                                """
                                Connected route
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute, self).__init__()

                                    self.yang_name = "connected-route"
                                    self.yang_parent_name = "connected-routes"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length",
                                                    "route_connected",
                                                    "route_metric",
                                                    "route_prefix",
                                                    "route_prefix_length",
                                                    "route_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute, self).__setattr__(name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "connected-route"

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("route_area_id",
                                                        "route_auto_excluded",
                                                        "route_forward_distance",
                                                        "route_rib_version",
                                                        "route_source",
                                                        "route_spf_priority",
                                                        "route_spf_version",
                                                        "route_srte_nbr_registered",
                                                        "route_srte_prefix_registered",
                                                        "route_te_metric") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo, self).__setattr__(name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-update-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-fail-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.route_area_id.is_set or
                                            self.route_auto_excluded.is_set or
                                            self.route_forward_distance.is_set or
                                            self.route_rib_version.is_set or
                                            self.route_source.is_set or
                                            self.route_spf_priority.is_set or
                                            self.route_spf_version.is_set or
                                            self.route_srte_nbr_registered.is_set or
                                            self.route_srte_prefix_registered.is_set or
                                            self.route_te_metric.is_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                            (self.route_update_time is not None and self.route_update_time.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.route_area_id.yfilter != YFilter.not_set or
                                            self.route_auto_excluded.yfilter != YFilter.not_set or
                                            self.route_forward_distance.yfilter != YFilter.not_set or
                                            self.route_rib_version.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            self.route_spf_priority.yfilter != YFilter.not_set or
                                            self.route_spf_version.yfilter != YFilter.not_set or
                                            self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                            self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                            self.route_te_metric.yfilter != YFilter.not_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                            (self.route_update_time is not None and self.route_update_time.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                        if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                        if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                        if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())
                                        if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                        if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                        if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                        if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                        if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-fail-time"):
                                            if (self.route_fail_time is None):
                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                            return self.route_fail_time

                                        if (child_yang_name == "route-update-time"):
                                            if (self.route_update_time is None):
                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                            return self.route_update_time

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "route-area-id"):
                                            self.route_area_id = value
                                            self.route_area_id.value_namespace = name_space
                                            self.route_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-auto-excluded"):
                                            self.route_auto_excluded = value
                                            self.route_auto_excluded.value_namespace = name_space
                                            self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-forward-distance"):
                                            self.route_forward_distance = value
                                            self.route_forward_distance.value_namespace = name_space
                                            self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-rib-version"):
                                            self.route_rib_version = value
                                            self.route_rib_version.value_namespace = name_space
                                            self.route_rib_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-priority"):
                                            self.route_spf_priority = value
                                            self.route_spf_priority.value_namespace = name_space
                                            self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-version"):
                                            self.route_spf_version = value
                                            self.route_spf_version.value_namespace = name_space
                                            self.route_spf_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-nbr-registered"):
                                            self.route_srte_nbr_registered = value
                                            self.route_srte_nbr_registered.value_namespace = name_space
                                            self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-prefix-registered"):
                                            self.route_srte_prefix_registered = value
                                            self.route_srte_prefix_registered.value_namespace = name_space
                                            self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-te-metric"):
                                            self.route_te_metric = value
                                            self.route_te_metric.value_namespace = name_space
                                            self.route_te_metric.value_namespace_prefix = name_space_prefix


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: area_format
                                    
                                    	Area format IP or uint32
                                    	**type**\:  bool
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "connected-route"

                                        self.area_format = YLeaf(YType.boolean, "area-format")

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("area_format",
                                                        "area_id",
                                                        "lsa_type",
                                                        "route_interface_name",
                                                        "route_lsaid",
                                                        "route_metric",
                                                        "route_next_hop_address",
                                                        "route_path_is_mcast_intact",
                                                        "route_path_is_ucmp_path",
                                                        "route_source") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath, self).__setattr__(name, value)


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("microloop_repair_list_size",
                                                            "microloop_strict_spf",
                                                            "microloop_tunnel_interface_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("repair_element_id",
                                                                "repair_element_type",
                                                                "repair_label") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.repair_element_id.is_set or
                                                    self.repair_element_type.is_set or
                                                    self.repair_label.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.repair_element_id.yfilter != YFilter.not_set or
                                                    self.repair_element_type.yfilter != YFilter.not_set or
                                                    self.repair_label.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "microloop-repair" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "repair-element-id"):
                                                    self.repair_element_id = value
                                                    self.repair_element_id.value_namespace = name_space
                                                    self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-element-type"):
                                                    self.repair_element_type = value
                                                    self.repair_element_type.value_namespace = name_space
                                                    self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-label"):
                                                    self.repair_label = value
                                                    self.repair_label.value_namespace = name_space
                                                    self.repair_label.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.microloop_repair:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.microloop_repair_list_size.is_set or
                                                self.microloop_strict_spf.is_set or
                                                self.microloop_tunnel_interface_name.is_set)

                                        def has_operation(self):
                                            for c in self.microloop_repair:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                            if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                            if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "microloop-repair"):
                                                for c in self.microloop_repair:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.microloop_repair.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "microloop-repair-list-size"):
                                                self.microloop_repair_list_size = value
                                                self.microloop_repair_list_size.value_namespace = name_space
                                                self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-strict-spf"):
                                                self.microloop_strict_spf = value
                                                self.microloop_strict_spf.value_namespace = name_space
                                                self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-tunnel-interface-name"):
                                                self.microloop_tunnel_interface_name = value
                                                self.microloop_tunnel_interface_name.value_namespace = name_space
                                                self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.area_format.is_set or
                                            self.area_id.is_set or
                                            self.lsa_type.is_set or
                                            self.route_interface_name.is_set or
                                            self.route_lsaid.is_set or
                                            self.route_metric.is_set or
                                            self.route_next_hop_address.is_set or
                                            self.route_path_is_mcast_intact.is_set or
                                            self.route_path_is_ucmp_path.is_set or
                                            self.route_source.is_set or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.area_format.yfilter != YFilter.not_set or
                                            self.area_id.yfilter != YFilter.not_set or
                                            self.lsa_type.yfilter != YFilter.not_set or
                                            self.route_interface_name.yfilter != YFilter.not_set or
                                            self.route_lsaid.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_next_hop_address.yfilter != YFilter.not_set or
                                            self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                            self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_format.get_name_leafdata())
                                        if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id.get_name_leafdata())
                                        if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                        if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                        if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                        if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                        if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "sr-microloop-avoidance-path"):
                                            if (self.sr_microloop_avoidance_path is None):
                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            return self.sr_microloop_avoidance_path

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "area-format"):
                                            self.area_format = value
                                            self.area_format.value_namespace = name_space
                                            self.area_format.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-id"):
                                            self.area_id = value
                                            self.area_id.value_namespace = name_space
                                            self.area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-type"):
                                            self.lsa_type = value
                                            self.lsa_type.value_namespace = name_space
                                            self.lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-interface-name"):
                                            self.route_interface_name = value
                                            self.route_interface_name.value_namespace = name_space
                                            self.route_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-lsaid"):
                                            self.route_lsaid = value
                                            self.route_lsaid.value_namespace = name_space
                                            self.route_lsaid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-next-hop-address"):
                                            self.route_next_hop_address = value
                                            self.route_next_hop_address.value_namespace = name_space
                                            self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-mcast-intact"):
                                            self.route_path_is_mcast_intact = value
                                            self.route_path_is_mcast_intact.value_namespace = name_space
                                            self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-ucmp-path"):
                                            self.route_path_is_ucmp_path = value
                                            self.route_path_is_ucmp_path.value_namespace = name_space
                                            self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.route_path:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        self.route_connected.is_set or
                                        self.route_metric.is_set or
                                        self.route_prefix.is_set or
                                        self.route_prefix_length.is_set or
                                        self.route_type.is_set or
                                        (self.route_info is not None and self.route_info.has_data()))

                                def has_operation(self):
                                    for c in self.route_path:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        self.route_connected.yfilter != YFilter.not_set or
                                        self.route_metric.yfilter != YFilter.not_set or
                                        self.route_prefix.yfilter != YFilter.not_set or
                                        self.route_prefix_length.yfilter != YFilter.not_set or
                                        self.route_type.yfilter != YFilter.not_set or
                                        (self.route_info is not None and self.route_info.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "connected-route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                    if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_connected.get_name_leafdata())
                                    if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_metric.get_name_leafdata())
                                    if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                    if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-info"):
                                        if (self.route_info is None):
                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                        return self.route_info

                                    if (child_yang_name == "route-path"):
                                        for c in self.route_path:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.route_path.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-connected"):
                                        self.route_connected = value
                                        self.route_connected.value_namespace = name_space
                                        self.route_connected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-metric"):
                                        self.route_metric = value
                                        self.route_metric.value_namespace = name_space
                                        self.route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix"):
                                        self.route_prefix = value
                                        self.route_prefix.value_namespace = name_space
                                        self.route_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix-length"):
                                        self.route_prefix_length = value
                                        self.route_prefix_length.value_namespace = name_space
                                        self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-type"):
                                        self.route_type = value
                                        self.route_type.value_namespace = name_space
                                        self.route_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.connected_route:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.connected_route:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "connected-routes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "connected-route"):
                                    for c in self.connected_route:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.connected_route.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "connected-route"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class LocalRoutes(Entity):
                            """
                            OSPF Local Route Table
                            
                            .. attribute:: local_route
                            
                            	Local route
                            	**type**\: list of    :py:class:`LocalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes, self).__init__()

                                self.yang_name = "local-routes"
                                self.yang_parent_name = "route-information"

                                self.local_route = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes, self).__setattr__(name, value)


                            class LocalRoute(Entity):
                                """
                                Local route
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute, self).__init__()

                                    self.yang_name = "local-route"
                                    self.yang_parent_name = "local-routes"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length",
                                                    "route_connected",
                                                    "route_metric",
                                                    "route_prefix",
                                                    "route_prefix_length",
                                                    "route_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute, self).__setattr__(name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "local-route"

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("route_area_id",
                                                        "route_auto_excluded",
                                                        "route_forward_distance",
                                                        "route_rib_version",
                                                        "route_source",
                                                        "route_spf_priority",
                                                        "route_spf_version",
                                                        "route_srte_nbr_registered",
                                                        "route_srte_prefix_registered",
                                                        "route_te_metric") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo, self).__setattr__(name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-update-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-fail-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.route_area_id.is_set or
                                            self.route_auto_excluded.is_set or
                                            self.route_forward_distance.is_set or
                                            self.route_rib_version.is_set or
                                            self.route_source.is_set or
                                            self.route_spf_priority.is_set or
                                            self.route_spf_version.is_set or
                                            self.route_srte_nbr_registered.is_set or
                                            self.route_srte_prefix_registered.is_set or
                                            self.route_te_metric.is_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                            (self.route_update_time is not None and self.route_update_time.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.route_area_id.yfilter != YFilter.not_set or
                                            self.route_auto_excluded.yfilter != YFilter.not_set or
                                            self.route_forward_distance.yfilter != YFilter.not_set or
                                            self.route_rib_version.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            self.route_spf_priority.yfilter != YFilter.not_set or
                                            self.route_spf_version.yfilter != YFilter.not_set or
                                            self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                            self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                            self.route_te_metric.yfilter != YFilter.not_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                            (self.route_update_time is not None and self.route_update_time.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                        if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                        if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                        if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())
                                        if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                        if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                        if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                        if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                        if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-fail-time"):
                                            if (self.route_fail_time is None):
                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                            return self.route_fail_time

                                        if (child_yang_name == "route-update-time"):
                                            if (self.route_update_time is None):
                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                            return self.route_update_time

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "route-area-id"):
                                            self.route_area_id = value
                                            self.route_area_id.value_namespace = name_space
                                            self.route_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-auto-excluded"):
                                            self.route_auto_excluded = value
                                            self.route_auto_excluded.value_namespace = name_space
                                            self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-forward-distance"):
                                            self.route_forward_distance = value
                                            self.route_forward_distance.value_namespace = name_space
                                            self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-rib-version"):
                                            self.route_rib_version = value
                                            self.route_rib_version.value_namespace = name_space
                                            self.route_rib_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-priority"):
                                            self.route_spf_priority = value
                                            self.route_spf_priority.value_namespace = name_space
                                            self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-version"):
                                            self.route_spf_version = value
                                            self.route_spf_version.value_namespace = name_space
                                            self.route_spf_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-nbr-registered"):
                                            self.route_srte_nbr_registered = value
                                            self.route_srte_nbr_registered.value_namespace = name_space
                                            self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-prefix-registered"):
                                            self.route_srte_prefix_registered = value
                                            self.route_srte_prefix_registered.value_namespace = name_space
                                            self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-te-metric"):
                                            self.route_te_metric = value
                                            self.route_te_metric.value_namespace = name_space
                                            self.route_te_metric.value_namespace_prefix = name_space_prefix


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: area_format
                                    
                                    	Area format IP or uint32
                                    	**type**\:  bool
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "local-route"

                                        self.area_format = YLeaf(YType.boolean, "area-format")

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("area_format",
                                                        "area_id",
                                                        "lsa_type",
                                                        "route_interface_name",
                                                        "route_lsaid",
                                                        "route_metric",
                                                        "route_next_hop_address",
                                                        "route_path_is_mcast_intact",
                                                        "route_path_is_ucmp_path",
                                                        "route_source") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath, self).__setattr__(name, value)


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("microloop_repair_list_size",
                                                            "microloop_strict_spf",
                                                            "microloop_tunnel_interface_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("repair_element_id",
                                                                "repair_element_type",
                                                                "repair_label") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.repair_element_id.is_set or
                                                    self.repair_element_type.is_set or
                                                    self.repair_label.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.repair_element_id.yfilter != YFilter.not_set or
                                                    self.repair_element_type.yfilter != YFilter.not_set or
                                                    self.repair_label.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "microloop-repair" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "repair-element-id"):
                                                    self.repair_element_id = value
                                                    self.repair_element_id.value_namespace = name_space
                                                    self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-element-type"):
                                                    self.repair_element_type = value
                                                    self.repair_element_type.value_namespace = name_space
                                                    self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-label"):
                                                    self.repair_label = value
                                                    self.repair_label.value_namespace = name_space
                                                    self.repair_label.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.microloop_repair:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.microloop_repair_list_size.is_set or
                                                self.microloop_strict_spf.is_set or
                                                self.microloop_tunnel_interface_name.is_set)

                                        def has_operation(self):
                                            for c in self.microloop_repair:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                            if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                            if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "microloop-repair"):
                                                for c in self.microloop_repair:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.microloop_repair.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "microloop-repair-list-size"):
                                                self.microloop_repair_list_size = value
                                                self.microloop_repair_list_size.value_namespace = name_space
                                                self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-strict-spf"):
                                                self.microloop_strict_spf = value
                                                self.microloop_strict_spf.value_namespace = name_space
                                                self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-tunnel-interface-name"):
                                                self.microloop_tunnel_interface_name = value
                                                self.microloop_tunnel_interface_name.value_namespace = name_space
                                                self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.area_format.is_set or
                                            self.area_id.is_set or
                                            self.lsa_type.is_set or
                                            self.route_interface_name.is_set or
                                            self.route_lsaid.is_set or
                                            self.route_metric.is_set or
                                            self.route_next_hop_address.is_set or
                                            self.route_path_is_mcast_intact.is_set or
                                            self.route_path_is_ucmp_path.is_set or
                                            self.route_source.is_set or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.area_format.yfilter != YFilter.not_set or
                                            self.area_id.yfilter != YFilter.not_set or
                                            self.lsa_type.yfilter != YFilter.not_set or
                                            self.route_interface_name.yfilter != YFilter.not_set or
                                            self.route_lsaid.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_next_hop_address.yfilter != YFilter.not_set or
                                            self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                            self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_format.get_name_leafdata())
                                        if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id.get_name_leafdata())
                                        if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                        if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                        if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                        if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                        if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "sr-microloop-avoidance-path"):
                                            if (self.sr_microloop_avoidance_path is None):
                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            return self.sr_microloop_avoidance_path

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "area-format"):
                                            self.area_format = value
                                            self.area_format.value_namespace = name_space
                                            self.area_format.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-id"):
                                            self.area_id = value
                                            self.area_id.value_namespace = name_space
                                            self.area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-type"):
                                            self.lsa_type = value
                                            self.lsa_type.value_namespace = name_space
                                            self.lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-interface-name"):
                                            self.route_interface_name = value
                                            self.route_interface_name.value_namespace = name_space
                                            self.route_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-lsaid"):
                                            self.route_lsaid = value
                                            self.route_lsaid.value_namespace = name_space
                                            self.route_lsaid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-next-hop-address"):
                                            self.route_next_hop_address = value
                                            self.route_next_hop_address.value_namespace = name_space
                                            self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-mcast-intact"):
                                            self.route_path_is_mcast_intact = value
                                            self.route_path_is_mcast_intact.value_namespace = name_space
                                            self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-ucmp-path"):
                                            self.route_path_is_ucmp_path = value
                                            self.route_path_is_ucmp_path.value_namespace = name_space
                                            self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.route_path:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        self.route_connected.is_set or
                                        self.route_metric.is_set or
                                        self.route_prefix.is_set or
                                        self.route_prefix_length.is_set or
                                        self.route_type.is_set or
                                        (self.route_info is not None and self.route_info.has_data()))

                                def has_operation(self):
                                    for c in self.route_path:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        self.route_connected.yfilter != YFilter.not_set or
                                        self.route_metric.yfilter != YFilter.not_set or
                                        self.route_prefix.yfilter != YFilter.not_set or
                                        self.route_prefix_length.yfilter != YFilter.not_set or
                                        self.route_type.yfilter != YFilter.not_set or
                                        (self.route_info is not None and self.route_info.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                    if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_connected.get_name_leafdata())
                                    if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_metric.get_name_leafdata())
                                    if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                    if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-info"):
                                        if (self.route_info is None):
                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                        return self.route_info

                                    if (child_yang_name == "route-path"):
                                        for c in self.route_path:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.route_path.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-connected"):
                                        self.route_connected = value
                                        self.route_connected.value_namespace = name_space
                                        self.route_connected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-metric"):
                                        self.route_metric = value
                                        self.route_metric.value_namespace = name_space
                                        self.route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix"):
                                        self.route_prefix = value
                                        self.route_prefix.value_namespace = name_space
                                        self.route_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix-length"):
                                        self.route_prefix_length = value
                                        self.route_prefix_length.value_namespace = name_space
                                        self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-type"):
                                        self.route_type = value
                                        self.route_type.value_namespace = name_space
                                        self.route_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.local_route:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.local_route:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-routes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "local-route"):
                                    for c in self.local_route:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.local_route.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-route"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class RouteAreas(Entity):
                            """
                            OSPF Area Route Table
                            
                            .. attribute:: route_area
                            
                            	OSPF Area Route
                            	**type**\: list of    :py:class:`RouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas, self).__init__()

                                self.yang_name = "route-areas"
                                self.yang_parent_name = "route-information"

                                self.route_area = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas, self).__setattr__(name, value)


                            class RouteArea(Entity):
                                """
                                OSPF Area Route
                                
                                .. attribute:: area_id  <key>
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: backup_route_areas
                                
                                	OSPF Route Table Including Backup Paths in an area
                                	**type**\:   :py:class:`BackupRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas>`
                                
                                .. attribute:: connected_route_areas
                                
                                	OSPF Connected Route Table in an area
                                	**type**\:   :py:class:`ConnectedRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas>`
                                
                                .. attribute:: local_route_areas
                                
                                	OSPF Local Route Table
                                	**type**\:   :py:class:`LocalRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas>`
                                
                                .. attribute:: multicast_intact_backup_route_areas
                                
                                	OSPF Route Table Including Multicast Intace Backup Paths in an area
                                	**type**\:   :py:class:`MulticastIntactBackupRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas>`
                                
                                .. attribute:: multicast_intact_route_areas
                                
                                	OSPF Area multicast\-intact included route entry
                                	**type**\:   :py:class:`MulticastIntactRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas>`
                                
                                .. attribute:: route_area_informations
                                
                                	OSPF Area Route Entry
                                	**type**\:   :py:class:`RouteAreaInformations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations>`
                                
                                .. attribute:: summary_area_information
                                
                                	OSPF route summary statistics
                                	**type**\:   :py:class:`SummaryAreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea, self).__init__()

                                    self.yang_name = "route-area"
                                    self.yang_parent_name = "route-areas"

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.backup_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas()
                                    self.backup_route_areas.parent = self
                                    self._children_name_map["backup_route_areas"] = "backup-route-areas"
                                    self._children_yang_names.add("backup-route-areas")

                                    self.connected_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas()
                                    self.connected_route_areas.parent = self
                                    self._children_name_map["connected_route_areas"] = "connected-route-areas"
                                    self._children_yang_names.add("connected-route-areas")

                                    self.local_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas()
                                    self.local_route_areas.parent = self
                                    self._children_name_map["local_route_areas"] = "local-route-areas"
                                    self._children_yang_names.add("local-route-areas")

                                    self.multicast_intact_backup_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas()
                                    self.multicast_intact_backup_route_areas.parent = self
                                    self._children_name_map["multicast_intact_backup_route_areas"] = "multicast-intact-backup-route-areas"
                                    self._children_yang_names.add("multicast-intact-backup-route-areas")

                                    self.multicast_intact_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas()
                                    self.multicast_intact_route_areas.parent = self
                                    self._children_name_map["multicast_intact_route_areas"] = "multicast-intact-route-areas"
                                    self._children_yang_names.add("multicast-intact-route-areas")

                                    self.route_area_informations = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations()
                                    self.route_area_informations.parent = self
                                    self._children_name_map["route_area_informations"] = "route-area-informations"
                                    self._children_yang_names.add("route-area-informations")

                                    self.summary_area_information = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation()
                                    self.summary_area_information.parent = self
                                    self._children_name_map["summary_area_information"] = "summary-area-information"
                                    self._children_yang_names.add("summary-area-information")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea, self).__setattr__(name, value)


                                class MulticastIntactBackupRouteAreas(Entity):
                                    """
                                    OSPF Route Table Including Multicast Intace
                                    Backup Paths in an area
                                    
                                    .. attribute:: multicast_intact_backup_route_area
                                    
                                    	OSPF route including Multicast intact backup paths
                                    	**type**\: list of    :py:class:`MulticastIntactBackupRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas, self).__init__()

                                        self.yang_name = "multicast-intact-backup-route-areas"
                                        self.yang_parent_name = "route-area"

                                        self.multicast_intact_backup_route_area = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas, self).__setattr__(name, value)


                                    class MulticastIntactBackupRouteArea(Entity):
                                        """
                                        OSPF route including Multicast intact backup
                                        paths
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..32
                                        
                                        .. attribute:: route_connected
                                        
                                        	If true, connected route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_info
                                        
                                        	Route information
                                        	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo>`
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_path
                                        
                                        	List of paths to this route
                                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath>`
                                        
                                        .. attribute:: route_prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_type
                                        
                                        	Route type
                                        	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea, self).__init__()

                                            self.yang_name = "multicast-intact-backup-route-area"
                                            self.yang_parent_name = "multicast-intact-backup-route-areas"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.route_connected = YLeaf(YType.boolean, "route-connected")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_prefix = YLeaf(YType.str, "route-prefix")

                                            self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                            self._children_yang_names.add("route-info")

                                            self.route_path = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length",
                                                            "route_connected",
                                                            "route_metric",
                                                            "route_prefix",
                                                            "route_prefix_length",
                                                            "route_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea, self).__setattr__(name, value)


                                        class RouteInfo(Entity):
                                            """
                                            Route information
                                            
                                            .. attribute:: route_area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_auto_excluded
                                            
                                            	If true, exclude from TE paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_fail_time
                                            
                                            	Last time update failed
                                            	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime>`
                                            
                                            .. attribute:: route_forward_distance
                                            
                                            	Forward distance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_rib_version
                                            
                                            	RIB version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_source
                                            
                                            	Protocol source
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_spf_priority
                                            
                                            	SPF priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_spf_version
                                            
                                            	SPF version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_srte_nbr_registered
                                            
                                            	SRTE registered neigbhor count on route
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_srte_prefix_registered
                                            
                                            	If true, SRTE registered prefix route
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_te_metric
                                            
                                            	TE metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_update_time
                                            
                                            	Last time updated
                                            	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo, self).__init__()

                                                self.yang_name = "route-info"
                                                self.yang_parent_name = "multicast-intact-backup-route-area"

                                                self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                                self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                                self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                                self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                                self.route_source = YLeaf(YType.uint16, "route-source")

                                                self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                                self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                                self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                                self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                                self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                                self._children_yang_names.add("route-fail-time")

                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                                self._children_yang_names.add("route-update-time")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("route_area_id",
                                                                "route_auto_excluded",
                                                                "route_forward_distance",
                                                                "route_rib_version",
                                                                "route_source",
                                                                "route_spf_priority",
                                                                "route_spf_version",
                                                                "route_srte_nbr_registered",
                                                                "route_srte_prefix_registered",
                                                                "route_te_metric") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo, self).__setattr__(name, value)


                                            class RouteUpdateTime(Entity):
                                                """
                                                Last time updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                    self.yang_name = "route-update-time"
                                                    self.yang_parent_name = "route-info"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-update-time" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix


                                            class RouteFailTime(Entity):
                                                """
                                                Last time update failed
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                    self.yang_name = "route-fail-time"
                                                    self.yang_parent_name = "route-info"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-fail-time" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.route_area_id.is_set or
                                                    self.route_auto_excluded.is_set or
                                                    self.route_forward_distance.is_set or
                                                    self.route_rib_version.is_set or
                                                    self.route_source.is_set or
                                                    self.route_spf_priority.is_set or
                                                    self.route_spf_version.is_set or
                                                    self.route_srte_nbr_registered.is_set or
                                                    self.route_srte_prefix_registered.is_set or
                                                    self.route_te_metric.is_set or
                                                    (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                                    (self.route_update_time is not None and self.route_update_time.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.route_area_id.yfilter != YFilter.not_set or
                                                    self.route_auto_excluded.yfilter != YFilter.not_set or
                                                    self.route_forward_distance.yfilter != YFilter.not_set or
                                                    self.route_rib_version.yfilter != YFilter.not_set or
                                                    self.route_source.yfilter != YFilter.not_set or
                                                    self.route_spf_priority.yfilter != YFilter.not_set or
                                                    self.route_spf_version.yfilter != YFilter.not_set or
                                                    self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                                    self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                                    self.route_te_metric.yfilter != YFilter.not_set or
                                                    (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                                    (self.route_update_time is not None and self.route_update_time.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-info" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                                if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                                if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                                if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                                if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_source.get_name_leafdata())
                                                if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                                if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                                if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                                if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                                if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-fail-time"):
                                                    if (self.route_fail_time is None):
                                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime()
                                                        self.route_fail_time.parent = self
                                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                                    return self.route_fail_time

                                                if (child_yang_name == "route-update-time"):
                                                    if (self.route_update_time is None):
                                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime()
                                                        self.route_update_time.parent = self
                                                        self._children_name_map["route_update_time"] = "route-update-time"
                                                    return self.route_update_time

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "route-area-id"):
                                                    self.route_area_id = value
                                                    self.route_area_id.value_namespace = name_space
                                                    self.route_area_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-auto-excluded"):
                                                    self.route_auto_excluded = value
                                                    self.route_auto_excluded.value_namespace = name_space
                                                    self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-forward-distance"):
                                                    self.route_forward_distance = value
                                                    self.route_forward_distance.value_namespace = name_space
                                                    self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-rib-version"):
                                                    self.route_rib_version = value
                                                    self.route_rib_version.value_namespace = name_space
                                                    self.route_rib_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-source"):
                                                    self.route_source = value
                                                    self.route_source.value_namespace = name_space
                                                    self.route_source.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-spf-priority"):
                                                    self.route_spf_priority = value
                                                    self.route_spf_priority.value_namespace = name_space
                                                    self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-spf-version"):
                                                    self.route_spf_version = value
                                                    self.route_spf_version.value_namespace = name_space
                                                    self.route_spf_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-srte-nbr-registered"):
                                                    self.route_srte_nbr_registered = value
                                                    self.route_srte_nbr_registered.value_namespace = name_space
                                                    self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-srte-prefix-registered"):
                                                    self.route_srte_prefix_registered = value
                                                    self.route_srte_prefix_registered.value_namespace = name_space
                                                    self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-te-metric"):
                                                    self.route_te_metric = value
                                                    self.route_te_metric.value_namespace = name_space
                                                    self.route_te_metric.value_namespace_prefix = name_space_prefix


                                        class RoutePath(Entity):
                                            """
                                            List of paths to this route
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type, see RFC2328 etc
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_backup_path
                                            
                                            	Backup Path Info
                                            	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath>`
                                            
                                            .. attribute:: route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: route_lsaid
                                            
                                            	LSA ID, see RFC2328
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_path_id
                                            
                                            	Path ID of path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_path_is_mcast_intact
                                            
                                            	Multicast\-intact path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_path_is_ucmp_path
                                            
                                            	UCMP path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sr_microloop_avoidance_path
                                            
                                            	SR Microloop avoidance Path Info
                                            	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath, self).__init__()

                                                self.yang_name = "route-path"
                                                self.yang_parent_name = "multicast-intact-backup-route-area"

                                                self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                                self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                                self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                                self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                                self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                                self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                                self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                                self.route_source = YLeaf(YType.str, "route-source")

                                                self.route_backup_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath()
                                                self.route_backup_path.parent = self
                                                self._children_name_map["route_backup_path"] = "route-backup-path"
                                                self._children_yang_names.add("route-backup-path")

                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                self._children_yang_names.add("sr-microloop-avoidance-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lsa_type",
                                                                "route_interface_name",
                                                                "route_lsaid",
                                                                "route_metric",
                                                                "route_next_hop_address",
                                                                "route_path_id",
                                                                "route_path_is_mcast_intact",
                                                                "route_path_is_ucmp_path",
                                                                "route_source") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath, self).__setattr__(name, value)


                                            class RouteBackupPath(Entity):
                                                """
                                                Backup Path Info
                                                
                                                .. attribute:: backup_metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_remote_lfa
                                                
                                                	IP address of remote LFA
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_route_interface_name
                                                
                                                	Next hop Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: backup_route_next_hop_address
                                                
                                                	Nexthop IP address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: backup_route_source
                                                
                                                	IP address of source of route
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: backup_tunnel_interface_name
                                                
                                                	Backup Tunnel Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: downstream
                                                
                                                	Downstream
                                                	**type**\:  bool
                                                
                                                .. attribute:: line_card_disjoint
                                                
                                                	Line Card Disjoint
                                                	**type**\:  bool
                                                
                                                .. attribute:: node_protect
                                                
                                                	Node Protect
                                                	**type**\:  bool
                                                
                                                .. attribute:: primary_path
                                                
                                                	Primary Path
                                                	**type**\:  bool
                                                
                                                .. attribute:: srlg_disjoint
                                                
                                                	SRLG Disjoint
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath, self).__init__()

                                                    self.yang_name = "route-backup-path"
                                                    self.yang_parent_name = "route-path"

                                                    self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                                    self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                                    self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                                    self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                                    self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                                    self.downstream = YLeaf(YType.boolean, "downstream")

                                                    self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                                    self.node_protect = YLeaf(YType.boolean, "node-protect")

                                                    self.primary_path = YLeaf(YType.boolean, "primary-path")

                                                    self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                                    self.backup_repair = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_metric",
                                                                    "backup_remote_lfa",
                                                                    "backup_repair_list_size",
                                                                    "backup_route_interface_name",
                                                                    "backup_route_next_hop_address",
                                                                    "backup_route_source",
                                                                    "backup_tunnel_interface_name",
                                                                    "downstream",
                                                                    "line_card_disjoint",
                                                                    "node_protect",
                                                                    "primary_path",
                                                                    "srlg_disjoint") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath, self).__setattr__(name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "route-backup-path"

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_id",
                                                                        "repair_element_type",
                                                                        "repair_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-id"):
                                                            self.repair_element_id = value
                                                            self.repair_element_id.value_namespace = name_space
                                                            self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_metric.is_set or
                                                        self.backup_remote_lfa.is_set or
                                                        self.backup_repair_list_size.is_set or
                                                        self.backup_route_interface_name.is_set or
                                                        self.backup_route_next_hop_address.is_set or
                                                        self.backup_route_source.is_set or
                                                        self.backup_tunnel_interface_name.is_set or
                                                        self.downstream.is_set or
                                                        self.line_card_disjoint.is_set or
                                                        self.node_protect.is_set or
                                                        self.primary_path.is_set or
                                                        self.srlg_disjoint.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_metric.yfilter != YFilter.not_set or
                                                        self.backup_remote_lfa.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.backup_route_interface_name.yfilter != YFilter.not_set or
                                                        self.backup_route_next_hop_address.yfilter != YFilter.not_set or
                                                        self.backup_route_source.yfilter != YFilter.not_set or
                                                        self.backup_tunnel_interface_name.yfilter != YFilter.not_set or
                                                        self.downstream.yfilter != YFilter.not_set or
                                                        self.line_card_disjoint.yfilter != YFilter.not_set or
                                                        self.node_protect.yfilter != YFilter.not_set or
                                                        self.primary_path.yfilter != YFilter.not_set or
                                                        self.srlg_disjoint.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-backup-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_metric.is_set or self.backup_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_metric.get_name_leafdata())
                                                    if (self.backup_remote_lfa.is_set or self.backup_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_remote_lfa.get_name_leafdata())
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.backup_route_interface_name.is_set or self.backup_route_interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_route_interface_name.get_name_leafdata())
                                                    if (self.backup_route_next_hop_address.is_set or self.backup_route_next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_route_next_hop_address.get_name_leafdata())
                                                    if (self.backup_route_source.is_set or self.backup_route_source.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_route_source.get_name_leafdata())
                                                    if (self.backup_tunnel_interface_name.is_set or self.backup_tunnel_interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_tunnel_interface_name.get_name_leafdata())
                                                    if (self.downstream.is_set or self.downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.downstream.get_name_leafdata())
                                                    if (self.line_card_disjoint.is_set or self.line_card_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.line_card_disjoint.get_name_leafdata())
                                                    if (self.node_protect.is_set or self.node_protect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.node_protect.get_name_leafdata())
                                                    if (self.primary_path.is_set or self.primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.primary_path.get_name_leafdata())
                                                    if (self.srlg_disjoint.is_set or self.srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.srlg_disjoint.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "backup-metric" or name == "backup-remote-lfa" or name == "backup-repair-list-size" or name == "backup-route-interface-name" or name == "backup-route-next-hop-address" or name == "backup-route-source" or name == "backup-tunnel-interface-name" or name == "downstream" or name == "line-card-disjoint" or name == "node-protect" or name == "primary-path" or name == "srlg-disjoint"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-metric"):
                                                        self.backup_metric = value
                                                        self.backup_metric.value_namespace = name_space
                                                        self.backup_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "backup-remote-lfa"):
                                                        self.backup_remote_lfa = value
                                                        self.backup_remote_lfa.value_namespace = name_space
                                                        self.backup_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "backup-route-interface-name"):
                                                        self.backup_route_interface_name = value
                                                        self.backup_route_interface_name.value_namespace = name_space
                                                        self.backup_route_interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "backup-route-next-hop-address"):
                                                        self.backup_route_next_hop_address = value
                                                        self.backup_route_next_hop_address.value_namespace = name_space
                                                        self.backup_route_next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "backup-route-source"):
                                                        self.backup_route_source = value
                                                        self.backup_route_source.value_namespace = name_space
                                                        self.backup_route_source.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "backup-tunnel-interface-name"):
                                                        self.backup_tunnel_interface_name = value
                                                        self.backup_tunnel_interface_name.value_namespace = name_space
                                                        self.backup_tunnel_interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "downstream"):
                                                        self.downstream = value
                                                        self.downstream.value_namespace = name_space
                                                        self.downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "line-card-disjoint"):
                                                        self.line_card_disjoint = value
                                                        self.line_card_disjoint.value_namespace = name_space
                                                        self.line_card_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "node-protect"):
                                                        self.node_protect = value
                                                        self.node_protect.value_namespace = name_space
                                                        self.node_protect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "primary-path"):
                                                        self.primary_path = value
                                                        self.primary_path.value_namespace = name_space
                                                        self.primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "srlg-disjoint"):
                                                        self.srlg_disjoint = value
                                                        self.srlg_disjoint.value_namespace = name_space
                                                        self.srlg_disjoint.value_namespace_prefix = name_space_prefix


                                            class SrMicroloopAvoidancePath(Entity):
                                                """
                                                SR Microloop avoidance Path Info
                                                
                                                .. attribute:: microloop_repair
                                                
                                                	Microloop Repair List
                                                	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                                
                                                .. attribute:: microloop_repair_list_size
                                                
                                                	Microloop Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: microloop_strict_spf
                                                
                                                	Strict SPF SID
                                                	**type**\:  bool
                                                
                                                .. attribute:: microloop_tunnel_interface_name
                                                
                                                	Microloop Tunnel Interface name
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                    self.yang_name = "sr-microloop-avoidance-path"
                                                    self.yang_parent_name = "route-path"

                                                    self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                    self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                    self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                    self.microloop_repair = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("microloop_repair_list_size",
                                                                    "microloop_strict_spf",
                                                                    "microloop_tunnel_interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                                class MicroloopRepair(Entity):
                                                    """
                                                    Microloop Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                        self.yang_name = "microloop-repair"
                                                        self.yang_parent_name = "sr-microloop-avoidance-path"

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_id",
                                                                        "repair_element_type",
                                                                        "repair_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "microloop-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-id"):
                                                            self.repair_element_id = value
                                                            self.repair_element_id.value_namespace = name_space
                                                            self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.microloop_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.microloop_repair_list_size.is_set or
                                                        self.microloop_strict_spf.is_set or
                                                        self.microloop_tunnel_interface_name.is_set)

                                                def has_operation(self):
                                                    for c in self.microloop_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                        self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                        self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                                    if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                                    if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "microloop-repair"):
                                                        for c in self.microloop_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.microloop_repair.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "microloop-repair-list-size"):
                                                        self.microloop_repair_list_size = value
                                                        self.microloop_repair_list_size.value_namespace = name_space
                                                        self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "microloop-strict-spf"):
                                                        self.microloop_strict_spf = value
                                                        self.microloop_strict_spf.value_namespace = name_space
                                                        self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "microloop-tunnel-interface-name"):
                                                        self.microloop_tunnel_interface_name = value
                                                        self.microloop_tunnel_interface_name.value_namespace = name_space
                                                        self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.lsa_type.is_set or
                                                    self.route_interface_name.is_set or
                                                    self.route_lsaid.is_set or
                                                    self.route_metric.is_set or
                                                    self.route_next_hop_address.is_set or
                                                    self.route_path_id.is_set or
                                                    self.route_path_is_mcast_intact.is_set or
                                                    self.route_path_is_ucmp_path.is_set or
                                                    self.route_source.is_set or
                                                    (self.route_backup_path is not None and self.route_backup_path.has_data()) or
                                                    (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lsa_type.yfilter != YFilter.not_set or
                                                    self.route_interface_name.yfilter != YFilter.not_set or
                                                    self.route_lsaid.yfilter != YFilter.not_set or
                                                    self.route_metric.yfilter != YFilter.not_set or
                                                    self.route_next_hop_address.yfilter != YFilter.not_set or
                                                    self.route_path_id.yfilter != YFilter.not_set or
                                                    self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                                    self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                                    self.route_source.yfilter != YFilter.not_set or
                                                    (self.route_backup_path is not None and self.route_backup_path.has_operation()) or
                                                    (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                                if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                                if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                                if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_metric.get_name_leafdata())
                                                if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                                if (self.route_path_id.is_set or self.route_path_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_id.get_name_leafdata())
                                                if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                                if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                                if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_source.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-backup-path"):
                                                    if (self.route_backup_path is None):
                                                        self.route_backup_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath()
                                                        self.route_backup_path.parent = self
                                                        self._children_name_map["route_backup_path"] = "route-backup-path"
                                                    return self.route_backup_path

                                                if (child_yang_name == "sr-microloop-avoidance-path"):
                                                    if (self.sr_microloop_avoidance_path is None):
                                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                        self.sr_microloop_avoidance_path.parent = self
                                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                    return self.sr_microloop_avoidance_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-backup-path" or name == "sr-microloop-avoidance-path" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-id" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lsa-type"):
                                                    self.lsa_type = value
                                                    self.lsa_type.value_namespace = name_space
                                                    self.lsa_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-interface-name"):
                                                    self.route_interface_name = value
                                                    self.route_interface_name.value_namespace = name_space
                                                    self.route_interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-lsaid"):
                                                    self.route_lsaid = value
                                                    self.route_lsaid.value_namespace = name_space
                                                    self.route_lsaid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-metric"):
                                                    self.route_metric = value
                                                    self.route_metric.value_namespace = name_space
                                                    self.route_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-next-hop-address"):
                                                    self.route_next_hop_address = value
                                                    self.route_next_hop_address.value_namespace = name_space
                                                    self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-id"):
                                                    self.route_path_id = value
                                                    self.route_path_id.value_namespace = name_space
                                                    self.route_path_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-is-mcast-intact"):
                                                    self.route_path_is_mcast_intact = value
                                                    self.route_path_is_mcast_intact.value_namespace = name_space
                                                    self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-is-ucmp-path"):
                                                    self.route_path_is_ucmp_path = value
                                                    self.route_path_is_ucmp_path.value_namespace = name_space
                                                    self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-source"):
                                                    self.route_source = value
                                                    self.route_source.value_namespace = name_space
                                                    self.route_source.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.route_path:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set or
                                                self.route_connected.is_set or
                                                self.route_metric.is_set or
                                                self.route_prefix.is_set or
                                                self.route_prefix_length.is_set or
                                                self.route_type.is_set or
                                                (self.route_info is not None and self.route_info.has_data()))

                                        def has_operation(self):
                                            for c in self.route_path:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set or
                                                self.route_connected.yfilter != YFilter.not_set or
                                                self.route_metric.yfilter != YFilter.not_set or
                                                self.route_prefix.yfilter != YFilter.not_set or
                                                self.route_prefix_length.yfilter != YFilter.not_set or
                                                self.route_type.yfilter != YFilter.not_set or
                                                (self.route_info is not None and self.route_info.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-intact-backup-route-area" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                            if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_connected.get_name_leafdata())
                                            if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_metric.get_name_leafdata())
                                            if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                            if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-info"):
                                                if (self.route_info is None):
                                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo()
                                                    self.route_info.parent = self
                                                    self._children_name_map["route_info"] = "route-info"
                                                return self.route_info

                                            if (child_yang_name == "route-path"):
                                                for c in self.route_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.route_path.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-connected"):
                                                self.route_connected = value
                                                self.route_connected.value_namespace = name_space
                                                self.route_connected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-metric"):
                                                self.route_metric = value
                                                self.route_metric.value_namespace = name_space
                                                self.route_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-prefix"):
                                                self.route_prefix = value
                                                self.route_prefix.value_namespace = name_space
                                                self.route_prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-prefix-length"):
                                                self.route_prefix_length = value
                                                self.route_prefix_length.value_namespace = name_space
                                                self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-type"):
                                                self.route_type = value
                                                self.route_type.value_namespace = name_space
                                                self.route_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.multicast_intact_backup_route_area:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.multicast_intact_backup_route_area:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-intact-backup-route-areas" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "multicast-intact-backup-route-area"):
                                            for c in self.multicast_intact_backup_route_area:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.multicast_intact_backup_route_area.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "multicast-intact-backup-route-area"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class ConnectedRouteAreas(Entity):
                                    """
                                    OSPF Connected Route Table in an area
                                    
                                    .. attribute:: connected_route_area
                                    
                                    	Connected route
                                    	**type**\: list of    :py:class:`ConnectedRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas, self).__init__()

                                        self.yang_name = "connected-route-areas"
                                        self.yang_parent_name = "route-area"

                                        self.connected_route_area = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas, self).__setattr__(name, value)


                                    class ConnectedRouteArea(Entity):
                                        """
                                        Connected route
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..32
                                        
                                        .. attribute:: route_connected
                                        
                                        	If true, connected route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_info
                                        
                                        	Route information
                                        	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo>`
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_path
                                        
                                        	List of paths to this route
                                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath>`
                                        
                                        .. attribute:: route_prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_type
                                        
                                        	Route type
                                        	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea, self).__init__()

                                            self.yang_name = "connected-route-area"
                                            self.yang_parent_name = "connected-route-areas"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.route_connected = YLeaf(YType.boolean, "route-connected")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_prefix = YLeaf(YType.str, "route-prefix")

                                            self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                            self._children_yang_names.add("route-info")

                                            self.route_path = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length",
                                                            "route_connected",
                                                            "route_metric",
                                                            "route_prefix",
                                                            "route_prefix_length",
                                                            "route_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea, self).__setattr__(name, value)


                                        class RouteInfo(Entity):
                                            """
                                            Route information
                                            
                                            .. attribute:: route_area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_auto_excluded
                                            
                                            	If true, exclude from TE paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_fail_time
                                            
                                            	Last time update failed
                                            	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime>`
                                            
                                            .. attribute:: route_forward_distance
                                            
                                            	Forward distance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_rib_version
                                            
                                            	RIB version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_source
                                            
                                            	Protocol source
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_spf_priority
                                            
                                            	SPF priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_spf_version
                                            
                                            	SPF version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_srte_nbr_registered
                                            
                                            	SRTE registered neigbhor count on route
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_srte_prefix_registered
                                            
                                            	If true, SRTE registered prefix route
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_te_metric
                                            
                                            	TE metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_update_time
                                            
                                            	Last time updated
                                            	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo, self).__init__()

                                                self.yang_name = "route-info"
                                                self.yang_parent_name = "connected-route-area"

                                                self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                                self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                                self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                                self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                                self.route_source = YLeaf(YType.uint16, "route-source")

                                                self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                                self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                                self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                                self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                                self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                                self._children_yang_names.add("route-fail-time")

                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                                self._children_yang_names.add("route-update-time")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("route_area_id",
                                                                "route_auto_excluded",
                                                                "route_forward_distance",
                                                                "route_rib_version",
                                                                "route_source",
                                                                "route_spf_priority",
                                                                "route_spf_version",
                                                                "route_srte_nbr_registered",
                                                                "route_srte_prefix_registered",
                                                                "route_te_metric") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo, self).__setattr__(name, value)


                                            class RouteUpdateTime(Entity):
                                                """
                                                Last time updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                    self.yang_name = "route-update-time"
                                                    self.yang_parent_name = "route-info"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-update-time" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix


                                            class RouteFailTime(Entity):
                                                """
                                                Last time update failed
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                    self.yang_name = "route-fail-time"
                                                    self.yang_parent_name = "route-info"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-fail-time" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.route_area_id.is_set or
                                                    self.route_auto_excluded.is_set or
                                                    self.route_forward_distance.is_set or
                                                    self.route_rib_version.is_set or
                                                    self.route_source.is_set or
                                                    self.route_spf_priority.is_set or
                                                    self.route_spf_version.is_set or
                                                    self.route_srte_nbr_registered.is_set or
                                                    self.route_srte_prefix_registered.is_set or
                                                    self.route_te_metric.is_set or
                                                    (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                                    (self.route_update_time is not None and self.route_update_time.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.route_area_id.yfilter != YFilter.not_set or
                                                    self.route_auto_excluded.yfilter != YFilter.not_set or
                                                    self.route_forward_distance.yfilter != YFilter.not_set or
                                                    self.route_rib_version.yfilter != YFilter.not_set or
                                                    self.route_source.yfilter != YFilter.not_set or
                                                    self.route_spf_priority.yfilter != YFilter.not_set or
                                                    self.route_spf_version.yfilter != YFilter.not_set or
                                                    self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                                    self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                                    self.route_te_metric.yfilter != YFilter.not_set or
                                                    (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                                    (self.route_update_time is not None and self.route_update_time.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-info" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                                if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                                if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                                if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                                if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_source.get_name_leafdata())
                                                if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                                if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                                if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                                if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                                if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-fail-time"):
                                                    if (self.route_fail_time is None):
                                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime()
                                                        self.route_fail_time.parent = self
                                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                                    return self.route_fail_time

                                                if (child_yang_name == "route-update-time"):
                                                    if (self.route_update_time is None):
                                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime()
                                                        self.route_update_time.parent = self
                                                        self._children_name_map["route_update_time"] = "route-update-time"
                                                    return self.route_update_time

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "route-area-id"):
                                                    self.route_area_id = value
                                                    self.route_area_id.value_namespace = name_space
                                                    self.route_area_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-auto-excluded"):
                                                    self.route_auto_excluded = value
                                                    self.route_auto_excluded.value_namespace = name_space
                                                    self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-forward-distance"):
                                                    self.route_forward_distance = value
                                                    self.route_forward_distance.value_namespace = name_space
                                                    self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-rib-version"):
                                                    self.route_rib_version = value
                                                    self.route_rib_version.value_namespace = name_space
                                                    self.route_rib_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-source"):
                                                    self.route_source = value
                                                    self.route_source.value_namespace = name_space
                                                    self.route_source.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-spf-priority"):
                                                    self.route_spf_priority = value
                                                    self.route_spf_priority.value_namespace = name_space
                                                    self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-spf-version"):
                                                    self.route_spf_version = value
                                                    self.route_spf_version.value_namespace = name_space
                                                    self.route_spf_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-srte-nbr-registered"):
                                                    self.route_srte_nbr_registered = value
                                                    self.route_srte_nbr_registered.value_namespace = name_space
                                                    self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-srte-prefix-registered"):
                                                    self.route_srte_prefix_registered = value
                                                    self.route_srte_prefix_registered.value_namespace = name_space
                                                    self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-te-metric"):
                                                    self.route_te_metric = value
                                                    self.route_te_metric.value_namespace = name_space
                                                    self.route_te_metric.value_namespace_prefix = name_space_prefix


                                        class RoutePath(Entity):
                                            """
                                            List of paths to this route
                                            
                                            .. attribute:: area_format
                                            
                                            	Area format IP or uint32
                                            	**type**\:  bool
                                            
                                            .. attribute:: area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type, see RFC2328 etc
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: route_lsaid
                                            
                                            	LSA ID, see RFC2328
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_path_is_mcast_intact
                                            
                                            	Multicast\-intact path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_path_is_ucmp_path
                                            
                                            	UCMP path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sr_microloop_avoidance_path
                                            
                                            	SR Microloop avoidance Path Info
                                            	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath, self).__init__()

                                                self.yang_name = "route-path"
                                                self.yang_parent_name = "connected-route-area"

                                                self.area_format = YLeaf(YType.boolean, "area-format")

                                                self.area_id = YLeaf(YType.uint32, "area-id")

                                                self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                                self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                                self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                                self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                                self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                                self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                                self.route_source = YLeaf(YType.str, "route-source")

                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                self._children_yang_names.add("sr-microloop-avoidance-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("area_format",
                                                                "area_id",
                                                                "lsa_type",
                                                                "route_interface_name",
                                                                "route_lsaid",
                                                                "route_metric",
                                                                "route_next_hop_address",
                                                                "route_path_is_mcast_intact",
                                                                "route_path_is_ucmp_path",
                                                                "route_source") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath, self).__setattr__(name, value)


                                            class SrMicroloopAvoidancePath(Entity):
                                                """
                                                SR Microloop avoidance Path Info
                                                
                                                .. attribute:: microloop_repair
                                                
                                                	Microloop Repair List
                                                	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                                
                                                .. attribute:: microloop_repair_list_size
                                                
                                                	Microloop Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: microloop_strict_spf
                                                
                                                	Strict SPF SID
                                                	**type**\:  bool
                                                
                                                .. attribute:: microloop_tunnel_interface_name
                                                
                                                	Microloop Tunnel Interface name
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                    self.yang_name = "sr-microloop-avoidance-path"
                                                    self.yang_parent_name = "route-path"

                                                    self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                    self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                    self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                    self.microloop_repair = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("microloop_repair_list_size",
                                                                    "microloop_strict_spf",
                                                                    "microloop_tunnel_interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                                class MicroloopRepair(Entity):
                                                    """
                                                    Microloop Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                        self.yang_name = "microloop-repair"
                                                        self.yang_parent_name = "sr-microloop-avoidance-path"

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_id",
                                                                        "repair_element_type",
                                                                        "repair_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "microloop-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-id"):
                                                            self.repair_element_id = value
                                                            self.repair_element_id.value_namespace = name_space
                                                            self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.microloop_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.microloop_repair_list_size.is_set or
                                                        self.microloop_strict_spf.is_set or
                                                        self.microloop_tunnel_interface_name.is_set)

                                                def has_operation(self):
                                                    for c in self.microloop_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                        self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                        self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                                    if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                                    if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "microloop-repair"):
                                                        for c in self.microloop_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.microloop_repair.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "microloop-repair-list-size"):
                                                        self.microloop_repair_list_size = value
                                                        self.microloop_repair_list_size.value_namespace = name_space
                                                        self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "microloop-strict-spf"):
                                                        self.microloop_strict_spf = value
                                                        self.microloop_strict_spf.value_namespace = name_space
                                                        self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "microloop-tunnel-interface-name"):
                                                        self.microloop_tunnel_interface_name = value
                                                        self.microloop_tunnel_interface_name.value_namespace = name_space
                                                        self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.area_format.is_set or
                                                    self.area_id.is_set or
                                                    self.lsa_type.is_set or
                                                    self.route_interface_name.is_set or
                                                    self.route_lsaid.is_set or
                                                    self.route_metric.is_set or
                                                    self.route_next_hop_address.is_set or
                                                    self.route_path_is_mcast_intact.is_set or
                                                    self.route_path_is_ucmp_path.is_set or
                                                    self.route_source.is_set or
                                                    (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.area_format.yfilter != YFilter.not_set or
                                                    self.area_id.yfilter != YFilter.not_set or
                                                    self.lsa_type.yfilter != YFilter.not_set or
                                                    self.route_interface_name.yfilter != YFilter.not_set or
                                                    self.route_lsaid.yfilter != YFilter.not_set or
                                                    self.route_metric.yfilter != YFilter.not_set or
                                                    self.route_next_hop_address.yfilter != YFilter.not_set or
                                                    self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                                    self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                                    self.route_source.yfilter != YFilter.not_set or
                                                    (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.area_format.get_name_leafdata())
                                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                                if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                                if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                                if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                                if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_metric.get_name_leafdata())
                                                if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                                if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                                if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                                if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_source.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "sr-microloop-avoidance-path"):
                                                    if (self.sr_microloop_avoidance_path is None):
                                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                        self.sr_microloop_avoidance_path.parent = self
                                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                    return self.sr_microloop_avoidance_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "area-format"):
                                                    self.area_format = value
                                                    self.area_format.value_namespace = name_space
                                                    self.area_format.value_namespace_prefix = name_space_prefix
                                                if(value_path == "area-id"):
                                                    self.area_id = value
                                                    self.area_id.value_namespace = name_space
                                                    self.area_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsa-type"):
                                                    self.lsa_type = value
                                                    self.lsa_type.value_namespace = name_space
                                                    self.lsa_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-interface-name"):
                                                    self.route_interface_name = value
                                                    self.route_interface_name.value_namespace = name_space
                                                    self.route_interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-lsaid"):
                                                    self.route_lsaid = value
                                                    self.route_lsaid.value_namespace = name_space
                                                    self.route_lsaid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-metric"):
                                                    self.route_metric = value
                                                    self.route_metric.value_namespace = name_space
                                                    self.route_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-next-hop-address"):
                                                    self.route_next_hop_address = value
                                                    self.route_next_hop_address.value_namespace = name_space
                                                    self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-is-mcast-intact"):
                                                    self.route_path_is_mcast_intact = value
                                                    self.route_path_is_mcast_intact.value_namespace = name_space
                                                    self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-is-ucmp-path"):
                                                    self.route_path_is_ucmp_path = value
                                                    self.route_path_is_ucmp_path.value_namespace = name_space
                                                    self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-source"):
                                                    self.route_source = value
                                                    self.route_source.value_namespace = name_space
                                                    self.route_source.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.route_path:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set or
                                                self.route_connected.is_set or
                                                self.route_metric.is_set or
                                                self.route_prefix.is_set or
                                                self.route_prefix_length.is_set or
                                                self.route_type.is_set or
                                                (self.route_info is not None and self.route_info.has_data()))

                                        def has_operation(self):
                                            for c in self.route_path:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set or
                                                self.route_connected.yfilter != YFilter.not_set or
                                                self.route_metric.yfilter != YFilter.not_set or
                                                self.route_prefix.yfilter != YFilter.not_set or
                                                self.route_prefix_length.yfilter != YFilter.not_set or
                                                self.route_type.yfilter != YFilter.not_set or
                                                (self.route_info is not None and self.route_info.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "connected-route-area" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                            if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_connected.get_name_leafdata())
                                            if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_metric.get_name_leafdata())
                                            if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                            if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-info"):
                                                if (self.route_info is None):
                                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo()
                                                    self.route_info.parent = self
                                                    self._children_name_map["route_info"] = "route-info"
                                                return self.route_info

                                            if (child_yang_name == "route-path"):
                                                for c in self.route_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.route_path.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-connected"):
                                                self.route_connected = value
                                                self.route_connected.value_namespace = name_space
                                                self.route_connected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-metric"):
                                                self.route_metric = value
                                                self.route_metric.value_namespace = name_space
                                                self.route_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-prefix"):
                                                self.route_prefix = value
                                                self.route_prefix.value_namespace = name_space
                                                self.route_prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-prefix-length"):
                                                self.route_prefix_length = value
                                                self.route_prefix_length.value_namespace = name_space
                                                self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-type"):
                                                self.route_type = value
                                                self.route_type.value_namespace = name_space
                                                self.route_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.connected_route_area:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.connected_route_area:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "connected-route-areas" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "connected-route-area"):
                                            for c in self.connected_route_area:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.connected_route_area.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "connected-route-area"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class BackupRouteAreas(Entity):
                                    """
                                    OSPF Route Table Including Backup Paths in an
                                    area
                                    
                                    .. attribute:: backup_route_area
                                    
                                    	OSPF route including backup paths
                                    	**type**\: list of    :py:class:`BackupRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas, self).__init__()

                                        self.yang_name = "backup-route-areas"
                                        self.yang_parent_name = "route-area"

                                        self.backup_route_area = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas, self).__setattr__(name, value)


                                    class BackupRouteArea(Entity):
                                        """
                                        OSPF route including backup paths
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..32
                                        
                                        .. attribute:: route_connected
                                        
                                        	If true, connected route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_info
                                        
                                        	Route information
                                        	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo>`
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_path
                                        
                                        	List of paths to this route
                                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath>`
                                        
                                        .. attribute:: route_prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_type
                                        
                                        	Route type
                                        	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea, self).__init__()

                                            self.yang_name = "backup-route-area"
                                            self.yang_parent_name = "backup-route-areas"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.route_connected = YLeaf(YType.boolean, "route-connected")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_prefix = YLeaf(YType.str, "route-prefix")

                                            self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                            self._children_yang_names.add("route-info")

                                            self.route_path = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length",
                                                            "route_connected",
                                                            "route_metric",
                                                            "route_prefix",
                                                            "route_prefix_length",
                                                            "route_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea, self).__setattr__(name, value)


                                        class RouteInfo(Entity):
                                            """
                                            Route information
                                            
                                            .. attribute:: route_area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_auto_excluded
                                            
                                            	If true, exclude from TE paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_fail_time
                                            
                                            	Last time update failed
                                            	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime>`
                                            
                                            .. attribute:: route_forward_distance
                                            
                                            	Forward distance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_rib_version
                                            
                                            	RIB version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_source
                                            
                                            	Protocol source
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_spf_priority
                                            
                                            	SPF priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_spf_version
                                            
                                            	SPF version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_srte_nbr_registered
                                            
                                            	SRTE registered neigbhor count on route
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_srte_prefix_registered
                                            
                                            	If true, SRTE registered prefix route
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_te_metric
                                            
                                            	TE metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_update_time
                                            
                                            	Last time updated
                                            	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo, self).__init__()

                                                self.yang_name = "route-info"
                                                self.yang_parent_name = "backup-route-area"

                                                self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                                self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                                self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                                self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                                self.route_source = YLeaf(YType.uint16, "route-source")

                                                self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                                self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                                self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                                self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                                self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                                self._children_yang_names.add("route-fail-time")

                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                                self._children_yang_names.add("route-update-time")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("route_area_id",
                                                                "route_auto_excluded",
                                                                "route_forward_distance",
                                                                "route_rib_version",
                                                                "route_source",
                                                                "route_spf_priority",
                                                                "route_spf_version",
                                                                "route_srte_nbr_registered",
                                                                "route_srte_prefix_registered",
                                                                "route_te_metric") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo, self).__setattr__(name, value)


                                            class RouteUpdateTime(Entity):
                                                """
                                                Last time updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                    self.yang_name = "route-update-time"
                                                    self.yang_parent_name = "route-info"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-update-time" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix


                                            class RouteFailTime(Entity):
                                                """
                                                Last time update failed
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                    self.yang_name = "route-fail-time"
                                                    self.yang_parent_name = "route-info"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-fail-time" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.route_area_id.is_set or
                                                    self.route_auto_excluded.is_set or
                                                    self.route_forward_distance.is_set or
                                                    self.route_rib_version.is_set or
                                                    self.route_source.is_set or
                                                    self.route_spf_priority.is_set or
                                                    self.route_spf_version.is_set or
                                                    self.route_srte_nbr_registered.is_set or
                                                    self.route_srte_prefix_registered.is_set or
                                                    self.route_te_metric.is_set or
                                                    (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                                    (self.route_update_time is not None and self.route_update_time.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.route_area_id.yfilter != YFilter.not_set or
                                                    self.route_auto_excluded.yfilter != YFilter.not_set or
                                                    self.route_forward_distance.yfilter != YFilter.not_set or
                                                    self.route_rib_version.yfilter != YFilter.not_set or
                                                    self.route_source.yfilter != YFilter.not_set or
                                                    self.route_spf_priority.yfilter != YFilter.not_set or
                                                    self.route_spf_version.yfilter != YFilter.not_set or
                                                    self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                                    self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                                    self.route_te_metric.yfilter != YFilter.not_set or
                                                    (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                                    (self.route_update_time is not None and self.route_update_time.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-info" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                                if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                                if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                                if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                                if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_source.get_name_leafdata())
                                                if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                                if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                                if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                                if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                                if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-fail-time"):
                                                    if (self.route_fail_time is None):
                                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime()
                                                        self.route_fail_time.parent = self
                                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                                    return self.route_fail_time

                                                if (child_yang_name == "route-update-time"):
                                                    if (self.route_update_time is None):
                                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime()
                                                        self.route_update_time.parent = self
                                                        self._children_name_map["route_update_time"] = "route-update-time"
                                                    return self.route_update_time

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "route-area-id"):
                                                    self.route_area_id = value
                                                    self.route_area_id.value_namespace = name_space
                                                    self.route_area_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-auto-excluded"):
                                                    self.route_auto_excluded = value
                                                    self.route_auto_excluded.value_namespace = name_space
                                                    self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-forward-distance"):
                                                    self.route_forward_distance = value
                                                    self.route_forward_distance.value_namespace = name_space
                                                    self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-rib-version"):
                                                    self.route_rib_version = value
                                                    self.route_rib_version.value_namespace = name_space
                                                    self.route_rib_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-source"):
                                                    self.route_source = value
                                                    self.route_source.value_namespace = name_space
                                                    self.route_source.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-spf-priority"):
                                                    self.route_spf_priority = value
                                                    self.route_spf_priority.value_namespace = name_space
                                                    self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-spf-version"):
                                                    self.route_spf_version = value
                                                    self.route_spf_version.value_namespace = name_space
                                                    self.route_spf_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-srte-nbr-registered"):
                                                    self.route_srte_nbr_registered = value
                                                    self.route_srte_nbr_registered.value_namespace = name_space
                                                    self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-srte-prefix-registered"):
                                                    self.route_srte_prefix_registered = value
                                                    self.route_srte_prefix_registered.value_namespace = name_space
                                                    self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-te-metric"):
                                                    self.route_te_metric = value
                                                    self.route_te_metric.value_namespace = name_space
                                                    self.route_te_metric.value_namespace_prefix = name_space_prefix


                                        class RoutePath(Entity):
                                            """
                                            List of paths to this route
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type, see RFC2328 etc
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_backup_path
                                            
                                            	Backup Path Info
                                            	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath>`
                                            
                                            .. attribute:: route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: route_lsaid
                                            
                                            	LSA ID, see RFC2328
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_path_id
                                            
                                            	Path ID of path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_path_is_mcast_intact
                                            
                                            	Multicast\-intact path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_path_is_ucmp_path
                                            
                                            	UCMP path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sr_microloop_avoidance_path
                                            
                                            	SR Microloop avoidance Path Info
                                            	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath, self).__init__()

                                                self.yang_name = "route-path"
                                                self.yang_parent_name = "backup-route-area"

                                                self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                                self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                                self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                                self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                                self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                                self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                                self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                                self.route_source = YLeaf(YType.str, "route-source")

                                                self.route_backup_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath()
                                                self.route_backup_path.parent = self
                                                self._children_name_map["route_backup_path"] = "route-backup-path"
                                                self._children_yang_names.add("route-backup-path")

                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                self._children_yang_names.add("sr-microloop-avoidance-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lsa_type",
                                                                "route_interface_name",
                                                                "route_lsaid",
                                                                "route_metric",
                                                                "route_next_hop_address",
                                                                "route_path_id",
                                                                "route_path_is_mcast_intact",
                                                                "route_path_is_ucmp_path",
                                                                "route_source") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath, self).__setattr__(name, value)


                                            class RouteBackupPath(Entity):
                                                """
                                                Backup Path Info
                                                
                                                .. attribute:: backup_metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_remote_lfa
                                                
                                                	IP address of remote LFA
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_route_interface_name
                                                
                                                	Next hop Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: backup_route_next_hop_address
                                                
                                                	Nexthop IP address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: backup_route_source
                                                
                                                	IP address of source of route
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: backup_tunnel_interface_name
                                                
                                                	Backup Tunnel Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: downstream
                                                
                                                	Downstream
                                                	**type**\:  bool
                                                
                                                .. attribute:: line_card_disjoint
                                                
                                                	Line Card Disjoint
                                                	**type**\:  bool
                                                
                                                .. attribute:: node_protect
                                                
                                                	Node Protect
                                                	**type**\:  bool
                                                
                                                .. attribute:: primary_path
                                                
                                                	Primary Path
                                                	**type**\:  bool
                                                
                                                .. attribute:: srlg_disjoint
                                                
                                                	SRLG Disjoint
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath, self).__init__()

                                                    self.yang_name = "route-backup-path"
                                                    self.yang_parent_name = "route-path"

                                                    self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                                    self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                                    self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                                    self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                                    self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                                    self.downstream = YLeaf(YType.boolean, "downstream")

                                                    self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                                    self.node_protect = YLeaf(YType.boolean, "node-protect")

                                                    self.primary_path = YLeaf(YType.boolean, "primary-path")

                                                    self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                                    self.backup_repair = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_metric",
                                                                    "backup_remote_lfa",
                                                                    "backup_repair_list_size",
                                                                    "backup_route_interface_name",
                                                                    "backup_route_next_hop_address",
                                                                    "backup_route_source",
                                                                    "backup_tunnel_interface_name",
                                                                    "downstream",
                                                                    "line_card_disjoint",
                                                                    "node_protect",
                                                                    "primary_path",
                                                                    "srlg_disjoint") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath, self).__setattr__(name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "route-backup-path"

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_id",
                                                                        "repair_element_type",
                                                                        "repair_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-id"):
                                                            self.repair_element_id = value
                                                            self.repair_element_id.value_namespace = name_space
                                                            self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_metric.is_set or
                                                        self.backup_remote_lfa.is_set or
                                                        self.backup_repair_list_size.is_set or
                                                        self.backup_route_interface_name.is_set or
                                                        self.backup_route_next_hop_address.is_set or
                                                        self.backup_route_source.is_set or
                                                        self.backup_tunnel_interface_name.is_set or
                                                        self.downstream.is_set or
                                                        self.line_card_disjoint.is_set or
                                                        self.node_protect.is_set or
                                                        self.primary_path.is_set or
                                                        self.srlg_disjoint.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_metric.yfilter != YFilter.not_set or
                                                        self.backup_remote_lfa.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.backup_route_interface_name.yfilter != YFilter.not_set or
                                                        self.backup_route_next_hop_address.yfilter != YFilter.not_set or
                                                        self.backup_route_source.yfilter != YFilter.not_set or
                                                        self.backup_tunnel_interface_name.yfilter != YFilter.not_set or
                                                        self.downstream.yfilter != YFilter.not_set or
                                                        self.line_card_disjoint.yfilter != YFilter.not_set or
                                                        self.node_protect.yfilter != YFilter.not_set or
                                                        self.primary_path.yfilter != YFilter.not_set or
                                                        self.srlg_disjoint.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-backup-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_metric.is_set or self.backup_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_metric.get_name_leafdata())
                                                    if (self.backup_remote_lfa.is_set or self.backup_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_remote_lfa.get_name_leafdata())
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.backup_route_interface_name.is_set or self.backup_route_interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_route_interface_name.get_name_leafdata())
                                                    if (self.backup_route_next_hop_address.is_set or self.backup_route_next_hop_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_route_next_hop_address.get_name_leafdata())
                                                    if (self.backup_route_source.is_set or self.backup_route_source.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_route_source.get_name_leafdata())
                                                    if (self.backup_tunnel_interface_name.is_set or self.backup_tunnel_interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_tunnel_interface_name.get_name_leafdata())
                                                    if (self.downstream.is_set or self.downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.downstream.get_name_leafdata())
                                                    if (self.line_card_disjoint.is_set or self.line_card_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.line_card_disjoint.get_name_leafdata())
                                                    if (self.node_protect.is_set or self.node_protect.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.node_protect.get_name_leafdata())
                                                    if (self.primary_path.is_set or self.primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.primary_path.get_name_leafdata())
                                                    if (self.srlg_disjoint.is_set or self.srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.srlg_disjoint.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "backup-metric" or name == "backup-remote-lfa" or name == "backup-repair-list-size" or name == "backup-route-interface-name" or name == "backup-route-next-hop-address" or name == "backup-route-source" or name == "backup-tunnel-interface-name" or name == "downstream" or name == "line-card-disjoint" or name == "node-protect" or name == "primary-path" or name == "srlg-disjoint"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-metric"):
                                                        self.backup_metric = value
                                                        self.backup_metric.value_namespace = name_space
                                                        self.backup_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "backup-remote-lfa"):
                                                        self.backup_remote_lfa = value
                                                        self.backup_remote_lfa.value_namespace = name_space
                                                        self.backup_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "backup-route-interface-name"):
                                                        self.backup_route_interface_name = value
                                                        self.backup_route_interface_name.value_namespace = name_space
                                                        self.backup_route_interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "backup-route-next-hop-address"):
                                                        self.backup_route_next_hop_address = value
                                                        self.backup_route_next_hop_address.value_namespace = name_space
                                                        self.backup_route_next_hop_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "backup-route-source"):
                                                        self.backup_route_source = value
                                                        self.backup_route_source.value_namespace = name_space
                                                        self.backup_route_source.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "backup-tunnel-interface-name"):
                                                        self.backup_tunnel_interface_name = value
                                                        self.backup_tunnel_interface_name.value_namespace = name_space
                                                        self.backup_tunnel_interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "downstream"):
                                                        self.downstream = value
                                                        self.downstream.value_namespace = name_space
                                                        self.downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "line-card-disjoint"):
                                                        self.line_card_disjoint = value
                                                        self.line_card_disjoint.value_namespace = name_space
                                                        self.line_card_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "node-protect"):
                                                        self.node_protect = value
                                                        self.node_protect.value_namespace = name_space
                                                        self.node_protect.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "primary-path"):
                                                        self.primary_path = value
                                                        self.primary_path.value_namespace = name_space
                                                        self.primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "srlg-disjoint"):
                                                        self.srlg_disjoint = value
                                                        self.srlg_disjoint.value_namespace = name_space
                                                        self.srlg_disjoint.value_namespace_prefix = name_space_prefix


                                            class SrMicroloopAvoidancePath(Entity):
                                                """
                                                SR Microloop avoidance Path Info
                                                
                                                .. attribute:: microloop_repair
                                                
                                                	Microloop Repair List
                                                	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                                
                                                .. attribute:: microloop_repair_list_size
                                                
                                                	Microloop Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: microloop_strict_spf
                                                
                                                	Strict SPF SID
                                                	**type**\:  bool
                                                
                                                .. attribute:: microloop_tunnel_interface_name
                                                
                                                	Microloop Tunnel Interface name
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                    self.yang_name = "sr-microloop-avoidance-path"
                                                    self.yang_parent_name = "route-path"

                                                    self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                    self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                    self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                    self.microloop_repair = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("microloop_repair_list_size",
                                                                    "microloop_strict_spf",
                                                                    "microloop_tunnel_interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                                class MicroloopRepair(Entity):
                                                    """
                                                    Microloop Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                        self.yang_name = "microloop-repair"
                                                        self.yang_parent_name = "sr-microloop-avoidance-path"

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_id",
                                                                        "repair_element_type",
                                                                        "repair_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "microloop-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-id"):
                                                            self.repair_element_id = value
                                                            self.repair_element_id.value_namespace = name_space
                                                            self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.microloop_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.microloop_repair_list_size.is_set or
                                                        self.microloop_strict_spf.is_set or
                                                        self.microloop_tunnel_interface_name.is_set)

                                                def has_operation(self):
                                                    for c in self.microloop_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                        self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                        self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                                    if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                                    if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "microloop-repair"):
                                                        for c in self.microloop_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.microloop_repair.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "microloop-repair-list-size"):
                                                        self.microloop_repair_list_size = value
                                                        self.microloop_repair_list_size.value_namespace = name_space
                                                        self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "microloop-strict-spf"):
                                                        self.microloop_strict_spf = value
                                                        self.microloop_strict_spf.value_namespace = name_space
                                                        self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "microloop-tunnel-interface-name"):
                                                        self.microloop_tunnel_interface_name = value
                                                        self.microloop_tunnel_interface_name.value_namespace = name_space
                                                        self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.lsa_type.is_set or
                                                    self.route_interface_name.is_set or
                                                    self.route_lsaid.is_set or
                                                    self.route_metric.is_set or
                                                    self.route_next_hop_address.is_set or
                                                    self.route_path_id.is_set or
                                                    self.route_path_is_mcast_intact.is_set or
                                                    self.route_path_is_ucmp_path.is_set or
                                                    self.route_source.is_set or
                                                    (self.route_backup_path is not None and self.route_backup_path.has_data()) or
                                                    (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lsa_type.yfilter != YFilter.not_set or
                                                    self.route_interface_name.yfilter != YFilter.not_set or
                                                    self.route_lsaid.yfilter != YFilter.not_set or
                                                    self.route_metric.yfilter != YFilter.not_set or
                                                    self.route_next_hop_address.yfilter != YFilter.not_set or
                                                    self.route_path_id.yfilter != YFilter.not_set or
                                                    self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                                    self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                                    self.route_source.yfilter != YFilter.not_set or
                                                    (self.route_backup_path is not None and self.route_backup_path.has_operation()) or
                                                    (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                                if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                                if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                                if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_metric.get_name_leafdata())
                                                if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                                if (self.route_path_id.is_set or self.route_path_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_id.get_name_leafdata())
                                                if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                                if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                                if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_source.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-backup-path"):
                                                    if (self.route_backup_path is None):
                                                        self.route_backup_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath()
                                                        self.route_backup_path.parent = self
                                                        self._children_name_map["route_backup_path"] = "route-backup-path"
                                                    return self.route_backup_path

                                                if (child_yang_name == "sr-microloop-avoidance-path"):
                                                    if (self.sr_microloop_avoidance_path is None):
                                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                        self.sr_microloop_avoidance_path.parent = self
                                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                    return self.sr_microloop_avoidance_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-backup-path" or name == "sr-microloop-avoidance-path" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-id" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lsa-type"):
                                                    self.lsa_type = value
                                                    self.lsa_type.value_namespace = name_space
                                                    self.lsa_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-interface-name"):
                                                    self.route_interface_name = value
                                                    self.route_interface_name.value_namespace = name_space
                                                    self.route_interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-lsaid"):
                                                    self.route_lsaid = value
                                                    self.route_lsaid.value_namespace = name_space
                                                    self.route_lsaid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-metric"):
                                                    self.route_metric = value
                                                    self.route_metric.value_namespace = name_space
                                                    self.route_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-next-hop-address"):
                                                    self.route_next_hop_address = value
                                                    self.route_next_hop_address.value_namespace = name_space
                                                    self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-id"):
                                                    self.route_path_id = value
                                                    self.route_path_id.value_namespace = name_space
                                                    self.route_path_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-is-mcast-intact"):
                                                    self.route_path_is_mcast_intact = value
                                                    self.route_path_is_mcast_intact.value_namespace = name_space
                                                    self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-is-ucmp-path"):
                                                    self.route_path_is_ucmp_path = value
                                                    self.route_path_is_ucmp_path.value_namespace = name_space
                                                    self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-source"):
                                                    self.route_source = value
                                                    self.route_source.value_namespace = name_space
                                                    self.route_source.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.route_path:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set or
                                                self.route_connected.is_set or
                                                self.route_metric.is_set or
                                                self.route_prefix.is_set or
                                                self.route_prefix_length.is_set or
                                                self.route_type.is_set or
                                                (self.route_info is not None and self.route_info.has_data()))

                                        def has_operation(self):
                                            for c in self.route_path:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set or
                                                self.route_connected.yfilter != YFilter.not_set or
                                                self.route_metric.yfilter != YFilter.not_set or
                                                self.route_prefix.yfilter != YFilter.not_set or
                                                self.route_prefix_length.yfilter != YFilter.not_set or
                                                self.route_type.yfilter != YFilter.not_set or
                                                (self.route_info is not None and self.route_info.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup-route-area" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                            if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_connected.get_name_leafdata())
                                            if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_metric.get_name_leafdata())
                                            if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                            if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-info"):
                                                if (self.route_info is None):
                                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo()
                                                    self.route_info.parent = self
                                                    self._children_name_map["route_info"] = "route-info"
                                                return self.route_info

                                            if (child_yang_name == "route-path"):
                                                for c in self.route_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.route_path.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-connected"):
                                                self.route_connected = value
                                                self.route_connected.value_namespace = name_space
                                                self.route_connected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-metric"):
                                                self.route_metric = value
                                                self.route_metric.value_namespace = name_space
                                                self.route_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-prefix"):
                                                self.route_prefix = value
                                                self.route_prefix.value_namespace = name_space
                                                self.route_prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-prefix-length"):
                                                self.route_prefix_length = value
                                                self.route_prefix_length.value_namespace = name_space
                                                self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-type"):
                                                self.route_type = value
                                                self.route_type.value_namespace = name_space
                                                self.route_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup_route_area:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.backup_route_area:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "backup-route-areas" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup-route-area"):
                                            for c in self.backup_route_area:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup_route_area.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup-route-area"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class RouteAreaInformations(Entity):
                                    """
                                    OSPF Area Route Entry
                                    
                                    .. attribute:: route_area_information
                                    
                                    	An OSPF route
                                    	**type**\: list of    :py:class:`RouteAreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations, self).__init__()

                                        self.yang_name = "route-area-informations"
                                        self.yang_parent_name = "route-area"

                                        self.route_area_information = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations, self).__setattr__(name, value)


                                    class RouteAreaInformation(Entity):
                                        """
                                        An OSPF route
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..32
                                        
                                        .. attribute:: route_connected
                                        
                                        	If true, connected route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_info
                                        
                                        	Route information
                                        	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo>`
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_path
                                        
                                        	List of paths to this route
                                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath>`
                                        
                                        .. attribute:: route_prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_type
                                        
                                        	Route type
                                        	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation, self).__init__()

                                            self.yang_name = "route-area-information"
                                            self.yang_parent_name = "route-area-informations"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.route_connected = YLeaf(YType.boolean, "route-connected")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_prefix = YLeaf(YType.str, "route-prefix")

                                            self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                            self._children_yang_names.add("route-info")

                                            self.route_path = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length",
                                                            "route_connected",
                                                            "route_metric",
                                                            "route_prefix",
                                                            "route_prefix_length",
                                                            "route_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation, self).__setattr__(name, value)


                                        class RouteInfo(Entity):
                                            """
                                            Route information
                                            
                                            .. attribute:: route_area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_auto_excluded
                                            
                                            	If true, exclude from TE paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_fail_time
                                            
                                            	Last time update failed
                                            	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime>`
                                            
                                            .. attribute:: route_forward_distance
                                            
                                            	Forward distance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_rib_version
                                            
                                            	RIB version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_source
                                            
                                            	Protocol source
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_spf_priority
                                            
                                            	SPF priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_spf_version
                                            
                                            	SPF version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_srte_nbr_registered
                                            
                                            	SRTE registered neigbhor count on route
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_srte_prefix_registered
                                            
                                            	If true, SRTE registered prefix route
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_te_metric
                                            
                                            	TE metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_update_time
                                            
                                            	Last time updated
                                            	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo, self).__init__()

                                                self.yang_name = "route-info"
                                                self.yang_parent_name = "route-area-information"

                                                self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                                self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                                self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                                self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                                self.route_source = YLeaf(YType.uint16, "route-source")

                                                self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                                self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                                self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                                self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                                self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                                self._children_yang_names.add("route-fail-time")

                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                                self._children_yang_names.add("route-update-time")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("route_area_id",
                                                                "route_auto_excluded",
                                                                "route_forward_distance",
                                                                "route_rib_version",
                                                                "route_source",
                                                                "route_spf_priority",
                                                                "route_spf_version",
                                                                "route_srte_nbr_registered",
                                                                "route_srte_prefix_registered",
                                                                "route_te_metric") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo, self).__setattr__(name, value)


                                            class RouteUpdateTime(Entity):
                                                """
                                                Last time updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime, self).__init__()

                                                    self.yang_name = "route-update-time"
                                                    self.yang_parent_name = "route-info"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-update-time" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix


                                            class RouteFailTime(Entity):
                                                """
                                                Last time update failed
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime, self).__init__()

                                                    self.yang_name = "route-fail-time"
                                                    self.yang_parent_name = "route-info"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-fail-time" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.route_area_id.is_set or
                                                    self.route_auto_excluded.is_set or
                                                    self.route_forward_distance.is_set or
                                                    self.route_rib_version.is_set or
                                                    self.route_source.is_set or
                                                    self.route_spf_priority.is_set or
                                                    self.route_spf_version.is_set or
                                                    self.route_srte_nbr_registered.is_set or
                                                    self.route_srte_prefix_registered.is_set or
                                                    self.route_te_metric.is_set or
                                                    (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                                    (self.route_update_time is not None and self.route_update_time.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.route_area_id.yfilter != YFilter.not_set or
                                                    self.route_auto_excluded.yfilter != YFilter.not_set or
                                                    self.route_forward_distance.yfilter != YFilter.not_set or
                                                    self.route_rib_version.yfilter != YFilter.not_set or
                                                    self.route_source.yfilter != YFilter.not_set or
                                                    self.route_spf_priority.yfilter != YFilter.not_set or
                                                    self.route_spf_version.yfilter != YFilter.not_set or
                                                    self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                                    self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                                    self.route_te_metric.yfilter != YFilter.not_set or
                                                    (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                                    (self.route_update_time is not None and self.route_update_time.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-info" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                                if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                                if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                                if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                                if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_source.get_name_leafdata())
                                                if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                                if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                                if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                                if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                                if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-fail-time"):
                                                    if (self.route_fail_time is None):
                                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime()
                                                        self.route_fail_time.parent = self
                                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                                    return self.route_fail_time

                                                if (child_yang_name == "route-update-time"):
                                                    if (self.route_update_time is None):
                                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime()
                                                        self.route_update_time.parent = self
                                                        self._children_name_map["route_update_time"] = "route-update-time"
                                                    return self.route_update_time

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "route-area-id"):
                                                    self.route_area_id = value
                                                    self.route_area_id.value_namespace = name_space
                                                    self.route_area_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-auto-excluded"):
                                                    self.route_auto_excluded = value
                                                    self.route_auto_excluded.value_namespace = name_space
                                                    self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-forward-distance"):
                                                    self.route_forward_distance = value
                                                    self.route_forward_distance.value_namespace = name_space
                                                    self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-rib-version"):
                                                    self.route_rib_version = value
                                                    self.route_rib_version.value_namespace = name_space
                                                    self.route_rib_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-source"):
                                                    self.route_source = value
                                                    self.route_source.value_namespace = name_space
                                                    self.route_source.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-spf-priority"):
                                                    self.route_spf_priority = value
                                                    self.route_spf_priority.value_namespace = name_space
                                                    self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-spf-version"):
                                                    self.route_spf_version = value
                                                    self.route_spf_version.value_namespace = name_space
                                                    self.route_spf_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-srte-nbr-registered"):
                                                    self.route_srte_nbr_registered = value
                                                    self.route_srte_nbr_registered.value_namespace = name_space
                                                    self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-srte-prefix-registered"):
                                                    self.route_srte_prefix_registered = value
                                                    self.route_srte_prefix_registered.value_namespace = name_space
                                                    self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-te-metric"):
                                                    self.route_te_metric = value
                                                    self.route_te_metric.value_namespace = name_space
                                                    self.route_te_metric.value_namespace_prefix = name_space_prefix


                                        class RoutePath(Entity):
                                            """
                                            List of paths to this route
                                            
                                            .. attribute:: area_format
                                            
                                            	Area format IP or uint32
                                            	**type**\:  bool
                                            
                                            .. attribute:: area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type, see RFC2328 etc
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: route_lsaid
                                            
                                            	LSA ID, see RFC2328
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_path_is_mcast_intact
                                            
                                            	Multicast\-intact path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_path_is_ucmp_path
                                            
                                            	UCMP path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sr_microloop_avoidance_path
                                            
                                            	SR Microloop avoidance Path Info
                                            	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath, self).__init__()

                                                self.yang_name = "route-path"
                                                self.yang_parent_name = "route-area-information"

                                                self.area_format = YLeaf(YType.boolean, "area-format")

                                                self.area_id = YLeaf(YType.uint32, "area-id")

                                                self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                                self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                                self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                                self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                                self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                                self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                                self.route_source = YLeaf(YType.str, "route-source")

                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                self._children_yang_names.add("sr-microloop-avoidance-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("area_format",
                                                                "area_id",
                                                                "lsa_type",
                                                                "route_interface_name",
                                                                "route_lsaid",
                                                                "route_metric",
                                                                "route_next_hop_address",
                                                                "route_path_is_mcast_intact",
                                                                "route_path_is_ucmp_path",
                                                                "route_source") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath, self).__setattr__(name, value)


                                            class SrMicroloopAvoidancePath(Entity):
                                                """
                                                SR Microloop avoidance Path Info
                                                
                                                .. attribute:: microloop_repair
                                                
                                                	Microloop Repair List
                                                	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                                
                                                .. attribute:: microloop_repair_list_size
                                                
                                                	Microloop Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: microloop_strict_spf
                                                
                                                	Strict SPF SID
                                                	**type**\:  bool
                                                
                                                .. attribute:: microloop_tunnel_interface_name
                                                
                                                	Microloop Tunnel Interface name
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                    self.yang_name = "sr-microloop-avoidance-path"
                                                    self.yang_parent_name = "route-path"

                                                    self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                    self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                    self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                    self.microloop_repair = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("microloop_repair_list_size",
                                                                    "microloop_strict_spf",
                                                                    "microloop_tunnel_interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                                class MicroloopRepair(Entity):
                                                    """
                                                    Microloop Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                        self.yang_name = "microloop-repair"
                                                        self.yang_parent_name = "sr-microloop-avoidance-path"

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_id",
                                                                        "repair_element_type",
                                                                        "repair_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "microloop-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-id"):
                                                            self.repair_element_id = value
                                                            self.repair_element_id.value_namespace = name_space
                                                            self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.microloop_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.microloop_repair_list_size.is_set or
                                                        self.microloop_strict_spf.is_set or
                                                        self.microloop_tunnel_interface_name.is_set)

                                                def has_operation(self):
                                                    for c in self.microloop_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                        self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                        self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                                    if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                                    if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "microloop-repair"):
                                                        for c in self.microloop_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.microloop_repair.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "microloop-repair-list-size"):
                                                        self.microloop_repair_list_size = value
                                                        self.microloop_repair_list_size.value_namespace = name_space
                                                        self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "microloop-strict-spf"):
                                                        self.microloop_strict_spf = value
                                                        self.microloop_strict_spf.value_namespace = name_space
                                                        self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "microloop-tunnel-interface-name"):
                                                        self.microloop_tunnel_interface_name = value
                                                        self.microloop_tunnel_interface_name.value_namespace = name_space
                                                        self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.area_format.is_set or
                                                    self.area_id.is_set or
                                                    self.lsa_type.is_set or
                                                    self.route_interface_name.is_set or
                                                    self.route_lsaid.is_set or
                                                    self.route_metric.is_set or
                                                    self.route_next_hop_address.is_set or
                                                    self.route_path_is_mcast_intact.is_set or
                                                    self.route_path_is_ucmp_path.is_set or
                                                    self.route_source.is_set or
                                                    (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.area_format.yfilter != YFilter.not_set or
                                                    self.area_id.yfilter != YFilter.not_set or
                                                    self.lsa_type.yfilter != YFilter.not_set or
                                                    self.route_interface_name.yfilter != YFilter.not_set or
                                                    self.route_lsaid.yfilter != YFilter.not_set or
                                                    self.route_metric.yfilter != YFilter.not_set or
                                                    self.route_next_hop_address.yfilter != YFilter.not_set or
                                                    self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                                    self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                                    self.route_source.yfilter != YFilter.not_set or
                                                    (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.area_format.get_name_leafdata())
                                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                                if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                                if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                                if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                                if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_metric.get_name_leafdata())
                                                if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                                if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                                if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                                if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_source.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "sr-microloop-avoidance-path"):
                                                    if (self.sr_microloop_avoidance_path is None):
                                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath()
                                                        self.sr_microloop_avoidance_path.parent = self
                                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                    return self.sr_microloop_avoidance_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "area-format"):
                                                    self.area_format = value
                                                    self.area_format.value_namespace = name_space
                                                    self.area_format.value_namespace_prefix = name_space_prefix
                                                if(value_path == "area-id"):
                                                    self.area_id = value
                                                    self.area_id.value_namespace = name_space
                                                    self.area_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsa-type"):
                                                    self.lsa_type = value
                                                    self.lsa_type.value_namespace = name_space
                                                    self.lsa_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-interface-name"):
                                                    self.route_interface_name = value
                                                    self.route_interface_name.value_namespace = name_space
                                                    self.route_interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-lsaid"):
                                                    self.route_lsaid = value
                                                    self.route_lsaid.value_namespace = name_space
                                                    self.route_lsaid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-metric"):
                                                    self.route_metric = value
                                                    self.route_metric.value_namespace = name_space
                                                    self.route_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-next-hop-address"):
                                                    self.route_next_hop_address = value
                                                    self.route_next_hop_address.value_namespace = name_space
                                                    self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-is-mcast-intact"):
                                                    self.route_path_is_mcast_intact = value
                                                    self.route_path_is_mcast_intact.value_namespace = name_space
                                                    self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-is-ucmp-path"):
                                                    self.route_path_is_ucmp_path = value
                                                    self.route_path_is_ucmp_path.value_namespace = name_space
                                                    self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-source"):
                                                    self.route_source = value
                                                    self.route_source.value_namespace = name_space
                                                    self.route_source.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.route_path:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set or
                                                self.route_connected.is_set or
                                                self.route_metric.is_set or
                                                self.route_prefix.is_set or
                                                self.route_prefix_length.is_set or
                                                self.route_type.is_set or
                                                (self.route_info is not None and self.route_info.has_data()))

                                        def has_operation(self):
                                            for c in self.route_path:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set or
                                                self.route_connected.yfilter != YFilter.not_set or
                                                self.route_metric.yfilter != YFilter.not_set or
                                                self.route_prefix.yfilter != YFilter.not_set or
                                                self.route_prefix_length.yfilter != YFilter.not_set or
                                                self.route_type.yfilter != YFilter.not_set or
                                                (self.route_info is not None and self.route_info.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-area-information" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                            if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_connected.get_name_leafdata())
                                            if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_metric.get_name_leafdata())
                                            if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                            if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-info"):
                                                if (self.route_info is None):
                                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo()
                                                    self.route_info.parent = self
                                                    self._children_name_map["route_info"] = "route-info"
                                                return self.route_info

                                            if (child_yang_name == "route-path"):
                                                for c in self.route_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.route_path.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-connected"):
                                                self.route_connected = value
                                                self.route_connected.value_namespace = name_space
                                                self.route_connected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-metric"):
                                                self.route_metric = value
                                                self.route_metric.value_namespace = name_space
                                                self.route_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-prefix"):
                                                self.route_prefix = value
                                                self.route_prefix.value_namespace = name_space
                                                self.route_prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-prefix-length"):
                                                self.route_prefix_length = value
                                                self.route_prefix_length.value_namespace = name_space
                                                self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-type"):
                                                self.route_type = value
                                                self.route_type.value_namespace = name_space
                                                self.route_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.route_area_information:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.route_area_information:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-area-informations" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-area-information"):
                                            for c in self.route_area_information:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.route_area_information.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-area-information"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class MulticastIntactRouteAreas(Entity):
                                    """
                                    OSPF Area multicast\-intact included route
                                    entry
                                    
                                    .. attribute:: multicast_intact_route_area
                                    
                                    	A Muliticast OSPF route in an area
                                    	**type**\: list of    :py:class:`MulticastIntactRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas, self).__init__()

                                        self.yang_name = "multicast-intact-route-areas"
                                        self.yang_parent_name = "route-area"

                                        self.multicast_intact_route_area = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas, self).__setattr__(name, value)


                                    class MulticastIntactRouteArea(Entity):
                                        """
                                        A Muliticast OSPF route in an area
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..32
                                        
                                        .. attribute:: route_connected
                                        
                                        	If true, connected route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_info
                                        
                                        	Route information
                                        	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo>`
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_path
                                        
                                        	List of paths to this route
                                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath>`
                                        
                                        .. attribute:: route_prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_type
                                        
                                        	Route type
                                        	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea, self).__init__()

                                            self.yang_name = "multicast-intact-route-area"
                                            self.yang_parent_name = "multicast-intact-route-areas"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.route_connected = YLeaf(YType.boolean, "route-connected")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_prefix = YLeaf(YType.str, "route-prefix")

                                            self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                            self._children_yang_names.add("route-info")

                                            self.route_path = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length",
                                                            "route_connected",
                                                            "route_metric",
                                                            "route_prefix",
                                                            "route_prefix_length",
                                                            "route_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea, self).__setattr__(name, value)


                                        class RouteInfo(Entity):
                                            """
                                            Route information
                                            
                                            .. attribute:: route_area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_auto_excluded
                                            
                                            	If true, exclude from TE paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_fail_time
                                            
                                            	Last time update failed
                                            	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime>`
                                            
                                            .. attribute:: route_forward_distance
                                            
                                            	Forward distance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_rib_version
                                            
                                            	RIB version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_source
                                            
                                            	Protocol source
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_spf_priority
                                            
                                            	SPF priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_spf_version
                                            
                                            	SPF version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_srte_nbr_registered
                                            
                                            	SRTE registered neigbhor count on route
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_srte_prefix_registered
                                            
                                            	If true, SRTE registered prefix route
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_te_metric
                                            
                                            	TE metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_update_time
                                            
                                            	Last time updated
                                            	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo, self).__init__()

                                                self.yang_name = "route-info"
                                                self.yang_parent_name = "multicast-intact-route-area"

                                                self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                                self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                                self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                                self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                                self.route_source = YLeaf(YType.uint16, "route-source")

                                                self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                                self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                                self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                                self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                                self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                                self._children_yang_names.add("route-fail-time")

                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                                self._children_yang_names.add("route-update-time")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("route_area_id",
                                                                "route_auto_excluded",
                                                                "route_forward_distance",
                                                                "route_rib_version",
                                                                "route_source",
                                                                "route_spf_priority",
                                                                "route_spf_version",
                                                                "route_srte_nbr_registered",
                                                                "route_srte_prefix_registered",
                                                                "route_te_metric") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo, self).__setattr__(name, value)


                                            class RouteUpdateTime(Entity):
                                                """
                                                Last time updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                    self.yang_name = "route-update-time"
                                                    self.yang_parent_name = "route-info"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-update-time" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix


                                            class RouteFailTime(Entity):
                                                """
                                                Last time update failed
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                    self.yang_name = "route-fail-time"
                                                    self.yang_parent_name = "route-info"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-fail-time" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.route_area_id.is_set or
                                                    self.route_auto_excluded.is_set or
                                                    self.route_forward_distance.is_set or
                                                    self.route_rib_version.is_set or
                                                    self.route_source.is_set or
                                                    self.route_spf_priority.is_set or
                                                    self.route_spf_version.is_set or
                                                    self.route_srte_nbr_registered.is_set or
                                                    self.route_srte_prefix_registered.is_set or
                                                    self.route_te_metric.is_set or
                                                    (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                                    (self.route_update_time is not None and self.route_update_time.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.route_area_id.yfilter != YFilter.not_set or
                                                    self.route_auto_excluded.yfilter != YFilter.not_set or
                                                    self.route_forward_distance.yfilter != YFilter.not_set or
                                                    self.route_rib_version.yfilter != YFilter.not_set or
                                                    self.route_source.yfilter != YFilter.not_set or
                                                    self.route_spf_priority.yfilter != YFilter.not_set or
                                                    self.route_spf_version.yfilter != YFilter.not_set or
                                                    self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                                    self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                                    self.route_te_metric.yfilter != YFilter.not_set or
                                                    (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                                    (self.route_update_time is not None and self.route_update_time.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-info" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                                if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                                if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                                if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                                if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_source.get_name_leafdata())
                                                if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                                if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                                if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                                if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                                if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-fail-time"):
                                                    if (self.route_fail_time is None):
                                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime()
                                                        self.route_fail_time.parent = self
                                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                                    return self.route_fail_time

                                                if (child_yang_name == "route-update-time"):
                                                    if (self.route_update_time is None):
                                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime()
                                                        self.route_update_time.parent = self
                                                        self._children_name_map["route_update_time"] = "route-update-time"
                                                    return self.route_update_time

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "route-area-id"):
                                                    self.route_area_id = value
                                                    self.route_area_id.value_namespace = name_space
                                                    self.route_area_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-auto-excluded"):
                                                    self.route_auto_excluded = value
                                                    self.route_auto_excluded.value_namespace = name_space
                                                    self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-forward-distance"):
                                                    self.route_forward_distance = value
                                                    self.route_forward_distance.value_namespace = name_space
                                                    self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-rib-version"):
                                                    self.route_rib_version = value
                                                    self.route_rib_version.value_namespace = name_space
                                                    self.route_rib_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-source"):
                                                    self.route_source = value
                                                    self.route_source.value_namespace = name_space
                                                    self.route_source.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-spf-priority"):
                                                    self.route_spf_priority = value
                                                    self.route_spf_priority.value_namespace = name_space
                                                    self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-spf-version"):
                                                    self.route_spf_version = value
                                                    self.route_spf_version.value_namespace = name_space
                                                    self.route_spf_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-srte-nbr-registered"):
                                                    self.route_srte_nbr_registered = value
                                                    self.route_srte_nbr_registered.value_namespace = name_space
                                                    self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-srte-prefix-registered"):
                                                    self.route_srte_prefix_registered = value
                                                    self.route_srte_prefix_registered.value_namespace = name_space
                                                    self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-te-metric"):
                                                    self.route_te_metric = value
                                                    self.route_te_metric.value_namespace = name_space
                                                    self.route_te_metric.value_namespace_prefix = name_space_prefix


                                        class RoutePath(Entity):
                                            """
                                            List of paths to this route
                                            
                                            .. attribute:: area_format
                                            
                                            	Area format IP or uint32
                                            	**type**\:  bool
                                            
                                            .. attribute:: area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type, see RFC2328 etc
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: route_lsaid
                                            
                                            	LSA ID, see RFC2328
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_path_is_mcast_intact
                                            
                                            	Multicast\-intact path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_path_is_ucmp_path
                                            
                                            	UCMP path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sr_microloop_avoidance_path
                                            
                                            	SR Microloop avoidance Path Info
                                            	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath, self).__init__()

                                                self.yang_name = "route-path"
                                                self.yang_parent_name = "multicast-intact-route-area"

                                                self.area_format = YLeaf(YType.boolean, "area-format")

                                                self.area_id = YLeaf(YType.uint32, "area-id")

                                                self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                                self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                                self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                                self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                                self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                                self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                                self.route_source = YLeaf(YType.str, "route-source")

                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                self._children_yang_names.add("sr-microloop-avoidance-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("area_format",
                                                                "area_id",
                                                                "lsa_type",
                                                                "route_interface_name",
                                                                "route_lsaid",
                                                                "route_metric",
                                                                "route_next_hop_address",
                                                                "route_path_is_mcast_intact",
                                                                "route_path_is_ucmp_path",
                                                                "route_source") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath, self).__setattr__(name, value)


                                            class SrMicroloopAvoidancePath(Entity):
                                                """
                                                SR Microloop avoidance Path Info
                                                
                                                .. attribute:: microloop_repair
                                                
                                                	Microloop Repair List
                                                	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                                
                                                .. attribute:: microloop_repair_list_size
                                                
                                                	Microloop Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: microloop_strict_spf
                                                
                                                	Strict SPF SID
                                                	**type**\:  bool
                                                
                                                .. attribute:: microloop_tunnel_interface_name
                                                
                                                	Microloop Tunnel Interface name
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                    self.yang_name = "sr-microloop-avoidance-path"
                                                    self.yang_parent_name = "route-path"

                                                    self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                    self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                    self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                    self.microloop_repair = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("microloop_repair_list_size",
                                                                    "microloop_strict_spf",
                                                                    "microloop_tunnel_interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                                class MicroloopRepair(Entity):
                                                    """
                                                    Microloop Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                        self.yang_name = "microloop-repair"
                                                        self.yang_parent_name = "sr-microloop-avoidance-path"

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_id",
                                                                        "repair_element_type",
                                                                        "repair_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "microloop-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-id"):
                                                            self.repair_element_id = value
                                                            self.repair_element_id.value_namespace = name_space
                                                            self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.microloop_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.microloop_repair_list_size.is_set or
                                                        self.microloop_strict_spf.is_set or
                                                        self.microloop_tunnel_interface_name.is_set)

                                                def has_operation(self):
                                                    for c in self.microloop_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                        self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                        self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                                    if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                                    if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "microloop-repair"):
                                                        for c in self.microloop_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.microloop_repair.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "microloop-repair-list-size"):
                                                        self.microloop_repair_list_size = value
                                                        self.microloop_repair_list_size.value_namespace = name_space
                                                        self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "microloop-strict-spf"):
                                                        self.microloop_strict_spf = value
                                                        self.microloop_strict_spf.value_namespace = name_space
                                                        self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "microloop-tunnel-interface-name"):
                                                        self.microloop_tunnel_interface_name = value
                                                        self.microloop_tunnel_interface_name.value_namespace = name_space
                                                        self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.area_format.is_set or
                                                    self.area_id.is_set or
                                                    self.lsa_type.is_set or
                                                    self.route_interface_name.is_set or
                                                    self.route_lsaid.is_set or
                                                    self.route_metric.is_set or
                                                    self.route_next_hop_address.is_set or
                                                    self.route_path_is_mcast_intact.is_set or
                                                    self.route_path_is_ucmp_path.is_set or
                                                    self.route_source.is_set or
                                                    (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.area_format.yfilter != YFilter.not_set or
                                                    self.area_id.yfilter != YFilter.not_set or
                                                    self.lsa_type.yfilter != YFilter.not_set or
                                                    self.route_interface_name.yfilter != YFilter.not_set or
                                                    self.route_lsaid.yfilter != YFilter.not_set or
                                                    self.route_metric.yfilter != YFilter.not_set or
                                                    self.route_next_hop_address.yfilter != YFilter.not_set or
                                                    self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                                    self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                                    self.route_source.yfilter != YFilter.not_set or
                                                    (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.area_format.get_name_leafdata())
                                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                                if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                                if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                                if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                                if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_metric.get_name_leafdata())
                                                if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                                if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                                if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                                if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_source.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "sr-microloop-avoidance-path"):
                                                    if (self.sr_microloop_avoidance_path is None):
                                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                        self.sr_microloop_avoidance_path.parent = self
                                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                    return self.sr_microloop_avoidance_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "area-format"):
                                                    self.area_format = value
                                                    self.area_format.value_namespace = name_space
                                                    self.area_format.value_namespace_prefix = name_space_prefix
                                                if(value_path == "area-id"):
                                                    self.area_id = value
                                                    self.area_id.value_namespace = name_space
                                                    self.area_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsa-type"):
                                                    self.lsa_type = value
                                                    self.lsa_type.value_namespace = name_space
                                                    self.lsa_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-interface-name"):
                                                    self.route_interface_name = value
                                                    self.route_interface_name.value_namespace = name_space
                                                    self.route_interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-lsaid"):
                                                    self.route_lsaid = value
                                                    self.route_lsaid.value_namespace = name_space
                                                    self.route_lsaid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-metric"):
                                                    self.route_metric = value
                                                    self.route_metric.value_namespace = name_space
                                                    self.route_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-next-hop-address"):
                                                    self.route_next_hop_address = value
                                                    self.route_next_hop_address.value_namespace = name_space
                                                    self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-is-mcast-intact"):
                                                    self.route_path_is_mcast_intact = value
                                                    self.route_path_is_mcast_intact.value_namespace = name_space
                                                    self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-is-ucmp-path"):
                                                    self.route_path_is_ucmp_path = value
                                                    self.route_path_is_ucmp_path.value_namespace = name_space
                                                    self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-source"):
                                                    self.route_source = value
                                                    self.route_source.value_namespace = name_space
                                                    self.route_source.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.route_path:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set or
                                                self.route_connected.is_set or
                                                self.route_metric.is_set or
                                                self.route_prefix.is_set or
                                                self.route_prefix_length.is_set or
                                                self.route_type.is_set or
                                                (self.route_info is not None and self.route_info.has_data()))

                                        def has_operation(self):
                                            for c in self.route_path:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set or
                                                self.route_connected.yfilter != YFilter.not_set or
                                                self.route_metric.yfilter != YFilter.not_set or
                                                self.route_prefix.yfilter != YFilter.not_set or
                                                self.route_prefix_length.yfilter != YFilter.not_set or
                                                self.route_type.yfilter != YFilter.not_set or
                                                (self.route_info is not None and self.route_info.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-intact-route-area" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                            if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_connected.get_name_leafdata())
                                            if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_metric.get_name_leafdata())
                                            if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                            if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-info"):
                                                if (self.route_info is None):
                                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo()
                                                    self.route_info.parent = self
                                                    self._children_name_map["route_info"] = "route-info"
                                                return self.route_info

                                            if (child_yang_name == "route-path"):
                                                for c in self.route_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.route_path.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-connected"):
                                                self.route_connected = value
                                                self.route_connected.value_namespace = name_space
                                                self.route_connected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-metric"):
                                                self.route_metric = value
                                                self.route_metric.value_namespace = name_space
                                                self.route_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-prefix"):
                                                self.route_prefix = value
                                                self.route_prefix.value_namespace = name_space
                                                self.route_prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-prefix-length"):
                                                self.route_prefix_length = value
                                                self.route_prefix_length.value_namespace = name_space
                                                self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-type"):
                                                self.route_type = value
                                                self.route_type.value_namespace = name_space
                                                self.route_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.multicast_intact_route_area:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.multicast_intact_route_area:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-intact-route-areas" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "multicast-intact-route-area"):
                                            for c in self.multicast_intact_route_area:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.multicast_intact_route_area.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "multicast-intact-route-area"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SummaryAreaInformation(Entity):
                                    """
                                    OSPF route summary statistics
                                    
                                    .. attribute:: common
                                    
                                    	OSPF route summary Information
                                    	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common>`
                                    
                                    .. attribute:: failure_address
                                    
                                    	Last failed address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: failure_time
                                    
                                    	Last time failed
                                    	**type**\:   :py:class:`FailureTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime>`
                                    
                                    .. attribute:: failures
                                    
                                    	RIB failure count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation, self).__init__()

                                        self.yang_name = "summary-area-information"
                                        self.yang_parent_name = "route-area"

                                        self.failure_address = YLeaf(YType.str, "failure-address")

                                        self.failures = YLeaf(YType.uint32, "failures")

                                        self.common = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common()
                                        self.common.parent = self
                                        self._children_name_map["common"] = "common"
                                        self._children_yang_names.add("common")

                                        self.failure_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime()
                                        self.failure_time.parent = self
                                        self._children_name_map["failure_time"] = "failure-time"
                                        self._children_yang_names.add("failure-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("failure_address",
                                                        "failures") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation, self).__setattr__(name, value)


                                    class FailureTime(Entity):
                                        """
                                        Last time failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime, self).__init__()

                                            self.yang_name = "failure-time"
                                            self.yang_parent_name = "summary-area-information"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "failure-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix


                                    class Common(Entity):
                                        """
                                        OSPF route summary Information
                                        
                                        .. attribute:: external_nssa_type1s
                                        
                                        	External NSSA type 1 count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_nssa_type2s
                                        
                                        	External NSSA type 2 count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_type1s
                                        
                                        	External type 1 count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_type2s
                                        
                                        	External type 2 count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inter_areas
                                        
                                        	Inter\-area count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: intra_areas
                                        
                                        	Intra\-area count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total
                                        
                                        	Total count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common, self).__init__()

                                            self.yang_name = "common"
                                            self.yang_parent_name = "summary-area-information"

                                            self.external_nssa_type1s = YLeaf(YType.uint32, "external-nssa-type1s")

                                            self.external_nssa_type2s = YLeaf(YType.uint32, "external-nssa-type2s")

                                            self.external_type1s = YLeaf(YType.uint32, "external-type1s")

                                            self.external_type2s = YLeaf(YType.uint32, "external-type2s")

                                            self.inter_areas = YLeaf(YType.uint32, "inter-areas")

                                            self.intra_areas = YLeaf(YType.uint32, "intra-areas")

                                            self.total = YLeaf(YType.uint32, "total")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("external_nssa_type1s",
                                                            "external_nssa_type2s",
                                                            "external_type1s",
                                                            "external_type2s",
                                                            "inter_areas",
                                                            "intra_areas",
                                                            "total") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.external_nssa_type1s.is_set or
                                                self.external_nssa_type2s.is_set or
                                                self.external_type1s.is_set or
                                                self.external_type2s.is_set or
                                                self.inter_areas.is_set or
                                                self.intra_areas.is_set or
                                                self.total.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.external_nssa_type1s.yfilter != YFilter.not_set or
                                                self.external_nssa_type2s.yfilter != YFilter.not_set or
                                                self.external_type1s.yfilter != YFilter.not_set or
                                                self.external_type2s.yfilter != YFilter.not_set or
                                                self.inter_areas.yfilter != YFilter.not_set or
                                                self.intra_areas.yfilter != YFilter.not_set or
                                                self.total.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "common" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.external_nssa_type1s.is_set or self.external_nssa_type1s.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.external_nssa_type1s.get_name_leafdata())
                                            if (self.external_nssa_type2s.is_set or self.external_nssa_type2s.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.external_nssa_type2s.get_name_leafdata())
                                            if (self.external_type1s.is_set or self.external_type1s.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.external_type1s.get_name_leafdata())
                                            if (self.external_type2s.is_set or self.external_type2s.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.external_type2s.get_name_leafdata())
                                            if (self.inter_areas.is_set or self.inter_areas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.inter_areas.get_name_leafdata())
                                            if (self.intra_areas.is_set or self.intra_areas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.intra_areas.get_name_leafdata())
                                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.total.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "external-nssa-type1s" or name == "external-nssa-type2s" or name == "external-type1s" or name == "external-type2s" or name == "inter-areas" or name == "intra-areas" or name == "total"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "external-nssa-type1s"):
                                                self.external_nssa_type1s = value
                                                self.external_nssa_type1s.value_namespace = name_space
                                                self.external_nssa_type1s.value_namespace_prefix = name_space_prefix
                                            if(value_path == "external-nssa-type2s"):
                                                self.external_nssa_type2s = value
                                                self.external_nssa_type2s.value_namespace = name_space
                                                self.external_nssa_type2s.value_namespace_prefix = name_space_prefix
                                            if(value_path == "external-type1s"):
                                                self.external_type1s = value
                                                self.external_type1s.value_namespace = name_space
                                                self.external_type1s.value_namespace_prefix = name_space_prefix
                                            if(value_path == "external-type2s"):
                                                self.external_type2s = value
                                                self.external_type2s.value_namespace = name_space
                                                self.external_type2s.value_namespace_prefix = name_space_prefix
                                            if(value_path == "inter-areas"):
                                                self.inter_areas = value
                                                self.inter_areas.value_namespace = name_space
                                                self.inter_areas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "intra-areas"):
                                                self.intra_areas = value
                                                self.intra_areas.value_namespace = name_space
                                                self.intra_areas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "total"):
                                                self.total = value
                                                self.total.value_namespace = name_space
                                                self.total.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.failure_address.is_set or
                                            self.failures.is_set or
                                            (self.common is not None and self.common.has_data()) or
                                            (self.failure_time is not None and self.failure_time.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.failure_address.yfilter != YFilter.not_set or
                                            self.failures.yfilter != YFilter.not_set or
                                            (self.common is not None and self.common.has_operation()) or
                                            (self.failure_time is not None and self.failure_time.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "summary-area-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.failure_address.is_set or self.failure_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.failure_address.get_name_leafdata())
                                        if (self.failures.is_set or self.failures.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.failures.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "common"):
                                            if (self.common is None):
                                                self.common = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common()
                                                self.common.parent = self
                                                self._children_name_map["common"] = "common"
                                            return self.common

                                        if (child_yang_name == "failure-time"):
                                            if (self.failure_time is None):
                                                self.failure_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime()
                                                self.failure_time.parent = self
                                                self._children_name_map["failure_time"] = "failure-time"
                                            return self.failure_time

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "common" or name == "failure-time" or name == "failure-address" or name == "failures"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "failure-address"):
                                            self.failure_address = value
                                            self.failure_address.value_namespace = name_space
                                            self.failure_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "failures"):
                                            self.failures = value
                                            self.failures.value_namespace = name_space
                                            self.failures.value_namespace_prefix = name_space_prefix


                                class LocalRouteAreas(Entity):
                                    """
                                    OSPF Local Route Table
                                    
                                    .. attribute:: local_route_area
                                    
                                    	Local route
                                    	**type**\: list of    :py:class:`LocalRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas, self).__init__()

                                        self.yang_name = "local-route-areas"
                                        self.yang_parent_name = "route-area"

                                        self.local_route_area = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas, self).__setattr__(name, value)


                                    class LocalRouteArea(Entity):
                                        """
                                        Local route
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..32
                                        
                                        .. attribute:: route_connected
                                        
                                        	If true, connected route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_info
                                        
                                        	Route information
                                        	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo>`
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_path
                                        
                                        	List of paths to this route
                                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath>`
                                        
                                        .. attribute:: route_prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_type
                                        
                                        	Route type
                                        	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea, self).__init__()

                                            self.yang_name = "local-route-area"
                                            self.yang_parent_name = "local-route-areas"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.route_connected = YLeaf(YType.boolean, "route-connected")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_prefix = YLeaf(YType.str, "route-prefix")

                                            self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                            self._children_yang_names.add("route-info")

                                            self.route_path = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length",
                                                            "route_connected",
                                                            "route_metric",
                                                            "route_prefix",
                                                            "route_prefix_length",
                                                            "route_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea, self).__setattr__(name, value)


                                        class RouteInfo(Entity):
                                            """
                                            Route information
                                            
                                            .. attribute:: route_area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_auto_excluded
                                            
                                            	If true, exclude from TE paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_fail_time
                                            
                                            	Last time update failed
                                            	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime>`
                                            
                                            .. attribute:: route_forward_distance
                                            
                                            	Forward distance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_rib_version
                                            
                                            	RIB version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_source
                                            
                                            	Protocol source
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_spf_priority
                                            
                                            	SPF priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_spf_version
                                            
                                            	SPF version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_srte_nbr_registered
                                            
                                            	SRTE registered neigbhor count on route
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_srte_prefix_registered
                                            
                                            	If true, SRTE registered prefix route
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_te_metric
                                            
                                            	TE metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_update_time
                                            
                                            	Last time updated
                                            	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo, self).__init__()

                                                self.yang_name = "route-info"
                                                self.yang_parent_name = "local-route-area"

                                                self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                                self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                                self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                                self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                                self.route_source = YLeaf(YType.uint16, "route-source")

                                                self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                                self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                                self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                                self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                                self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                                self._children_yang_names.add("route-fail-time")

                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                                self._children_yang_names.add("route-update-time")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("route_area_id",
                                                                "route_auto_excluded",
                                                                "route_forward_distance",
                                                                "route_rib_version",
                                                                "route_source",
                                                                "route_spf_priority",
                                                                "route_spf_version",
                                                                "route_srte_nbr_registered",
                                                                "route_srte_prefix_registered",
                                                                "route_te_metric") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo, self).__setattr__(name, value)


                                            class RouteUpdateTime(Entity):
                                                """
                                                Last time updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                    self.yang_name = "route-update-time"
                                                    self.yang_parent_name = "route-info"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-update-time" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix


                                            class RouteFailTime(Entity):
                                                """
                                                Last time update failed
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                    self.yang_name = "route-fail-time"
                                                    self.yang_parent_name = "route-info"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "route-fail-time" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.route_area_id.is_set or
                                                    self.route_auto_excluded.is_set or
                                                    self.route_forward_distance.is_set or
                                                    self.route_rib_version.is_set or
                                                    self.route_source.is_set or
                                                    self.route_spf_priority.is_set or
                                                    self.route_spf_version.is_set or
                                                    self.route_srte_nbr_registered.is_set or
                                                    self.route_srte_prefix_registered.is_set or
                                                    self.route_te_metric.is_set or
                                                    (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                                    (self.route_update_time is not None and self.route_update_time.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.route_area_id.yfilter != YFilter.not_set or
                                                    self.route_auto_excluded.yfilter != YFilter.not_set or
                                                    self.route_forward_distance.yfilter != YFilter.not_set or
                                                    self.route_rib_version.yfilter != YFilter.not_set or
                                                    self.route_source.yfilter != YFilter.not_set or
                                                    self.route_spf_priority.yfilter != YFilter.not_set or
                                                    self.route_spf_version.yfilter != YFilter.not_set or
                                                    self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                                    self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                                    self.route_te_metric.yfilter != YFilter.not_set or
                                                    (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                                    (self.route_update_time is not None and self.route_update_time.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-info" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                                if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                                if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                                if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                                if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_source.get_name_leafdata())
                                                if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                                if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                                if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                                if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                                if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "route-fail-time"):
                                                    if (self.route_fail_time is None):
                                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime()
                                                        self.route_fail_time.parent = self
                                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                                    return self.route_fail_time

                                                if (child_yang_name == "route-update-time"):
                                                    if (self.route_update_time is None):
                                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime()
                                                        self.route_update_time.parent = self
                                                        self._children_name_map["route_update_time"] = "route-update-time"
                                                    return self.route_update_time

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "route-area-id"):
                                                    self.route_area_id = value
                                                    self.route_area_id.value_namespace = name_space
                                                    self.route_area_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-auto-excluded"):
                                                    self.route_auto_excluded = value
                                                    self.route_auto_excluded.value_namespace = name_space
                                                    self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-forward-distance"):
                                                    self.route_forward_distance = value
                                                    self.route_forward_distance.value_namespace = name_space
                                                    self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-rib-version"):
                                                    self.route_rib_version = value
                                                    self.route_rib_version.value_namespace = name_space
                                                    self.route_rib_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-source"):
                                                    self.route_source = value
                                                    self.route_source.value_namespace = name_space
                                                    self.route_source.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-spf-priority"):
                                                    self.route_spf_priority = value
                                                    self.route_spf_priority.value_namespace = name_space
                                                    self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-spf-version"):
                                                    self.route_spf_version = value
                                                    self.route_spf_version.value_namespace = name_space
                                                    self.route_spf_version.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-srte-nbr-registered"):
                                                    self.route_srte_nbr_registered = value
                                                    self.route_srte_nbr_registered.value_namespace = name_space
                                                    self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-srte-prefix-registered"):
                                                    self.route_srte_prefix_registered = value
                                                    self.route_srte_prefix_registered.value_namespace = name_space
                                                    self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-te-metric"):
                                                    self.route_te_metric = value
                                                    self.route_te_metric.value_namespace = name_space
                                                    self.route_te_metric.value_namespace_prefix = name_space_prefix


                                        class RoutePath(Entity):
                                            """
                                            List of paths to this route
                                            
                                            .. attribute:: area_format
                                            
                                            	Area format IP or uint32
                                            	**type**\:  bool
                                            
                                            .. attribute:: area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type, see RFC2328 etc
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: route_lsaid
                                            
                                            	LSA ID, see RFC2328
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_path_is_mcast_intact
                                            
                                            	Multicast\-intact path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_path_is_ucmp_path
                                            
                                            	UCMP path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sr_microloop_avoidance_path
                                            
                                            	SR Microloop avoidance Path Info
                                            	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath, self).__init__()

                                                self.yang_name = "route-path"
                                                self.yang_parent_name = "local-route-area"

                                                self.area_format = YLeaf(YType.boolean, "area-format")

                                                self.area_id = YLeaf(YType.uint32, "area-id")

                                                self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                                self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                                self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                                self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                                self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                                self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                                self.route_source = YLeaf(YType.str, "route-source")

                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                self._children_yang_names.add("sr-microloop-avoidance-path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("area_format",
                                                                "area_id",
                                                                "lsa_type",
                                                                "route_interface_name",
                                                                "route_lsaid",
                                                                "route_metric",
                                                                "route_next_hop_address",
                                                                "route_path_is_mcast_intact",
                                                                "route_path_is_ucmp_path",
                                                                "route_source") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath, self).__setattr__(name, value)


                                            class SrMicroloopAvoidancePath(Entity):
                                                """
                                                SR Microloop avoidance Path Info
                                                
                                                .. attribute:: microloop_repair
                                                
                                                	Microloop Repair List
                                                	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                                
                                                .. attribute:: microloop_repair_list_size
                                                
                                                	Microloop Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: microloop_strict_spf
                                                
                                                	Strict SPF SID
                                                	**type**\:  bool
                                                
                                                .. attribute:: microloop_tunnel_interface_name
                                                
                                                	Microloop Tunnel Interface name
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                    self.yang_name = "sr-microloop-avoidance-path"
                                                    self.yang_parent_name = "route-path"

                                                    self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                    self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                    self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                    self.microloop_repair = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("microloop_repair_list_size",
                                                                    "microloop_strict_spf",
                                                                    "microloop_tunnel_interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                                class MicroloopRepair(Entity):
                                                    """
                                                    Microloop Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                        self.yang_name = "microloop-repair"
                                                        self.yang_parent_name = "sr-microloop-avoidance-path"

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_id",
                                                                        "repair_element_type",
                                                                        "repair_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "microloop-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-id"):
                                                            self.repair_element_id = value
                                                            self.repair_element_id.value_namespace = name_space
                                                            self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.microloop_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.microloop_repair_list_size.is_set or
                                                        self.microloop_strict_spf.is_set or
                                                        self.microloop_tunnel_interface_name.is_set)

                                                def has_operation(self):
                                                    for c in self.microloop_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                        self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                        self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                                    if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                                    if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "microloop-repair"):
                                                        for c in self.microloop_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.microloop_repair.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "microloop-repair-list-size"):
                                                        self.microloop_repair_list_size = value
                                                        self.microloop_repair_list_size.value_namespace = name_space
                                                        self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "microloop-strict-spf"):
                                                        self.microloop_strict_spf = value
                                                        self.microloop_strict_spf.value_namespace = name_space
                                                        self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "microloop-tunnel-interface-name"):
                                                        self.microloop_tunnel_interface_name = value
                                                        self.microloop_tunnel_interface_name.value_namespace = name_space
                                                        self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.area_format.is_set or
                                                    self.area_id.is_set or
                                                    self.lsa_type.is_set or
                                                    self.route_interface_name.is_set or
                                                    self.route_lsaid.is_set or
                                                    self.route_metric.is_set or
                                                    self.route_next_hop_address.is_set or
                                                    self.route_path_is_mcast_intact.is_set or
                                                    self.route_path_is_ucmp_path.is_set or
                                                    self.route_source.is_set or
                                                    (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.area_format.yfilter != YFilter.not_set or
                                                    self.area_id.yfilter != YFilter.not_set or
                                                    self.lsa_type.yfilter != YFilter.not_set or
                                                    self.route_interface_name.yfilter != YFilter.not_set or
                                                    self.route_lsaid.yfilter != YFilter.not_set or
                                                    self.route_metric.yfilter != YFilter.not_set or
                                                    self.route_next_hop_address.yfilter != YFilter.not_set or
                                                    self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                                    self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                                    self.route_source.yfilter != YFilter.not_set or
                                                    (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.area_format.get_name_leafdata())
                                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                                if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                                if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                                if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                                if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_metric.get_name_leafdata())
                                                if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                                if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                                if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                                if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.route_source.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "sr-microloop-avoidance-path"):
                                                    if (self.sr_microloop_avoidance_path is None):
                                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                        self.sr_microloop_avoidance_path.parent = self
                                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                    return self.sr_microloop_avoidance_path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "area-format"):
                                                    self.area_format = value
                                                    self.area_format.value_namespace = name_space
                                                    self.area_format.value_namespace_prefix = name_space_prefix
                                                if(value_path == "area-id"):
                                                    self.area_id = value
                                                    self.area_id.value_namespace = name_space
                                                    self.area_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsa-type"):
                                                    self.lsa_type = value
                                                    self.lsa_type.value_namespace = name_space
                                                    self.lsa_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-interface-name"):
                                                    self.route_interface_name = value
                                                    self.route_interface_name.value_namespace = name_space
                                                    self.route_interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-lsaid"):
                                                    self.route_lsaid = value
                                                    self.route_lsaid.value_namespace = name_space
                                                    self.route_lsaid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-metric"):
                                                    self.route_metric = value
                                                    self.route_metric.value_namespace = name_space
                                                    self.route_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-next-hop-address"):
                                                    self.route_next_hop_address = value
                                                    self.route_next_hop_address.value_namespace = name_space
                                                    self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-is-mcast-intact"):
                                                    self.route_path_is_mcast_intact = value
                                                    self.route_path_is_mcast_intact.value_namespace = name_space
                                                    self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-path-is-ucmp-path"):
                                                    self.route_path_is_ucmp_path = value
                                                    self.route_path_is_ucmp_path.value_namespace = name_space
                                                    self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                                if(value_path == "route-source"):
                                                    self.route_source = value
                                                    self.route_source.value_namespace = name_space
                                                    self.route_source.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.route_path:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set or
                                                self.route_connected.is_set or
                                                self.route_metric.is_set or
                                                self.route_prefix.is_set or
                                                self.route_prefix_length.is_set or
                                                self.route_type.is_set or
                                                (self.route_info is not None and self.route_info.has_data()))

                                        def has_operation(self):
                                            for c in self.route_path:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set or
                                                self.route_connected.yfilter != YFilter.not_set or
                                                self.route_metric.yfilter != YFilter.not_set or
                                                self.route_prefix.yfilter != YFilter.not_set or
                                                self.route_prefix_length.yfilter != YFilter.not_set or
                                                self.route_type.yfilter != YFilter.not_set or
                                                (self.route_info is not None and self.route_info.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-route-area" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                            if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_connected.get_name_leafdata())
                                            if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_metric.get_name_leafdata())
                                            if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                            if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                            if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-info"):
                                                if (self.route_info is None):
                                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo()
                                                    self.route_info.parent = self
                                                    self._children_name_map["route_info"] = "route-info"
                                                return self.route_info

                                            if (child_yang_name == "route-path"):
                                                for c in self.route_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.route_path.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-connected"):
                                                self.route_connected = value
                                                self.route_connected.value_namespace = name_space
                                                self.route_connected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-metric"):
                                                self.route_metric = value
                                                self.route_metric.value_namespace = name_space
                                                self.route_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-prefix"):
                                                self.route_prefix = value
                                                self.route_prefix.value_namespace = name_space
                                                self.route_prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-prefix-length"):
                                                self.route_prefix_length = value
                                                self.route_prefix_length.value_namespace = name_space
                                                self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-type"):
                                                self.route_type = value
                                                self.route_type.value_namespace = name_space
                                                self.route_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.local_route_area:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.local_route_area:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-route-areas" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local-route-area"):
                                            for c in self.local_route_area:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.local_route_area.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-route-area"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.area_id.is_set or
                                        (self.backup_route_areas is not None and self.backup_route_areas.has_data()) or
                                        (self.connected_route_areas is not None and self.connected_route_areas.has_data()) or
                                        (self.local_route_areas is not None and self.local_route_areas.has_data()) or
                                        (self.multicast_intact_backup_route_areas is not None and self.multicast_intact_backup_route_areas.has_data()) or
                                        (self.multicast_intact_route_areas is not None and self.multicast_intact_route_areas.has_data()) or
                                        (self.route_area_informations is not None and self.route_area_informations.has_data()) or
                                        (self.summary_area_information is not None and self.summary_area_information.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        (self.backup_route_areas is not None and self.backup_route_areas.has_operation()) or
                                        (self.connected_route_areas is not None and self.connected_route_areas.has_operation()) or
                                        (self.local_route_areas is not None and self.local_route_areas.has_operation()) or
                                        (self.multicast_intact_backup_route_areas is not None and self.multicast_intact_backup_route_areas.has_operation()) or
                                        (self.multicast_intact_route_areas is not None and self.multicast_intact_route_areas.has_operation()) or
                                        (self.route_area_informations is not None and self.route_area_informations.has_operation()) or
                                        (self.summary_area_information is not None and self.summary_area_information.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-area" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "backup-route-areas"):
                                        if (self.backup_route_areas is None):
                                            self.backup_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas()
                                            self.backup_route_areas.parent = self
                                            self._children_name_map["backup_route_areas"] = "backup-route-areas"
                                        return self.backup_route_areas

                                    if (child_yang_name == "connected-route-areas"):
                                        if (self.connected_route_areas is None):
                                            self.connected_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas()
                                            self.connected_route_areas.parent = self
                                            self._children_name_map["connected_route_areas"] = "connected-route-areas"
                                        return self.connected_route_areas

                                    if (child_yang_name == "local-route-areas"):
                                        if (self.local_route_areas is None):
                                            self.local_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas()
                                            self.local_route_areas.parent = self
                                            self._children_name_map["local_route_areas"] = "local-route-areas"
                                        return self.local_route_areas

                                    if (child_yang_name == "multicast-intact-backup-route-areas"):
                                        if (self.multicast_intact_backup_route_areas is None):
                                            self.multicast_intact_backup_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas()
                                            self.multicast_intact_backup_route_areas.parent = self
                                            self._children_name_map["multicast_intact_backup_route_areas"] = "multicast-intact-backup-route-areas"
                                        return self.multicast_intact_backup_route_areas

                                    if (child_yang_name == "multicast-intact-route-areas"):
                                        if (self.multicast_intact_route_areas is None):
                                            self.multicast_intact_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas()
                                            self.multicast_intact_route_areas.parent = self
                                            self._children_name_map["multicast_intact_route_areas"] = "multicast-intact-route-areas"
                                        return self.multicast_intact_route_areas

                                    if (child_yang_name == "route-area-informations"):
                                        if (self.route_area_informations is None):
                                            self.route_area_informations = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations()
                                            self.route_area_informations.parent = self
                                            self._children_name_map["route_area_informations"] = "route-area-informations"
                                        return self.route_area_informations

                                    if (child_yang_name == "summary-area-information"):
                                        if (self.summary_area_information is None):
                                            self.summary_area_information = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation()
                                            self.summary_area_information.parent = self
                                            self._children_name_map["summary_area_information"] = "summary-area-information"
                                        return self.summary_area_information

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "backup-route-areas" or name == "connected-route-areas" or name == "local-route-areas" or name == "multicast-intact-backup-route-areas" or name == "multicast-intact-route-areas" or name == "route-area-informations" or name == "summary-area-information" or name == "area-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.route_area:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.route_area:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "route-areas" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "route-area"):
                                    for c in self.route_area:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.route_area.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "route-area"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class RouteTable(Entity):
                            """
                            OSPF Route Table
                            
                            .. attribute:: route
                            
                            	An OSPF route
                            	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable, self).__init__()

                                self.yang_name = "route-table"
                                self.yang_parent_name = "route-information"

                                self.route = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable, self).__setattr__(name, value)


                            class Route(Entity):
                                """
                                An OSPF route
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route, self).__init__()

                                    self.yang_name = "route"
                                    self.yang_parent_name = "route-table"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length",
                                                    "route_connected",
                                                    "route_metric",
                                                    "route_prefix",
                                                    "route_prefix_length",
                                                    "route_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route, self).__setattr__(name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "route"

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("route_area_id",
                                                        "route_auto_excluded",
                                                        "route_forward_distance",
                                                        "route_rib_version",
                                                        "route_source",
                                                        "route_spf_priority",
                                                        "route_spf_version",
                                                        "route_srte_nbr_registered",
                                                        "route_srte_prefix_registered",
                                                        "route_te_metric") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo, self).__setattr__(name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-update-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-fail-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.route_area_id.is_set or
                                            self.route_auto_excluded.is_set or
                                            self.route_forward_distance.is_set or
                                            self.route_rib_version.is_set or
                                            self.route_source.is_set or
                                            self.route_spf_priority.is_set or
                                            self.route_spf_version.is_set or
                                            self.route_srte_nbr_registered.is_set or
                                            self.route_srte_prefix_registered.is_set or
                                            self.route_te_metric.is_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                            (self.route_update_time is not None and self.route_update_time.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.route_area_id.yfilter != YFilter.not_set or
                                            self.route_auto_excluded.yfilter != YFilter.not_set or
                                            self.route_forward_distance.yfilter != YFilter.not_set or
                                            self.route_rib_version.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            self.route_spf_priority.yfilter != YFilter.not_set or
                                            self.route_spf_version.yfilter != YFilter.not_set or
                                            self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                            self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                            self.route_te_metric.yfilter != YFilter.not_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                            (self.route_update_time is not None and self.route_update_time.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                        if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                        if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                        if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())
                                        if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                        if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                        if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                        if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                        if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-fail-time"):
                                            if (self.route_fail_time is None):
                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                            return self.route_fail_time

                                        if (child_yang_name == "route-update-time"):
                                            if (self.route_update_time is None):
                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                            return self.route_update_time

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "route-area-id"):
                                            self.route_area_id = value
                                            self.route_area_id.value_namespace = name_space
                                            self.route_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-auto-excluded"):
                                            self.route_auto_excluded = value
                                            self.route_auto_excluded.value_namespace = name_space
                                            self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-forward-distance"):
                                            self.route_forward_distance = value
                                            self.route_forward_distance.value_namespace = name_space
                                            self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-rib-version"):
                                            self.route_rib_version = value
                                            self.route_rib_version.value_namespace = name_space
                                            self.route_rib_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-priority"):
                                            self.route_spf_priority = value
                                            self.route_spf_priority.value_namespace = name_space
                                            self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-version"):
                                            self.route_spf_version = value
                                            self.route_spf_version.value_namespace = name_space
                                            self.route_spf_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-nbr-registered"):
                                            self.route_srte_nbr_registered = value
                                            self.route_srte_nbr_registered.value_namespace = name_space
                                            self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-prefix-registered"):
                                            self.route_srte_prefix_registered = value
                                            self.route_srte_prefix_registered.value_namespace = name_space
                                            self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-te-metric"):
                                            self.route_te_metric = value
                                            self.route_te_metric.value_namespace = name_space
                                            self.route_te_metric.value_namespace_prefix = name_space_prefix


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: area_format
                                    
                                    	Area format IP or uint32
                                    	**type**\:  bool
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "route"

                                        self.area_format = YLeaf(YType.boolean, "area-format")

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("area_format",
                                                        "area_id",
                                                        "lsa_type",
                                                        "route_interface_name",
                                                        "route_lsaid",
                                                        "route_metric",
                                                        "route_next_hop_address",
                                                        "route_path_is_mcast_intact",
                                                        "route_path_is_ucmp_path",
                                                        "route_source") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath, self).__setattr__(name, value)


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("microloop_repair_list_size",
                                                            "microloop_strict_spf",
                                                            "microloop_tunnel_interface_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("repair_element_id",
                                                                "repair_element_type",
                                                                "repair_label") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.repair_element_id.is_set or
                                                    self.repair_element_type.is_set or
                                                    self.repair_label.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.repair_element_id.yfilter != YFilter.not_set or
                                                    self.repair_element_type.yfilter != YFilter.not_set or
                                                    self.repair_label.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "microloop-repair" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "repair-element-id"):
                                                    self.repair_element_id = value
                                                    self.repair_element_id.value_namespace = name_space
                                                    self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-element-type"):
                                                    self.repair_element_type = value
                                                    self.repair_element_type.value_namespace = name_space
                                                    self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-label"):
                                                    self.repair_label = value
                                                    self.repair_label.value_namespace = name_space
                                                    self.repair_label.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.microloop_repair:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.microloop_repair_list_size.is_set or
                                                self.microloop_strict_spf.is_set or
                                                self.microloop_tunnel_interface_name.is_set)

                                        def has_operation(self):
                                            for c in self.microloop_repair:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                            if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                            if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "microloop-repair"):
                                                for c in self.microloop_repair:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.microloop_repair.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "microloop-repair-list-size"):
                                                self.microloop_repair_list_size = value
                                                self.microloop_repair_list_size.value_namespace = name_space
                                                self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-strict-spf"):
                                                self.microloop_strict_spf = value
                                                self.microloop_strict_spf.value_namespace = name_space
                                                self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-tunnel-interface-name"):
                                                self.microloop_tunnel_interface_name = value
                                                self.microloop_tunnel_interface_name.value_namespace = name_space
                                                self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.area_format.is_set or
                                            self.area_id.is_set or
                                            self.lsa_type.is_set or
                                            self.route_interface_name.is_set or
                                            self.route_lsaid.is_set or
                                            self.route_metric.is_set or
                                            self.route_next_hop_address.is_set or
                                            self.route_path_is_mcast_intact.is_set or
                                            self.route_path_is_ucmp_path.is_set or
                                            self.route_source.is_set or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.area_format.yfilter != YFilter.not_set or
                                            self.area_id.yfilter != YFilter.not_set or
                                            self.lsa_type.yfilter != YFilter.not_set or
                                            self.route_interface_name.yfilter != YFilter.not_set or
                                            self.route_lsaid.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_next_hop_address.yfilter != YFilter.not_set or
                                            self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                            self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_format.get_name_leafdata())
                                        if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id.get_name_leafdata())
                                        if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                        if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                        if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                        if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                        if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "sr-microloop-avoidance-path"):
                                            if (self.sr_microloop_avoidance_path is None):
                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            return self.sr_microloop_avoidance_path

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "area-format"):
                                            self.area_format = value
                                            self.area_format.value_namespace = name_space
                                            self.area_format.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-id"):
                                            self.area_id = value
                                            self.area_id.value_namespace = name_space
                                            self.area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-type"):
                                            self.lsa_type = value
                                            self.lsa_type.value_namespace = name_space
                                            self.lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-interface-name"):
                                            self.route_interface_name = value
                                            self.route_interface_name.value_namespace = name_space
                                            self.route_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-lsaid"):
                                            self.route_lsaid = value
                                            self.route_lsaid.value_namespace = name_space
                                            self.route_lsaid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-next-hop-address"):
                                            self.route_next_hop_address = value
                                            self.route_next_hop_address.value_namespace = name_space
                                            self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-mcast-intact"):
                                            self.route_path_is_mcast_intact = value
                                            self.route_path_is_mcast_intact.value_namespace = name_space
                                            self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-ucmp-path"):
                                            self.route_path_is_ucmp_path = value
                                            self.route_path_is_ucmp_path.value_namespace = name_space
                                            self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.route_path:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        self.route_connected.is_set or
                                        self.route_metric.is_set or
                                        self.route_prefix.is_set or
                                        self.route_prefix_length.is_set or
                                        self.route_type.is_set or
                                        (self.route_info is not None and self.route_info.has_data()))

                                def has_operation(self):
                                    for c in self.route_path:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        self.route_connected.yfilter != YFilter.not_set or
                                        self.route_metric.yfilter != YFilter.not_set or
                                        self.route_prefix.yfilter != YFilter.not_set or
                                        self.route_prefix_length.yfilter != YFilter.not_set or
                                        self.route_type.yfilter != YFilter.not_set or
                                        (self.route_info is not None and self.route_info.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                    if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_connected.get_name_leafdata())
                                    if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_metric.get_name_leafdata())
                                    if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                    if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-info"):
                                        if (self.route_info is None):
                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                        return self.route_info

                                    if (child_yang_name == "route-path"):
                                        for c in self.route_path:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.route_path.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-connected"):
                                        self.route_connected = value
                                        self.route_connected.value_namespace = name_space
                                        self.route_connected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-metric"):
                                        self.route_metric = value
                                        self.route_metric.value_namespace = name_space
                                        self.route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix"):
                                        self.route_prefix = value
                                        self.route_prefix.value_namespace = name_space
                                        self.route_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix-length"):
                                        self.route_prefix_length = value
                                        self.route_prefix_length.value_namespace = name_space
                                        self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-type"):
                                        self.route_type = value
                                        self.route_type.value_namespace = name_space
                                        self.route_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.route:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.route:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "route-table" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "route"):
                                    for c in self.route:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.route.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "route"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class ExternalRoutes(Entity):
                            """
                            OSPF External Route Table
                            
                            .. attribute:: external_route
                            
                            	OSPF external route
                            	**type**\: list of    :py:class:`ExternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes, self).__init__()

                                self.yang_name = "external-routes"
                                self.yang_parent_name = "route-information"

                                self.external_route = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes, self).__setattr__(name, value)


                            class ExternalRoute(Entity):
                                """
                                OSPF external route
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: protocol_name
                                
                                	Name of protocol from which the external route was redistributed
                                	**type**\:   :py:class:`ProtocolName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName>`
                                
                                .. attribute:: route_extended_community
                                
                                	Extended communities in the route
                                	**type**\:   :py:class:`RouteExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity>`
                                
                                .. attribute:: route_information
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute, self).__init__()

                                    self.yang_name = "external-route"
                                    self.yang_parent_name = "external-routes"

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.protocol_name = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName()
                                    self.protocol_name.parent = self
                                    self._children_name_map["protocol_name"] = "protocol-name"
                                    self._children_yang_names.add("protocol-name")

                                    self.route_extended_community = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity()
                                    self.route_extended_community.parent = self
                                    self._children_name_map["route_extended_community"] = "route-extended-community"
                                    self._children_yang_names.add("route-extended-community")

                                    self.route_information = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation()
                                    self.route_information.parent = self
                                    self._children_name_map["route_information"] = "route-information"
                                    self._children_yang_names.add("route-information")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("prefix",
                                                    "prefix_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute, self).__setattr__(name, value)


                                class RouteInformation(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation, self).__init__()

                                        self.yang_name = "route-information"
                                        self.yang_parent_name = "external-route"

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("route_connected",
                                                        "route_metric",
                                                        "route_prefix",
                                                        "route_prefix_length",
                                                        "route_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation, self).__setattr__(name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "route-information"

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("route_area_id",
                                                            "route_auto_excluded",
                                                            "route_forward_distance",
                                                            "route_rib_version",
                                                            "route_source",
                                                            "route_spf_priority",
                                                            "route_spf_version",
                                                            "route_srte_nbr_registered",
                                                            "route_srte_prefix_registered",
                                                            "route_te_metric") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo, self).__setattr__(name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-update-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-fail-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.route_area_id.is_set or
                                                self.route_auto_excluded.is_set or
                                                self.route_forward_distance.is_set or
                                                self.route_rib_version.is_set or
                                                self.route_source.is_set or
                                                self.route_spf_priority.is_set or
                                                self.route_spf_version.is_set or
                                                self.route_srte_nbr_registered.is_set or
                                                self.route_srte_prefix_registered.is_set or
                                                self.route_te_metric.is_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                                (self.route_update_time is not None and self.route_update_time.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.route_area_id.yfilter != YFilter.not_set or
                                                self.route_auto_excluded.yfilter != YFilter.not_set or
                                                self.route_forward_distance.yfilter != YFilter.not_set or
                                                self.route_rib_version.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                self.route_spf_priority.yfilter != YFilter.not_set or
                                                self.route_spf_version.yfilter != YFilter.not_set or
                                                self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                                self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                                self.route_te_metric.yfilter != YFilter.not_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                                (self.route_update_time is not None and self.route_update_time.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-info" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                            if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                            if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                            if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())
                                            if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                            if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                            if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                            if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                            if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-fail-time"):
                                                if (self.route_fail_time is None):
                                                    self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime()
                                                    self.route_fail_time.parent = self
                                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                                return self.route_fail_time

                                            if (child_yang_name == "route-update-time"):
                                                if (self.route_update_time is None):
                                                    self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime()
                                                    self.route_update_time.parent = self
                                                    self._children_name_map["route_update_time"] = "route-update-time"
                                                return self.route_update_time

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "route-area-id"):
                                                self.route_area_id = value
                                                self.route_area_id.value_namespace = name_space
                                                self.route_area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-auto-excluded"):
                                                self.route_auto_excluded = value
                                                self.route_auto_excluded.value_namespace = name_space
                                                self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-forward-distance"):
                                                self.route_forward_distance = value
                                                self.route_forward_distance.value_namespace = name_space
                                                self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-rib-version"):
                                                self.route_rib_version = value
                                                self.route_rib_version.value_namespace = name_space
                                                self.route_rib_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-priority"):
                                                self.route_spf_priority = value
                                                self.route_spf_priority.value_namespace = name_space
                                                self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-version"):
                                                self.route_spf_version = value
                                                self.route_spf_version.value_namespace = name_space
                                                self.route_spf_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-nbr-registered"):
                                                self.route_srte_nbr_registered = value
                                                self.route_srte_nbr_registered.value_namespace = name_space
                                                self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-prefix-registered"):
                                                self.route_srte_prefix_registered = value
                                                self.route_srte_prefix_registered.value_namespace = name_space
                                                self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-te-metric"):
                                                self.route_te_metric = value
                                                self.route_te_metric.value_namespace = name_space
                                                self.route_te_metric.value_namespace_prefix = name_space_prefix


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: area_format
                                        
                                        	Area format IP or uint32
                                        	**type**\:  bool
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "route-information"

                                            self.area_format = YLeaf(YType.boolean, "area-format")

                                            self.area_id = YLeaf(YType.uint32, "area-id")

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("area_format",
                                                            "area_id",
                                                            "lsa_type",
                                                            "route_interface_name",
                                                            "route_lsaid",
                                                            "route_metric",
                                                            "route_next_hop_address",
                                                            "route_path_is_mcast_intact",
                                                            "route_path_is_ucmp_path",
                                                            "route_source") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath, self).__setattr__(name, value)


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("microloop_repair_list_size",
                                                                "microloop_strict_spf",
                                                                "microloop_tunnel_interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_id",
                                                                    "repair_element_type",
                                                                    "repair_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "microloop-repair" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-id"):
                                                        self.repair_element_id = value
                                                        self.repair_element_id.value_namespace = name_space
                                                        self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.microloop_repair_list_size.is_set or
                                                    self.microloop_strict_spf.is_set or
                                                    self.microloop_tunnel_interface_name.is_set)

                                            def has_operation(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                    self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                    self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                                if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                                if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "microloop-repair"):
                                                    for c in self.microloop_repair:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.microloop_repair.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "microloop-repair-list-size"):
                                                    self.microloop_repair_list_size = value
                                                    self.microloop_repair_list_size.value_namespace = name_space
                                                    self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-strict-spf"):
                                                    self.microloop_strict_spf = value
                                                    self.microloop_strict_spf.value_namespace = name_space
                                                    self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-tunnel-interface-name"):
                                                    self.microloop_tunnel_interface_name = value
                                                    self.microloop_tunnel_interface_name.value_namespace = name_space
                                                    self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.area_format.is_set or
                                                self.area_id.is_set or
                                                self.lsa_type.is_set or
                                                self.route_interface_name.is_set or
                                                self.route_lsaid.is_set or
                                                self.route_metric.is_set or
                                                self.route_next_hop_address.is_set or
                                                self.route_path_is_mcast_intact.is_set or
                                                self.route_path_is_ucmp_path.is_set or
                                                self.route_source.is_set or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.area_format.yfilter != YFilter.not_set or
                                                self.area_id.yfilter != YFilter.not_set or
                                                self.lsa_type.yfilter != YFilter.not_set or
                                                self.route_interface_name.yfilter != YFilter.not_set or
                                                self.route_lsaid.yfilter != YFilter.not_set or
                                                self.route_metric.yfilter != YFilter.not_set or
                                                self.route_next_hop_address.yfilter != YFilter.not_set or
                                                self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                                self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_format.get_name_leafdata())
                                            if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_id.get_name_leafdata())
                                            if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                            if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                            if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                            if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_metric.get_name_leafdata())
                                            if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                            if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                            if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "sr-microloop-avoidance-path"):
                                                if (self.sr_microloop_avoidance_path is None):
                                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath()
                                                    self.sr_microloop_avoidance_path.parent = self
                                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                return self.sr_microloop_avoidance_path

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "area-format"):
                                                self.area_format = value
                                                self.area_format.value_namespace = name_space
                                                self.area_format.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-id"):
                                                self.area_id = value
                                                self.area_id.value_namespace = name_space
                                                self.area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-type"):
                                                self.lsa_type = value
                                                self.lsa_type.value_namespace = name_space
                                                self.lsa_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-interface-name"):
                                                self.route_interface_name = value
                                                self.route_interface_name.value_namespace = name_space
                                                self.route_interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-lsaid"):
                                                self.route_lsaid = value
                                                self.route_lsaid.value_namespace = name_space
                                                self.route_lsaid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-metric"):
                                                self.route_metric = value
                                                self.route_metric.value_namespace = name_space
                                                self.route_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-next-hop-address"):
                                                self.route_next_hop_address = value
                                                self.route_next_hop_address.value_namespace = name_space
                                                self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-mcast-intact"):
                                                self.route_path_is_mcast_intact = value
                                                self.route_path_is_mcast_intact.value_namespace = name_space
                                                self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-ucmp-path"):
                                                self.route_path_is_ucmp_path = value
                                                self.route_path_is_ucmp_path.value_namespace = name_space
                                                self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.route_path:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.route_connected.is_set or
                                            self.route_metric.is_set or
                                            self.route_prefix.is_set or
                                            self.route_prefix_length.is_set or
                                            self.route_type.is_set or
                                            (self.route_info is not None and self.route_info.has_data()))

                                    def has_operation(self):
                                        for c in self.route_path:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.route_connected.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_prefix.yfilter != YFilter.not_set or
                                            self.route_prefix_length.yfilter != YFilter.not_set or
                                            self.route_type.yfilter != YFilter.not_set or
                                            (self.route_info is not None and self.route_info.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_connected.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                        if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                        if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-info"):
                                            if (self.route_info is None):
                                                self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo()
                                                self.route_info.parent = self
                                                self._children_name_map["route_info"] = "route-info"
                                            return self.route_info

                                        if (child_yang_name == "route-path"):
                                            for c in self.route_path:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.route_path.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-info" or name == "route-path" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "route-connected"):
                                            self.route_connected = value
                                            self.route_connected.value_namespace = name_space
                                            self.route_connected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix"):
                                            self.route_prefix = value
                                            self.route_prefix.value_namespace = name_space
                                            self.route_prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix-length"):
                                            self.route_prefix_length = value
                                            self.route_prefix_length.value_namespace = name_space
                                            self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-type"):
                                            self.route_type = value
                                            self.route_type.value_namespace = name_space
                                            self.route_type.value_namespace_prefix = name_space_prefix


                                class ProtocolName(Entity):
                                    """
                                    Name of protocol from which the external route
                                    was redistributed
                                    
                                    .. attribute:: bgp_as_number
                                    
                                    	BGP Autonomous System Number
                                    	**type**\:  str
                                    
                                    .. attribute:: connected_instance
                                    
                                    	Connected instance name
                                    	**type**\:  str
                                    
                                    .. attribute:: eigrp_as_number
                                    
                                    	Autonomous System Number
                                    	**type**\:  str
                                    
                                    .. attribute:: isis_instance_id
                                    
                                    	ISIS instance identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: ospf_process_id
                                    
                                    	OSPF process identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: protocol_type
                                    
                                    	ProtocolType
                                    	**type**\:   :py:class:`RedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.RedistProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName, self).__init__()

                                        self.yang_name = "protocol-name"
                                        self.yang_parent_name = "external-route"

                                        self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                        self.connected_instance = YLeaf(YType.str, "connected-instance")

                                        self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                        self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                        self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                        self.protocol_type = YLeaf(YType.enumeration, "protocol-type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_as_number",
                                                        "connected_instance",
                                                        "eigrp_as_number",
                                                        "isis_instance_id",
                                                        "ospf_process_id",
                                                        "protocol_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_as_number.is_set or
                                            self.connected_instance.is_set or
                                            self.eigrp_as_number.is_set or
                                            self.isis_instance_id.is_set or
                                            self.ospf_process_id.is_set or
                                            self.protocol_type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_as_number.yfilter != YFilter.not_set or
                                            self.connected_instance.yfilter != YFilter.not_set or
                                            self.eigrp_as_number.yfilter != YFilter.not_set or
                                            self.isis_instance_id.yfilter != YFilter.not_set or
                                            self.ospf_process_id.yfilter != YFilter.not_set or
                                            self.protocol_type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "protocol-name" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_as_number.is_set or self.bgp_as_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_as_number.get_name_leafdata())
                                        if (self.connected_instance.is_set or self.connected_instance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.connected_instance.get_name_leafdata())
                                        if (self.eigrp_as_number.is_set or self.eigrp_as_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.eigrp_as_number.get_name_leafdata())
                                        if (self.isis_instance_id.is_set or self.isis_instance_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.isis_instance_id.get_name_leafdata())
                                        if (self.ospf_process_id.is_set or self.ospf_process_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_process_id.get_name_leafdata())
                                        if (self.protocol_type.is_set or self.protocol_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-as-number" or name == "connected-instance" or name == "eigrp-as-number" or name == "isis-instance-id" or name == "ospf-process-id" or name == "protocol-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-as-number"):
                                            self.bgp_as_number = value
                                            self.bgp_as_number.value_namespace = name_space
                                            self.bgp_as_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "connected-instance"):
                                            self.connected_instance = value
                                            self.connected_instance.value_namespace = name_space
                                            self.connected_instance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "eigrp-as-number"):
                                            self.eigrp_as_number = value
                                            self.eigrp_as_number.value_namespace = name_space
                                            self.eigrp_as_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "isis-instance-id"):
                                            self.isis_instance_id = value
                                            self.isis_instance_id.value_namespace = name_space
                                            self.isis_instance_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-process-id"):
                                            self.ospf_process_id = value
                                            self.ospf_process_id.value_namespace = name_space
                                            self.ospf_process_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol-type"):
                                            self.protocol_type = value
                                            self.protocol_type.value_namespace = name_space
                                            self.protocol_type.value_namespace_prefix = name_space_prefix


                                class RouteExtendedCommunity(Entity):
                                    """
                                    Extended communities in the route
                                    
                                    .. attribute:: extended_community_area_id
                                    
                                    	Area id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: extended_community_domain_id_value
                                    
                                    	Domain ID value
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extended_community_options
                                    
                                    	Route Options
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: extended_community_route_type
                                    
                                    	Route type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: extended_community_router_id
                                    
                                    	Router id
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: extended_communityl_domain_id_type
                                    
                                    	Domain ID type
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, self).__init__()

                                        self.yang_name = "route-extended-community"
                                        self.yang_parent_name = "external-route"

                                        self.extended_community_area_id = YLeaf(YType.uint32, "extended-community-area-id")

                                        self.extended_community_domain_id_value = YLeaf(YType.str, "extended-community-domain-id-value")

                                        self.extended_community_options = YLeaf(YType.uint8, "extended-community-options")

                                        self.extended_community_route_type = YLeaf(YType.uint8, "extended-community-route-type")

                                        self.extended_community_router_id = YLeaf(YType.str, "extended-community-router-id")

                                        self.extended_communityl_domain_id_type = YLeaf(YType.uint16, "extended-communityl-domain-id-type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("extended_community_area_id",
                                                        "extended_community_domain_id_value",
                                                        "extended_community_options",
                                                        "extended_community_route_type",
                                                        "extended_community_router_id",
                                                        "extended_communityl_domain_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.extended_community_area_id.is_set or
                                            self.extended_community_domain_id_value.is_set or
                                            self.extended_community_options.is_set or
                                            self.extended_community_route_type.is_set or
                                            self.extended_community_router_id.is_set or
                                            self.extended_communityl_domain_id_type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.extended_community_area_id.yfilter != YFilter.not_set or
                                            self.extended_community_domain_id_value.yfilter != YFilter.not_set or
                                            self.extended_community_options.yfilter != YFilter.not_set or
                                            self.extended_community_route_type.yfilter != YFilter.not_set or
                                            self.extended_community_router_id.yfilter != YFilter.not_set or
                                            self.extended_communityl_domain_id_type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-extended-community" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.extended_community_area_id.is_set or self.extended_community_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.extended_community_area_id.get_name_leafdata())
                                        if (self.extended_community_domain_id_value.is_set or self.extended_community_domain_id_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.extended_community_domain_id_value.get_name_leafdata())
                                        if (self.extended_community_options.is_set or self.extended_community_options.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.extended_community_options.get_name_leafdata())
                                        if (self.extended_community_route_type.is_set or self.extended_community_route_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.extended_community_route_type.get_name_leafdata())
                                        if (self.extended_community_router_id.is_set or self.extended_community_router_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.extended_community_router_id.get_name_leafdata())
                                        if (self.extended_communityl_domain_id_type.is_set or self.extended_communityl_domain_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.extended_communityl_domain_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "extended-community-area-id" or name == "extended-community-domain-id-value" or name == "extended-community-options" or name == "extended-community-route-type" or name == "extended-community-router-id" or name == "extended-communityl-domain-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "extended-community-area-id"):
                                            self.extended_community_area_id = value
                                            self.extended_community_area_id.value_namespace = name_space
                                            self.extended_community_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "extended-community-domain-id-value"):
                                            self.extended_community_domain_id_value = value
                                            self.extended_community_domain_id_value.value_namespace = name_space
                                            self.extended_community_domain_id_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "extended-community-options"):
                                            self.extended_community_options = value
                                            self.extended_community_options.value_namespace = name_space
                                            self.extended_community_options.value_namespace_prefix = name_space_prefix
                                        if(value_path == "extended-community-route-type"):
                                            self.extended_community_route_type = value
                                            self.extended_community_route_type.value_namespace = name_space
                                            self.extended_community_route_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "extended-community-router-id"):
                                            self.extended_community_router_id = value
                                            self.extended_community_router_id.value_namespace = name_space
                                            self.extended_community_router_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "extended-communityl-domain-id-type"):
                                            self.extended_communityl_domain_id_type = value
                                            self.extended_communityl_domain_id_type.value_namespace = name_space
                                            self.extended_communityl_domain_id_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.prefix.is_set or
                                        self.prefix_length.is_set or
                                        (self.protocol_name is not None and self.protocol_name.has_data()) or
                                        (self.route_extended_community is not None and self.route_extended_community.has_data()) or
                                        (self.route_information is not None and self.route_information.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set or
                                        (self.protocol_name is not None and self.protocol_name.has_operation()) or
                                        (self.route_extended_community is not None and self.route_extended_community.has_operation()) or
                                        (self.route_information is not None and self.route_information.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "external-route" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "protocol-name"):
                                        if (self.protocol_name is None):
                                            self.protocol_name = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName()
                                            self.protocol_name.parent = self
                                            self._children_name_map["protocol_name"] = "protocol-name"
                                        return self.protocol_name

                                    if (child_yang_name == "route-extended-community"):
                                        if (self.route_extended_community is None):
                                            self.route_extended_community = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity()
                                            self.route_extended_community.parent = self
                                            self._children_name_map["route_extended_community"] = "route-extended-community"
                                        return self.route_extended_community

                                    if (child_yang_name == "route-information"):
                                        if (self.route_information is None):
                                            self.route_information = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation()
                                            self.route_information.parent = self
                                            self._children_name_map["route_information"] = "route-information"
                                        return self.route_information

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "protocol-name" or name == "route-extended-community" or name == "route-information" or name == "prefix" or name == "prefix-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.external_route:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.external_route:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "external-routes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "external-route"):
                                    for c in self.external_route:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.external_route.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "external-route"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.backup_routes is not None and self.backup_routes.has_data()) or
                                (self.connected_routes is not None and self.connected_routes.has_data()) or
                                (self.external_routes is not None and self.external_routes.has_data()) or
                                (self.local_routes is not None and self.local_routes.has_data()) or
                                (self.multicast_intact_backup_routes is not None and self.multicast_intact_backup_routes.has_data()) or
                                (self.multicast_intact_route_table is not None and self.multicast_intact_route_table.has_data()) or
                                (self.route_areas is not None and self.route_areas.has_data()) or
                                (self.route_table is not None and self.route_table.has_data()) or
                                (self.summary_information is not None and self.summary_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.backup_routes is not None and self.backup_routes.has_operation()) or
                                (self.connected_routes is not None and self.connected_routes.has_operation()) or
                                (self.external_routes is not None and self.external_routes.has_operation()) or
                                (self.local_routes is not None and self.local_routes.has_operation()) or
                                (self.multicast_intact_backup_routes is not None and self.multicast_intact_backup_routes.has_operation()) or
                                (self.multicast_intact_route_table is not None and self.multicast_intact_route_table.has_operation()) or
                                (self.route_areas is not None and self.route_areas.has_operation()) or
                                (self.route_table is not None and self.route_table.has_operation()) or
                                (self.summary_information is not None and self.summary_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "backup-routes"):
                                if (self.backup_routes is None):
                                    self.backup_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes()
                                    self.backup_routes.parent = self
                                    self._children_name_map["backup_routes"] = "backup-routes"
                                return self.backup_routes

                            if (child_yang_name == "connected-routes"):
                                if (self.connected_routes is None):
                                    self.connected_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes()
                                    self.connected_routes.parent = self
                                    self._children_name_map["connected_routes"] = "connected-routes"
                                return self.connected_routes

                            if (child_yang_name == "external-routes"):
                                if (self.external_routes is None):
                                    self.external_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes()
                                    self.external_routes.parent = self
                                    self._children_name_map["external_routes"] = "external-routes"
                                return self.external_routes

                            if (child_yang_name == "local-routes"):
                                if (self.local_routes is None):
                                    self.local_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes()
                                    self.local_routes.parent = self
                                    self._children_name_map["local_routes"] = "local-routes"
                                return self.local_routes

                            if (child_yang_name == "multicast-intact-backup-routes"):
                                if (self.multicast_intact_backup_routes is None):
                                    self.multicast_intact_backup_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes()
                                    self.multicast_intact_backup_routes.parent = self
                                    self._children_name_map["multicast_intact_backup_routes"] = "multicast-intact-backup-routes"
                                return self.multicast_intact_backup_routes

                            if (child_yang_name == "multicast-intact-route-table"):
                                if (self.multicast_intact_route_table is None):
                                    self.multicast_intact_route_table = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable()
                                    self.multicast_intact_route_table.parent = self
                                    self._children_name_map["multicast_intact_route_table"] = "multicast-intact-route-table"
                                return self.multicast_intact_route_table

                            if (child_yang_name == "route-areas"):
                                if (self.route_areas is None):
                                    self.route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas()
                                    self.route_areas.parent = self
                                    self._children_name_map["route_areas"] = "route-areas"
                                return self.route_areas

                            if (child_yang_name == "route-table"):
                                if (self.route_table is None):
                                    self.route_table = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable()
                                    self.route_table.parent = self
                                    self._children_name_map["route_table"] = "route-table"
                                return self.route_table

                            if (child_yang_name == "summary-information"):
                                if (self.summary_information is None):
                                    self.summary_information = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation()
                                    self.summary_information.parent = self
                                    self._children_name_map["summary_information"] = "summary-information"
                                return self.summary_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "backup-routes" or name == "connected-routes" or name == "external-routes" or name == "local-routes" or name == "multicast-intact-backup-routes" or name == "multicast-intact-route-table" or name == "route-areas" or name == "route-table" or name == "summary-information"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class InterfaceInformation(Entity):
                        """
                        Container for OSPF Interfaces/links
                        
                        .. attribute:: interface_briefs
                        
                        	OSPF Interface Brief Table
                        	**type**\:   :py:class:`InterfaceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs>`
                        
                        .. attribute:: interfaces
                        
                        	OSPF Interface Table
                        	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces>`
                        
                        .. attribute:: virtual_links
                        
                        	Virtual Link table
                        	**type**\:   :py:class:`VirtualLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation, self).__init__()

                            self.yang_name = "interface-information"
                            self.yang_parent_name = "vrf"

                            self.interface_briefs = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs()
                            self.interface_briefs.parent = self
                            self._children_name_map["interface_briefs"] = "interface-briefs"
                            self._children_yang_names.add("interface-briefs")

                            self.interfaces = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                            self._children_yang_names.add("interfaces")

                            self.virtual_links = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks()
                            self.virtual_links.parent = self
                            self._children_name_map["virtual_links"] = "virtual-links"
                            self._children_yang_names.add("virtual-links")


                        class VirtualLinks(Entity):
                            """
                            Virtual Link table
                            
                            .. attribute:: virtual_link
                            
                            	Information for one Virtual link
                            	**type**\: list of    :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks, self).__init__()

                                self.yang_name = "virtual-links"
                                self.yang_parent_name = "interface-information"

                                self.virtual_link = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks, self).__setattr__(name, value)


                            class VirtualLink(Entity):
                                """
                                Information for one Virtual link
                                
                                .. attribute:: virtual_link_name  <key>
                                
                                	Virtual link
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: transit_area
                                
                                	Transit area id
                                	**type**\:  str
                                
                                .. attribute:: virtaul_link_retransmission_interval
                                
                                	Retransmission interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_authentication_type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                
                                .. attribute:: virtual_link_cost
                                
                                	Cost of the virtual link
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtual_link_dc_bitless_lsa
                                
                                	Number of LSA's with demand circuit bit not set
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_dead_interval
                                
                                	Dead interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_demand_circuit
                                
                                	If true, the link runs as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: virtual_link_hello_interval
                                
                                	Hello interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_hello_interval_ms
                                
                                	Hello interval (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_interface_name
                                
                                	Interface on which this virtual link is formed
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: virtual_link_keychain_id
                                
                                	Virtual Link Keychain ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: virtual_link_last_nsf
                                
                                	Time in seconds since last NSF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: virtual_link_md_key
                                
                                	List of old MD keys (if any)
                                	**type**\: list of    :py:class:`VirtualLinkMdKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey>`
                                
                                .. attribute:: virtual_link_name_xr
                                
                                	Virtual link name
                                	**type**\:  str
                                
                                .. attribute:: virtual_link_neighbor
                                
                                	Neighbor information
                                	**type**\:   :py:class:`VirtualLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor>`
                                
                                .. attribute:: virtual_link_neighbor_id
                                
                                	Neighbor on other end of this virtual link
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: virtual_link_next_hello
                                
                                	Time until next hello (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_next_hello_ms
                                
                                	Time until next hello (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_nsf
                                
                                	If true, NSF restart in progress on the virtual link
                                	**type**\:  bool
                                
                                .. attribute:: virtual_link_nsf_enabled
                                
                                	If true, NSF enabled
                                	**type**\:  bool
                                
                                .. attribute:: virtual_link_old_md_key_count
                                
                                	Number of neighbors still using the old key (rollover in progress)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_passive
                                
                                	If true, interface is passive
                                	**type**\:  bool
                                
                                .. attribute:: virtual_link_state
                                
                                	OSPF interface state for the virtual link
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                .. attribute:: virtual_link_wait_interval
                                
                                	Wait interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_youngest_md_key
                                
                                	If true, MD key configured
                                	**type**\:  bool
                                
                                .. attribute:: virtual_link_youngest_md_key_id
                                
                                	Youngest MD key ID
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virual_link_transmission_delay
                                
                                	Transmission delay in seconds
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink, self).__init__()

                                    self.yang_name = "virtual-link"
                                    self.yang_parent_name = "virtual-links"

                                    self.virtual_link_name = YLeaf(YType.str, "virtual-link-name")

                                    self.transit_area = YLeaf(YType.str, "transit-area")

                                    self.virtaul_link_retransmission_interval = YLeaf(YType.uint32, "virtaul-link-retransmission-interval")

                                    self.virtual_link_authentication_type = YLeaf(YType.enumeration, "virtual-link-authentication-type")

                                    self.virtual_link_cost = YLeaf(YType.uint16, "virtual-link-cost")

                                    self.virtual_link_dc_bitless_lsa = YLeaf(YType.uint32, "virtual-link-dc-bitless-lsa")

                                    self.virtual_link_dead_interval = YLeaf(YType.uint32, "virtual-link-dead-interval")

                                    self.virtual_link_demand_circuit = YLeaf(YType.boolean, "virtual-link-demand-circuit")

                                    self.virtual_link_hello_interval = YLeaf(YType.uint32, "virtual-link-hello-interval")

                                    self.virtual_link_hello_interval_ms = YLeaf(YType.uint32, "virtual-link-hello-interval-ms")

                                    self.virtual_link_interface_name = YLeaf(YType.str, "virtual-link-interface-name")

                                    self.virtual_link_keychain_id = YLeaf(YType.uint64, "virtual-link-keychain-id")

                                    self.virtual_link_last_nsf = YLeaf(YType.uint32, "virtual-link-last-nsf")

                                    self.virtual_link_name_xr = YLeaf(YType.str, "virtual-link-name-xr")

                                    self.virtual_link_neighbor_id = YLeaf(YType.str, "virtual-link-neighbor-id")

                                    self.virtual_link_next_hello = YLeaf(YType.uint32, "virtual-link-next-hello")

                                    self.virtual_link_next_hello_ms = YLeaf(YType.uint32, "virtual-link-next-hello-ms")

                                    self.virtual_link_nsf = YLeaf(YType.boolean, "virtual-link-nsf")

                                    self.virtual_link_nsf_enabled = YLeaf(YType.boolean, "virtual-link-nsf-enabled")

                                    self.virtual_link_old_md_key_count = YLeaf(YType.uint32, "virtual-link-old-md-key-count")

                                    self.virtual_link_passive = YLeaf(YType.boolean, "virtual-link-passive")

                                    self.virtual_link_state = YLeaf(YType.enumeration, "virtual-link-state")

                                    self.virtual_link_wait_interval = YLeaf(YType.uint32, "virtual-link-wait-interval")

                                    self.virtual_link_youngest_md_key = YLeaf(YType.boolean, "virtual-link-youngest-md-key")

                                    self.virtual_link_youngest_md_key_id = YLeaf(YType.uint16, "virtual-link-youngest-md-key-id")

                                    self.virual_link_transmission_delay = YLeaf(YType.uint16, "virual-link-transmission-delay")

                                    self.virtual_link_neighbor = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor()
                                    self.virtual_link_neighbor.parent = self
                                    self._children_name_map["virtual_link_neighbor"] = "virtual-link-neighbor"
                                    self._children_yang_names.add("virtual-link-neighbor")

                                    self.virtual_link_md_key = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("virtual_link_name",
                                                    "transit_area",
                                                    "virtaul_link_retransmission_interval",
                                                    "virtual_link_authentication_type",
                                                    "virtual_link_cost",
                                                    "virtual_link_dc_bitless_lsa",
                                                    "virtual_link_dead_interval",
                                                    "virtual_link_demand_circuit",
                                                    "virtual_link_hello_interval",
                                                    "virtual_link_hello_interval_ms",
                                                    "virtual_link_interface_name",
                                                    "virtual_link_keychain_id",
                                                    "virtual_link_last_nsf",
                                                    "virtual_link_name_xr",
                                                    "virtual_link_neighbor_id",
                                                    "virtual_link_next_hello",
                                                    "virtual_link_next_hello_ms",
                                                    "virtual_link_nsf",
                                                    "virtual_link_nsf_enabled",
                                                    "virtual_link_old_md_key_count",
                                                    "virtual_link_passive",
                                                    "virtual_link_state",
                                                    "virtual_link_wait_interval",
                                                    "virtual_link_youngest_md_key",
                                                    "virtual_link_youngest_md_key_id",
                                                    "virual_link_transmission_delay") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink, self).__setattr__(name, value)


                                class VirtualLinkNeighbor(Entity):
                                    """
                                    Neighbor information
                                    
                                    .. attribute:: virtual_link_retransmissoin
                                    
                                    	Neighbor retransmission info
                                    	**type**\:   :py:class:`VirtualLinkRetransmissoin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin>`
                                    
                                    .. attribute:: virtual_link_state
                                    
                                    	Adjacency state
                                    	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                    
                                    .. attribute:: virtual_link_suppress_hello
                                    
                                    	If true Hellos suppressed
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor, self).__init__()

                                        self.yang_name = "virtual-link-neighbor"
                                        self.yang_parent_name = "virtual-link"

                                        self.virtual_link_state = YLeaf(YType.enumeration, "virtual-link-state")

                                        self.virtual_link_suppress_hello = YLeaf(YType.boolean, "virtual-link-suppress-hello")

                                        self.virtual_link_retransmissoin = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin()
                                        self.virtual_link_retransmissoin.parent = self
                                        self._children_name_map["virtual_link_retransmissoin"] = "virtual-link-retransmissoin"
                                        self._children_yang_names.add("virtual-link-retransmissoin")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("virtual_link_state",
                                                        "virtual_link_suppress_hello") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor, self).__setattr__(name, value)


                                    class VirtualLinkRetransmissoin(Entity):
                                        """
                                        Neighbor retransmission info
                                        
                                        .. attribute:: area_first_flood_information
                                        
                                        	First flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood_information_index
                                        
                                        	Index of the first flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_flooding_index
                                        
                                        	Area scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_information
                                        
                                        	Next flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_information_index
                                        
                                        	Index of next flood item for Area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_information
                                        
                                        	First flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_information_index
                                        
                                        	Index for first flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_flood_index
                                        
                                        	AS scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_information
                                        
                                        	Next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_information_index
                                        
                                        	Index of next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dbd_retransmission_count
                                        
                                        	Number of DBD retransmissions during last exchange
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dbd_retransmission_total_count
                                        
                                        	Total number of DBD retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_length
                                        
                                        	Number of LSAs sent in last retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_time
                                        
                                        	Last retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_retransmission_timer
                                        
                                        	Time until next LSA retransmission (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_length
                                        
                                        	Maximum number of LSAs sent in a retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_time
                                        
                                        	Maximum retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmission_count
                                        
                                        	Retransmission queue length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_retransmissions
                                        
                                        	Number of retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin, self).__init__()

                                            self.yang_name = "virtual-link-retransmissoin"
                                            self.yang_parent_name = "virtual-link-neighbor"

                                            self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                            self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                            self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                            self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                            self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                            self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                            self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                            self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                            self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                            self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                            self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                            self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                            self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                            self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                            self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                            self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                            self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                            self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                            self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("area_first_flood_information",
                                                            "area_first_flood_information_index",
                                                            "area_flooding_index",
                                                            "area_next_flood_information",
                                                            "area_next_flood_information_index",
                                                            "as_first_flood_information",
                                                            "as_first_flood_information_index",
                                                            "as_flood_index",
                                                            "as_next_flood_information",
                                                            "as_next_flood_information_index",
                                                            "dbd_retransmission_count",
                                                            "dbd_retransmission_total_count",
                                                            "last_retransmission_length",
                                                            "last_retransmission_time",
                                                            "lsa_retransmission_timer",
                                                            "maximum_retransmission_length",
                                                            "maximum_retransmission_time",
                                                            "neighbor_retransmission_count",
                                                            "number_of_retransmissions") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.area_first_flood_information.is_set or
                                                self.area_first_flood_information_index.is_set or
                                                self.area_flooding_index.is_set or
                                                self.area_next_flood_information.is_set or
                                                self.area_next_flood_information_index.is_set or
                                                self.as_first_flood_information.is_set or
                                                self.as_first_flood_information_index.is_set or
                                                self.as_flood_index.is_set or
                                                self.as_next_flood_information.is_set or
                                                self.as_next_flood_information_index.is_set or
                                                self.dbd_retransmission_count.is_set or
                                                self.dbd_retransmission_total_count.is_set or
                                                self.last_retransmission_length.is_set or
                                                self.last_retransmission_time.is_set or
                                                self.lsa_retransmission_timer.is_set or
                                                self.maximum_retransmission_length.is_set or
                                                self.maximum_retransmission_time.is_set or
                                                self.neighbor_retransmission_count.is_set or
                                                self.number_of_retransmissions.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.area_first_flood_information.yfilter != YFilter.not_set or
                                                self.area_first_flood_information_index.yfilter != YFilter.not_set or
                                                self.area_flooding_index.yfilter != YFilter.not_set or
                                                self.area_next_flood_information.yfilter != YFilter.not_set or
                                                self.area_next_flood_information_index.yfilter != YFilter.not_set or
                                                self.as_first_flood_information.yfilter != YFilter.not_set or
                                                self.as_first_flood_information_index.yfilter != YFilter.not_set or
                                                self.as_flood_index.yfilter != YFilter.not_set or
                                                self.as_next_flood_information.yfilter != YFilter.not_set or
                                                self.as_next_flood_information_index.yfilter != YFilter.not_set or
                                                self.dbd_retransmission_count.yfilter != YFilter.not_set or
                                                self.dbd_retransmission_total_count.yfilter != YFilter.not_set or
                                                self.last_retransmission_length.yfilter != YFilter.not_set or
                                                self.last_retransmission_time.yfilter != YFilter.not_set or
                                                self.lsa_retransmission_timer.yfilter != YFilter.not_set or
                                                self.maximum_retransmission_length.yfilter != YFilter.not_set or
                                                self.maximum_retransmission_time.yfilter != YFilter.not_set or
                                                self.neighbor_retransmission_count.yfilter != YFilter.not_set or
                                                self.number_of_retransmissions.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "virtual-link-retransmissoin" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.area_first_flood_information.is_set or self.area_first_flood_information.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_first_flood_information.get_name_leafdata())
                                            if (self.area_first_flood_information_index.is_set or self.area_first_flood_information_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_first_flood_information_index.get_name_leafdata())
                                            if (self.area_flooding_index.is_set or self.area_flooding_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_flooding_index.get_name_leafdata())
                                            if (self.area_next_flood_information.is_set or self.area_next_flood_information.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_next_flood_information.get_name_leafdata())
                                            if (self.area_next_flood_information_index.is_set or self.area_next_flood_information_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_next_flood_information_index.get_name_leafdata())
                                            if (self.as_first_flood_information.is_set or self.as_first_flood_information.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_first_flood_information.get_name_leafdata())
                                            if (self.as_first_flood_information_index.is_set or self.as_first_flood_information_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_first_flood_information_index.get_name_leafdata())
                                            if (self.as_flood_index.is_set or self.as_flood_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_flood_index.get_name_leafdata())
                                            if (self.as_next_flood_information.is_set or self.as_next_flood_information.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_next_flood_information.get_name_leafdata())
                                            if (self.as_next_flood_information_index.is_set or self.as_next_flood_information_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_next_flood_information_index.get_name_leafdata())
                                            if (self.dbd_retransmission_count.is_set or self.dbd_retransmission_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dbd_retransmission_count.get_name_leafdata())
                                            if (self.dbd_retransmission_total_count.is_set or self.dbd_retransmission_total_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dbd_retransmission_total_count.get_name_leafdata())
                                            if (self.last_retransmission_length.is_set or self.last_retransmission_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.last_retransmission_length.get_name_leafdata())
                                            if (self.last_retransmission_time.is_set or self.last_retransmission_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.last_retransmission_time.get_name_leafdata())
                                            if (self.lsa_retransmission_timer.is_set or self.lsa_retransmission_timer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_retransmission_timer.get_name_leafdata())
                                            if (self.maximum_retransmission_length.is_set or self.maximum_retransmission_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_retransmission_length.get_name_leafdata())
                                            if (self.maximum_retransmission_time.is_set or self.maximum_retransmission_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_retransmission_time.get_name_leafdata())
                                            if (self.neighbor_retransmission_count.is_set or self.neighbor_retransmission_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_retransmission_count.get_name_leafdata())
                                            if (self.number_of_retransmissions.is_set or self.number_of_retransmissions.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.number_of_retransmissions.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "area-first-flood-information" or name == "area-first-flood-information-index" or name == "area-flooding-index" or name == "area-next-flood-information" or name == "area-next-flood-information-index" or name == "as-first-flood-information" or name == "as-first-flood-information-index" or name == "as-flood-index" or name == "as-next-flood-information" or name == "as-next-flood-information-index" or name == "dbd-retransmission-count" or name == "dbd-retransmission-total-count" or name == "last-retransmission-length" or name == "last-retransmission-time" or name == "lsa-retransmission-timer" or name == "maximum-retransmission-length" or name == "maximum-retransmission-time" or name == "neighbor-retransmission-count" or name == "number-of-retransmissions"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "area-first-flood-information"):
                                                self.area_first_flood_information = value
                                                self.area_first_flood_information.value_namespace = name_space
                                                self.area_first_flood_information.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-first-flood-information-index"):
                                                self.area_first_flood_information_index = value
                                                self.area_first_flood_information_index.value_namespace = name_space
                                                self.area_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-flooding-index"):
                                                self.area_flooding_index = value
                                                self.area_flooding_index.value_namespace = name_space
                                                self.area_flooding_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-next-flood-information"):
                                                self.area_next_flood_information = value
                                                self.area_next_flood_information.value_namespace = name_space
                                                self.area_next_flood_information.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-next-flood-information-index"):
                                                self.area_next_flood_information_index = value
                                                self.area_next_flood_information_index.value_namespace = name_space
                                                self.area_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-first-flood-information"):
                                                self.as_first_flood_information = value
                                                self.as_first_flood_information.value_namespace = name_space
                                                self.as_first_flood_information.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-first-flood-information-index"):
                                                self.as_first_flood_information_index = value
                                                self.as_first_flood_information_index.value_namespace = name_space
                                                self.as_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-flood-index"):
                                                self.as_flood_index = value
                                                self.as_flood_index.value_namespace = name_space
                                                self.as_flood_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-next-flood-information"):
                                                self.as_next_flood_information = value
                                                self.as_next_flood_information.value_namespace = name_space
                                                self.as_next_flood_information.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-next-flood-information-index"):
                                                self.as_next_flood_information_index = value
                                                self.as_next_flood_information_index.value_namespace = name_space
                                                self.as_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dbd-retransmission-count"):
                                                self.dbd_retransmission_count = value
                                                self.dbd_retransmission_count.value_namespace = name_space
                                                self.dbd_retransmission_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dbd-retransmission-total-count"):
                                                self.dbd_retransmission_total_count = value
                                                self.dbd_retransmission_total_count.value_namespace = name_space
                                                self.dbd_retransmission_total_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "last-retransmission-length"):
                                                self.last_retransmission_length = value
                                                self.last_retransmission_length.value_namespace = name_space
                                                self.last_retransmission_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "last-retransmission-time"):
                                                self.last_retransmission_time = value
                                                self.last_retransmission_time.value_namespace = name_space
                                                self.last_retransmission_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-retransmission-timer"):
                                                self.lsa_retransmission_timer = value
                                                self.lsa_retransmission_timer.value_namespace = name_space
                                                self.lsa_retransmission_timer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-retransmission-length"):
                                                self.maximum_retransmission_length = value
                                                self.maximum_retransmission_length.value_namespace = name_space
                                                self.maximum_retransmission_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-retransmission-time"):
                                                self.maximum_retransmission_time = value
                                                self.maximum_retransmission_time.value_namespace = name_space
                                                self.maximum_retransmission_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-retransmission-count"):
                                                self.neighbor_retransmission_count = value
                                                self.neighbor_retransmission_count.value_namespace = name_space
                                                self.neighbor_retransmission_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "number-of-retransmissions"):
                                                self.number_of_retransmissions = value
                                                self.number_of_retransmissions.value_namespace = name_space
                                                self.number_of_retransmissions.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.virtual_link_state.is_set or
                                            self.virtual_link_suppress_hello.is_set or
                                            (self.virtual_link_retransmissoin is not None and self.virtual_link_retransmissoin.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.virtual_link_state.yfilter != YFilter.not_set or
                                            self.virtual_link_suppress_hello.yfilter != YFilter.not_set or
                                            (self.virtual_link_retransmissoin is not None and self.virtual_link_retransmissoin.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "virtual-link-neighbor" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.virtual_link_state.is_set or self.virtual_link_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.virtual_link_state.get_name_leafdata())
                                        if (self.virtual_link_suppress_hello.is_set or self.virtual_link_suppress_hello.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.virtual_link_suppress_hello.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "virtual-link-retransmissoin"):
                                            if (self.virtual_link_retransmissoin is None):
                                                self.virtual_link_retransmissoin = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin()
                                                self.virtual_link_retransmissoin.parent = self
                                                self._children_name_map["virtual_link_retransmissoin"] = "virtual-link-retransmissoin"
                                            return self.virtual_link_retransmissoin

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "virtual-link-retransmissoin" or name == "virtual-link-state" or name == "virtual-link-suppress-hello"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "virtual-link-state"):
                                            self.virtual_link_state = value
                                            self.virtual_link_state.value_namespace = name_space
                                            self.virtual_link_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "virtual-link-suppress-hello"):
                                            self.virtual_link_suppress_hello = value
                                            self.virtual_link_suppress_hello.value_namespace = name_space
                                            self.virtual_link_suppress_hello.value_namespace_prefix = name_space_prefix


                                class VirtualLinkMdKey(Entity):
                                    """
                                    List of old MD keys (if any)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey, self).__init__()

                                        self.yang_name = "virtual-link-md-key"
                                        self.yang_parent_name = "virtual-link"

                                        self.entry = YLeaf(YType.uint16, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "virtual-link-md-key" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.virtual_link_md_key:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.virtual_link_name.is_set or
                                        self.transit_area.is_set or
                                        self.virtaul_link_retransmission_interval.is_set or
                                        self.virtual_link_authentication_type.is_set or
                                        self.virtual_link_cost.is_set or
                                        self.virtual_link_dc_bitless_lsa.is_set or
                                        self.virtual_link_dead_interval.is_set or
                                        self.virtual_link_demand_circuit.is_set or
                                        self.virtual_link_hello_interval.is_set or
                                        self.virtual_link_hello_interval_ms.is_set or
                                        self.virtual_link_interface_name.is_set or
                                        self.virtual_link_keychain_id.is_set or
                                        self.virtual_link_last_nsf.is_set or
                                        self.virtual_link_name_xr.is_set or
                                        self.virtual_link_neighbor_id.is_set or
                                        self.virtual_link_next_hello.is_set or
                                        self.virtual_link_next_hello_ms.is_set or
                                        self.virtual_link_nsf.is_set or
                                        self.virtual_link_nsf_enabled.is_set or
                                        self.virtual_link_old_md_key_count.is_set or
                                        self.virtual_link_passive.is_set or
                                        self.virtual_link_state.is_set or
                                        self.virtual_link_wait_interval.is_set or
                                        self.virtual_link_youngest_md_key.is_set or
                                        self.virtual_link_youngest_md_key_id.is_set or
                                        self.virual_link_transmission_delay.is_set or
                                        (self.virtual_link_neighbor is not None and self.virtual_link_neighbor.has_data()))

                                def has_operation(self):
                                    for c in self.virtual_link_md_key:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.virtual_link_name.yfilter != YFilter.not_set or
                                        self.transit_area.yfilter != YFilter.not_set or
                                        self.virtaul_link_retransmission_interval.yfilter != YFilter.not_set or
                                        self.virtual_link_authentication_type.yfilter != YFilter.not_set or
                                        self.virtual_link_cost.yfilter != YFilter.not_set or
                                        self.virtual_link_dc_bitless_lsa.yfilter != YFilter.not_set or
                                        self.virtual_link_dead_interval.yfilter != YFilter.not_set or
                                        self.virtual_link_demand_circuit.yfilter != YFilter.not_set or
                                        self.virtual_link_hello_interval.yfilter != YFilter.not_set or
                                        self.virtual_link_hello_interval_ms.yfilter != YFilter.not_set or
                                        self.virtual_link_interface_name.yfilter != YFilter.not_set or
                                        self.virtual_link_keychain_id.yfilter != YFilter.not_set or
                                        self.virtual_link_last_nsf.yfilter != YFilter.not_set or
                                        self.virtual_link_name_xr.yfilter != YFilter.not_set or
                                        self.virtual_link_neighbor_id.yfilter != YFilter.not_set or
                                        self.virtual_link_next_hello.yfilter != YFilter.not_set or
                                        self.virtual_link_next_hello_ms.yfilter != YFilter.not_set or
                                        self.virtual_link_nsf.yfilter != YFilter.not_set or
                                        self.virtual_link_nsf_enabled.yfilter != YFilter.not_set or
                                        self.virtual_link_old_md_key_count.yfilter != YFilter.not_set or
                                        self.virtual_link_passive.yfilter != YFilter.not_set or
                                        self.virtual_link_state.yfilter != YFilter.not_set or
                                        self.virtual_link_wait_interval.yfilter != YFilter.not_set or
                                        self.virtual_link_youngest_md_key.yfilter != YFilter.not_set or
                                        self.virtual_link_youngest_md_key_id.yfilter != YFilter.not_set or
                                        self.virual_link_transmission_delay.yfilter != YFilter.not_set or
                                        (self.virtual_link_neighbor is not None and self.virtual_link_neighbor.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "virtual-link" + "[virtual-link-name='" + self.virtual_link_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.virtual_link_name.is_set or self.virtual_link_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_name.get_name_leafdata())
                                    if (self.transit_area.is_set or self.transit_area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transit_area.get_name_leafdata())
                                    if (self.virtaul_link_retransmission_interval.is_set or self.virtaul_link_retransmission_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtaul_link_retransmission_interval.get_name_leafdata())
                                    if (self.virtual_link_authentication_type.is_set or self.virtual_link_authentication_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_authentication_type.get_name_leafdata())
                                    if (self.virtual_link_cost.is_set or self.virtual_link_cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_cost.get_name_leafdata())
                                    if (self.virtual_link_dc_bitless_lsa.is_set or self.virtual_link_dc_bitless_lsa.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_dc_bitless_lsa.get_name_leafdata())
                                    if (self.virtual_link_dead_interval.is_set or self.virtual_link_dead_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_dead_interval.get_name_leafdata())
                                    if (self.virtual_link_demand_circuit.is_set or self.virtual_link_demand_circuit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_demand_circuit.get_name_leafdata())
                                    if (self.virtual_link_hello_interval.is_set or self.virtual_link_hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_hello_interval.get_name_leafdata())
                                    if (self.virtual_link_hello_interval_ms.is_set or self.virtual_link_hello_interval_ms.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_hello_interval_ms.get_name_leafdata())
                                    if (self.virtual_link_interface_name.is_set or self.virtual_link_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_interface_name.get_name_leafdata())
                                    if (self.virtual_link_keychain_id.is_set or self.virtual_link_keychain_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_keychain_id.get_name_leafdata())
                                    if (self.virtual_link_last_nsf.is_set or self.virtual_link_last_nsf.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_last_nsf.get_name_leafdata())
                                    if (self.virtual_link_name_xr.is_set or self.virtual_link_name_xr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_name_xr.get_name_leafdata())
                                    if (self.virtual_link_neighbor_id.is_set or self.virtual_link_neighbor_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_neighbor_id.get_name_leafdata())
                                    if (self.virtual_link_next_hello.is_set or self.virtual_link_next_hello.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_next_hello.get_name_leafdata())
                                    if (self.virtual_link_next_hello_ms.is_set or self.virtual_link_next_hello_ms.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_next_hello_ms.get_name_leafdata())
                                    if (self.virtual_link_nsf.is_set or self.virtual_link_nsf.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_nsf.get_name_leafdata())
                                    if (self.virtual_link_nsf_enabled.is_set or self.virtual_link_nsf_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_nsf_enabled.get_name_leafdata())
                                    if (self.virtual_link_old_md_key_count.is_set or self.virtual_link_old_md_key_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_old_md_key_count.get_name_leafdata())
                                    if (self.virtual_link_passive.is_set or self.virtual_link_passive.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_passive.get_name_leafdata())
                                    if (self.virtual_link_state.is_set or self.virtual_link_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_state.get_name_leafdata())
                                    if (self.virtual_link_wait_interval.is_set or self.virtual_link_wait_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_wait_interval.get_name_leafdata())
                                    if (self.virtual_link_youngest_md_key.is_set or self.virtual_link_youngest_md_key.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_youngest_md_key.get_name_leafdata())
                                    if (self.virtual_link_youngest_md_key_id.is_set or self.virtual_link_youngest_md_key_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_youngest_md_key_id.get_name_leafdata())
                                    if (self.virual_link_transmission_delay.is_set or self.virual_link_transmission_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virual_link_transmission_delay.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "virtual-link-md-key"):
                                        for c in self.virtual_link_md_key:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.virtual_link_md_key.append(c)
                                        return c

                                    if (child_yang_name == "virtual-link-neighbor"):
                                        if (self.virtual_link_neighbor is None):
                                            self.virtual_link_neighbor = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor()
                                            self.virtual_link_neighbor.parent = self
                                            self._children_name_map["virtual_link_neighbor"] = "virtual-link-neighbor"
                                        return self.virtual_link_neighbor

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "virtual-link-md-key" or name == "virtual-link-neighbor" or name == "virtual-link-name" or name == "transit-area" or name == "virtaul-link-retransmission-interval" or name == "virtual-link-authentication-type" or name == "virtual-link-cost" or name == "virtual-link-dc-bitless-lsa" or name == "virtual-link-dead-interval" or name == "virtual-link-demand-circuit" or name == "virtual-link-hello-interval" or name == "virtual-link-hello-interval-ms" or name == "virtual-link-interface-name" or name == "virtual-link-keychain-id" or name == "virtual-link-last-nsf" or name == "virtual-link-name-xr" or name == "virtual-link-neighbor-id" or name == "virtual-link-next-hello" or name == "virtual-link-next-hello-ms" or name == "virtual-link-nsf" or name == "virtual-link-nsf-enabled" or name == "virtual-link-old-md-key-count" or name == "virtual-link-passive" or name == "virtual-link-state" or name == "virtual-link-wait-interval" or name == "virtual-link-youngest-md-key" or name == "virtual-link-youngest-md-key-id" or name == "virual-link-transmission-delay"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "virtual-link-name"):
                                        self.virtual_link_name = value
                                        self.virtual_link_name.value_namespace = name_space
                                        self.virtual_link_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transit-area"):
                                        self.transit_area = value
                                        self.transit_area.value_namespace = name_space
                                        self.transit_area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtaul-link-retransmission-interval"):
                                        self.virtaul_link_retransmission_interval = value
                                        self.virtaul_link_retransmission_interval.value_namespace = name_space
                                        self.virtaul_link_retransmission_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-authentication-type"):
                                        self.virtual_link_authentication_type = value
                                        self.virtual_link_authentication_type.value_namespace = name_space
                                        self.virtual_link_authentication_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-cost"):
                                        self.virtual_link_cost = value
                                        self.virtual_link_cost.value_namespace = name_space
                                        self.virtual_link_cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-dc-bitless-lsa"):
                                        self.virtual_link_dc_bitless_lsa = value
                                        self.virtual_link_dc_bitless_lsa.value_namespace = name_space
                                        self.virtual_link_dc_bitless_lsa.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-dead-interval"):
                                        self.virtual_link_dead_interval = value
                                        self.virtual_link_dead_interval.value_namespace = name_space
                                        self.virtual_link_dead_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-demand-circuit"):
                                        self.virtual_link_demand_circuit = value
                                        self.virtual_link_demand_circuit.value_namespace = name_space
                                        self.virtual_link_demand_circuit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-hello-interval"):
                                        self.virtual_link_hello_interval = value
                                        self.virtual_link_hello_interval.value_namespace = name_space
                                        self.virtual_link_hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-hello-interval-ms"):
                                        self.virtual_link_hello_interval_ms = value
                                        self.virtual_link_hello_interval_ms.value_namespace = name_space
                                        self.virtual_link_hello_interval_ms.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-interface-name"):
                                        self.virtual_link_interface_name = value
                                        self.virtual_link_interface_name.value_namespace = name_space
                                        self.virtual_link_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-keychain-id"):
                                        self.virtual_link_keychain_id = value
                                        self.virtual_link_keychain_id.value_namespace = name_space
                                        self.virtual_link_keychain_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-last-nsf"):
                                        self.virtual_link_last_nsf = value
                                        self.virtual_link_last_nsf.value_namespace = name_space
                                        self.virtual_link_last_nsf.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-name-xr"):
                                        self.virtual_link_name_xr = value
                                        self.virtual_link_name_xr.value_namespace = name_space
                                        self.virtual_link_name_xr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-neighbor-id"):
                                        self.virtual_link_neighbor_id = value
                                        self.virtual_link_neighbor_id.value_namespace = name_space
                                        self.virtual_link_neighbor_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-next-hello"):
                                        self.virtual_link_next_hello = value
                                        self.virtual_link_next_hello.value_namespace = name_space
                                        self.virtual_link_next_hello.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-next-hello-ms"):
                                        self.virtual_link_next_hello_ms = value
                                        self.virtual_link_next_hello_ms.value_namespace = name_space
                                        self.virtual_link_next_hello_ms.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-nsf"):
                                        self.virtual_link_nsf = value
                                        self.virtual_link_nsf.value_namespace = name_space
                                        self.virtual_link_nsf.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-nsf-enabled"):
                                        self.virtual_link_nsf_enabled = value
                                        self.virtual_link_nsf_enabled.value_namespace = name_space
                                        self.virtual_link_nsf_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-old-md-key-count"):
                                        self.virtual_link_old_md_key_count = value
                                        self.virtual_link_old_md_key_count.value_namespace = name_space
                                        self.virtual_link_old_md_key_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-passive"):
                                        self.virtual_link_passive = value
                                        self.virtual_link_passive.value_namespace = name_space
                                        self.virtual_link_passive.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-state"):
                                        self.virtual_link_state = value
                                        self.virtual_link_state.value_namespace = name_space
                                        self.virtual_link_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-wait-interval"):
                                        self.virtual_link_wait_interval = value
                                        self.virtual_link_wait_interval.value_namespace = name_space
                                        self.virtual_link_wait_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-youngest-md-key"):
                                        self.virtual_link_youngest_md_key = value
                                        self.virtual_link_youngest_md_key.value_namespace = name_space
                                        self.virtual_link_youngest_md_key.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-youngest-md-key-id"):
                                        self.virtual_link_youngest_md_key_id = value
                                        self.virtual_link_youngest_md_key_id.value_namespace = name_space
                                        self.virtual_link_youngest_md_key_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virual-link-transmission-delay"):
                                        self.virual_link_transmission_delay = value
                                        self.virual_link_transmission_delay.value_namespace = name_space
                                        self.virual_link_transmission_delay.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.virtual_link:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.virtual_link:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "virtual-links" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "virtual-link"):
                                    for c in self.virtual_link:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.virtual_link.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "virtual-link"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class InterfaceBriefs(Entity):
                            """
                            OSPF Interface Brief Table
                            
                            .. attribute:: interface_brief
                            
                            	OSPF interface brief information
                            	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs, self).__init__()

                                self.yang_name = "interface-briefs"
                                self.yang_parent_name = "interface-information"

                                self.interface_brief = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs, self).__setattr__(name, value)


                            class InterfaceBrief(Entity):
                                """
                                OSPF interface brief information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: interface_address
                                
                                	Interface IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_adj_neighbor_count
                                
                                	Total number of Adjacent Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_area
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: interface_fast_detect_hold_down
                                
                                	Interface in fast detect hold down state
                                	**type**\:  bool
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_madj
                                
                                	Information for multi\-area on the interface
                                	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj>`
                                
                                .. attribute:: interface_madj_count
                                
                                	Total number of multi\-area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_mask
                                
                                	Interface IP Mask
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: interface_neighbor_count
                                
                                	Total number of Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interfaceis_madj
                                
                                	If true, interface is multi\-area
                                	**type**\:  bool
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief, self).__init__()

                                    self.yang_name = "interface-brief"
                                    self.yang_parent_name = "interface-briefs"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.interface_address = YLeaf(YType.str, "interface-address")

                                    self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                    self.interface_area = YLeaf(YType.str, "interface-area")

                                    self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                    self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                    self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                    self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                    self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                    self.interface_madj = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "interface_address",
                                                    "interface_adj_neighbor_count",
                                                    "interface_area",
                                                    "interface_fast_detect_hold_down",
                                                    "interface_link_cost",
                                                    "interface_madj_count",
                                                    "interface_mask",
                                                    "interface_name_xr",
                                                    "interface_neighbor_count",
                                                    "interfaceis_madj",
                                                    "ospf_interface_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief, self).__setattr__(name, value)


                                class InterfaceMadj(Entity):
                                    """
                                    Information for multi\-area on the interface
                                    
                                    .. attribute:: interface_adj_neighbor_count
                                    
                                    	Total number of Adjacent Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_area
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: madj_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__init__()

                                        self.yang_name = "interface-madj"
                                        self.yang_parent_name = "interface-brief"

                                        self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                        self.interface_area = YLeaf(YType.str, "interface-area")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_adj_neighbor_count",
                                                        "interface_area",
                                                        "interface_link_cost",
                                                        "interface_neighbor_count",
                                                        "madj_area_id",
                                                        "ospf_interface_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interface_adj_neighbor_count.is_set or
                                            self.interface_area.is_set or
                                            self.interface_link_cost.is_set or
                                            self.interface_neighbor_count.is_set or
                                            self.madj_area_id.is_set or
                                            self.ospf_interface_state.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_adj_neighbor_count.yfilter != YFilter.not_set or
                                            self.interface_area.yfilter != YFilter.not_set or
                                            self.interface_link_cost.yfilter != YFilter.not_set or
                                            self.interface_neighbor_count.yfilter != YFilter.not_set or
                                            self.madj_area_id.yfilter != YFilter.not_set or
                                            self.ospf_interface_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-madj" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_adj_neighbor_count.is_set or self.interface_adj_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_adj_neighbor_count.get_name_leafdata())
                                        if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_area.get_name_leafdata())
                                        if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                        if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                        if (self.madj_area_id.is_set or self.madj_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.madj_area_id.get_name_leafdata())
                                        if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-adj-neighbor-count" or name == "interface-area" or name == "interface-link-cost" or name == "interface-neighbor-count" or name == "madj-area-id" or name == "ospf-interface-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-adj-neighbor-count"):
                                            self.interface_adj_neighbor_count = value
                                            self.interface_adj_neighbor_count.value_namespace = name_space
                                            self.interface_adj_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-area"):
                                            self.interface_area = value
                                            self.interface_area.value_namespace = name_space
                                            self.interface_area.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-link-cost"):
                                            self.interface_link_cost = value
                                            self.interface_link_cost.value_namespace = name_space
                                            self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-neighbor-count"):
                                            self.interface_neighbor_count = value
                                            self.interface_neighbor_count.value_namespace = name_space
                                            self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "madj-area-id"):
                                            self.madj_area_id = value
                                            self.madj_area_id.value_namespace = name_space
                                            self.madj_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-interface-state"):
                                            self.ospf_interface_state = value
                                            self.ospf_interface_state.value_namespace = name_space
                                            self.ospf_interface_state.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.interface_madj:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.interface_name.is_set or
                                        self.interface_address.is_set or
                                        self.interface_adj_neighbor_count.is_set or
                                        self.interface_area.is_set or
                                        self.interface_fast_detect_hold_down.is_set or
                                        self.interface_link_cost.is_set or
                                        self.interface_madj_count.is_set or
                                        self.interface_mask.is_set or
                                        self.interface_name_xr.is_set or
                                        self.interface_neighbor_count.is_set or
                                        self.interfaceis_madj.is_set or
                                        self.ospf_interface_state.is_set)

                                def has_operation(self):
                                    for c in self.interface_madj:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.interface_address.yfilter != YFilter.not_set or
                                        self.interface_adj_neighbor_count.yfilter != YFilter.not_set or
                                        self.interface_area.yfilter != YFilter.not_set or
                                        self.interface_fast_detect_hold_down.yfilter != YFilter.not_set or
                                        self.interface_link_cost.yfilter != YFilter.not_set or
                                        self.interface_madj_count.yfilter != YFilter.not_set or
                                        self.interface_mask.yfilter != YFilter.not_set or
                                        self.interface_name_xr.yfilter != YFilter.not_set or
                                        self.interface_neighbor_count.yfilter != YFilter.not_set or
                                        self.interfaceis_madj.yfilter != YFilter.not_set or
                                        self.ospf_interface_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface-brief" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.interface_address.is_set or self.interface_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_address.get_name_leafdata())
                                    if (self.interface_adj_neighbor_count.is_set or self.interface_adj_neighbor_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_adj_neighbor_count.get_name_leafdata())
                                    if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_area.get_name_leafdata())
                                    if (self.interface_fast_detect_hold_down.is_set or self.interface_fast_detect_hold_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_fast_detect_hold_down.get_name_leafdata())
                                    if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                    if (self.interface_madj_count.is_set or self.interface_madj_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_madj_count.get_name_leafdata())
                                    if (self.interface_mask.is_set or self.interface_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_mask.get_name_leafdata())
                                    if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                    if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                    if (self.interfaceis_madj.is_set or self.interfaceis_madj.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interfaceis_madj.get_name_leafdata())
                                    if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-madj"):
                                        for c in self.interface_madj:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.interface_madj.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-madj" or name == "interface-name" or name == "interface-address" or name == "interface-adj-neighbor-count" or name == "interface-area" or name == "interface-fast-detect-hold-down" or name == "interface-link-cost" or name == "interface-madj-count" or name == "interface-mask" or name == "interface-name-xr" or name == "interface-neighbor-count" or name == "interfaceis-madj" or name == "ospf-interface-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-address"):
                                        self.interface_address = value
                                        self.interface_address.value_namespace = name_space
                                        self.interface_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-adj-neighbor-count"):
                                        self.interface_adj_neighbor_count = value
                                        self.interface_adj_neighbor_count.value_namespace = name_space
                                        self.interface_adj_neighbor_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-area"):
                                        self.interface_area = value
                                        self.interface_area.value_namespace = name_space
                                        self.interface_area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-fast-detect-hold-down"):
                                        self.interface_fast_detect_hold_down = value
                                        self.interface_fast_detect_hold_down.value_namespace = name_space
                                        self.interface_fast_detect_hold_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-link-cost"):
                                        self.interface_link_cost = value
                                        self.interface_link_cost.value_namespace = name_space
                                        self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-madj-count"):
                                        self.interface_madj_count = value
                                        self.interface_madj_count.value_namespace = name_space
                                        self.interface_madj_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-mask"):
                                        self.interface_mask = value
                                        self.interface_mask.value_namespace = name_space
                                        self.interface_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name-xr"):
                                        self.interface_name_xr = value
                                        self.interface_name_xr.value_namespace = name_space
                                        self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-neighbor-count"):
                                        self.interface_neighbor_count = value
                                        self.interface_neighbor_count.value_namespace = name_space
                                        self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interfaceis-madj"):
                                        self.interfaceis_madj = value
                                        self.interfaceis_madj.value_namespace = name_space
                                        self.interfaceis_madj.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-interface-state"):
                                        self.ospf_interface_state = value
                                        self.ospf_interface_state.value_namespace = name_space
                                        self.ospf_interface_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface_brief:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.interface_brief:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-briefs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface-brief"):
                                    for c in self.interface_brief:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface_brief.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-brief"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Interfaces(Entity):
                            """
                            OSPF Interface Table
                            
                            .. attribute:: interface
                            
                            	OSPF interface information
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces, self).__init__()

                                self.yang_name = "interfaces"
                                self.yang_parent_name = "interface-information"

                                self.interface = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces, self).__setattr__(name, value)


                            class Interface(Entity):
                                """
                                OSPF interface information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: active_interface
                                
                                	Active interface details
                                	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface>`
                                
                                .. attribute:: backup_designated_router
                                
                                	If true, backup designated router
                                	**type**\:  bool
                                
                                .. attribute:: backup_designated_router_address
                                
                                	Backup designated router interface address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_designated_router_id
                                
                                	Backup designated router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: cfg_cost_fallback
                                
                                	If true, cost fallback is configured
                                	**type**\:  bool
                                
                                .. attribute:: configured_demand_circuit
                                
                                	If true, configured as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: configured_ldp_sync
                                
                                	If true, configured as LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: configured_ldp_sync_igp_shortcuts
                                
                                	If true, sync igp shortcuts
                                	**type**\:  bool
                                
                                .. attribute:: cost_fallback_active
                                
                                	If true, cost fallback is active
                                	**type**\:  bool
                                
                                .. attribute:: dead_interval
                                
                                	Configured dead interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: designated_router
                                
                                	If true, designated router
                                	**type**\:  bool
                                
                                .. attribute:: designated_router_address
                                
                                	Designated router interface address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: designated_router_id
                                
                                	Designated router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: fast_detect_hold_down_time
                                
                                	Hold\-down time in ms for fast\-detect event
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fast_detect_hold_down_time_remaining
                                
                                	Remaining hold down time in ms
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fast_reroute_topology_independent_lfa
                                
                                	Topology Independent LFA
                                	**type**\:  bool
                                
                                .. attribute:: fast_reroute_type
                                
                                	IP Fast Reroute Type
                                	**type**\:   :py:class:`Ipfrr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ipfrr>`
                                
                                .. attribute:: hello_interval
                                
                                	Configured hello interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: hello_interval_ms
                                
                                	Configured hello interval (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ack_list_count
                                
                                	Ack List Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ack_list_high_watermark
                                
                                	Ack List High Watermark
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_address
                                
                                	Interface IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_area
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: interface_bandwidth
                                
                                	Interface bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_bfd_information
                                
                                	BFD information
                                	**type**\:   :py:class:`InterfaceBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation>`
                                
                                .. attribute:: interface_cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_dc_bitless_lsa_count
                                
                                	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_demand_circuit
                                
                                	If true, interface running as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: interface_fast_detect_hold_down
                                
                                	Link in hold\-down state due to fast detect event
                                	**type**\:  bool
                                
                                .. attribute:: interface_last_nsf
                                
                                	Time since last NSF restart (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ldp_sync
                                
                                	If true, interface LDP sync is achieved
                                	**type**\:  bool
                                
                                .. attribute:: interface_line_state
                                
                                	If true, line protocol is up
                                	**type**\:  bool
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_lsa_filter
                                
                                	Filter is configured for out going LSAs
                                	**type**\:  bool
                                
                                .. attribute:: interface_madj
                                
                                	Information for multi\-area on the interface
                                	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj>`
                                
                                .. attribute:: interface_madj_count
                                
                                	Total number of multi\-area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_mask
                                
                                	Interface IP Mask
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: interface_neighbor
                                
                                	Information for neighbors on the interface
                                	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor>`
                                
                                .. attribute:: interface_nsf
                                
                                	If true, NSF restart in progress on this interface
                                	**type**\:  bool
                                
                                .. attribute:: interface_nsf_enabled
                                
                                	If true, NSF is enabled
                                	**type**\:  bool
                                
                                .. attribute:: interface_priority
                                
                                	Interface priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: interface_retransmission_interrval
                                
                                	Configured retransmit interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_router_id
                                
                                	Interface Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_sid
                                
                                	Interface SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_sid_n_flag_clear
                                
                                	SID N\-Flag Clear
                                	**type**\:  bool
                                
                                .. attribute:: interface_sid_php_off
                                
                                	SID PHP Off
                                	**type**\:  bool
                                
                                .. attribute:: interface_state
                                
                                	Interface state
                                	**type**\:   :py:class:`InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.InterfaceState>`
                                
                                .. attribute:: interface_strict_spf_sid
                                
                                	Interface Strict\-SPF SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_strict_spf_sid_n_flag_clear
                                
                                	Strict\-SPF SID N\-Flag Clear
                                	**type**\:  bool
                                
                                .. attribute:: interface_strict_spf_sid_php_off
                                
                                	Strict\-SPF SID PHP Off
                                	**type**\:  bool
                                
                                .. attribute:: interface_tunnel_flags
                                
                                	Interface tunnel flags
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interfaceis_madj
                                
                                	If true, interface is multi\-area
                                	**type**\:  bool
                                
                                .. attribute:: ip_mtu
                                
                                	IP MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ipfrr_tiebreakers
                                
                                	IPFRR\-Tiebreakers list
                                	**type**\: list of    :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers>`
                                
                                .. attribute:: is_loopback_stub_network
                                
                                	If true, loopback interface is advertised as a stub network
                                	**type**\:  bool
                                
                                .. attribute:: maximum_packet_size
                                
                                	Maximum Packet Size
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: network_lsa_flush_timer
                                
                                	The amount of time in seconds before flush timer for old network LSA expires
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: network_type
                                
                                	Network type
                                	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                                
                                .. attribute:: next_hello_time
                                
                                	Time until next Hello (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hello_time_ms
                                
                                	Time until next Hello (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                .. attribute:: passive_interface
                                
                                	If true, passive interface
                                	**type**\:  bool
                                
                                .. attribute:: prefix_suppress_primary_addresses
                                
                                	Prefix Suppression for primary addresses
                                	**type**\:  bool
                                
                                .. attribute:: prefix_suppress_secondary_addresses
                                
                                	Prefix Suppression for secondary addresses
                                	**type**\:  bool
                                
                                .. attribute:: registered_for_link_down_fast_detection
                                
                                	Registered for Link Down Fast Detection
                                	**type**\:  bool
                                
                                .. attribute:: srlg
                                
                                	SRLG Values
                                	**type**\: list of    :py:class:`Srlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.Srlg>`
                                
                                .. attribute:: transmission_delay
                                
                                	Interface Transmission delay
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL security enabled on the interface
                                	**type**\:  bool
                                
                                .. attribute:: ttl_security_hop_count
                                
                                	TTL security hop counts
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wait_interval
                                
                                	Configured wait interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interfaces"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.backup_designated_router = YLeaf(YType.boolean, "backup-designated-router")

                                    self.backup_designated_router_address = YLeaf(YType.str, "backup-designated-router-address")

                                    self.backup_designated_router_id = YLeaf(YType.str, "backup-designated-router-id")

                                    self.cfg_cost_fallback = YLeaf(YType.boolean, "cfg-cost-fallback")

                                    self.configured_demand_circuit = YLeaf(YType.boolean, "configured-demand-circuit")

                                    self.configured_ldp_sync = YLeaf(YType.boolean, "configured-ldp-sync")

                                    self.configured_ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "configured-ldp-sync-igp-shortcuts")

                                    self.cost_fallback_active = YLeaf(YType.boolean, "cost-fallback-active")

                                    self.dead_interval = YLeaf(YType.uint32, "dead-interval")

                                    self.designated_router = YLeaf(YType.boolean, "designated-router")

                                    self.designated_router_address = YLeaf(YType.str, "designated-router-address")

                                    self.designated_router_id = YLeaf(YType.str, "designated-router-id")

                                    self.fast_detect_hold_down_time = YLeaf(YType.uint32, "fast-detect-hold-down-time")

                                    self.fast_detect_hold_down_time_remaining = YLeaf(YType.uint32, "fast-detect-hold-down-time-remaining")

                                    self.fast_reroute_topology_independent_lfa = YLeaf(YType.boolean, "fast-reroute-topology-independent-lfa")

                                    self.fast_reroute_type = YLeaf(YType.enumeration, "fast-reroute-type")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.hello_interval_ms = YLeaf(YType.uint32, "hello-interval-ms")

                                    self.interface_ack_list_count = YLeaf(YType.uint32, "interface-ack-list-count")

                                    self.interface_ack_list_high_watermark = YLeaf(YType.uint32, "interface-ack-list-high-watermark")

                                    self.interface_address = YLeaf(YType.str, "interface-address")

                                    self.interface_area = YLeaf(YType.str, "interface-area")

                                    self.interface_bandwidth = YLeaf(YType.uint32, "interface-bandwidth")

                                    self.interface_cost_fallback = YLeaf(YType.uint16, "interface-cost-fallback")

                                    self.interface_dc_bitless_lsa_count = YLeaf(YType.uint32, "interface-dc-bitless-lsa-count")

                                    self.interface_demand_circuit = YLeaf(YType.boolean, "interface-demand-circuit")

                                    self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                    self.interface_last_nsf = YLeaf(YType.uint32, "interface-last-nsf")

                                    self.interface_ldp_sync = YLeaf(YType.boolean, "interface-ldp-sync")

                                    self.interface_line_state = YLeaf(YType.boolean, "interface-line-state")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_lsa_filter = YLeaf(YType.boolean, "interface-lsa-filter")

                                    self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                    self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                    self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                    self.interface_nsf = YLeaf(YType.boolean, "interface-nsf")

                                    self.interface_nsf_enabled = YLeaf(YType.boolean, "interface-nsf-enabled")

                                    self.interface_priority = YLeaf(YType.uint8, "interface-priority")

                                    self.interface_retransmission_interrval = YLeaf(YType.uint32, "interface-retransmission-interrval")

                                    self.interface_router_id = YLeaf(YType.str, "interface-router-id")

                                    self.interface_sid = YLeaf(YType.uint32, "interface-sid")

                                    self.interface_sid_n_flag_clear = YLeaf(YType.boolean, "interface-sid-n-flag-clear")

                                    self.interface_sid_php_off = YLeaf(YType.boolean, "interface-sid-php-off")

                                    self.interface_state = YLeaf(YType.enumeration, "interface-state")

                                    self.interface_strict_spf_sid = YLeaf(YType.uint32, "interface-strict-spf-sid")

                                    self.interface_strict_spf_sid_n_flag_clear = YLeaf(YType.boolean, "interface-strict-spf-sid-n-flag-clear")

                                    self.interface_strict_spf_sid_php_off = YLeaf(YType.boolean, "interface-strict-spf-sid-php-off")

                                    self.interface_tunnel_flags = YLeaf(YType.uint32, "interface-tunnel-flags")

                                    self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                    self.ip_mtu = YLeaf(YType.uint16, "ip-mtu")

                                    self.is_loopback_stub_network = YLeaf(YType.boolean, "is-loopback-stub-network")

                                    self.maximum_packet_size = YLeaf(YType.uint16, "maximum-packet-size")

                                    self.network_lsa_flush_timer = YLeaf(YType.uint32, "network-lsa-flush-timer")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.next_hello_time = YLeaf(YType.uint32, "next-hello-time")

                                    self.next_hello_time_ms = YLeaf(YType.uint32, "next-hello-time-ms")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                    self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                                    self.prefix_suppress_primary_addresses = YLeaf(YType.boolean, "prefix-suppress-primary-addresses")

                                    self.prefix_suppress_secondary_addresses = YLeaf(YType.boolean, "prefix-suppress-secondary-addresses")

                                    self.registered_for_link_down_fast_detection = YLeaf(YType.boolean, "registered-for-link-down-fast-detection")

                                    self.transmission_delay = YLeaf(YType.uint16, "transmission-delay")

                                    self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                    self.ttl_security_hop_count = YLeaf(YType.uint32, "ttl-security-hop-count")

                                    self.wait_interval = YLeaf(YType.uint32, "wait-interval")

                                    self.active_interface = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface()
                                    self.active_interface.parent = self
                                    self._children_name_map["active_interface"] = "active-interface"
                                    self._children_yang_names.add("active-interface")

                                    self.interface_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation()
                                    self.interface_bfd_information.parent = self
                                    self._children_name_map["interface_bfd_information"] = "interface-bfd-information"
                                    self._children_yang_names.add("interface-bfd-information")

                                    self.interface_madj = YList(self)
                                    self.interface_neighbor = YList(self)
                                    self.ipfrr_tiebreakers = YList(self)
                                    self.srlg = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "backup_designated_router",
                                                    "backup_designated_router_address",
                                                    "backup_designated_router_id",
                                                    "cfg_cost_fallback",
                                                    "configured_demand_circuit",
                                                    "configured_ldp_sync",
                                                    "configured_ldp_sync_igp_shortcuts",
                                                    "cost_fallback_active",
                                                    "dead_interval",
                                                    "designated_router",
                                                    "designated_router_address",
                                                    "designated_router_id",
                                                    "fast_detect_hold_down_time",
                                                    "fast_detect_hold_down_time_remaining",
                                                    "fast_reroute_topology_independent_lfa",
                                                    "fast_reroute_type",
                                                    "hello_interval",
                                                    "hello_interval_ms",
                                                    "interface_ack_list_count",
                                                    "interface_ack_list_high_watermark",
                                                    "interface_address",
                                                    "interface_area",
                                                    "interface_bandwidth",
                                                    "interface_cost_fallback",
                                                    "interface_dc_bitless_lsa_count",
                                                    "interface_demand_circuit",
                                                    "interface_fast_detect_hold_down",
                                                    "interface_last_nsf",
                                                    "interface_ldp_sync",
                                                    "interface_line_state",
                                                    "interface_link_cost",
                                                    "interface_lsa_filter",
                                                    "interface_madj_count",
                                                    "interface_mask",
                                                    "interface_name_xr",
                                                    "interface_nsf",
                                                    "interface_nsf_enabled",
                                                    "interface_priority",
                                                    "interface_retransmission_interrval",
                                                    "interface_router_id",
                                                    "interface_sid",
                                                    "interface_sid_n_flag_clear",
                                                    "interface_sid_php_off",
                                                    "interface_state",
                                                    "interface_strict_spf_sid",
                                                    "interface_strict_spf_sid_n_flag_clear",
                                                    "interface_strict_spf_sid_php_off",
                                                    "interface_tunnel_flags",
                                                    "interfaceis_madj",
                                                    "ip_mtu",
                                                    "is_loopback_stub_network",
                                                    "maximum_packet_size",
                                                    "network_lsa_flush_timer",
                                                    "network_type",
                                                    "next_hello_time",
                                                    "next_hello_time_ms",
                                                    "ospf_interface_state",
                                                    "passive_interface",
                                                    "prefix_suppress_primary_addresses",
                                                    "prefix_suppress_secondary_addresses",
                                                    "registered_for_link_down_fast_detection",
                                                    "transmission_delay",
                                                    "ttl_security_enabled",
                                                    "ttl_security_hop_count",
                                                    "wait_interval") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface, self).__setattr__(name, value)


                                class InterfaceBfdInformation(Entity):
                                    """
                                    BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	BFD detection multiplier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interval
                                    
                                    	BFD interval (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation, self).__init__()

                                        self.yang_name = "interface-bfd-information"
                                        self.yang_parent_name = "interface"

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                        self.interval = YLeaf(YType.uint32, "interval")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bfd_intf_enable_mode",
                                                        "detection_multiplier",
                                                        "interval") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bfd_intf_enable_mode.is_set or
                                            self.detection_multiplier.is_set or
                                            self.interval.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                            self.detection_multiplier.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-bfd-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                        if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bfd-intf-enable-mode" or name == "detection-multiplier" or name == "interval"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bfd-intf-enable-mode"):
                                            self.bfd_intf_enable_mode = value
                                            self.bfd_intf_enable_mode.value_namespace = name_space
                                            self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "detection-multiplier"):
                                            self.detection_multiplier = value
                                            self.detection_multiplier.value_namespace = name_space
                                            self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix


                                class ActiveInterface(Entity):
                                    """
                                    Active interface details
                                    
                                    .. attribute:: flood_scan_length
                                    
                                    	Last flood scan length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_flood_index
                                    
                                    	Area scope LSAs flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood
                                    
                                    	Next LSA to flood (Area scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood_index
                                    
                                    	Index of next LSA to flood (Area scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_flood_index
                                    
                                    	AS scope LSAs flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood
                                    
                                    	Next LSA to flood (AS scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood_index
                                    
                                    	Index of next LSA to flood (AS scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_authentication_type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                    
                                    .. attribute:: interface_flood_length
                                    
                                    	Flood queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_flood_pacing_timer
                                    
                                    	Time until next flood pacing timer (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Total number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: keychain_id
                                    
                                    	Keychain ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: last_flood_time
                                    
                                    	Last flood scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_length
                                    
                                    	Maximum flood length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_time
                                    
                                    	Maximum flood time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: md_keys
                                    
                                    	List of old MD keys
                                    	**type**\: list of    :py:class:`MdKeys <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys>`
                                    
                                    .. attribute:: old_md5_key_neighbor_count
                                    
                                    	Number of neighbors using the old key (if rollover in progress)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: suppress_hello_count
                                    
                                    	Number of neighbors for which hellos are suppressed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: wait_time
                                    
                                    	Wait time for DR/BDR selection (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: youngest_md_key
                                    
                                    	If true, MD key is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: youngest_md_key_id
                                    
                                    	Youngest MD key ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface, self).__init__()

                                        self.yang_name = "active-interface"
                                        self.yang_parent_name = "interface"

                                        self.flood_scan_length = YLeaf(YType.uint32, "flood-scan-length")

                                        self.interface_area_flood_index = YLeaf(YType.uint32, "interface-area-flood-index")

                                        self.interface_area_next_flood = YLeaf(YType.uint32, "interface-area-next-flood")

                                        self.interface_area_next_flood_index = YLeaf(YType.uint32, "interface-area-next-flood-index")

                                        self.interface_as_flood_index = YLeaf(YType.uint32, "interface-as-flood-index")

                                        self.interface_as_next_flood = YLeaf(YType.uint32, "interface-as-next-flood")

                                        self.interface_as_next_flood_index = YLeaf(YType.uint32, "interface-as-next-flood-index")

                                        self.interface_authentication_type = YLeaf(YType.enumeration, "interface-authentication-type")

                                        self.interface_flood_length = YLeaf(YType.uint32, "interface-flood-length")

                                        self.interface_flood_pacing_timer = YLeaf(YType.uint32, "interface-flood-pacing-timer")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.keychain_id = YLeaf(YType.uint64, "keychain-id")

                                        self.last_flood_time = YLeaf(YType.uint32, "last-flood-time")

                                        self.maximum_flood_length = YLeaf(YType.uint32, "maximum-flood-length")

                                        self.maximum_flood_time = YLeaf(YType.uint32, "maximum-flood-time")

                                        self.old_md5_key_neighbor_count = YLeaf(YType.uint32, "old-md5-key-neighbor-count")

                                        self.suppress_hello_count = YLeaf(YType.uint16, "suppress-hello-count")

                                        self.wait_time = YLeaf(YType.uint32, "wait-time")

                                        self.youngest_md_key = YLeaf(YType.boolean, "youngest-md-key")

                                        self.youngest_md_key_id = YLeaf(YType.uint16, "youngest-md-key-id")

                                        self.md_keys = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("flood_scan_length",
                                                        "interface_area_flood_index",
                                                        "interface_area_next_flood",
                                                        "interface_area_next_flood_index",
                                                        "interface_as_flood_index",
                                                        "interface_as_next_flood",
                                                        "interface_as_next_flood_index",
                                                        "interface_authentication_type",
                                                        "interface_flood_length",
                                                        "interface_flood_pacing_timer",
                                                        "interface_neighbor_count",
                                                        "keychain_id",
                                                        "last_flood_time",
                                                        "maximum_flood_length",
                                                        "maximum_flood_time",
                                                        "old_md5_key_neighbor_count",
                                                        "suppress_hello_count",
                                                        "wait_time",
                                                        "youngest_md_key",
                                                        "youngest_md_key_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface, self).__setattr__(name, value)


                                    class MdKeys(Entity):
                                        """
                                        List of old MD keys
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys, self).__init__()

                                            self.yang_name = "md-keys"
                                            self.yang_parent_name = "active-interface"

                                            self.entry = YLeaf(YType.uint16, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "md-keys" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.md_keys:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.flood_scan_length.is_set or
                                            self.interface_area_flood_index.is_set or
                                            self.interface_area_next_flood.is_set or
                                            self.interface_area_next_flood_index.is_set or
                                            self.interface_as_flood_index.is_set or
                                            self.interface_as_next_flood.is_set or
                                            self.interface_as_next_flood_index.is_set or
                                            self.interface_authentication_type.is_set or
                                            self.interface_flood_length.is_set or
                                            self.interface_flood_pacing_timer.is_set or
                                            self.interface_neighbor_count.is_set or
                                            self.keychain_id.is_set or
                                            self.last_flood_time.is_set or
                                            self.maximum_flood_length.is_set or
                                            self.maximum_flood_time.is_set or
                                            self.old_md5_key_neighbor_count.is_set or
                                            self.suppress_hello_count.is_set or
                                            self.wait_time.is_set or
                                            self.youngest_md_key.is_set or
                                            self.youngest_md_key_id.is_set)

                                    def has_operation(self):
                                        for c in self.md_keys:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.flood_scan_length.yfilter != YFilter.not_set or
                                            self.interface_area_flood_index.yfilter != YFilter.not_set or
                                            self.interface_area_next_flood.yfilter != YFilter.not_set or
                                            self.interface_area_next_flood_index.yfilter != YFilter.not_set or
                                            self.interface_as_flood_index.yfilter != YFilter.not_set or
                                            self.interface_as_next_flood.yfilter != YFilter.not_set or
                                            self.interface_as_next_flood_index.yfilter != YFilter.not_set or
                                            self.interface_authentication_type.yfilter != YFilter.not_set or
                                            self.interface_flood_length.yfilter != YFilter.not_set or
                                            self.interface_flood_pacing_timer.yfilter != YFilter.not_set or
                                            self.interface_neighbor_count.yfilter != YFilter.not_set or
                                            self.keychain_id.yfilter != YFilter.not_set or
                                            self.last_flood_time.yfilter != YFilter.not_set or
                                            self.maximum_flood_length.yfilter != YFilter.not_set or
                                            self.maximum_flood_time.yfilter != YFilter.not_set or
                                            self.old_md5_key_neighbor_count.yfilter != YFilter.not_set or
                                            self.suppress_hello_count.yfilter != YFilter.not_set or
                                            self.wait_time.yfilter != YFilter.not_set or
                                            self.youngest_md_key.yfilter != YFilter.not_set or
                                            self.youngest_md_key_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "active-interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.flood_scan_length.is_set or self.flood_scan_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_scan_length.get_name_leafdata())
                                        if (self.interface_area_flood_index.is_set or self.interface_area_flood_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_area_flood_index.get_name_leafdata())
                                        if (self.interface_area_next_flood.is_set or self.interface_area_next_flood.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_area_next_flood.get_name_leafdata())
                                        if (self.interface_area_next_flood_index.is_set or self.interface_area_next_flood_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_area_next_flood_index.get_name_leafdata())
                                        if (self.interface_as_flood_index.is_set or self.interface_as_flood_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_as_flood_index.get_name_leafdata())
                                        if (self.interface_as_next_flood.is_set or self.interface_as_next_flood.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_as_next_flood.get_name_leafdata())
                                        if (self.interface_as_next_flood_index.is_set or self.interface_as_next_flood_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_as_next_flood_index.get_name_leafdata())
                                        if (self.interface_authentication_type.is_set or self.interface_authentication_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_authentication_type.get_name_leafdata())
                                        if (self.interface_flood_length.is_set or self.interface_flood_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_flood_length.get_name_leafdata())
                                        if (self.interface_flood_pacing_timer.is_set or self.interface_flood_pacing_timer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_flood_pacing_timer.get_name_leafdata())
                                        if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                        if (self.keychain_id.is_set or self.keychain_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_id.get_name_leafdata())
                                        if (self.last_flood_time.is_set or self.last_flood_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_flood_time.get_name_leafdata())
                                        if (self.maximum_flood_length.is_set or self.maximum_flood_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_flood_length.get_name_leafdata())
                                        if (self.maximum_flood_time.is_set or self.maximum_flood_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_flood_time.get_name_leafdata())
                                        if (self.old_md5_key_neighbor_count.is_set or self.old_md5_key_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.old_md5_key_neighbor_count.get_name_leafdata())
                                        if (self.suppress_hello_count.is_set or self.suppress_hello_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.suppress_hello_count.get_name_leafdata())
                                        if (self.wait_time.is_set or self.wait_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.wait_time.get_name_leafdata())
                                        if (self.youngest_md_key.is_set or self.youngest_md_key.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.youngest_md_key.get_name_leafdata())
                                        if (self.youngest_md_key_id.is_set or self.youngest_md_key_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.youngest_md_key_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "md-keys"):
                                            for c in self.md_keys:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.md_keys.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "md-keys" or name == "flood-scan-length" or name == "interface-area-flood-index" or name == "interface-area-next-flood" or name == "interface-area-next-flood-index" or name == "interface-as-flood-index" or name == "interface-as-next-flood" or name == "interface-as-next-flood-index" or name == "interface-authentication-type" or name == "interface-flood-length" or name == "interface-flood-pacing-timer" or name == "interface-neighbor-count" or name == "keychain-id" or name == "last-flood-time" or name == "maximum-flood-length" or name == "maximum-flood-time" or name == "old-md5-key-neighbor-count" or name == "suppress-hello-count" or name == "wait-time" or name == "youngest-md-key" or name == "youngest-md-key-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "flood-scan-length"):
                                            self.flood_scan_length = value
                                            self.flood_scan_length.value_namespace = name_space
                                            self.flood_scan_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-area-flood-index"):
                                            self.interface_area_flood_index = value
                                            self.interface_area_flood_index.value_namespace = name_space
                                            self.interface_area_flood_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-area-next-flood"):
                                            self.interface_area_next_flood = value
                                            self.interface_area_next_flood.value_namespace = name_space
                                            self.interface_area_next_flood.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-area-next-flood-index"):
                                            self.interface_area_next_flood_index = value
                                            self.interface_area_next_flood_index.value_namespace = name_space
                                            self.interface_area_next_flood_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-as-flood-index"):
                                            self.interface_as_flood_index = value
                                            self.interface_as_flood_index.value_namespace = name_space
                                            self.interface_as_flood_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-as-next-flood"):
                                            self.interface_as_next_flood = value
                                            self.interface_as_next_flood.value_namespace = name_space
                                            self.interface_as_next_flood.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-as-next-flood-index"):
                                            self.interface_as_next_flood_index = value
                                            self.interface_as_next_flood_index.value_namespace = name_space
                                            self.interface_as_next_flood_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-authentication-type"):
                                            self.interface_authentication_type = value
                                            self.interface_authentication_type.value_namespace = name_space
                                            self.interface_authentication_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-flood-length"):
                                            self.interface_flood_length = value
                                            self.interface_flood_length.value_namespace = name_space
                                            self.interface_flood_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-flood-pacing-timer"):
                                            self.interface_flood_pacing_timer = value
                                            self.interface_flood_pacing_timer.value_namespace = name_space
                                            self.interface_flood_pacing_timer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-neighbor-count"):
                                            self.interface_neighbor_count = value
                                            self.interface_neighbor_count.value_namespace = name_space
                                            self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keychain-id"):
                                            self.keychain_id = value
                                            self.keychain_id.value_namespace = name_space
                                            self.keychain_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-flood-time"):
                                            self.last_flood_time = value
                                            self.last_flood_time.value_namespace = name_space
                                            self.last_flood_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-flood-length"):
                                            self.maximum_flood_length = value
                                            self.maximum_flood_length.value_namespace = name_space
                                            self.maximum_flood_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-flood-time"):
                                            self.maximum_flood_time = value
                                            self.maximum_flood_time.value_namespace = name_space
                                            self.maximum_flood_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "old-md5-key-neighbor-count"):
                                            self.old_md5_key_neighbor_count = value
                                            self.old_md5_key_neighbor_count.value_namespace = name_space
                                            self.old_md5_key_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "suppress-hello-count"):
                                            self.suppress_hello_count = value
                                            self.suppress_hello_count.value_namespace = name_space
                                            self.suppress_hello_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "wait-time"):
                                            self.wait_time = value
                                            self.wait_time.value_namespace = name_space
                                            self.wait_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "youngest-md-key"):
                                            self.youngest_md_key = value
                                            self.youngest_md_key.value_namespace = name_space
                                            self.youngest_md_key.value_namespace_prefix = name_space_prefix
                                        if(value_path == "youngest-md-key-id"):
                                            self.youngest_md_key_id = value
                                            self.youngest_md_key_id.value_namespace = name_space
                                            self.youngest_md_key_id.value_namespace_prefix = name_space_prefix


                                class Srlg(Entity):
                                    """
                                    SRLG Values
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.Srlg, self).__init__()

                                        self.yang_name = "srlg"
                                        self.yang_parent_name = "interface"

                                        self.entry = YLeaf(YType.uint32, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.Srlg, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.Srlg, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "srlg" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix


                                class InterfaceNeighbor(Entity):
                                    """
                                    Information for neighbors on the interface
                                    
                                    .. attribute:: interface_neighbor_cost
                                    
                                    	Cost of link to neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_neighbor_id
                                    
                                    	Neighbor Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bdr
                                    
                                    	If true, Backup designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_dr
                                    
                                    	If true, Designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: suppress_hello
                                    
                                    	If true, hellos suppressed
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor, self).__init__()

                                        self.yang_name = "interface-neighbor"
                                        self.yang_parent_name = "interface"

                                        self.interface_neighbor_cost = YLeaf(YType.uint32, "interface-neighbor-cost")

                                        self.interface_neighbor_id = YLeaf(YType.str, "interface-neighbor-id")

                                        self.neighbor_bdr = YLeaf(YType.boolean, "neighbor-bdr")

                                        self.neighbor_dr = YLeaf(YType.boolean, "neighbor-dr")

                                        self.suppress_hello = YLeaf(YType.boolean, "suppress-hello")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_neighbor_cost",
                                                        "interface_neighbor_id",
                                                        "neighbor_bdr",
                                                        "neighbor_dr",
                                                        "suppress_hello") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interface_neighbor_cost.is_set or
                                            self.interface_neighbor_id.is_set or
                                            self.neighbor_bdr.is_set or
                                            self.neighbor_dr.is_set or
                                            self.suppress_hello.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_neighbor_cost.yfilter != YFilter.not_set or
                                            self.interface_neighbor_id.yfilter != YFilter.not_set or
                                            self.neighbor_bdr.yfilter != YFilter.not_set or
                                            self.neighbor_dr.yfilter != YFilter.not_set or
                                            self.suppress_hello.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-neighbor" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_neighbor_cost.is_set or self.interface_neighbor_cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_neighbor_cost.get_name_leafdata())
                                        if (self.interface_neighbor_id.is_set or self.interface_neighbor_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_neighbor_id.get_name_leafdata())
                                        if (self.neighbor_bdr.is_set or self.neighbor_bdr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_bdr.get_name_leafdata())
                                        if (self.neighbor_dr.is_set or self.neighbor_dr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_dr.get_name_leafdata())
                                        if (self.suppress_hello.is_set or self.suppress_hello.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.suppress_hello.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-neighbor-cost" or name == "interface-neighbor-id" or name == "neighbor-bdr" or name == "neighbor-dr" or name == "suppress-hello"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-neighbor-cost"):
                                            self.interface_neighbor_cost = value
                                            self.interface_neighbor_cost.value_namespace = name_space
                                            self.interface_neighbor_cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-neighbor-id"):
                                            self.interface_neighbor_id = value
                                            self.interface_neighbor_id.value_namespace = name_space
                                            self.interface_neighbor_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-bdr"):
                                            self.neighbor_bdr = value
                                            self.neighbor_bdr.value_namespace = name_space
                                            self.neighbor_bdr.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-dr"):
                                            self.neighbor_dr = value
                                            self.neighbor_dr.value_namespace = name_space
                                            self.neighbor_dr.value_namespace_prefix = name_space_prefix
                                        if(value_path == "suppress-hello"):
                                            self.suppress_hello = value
                                            self.suppress_hello.value_namespace = name_space
                                            self.suppress_hello.value_namespace_prefix = name_space_prefix


                                class InterfaceMadj(Entity):
                                    """
                                    Information for multi\-area on the interface
                                    
                                    .. attribute:: interface_adj_neighbor_count
                                    
                                    	Total number of Adjacent Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_area
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: madj_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj, self).__init__()

                                        self.yang_name = "interface-madj"
                                        self.yang_parent_name = "interface"

                                        self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                        self.interface_area = YLeaf(YType.str, "interface-area")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_adj_neighbor_count",
                                                        "interface_area",
                                                        "interface_link_cost",
                                                        "interface_neighbor_count",
                                                        "madj_area_id",
                                                        "ospf_interface_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interface_adj_neighbor_count.is_set or
                                            self.interface_area.is_set or
                                            self.interface_link_cost.is_set or
                                            self.interface_neighbor_count.is_set or
                                            self.madj_area_id.is_set or
                                            self.ospf_interface_state.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_adj_neighbor_count.yfilter != YFilter.not_set or
                                            self.interface_area.yfilter != YFilter.not_set or
                                            self.interface_link_cost.yfilter != YFilter.not_set or
                                            self.interface_neighbor_count.yfilter != YFilter.not_set or
                                            self.madj_area_id.yfilter != YFilter.not_set or
                                            self.ospf_interface_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-madj" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_adj_neighbor_count.is_set or self.interface_adj_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_adj_neighbor_count.get_name_leafdata())
                                        if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_area.get_name_leafdata())
                                        if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                        if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                        if (self.madj_area_id.is_set or self.madj_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.madj_area_id.get_name_leafdata())
                                        if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-adj-neighbor-count" or name == "interface-area" or name == "interface-link-cost" or name == "interface-neighbor-count" or name == "madj-area-id" or name == "ospf-interface-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-adj-neighbor-count"):
                                            self.interface_adj_neighbor_count = value
                                            self.interface_adj_neighbor_count.value_namespace = name_space
                                            self.interface_adj_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-area"):
                                            self.interface_area = value
                                            self.interface_area.value_namespace = name_space
                                            self.interface_area.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-link-cost"):
                                            self.interface_link_cost = value
                                            self.interface_link_cost.value_namespace = name_space
                                            self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-neighbor-count"):
                                            self.interface_neighbor_count = value
                                            self.interface_neighbor_count.value_namespace = name_space
                                            self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "madj-area-id"):
                                            self.madj_area_id = value
                                            self.madj_area_id.value_namespace = name_space
                                            self.madj_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-interface-state"):
                                            self.ospf_interface_state = value
                                            self.ospf_interface_state.value_namespace = name_space
                                            self.ospf_interface_state.value_namespace_prefix = name_space_prefix


                                class IpfrrTiebreakers(Entity):
                                    """
                                    IPFRR\-Tiebreakers list
                                    
                                    .. attribute:: tiebreaker_index
                                    
                                    	Tiebreaker Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tiebreaker_type
                                    
                                    	Tiebreaker Type
                                    	**type**\:   :py:class:`IpfrrTbrkr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IpfrrTbrkr>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers, self).__init__()

                                        self.yang_name = "ipfrr-tiebreakers"
                                        self.yang_parent_name = "interface"

                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tiebreaker_index",
                                                        "tiebreaker_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.tiebreaker_index.is_set or
                                            self.tiebreaker_type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tiebreaker_index.yfilter != YFilter.not_set or
                                            self.tiebreaker_type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipfrr-tiebreakers" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())
                                        if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tiebreaker-index" or name == "tiebreaker-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tiebreaker-index"):
                                            self.tiebreaker_index = value
                                            self.tiebreaker_index.value_namespace = name_space
                                            self.tiebreaker_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tiebreaker-type"):
                                            self.tiebreaker_type = value
                                            self.tiebreaker_type.value_namespace = name_space
                                            self.tiebreaker_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.interface_madj:
                                        if (c.has_data()):
                                            return True
                                    for c in self.interface_neighbor:
                                        if (c.has_data()):
                                            return True
                                    for c in self.ipfrr_tiebreakers:
                                        if (c.has_data()):
                                            return True
                                    for c in self.srlg:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.interface_name.is_set or
                                        self.backup_designated_router.is_set or
                                        self.backup_designated_router_address.is_set or
                                        self.backup_designated_router_id.is_set or
                                        self.cfg_cost_fallback.is_set or
                                        self.configured_demand_circuit.is_set or
                                        self.configured_ldp_sync.is_set or
                                        self.configured_ldp_sync_igp_shortcuts.is_set or
                                        self.cost_fallback_active.is_set or
                                        self.dead_interval.is_set or
                                        self.designated_router.is_set or
                                        self.designated_router_address.is_set or
                                        self.designated_router_id.is_set or
                                        self.fast_detect_hold_down_time.is_set or
                                        self.fast_detect_hold_down_time_remaining.is_set or
                                        self.fast_reroute_topology_independent_lfa.is_set or
                                        self.fast_reroute_type.is_set or
                                        self.hello_interval.is_set or
                                        self.hello_interval_ms.is_set or
                                        self.interface_ack_list_count.is_set or
                                        self.interface_ack_list_high_watermark.is_set or
                                        self.interface_address.is_set or
                                        self.interface_area.is_set or
                                        self.interface_bandwidth.is_set or
                                        self.interface_cost_fallback.is_set or
                                        self.interface_dc_bitless_lsa_count.is_set or
                                        self.interface_demand_circuit.is_set or
                                        self.interface_fast_detect_hold_down.is_set or
                                        self.interface_last_nsf.is_set or
                                        self.interface_ldp_sync.is_set or
                                        self.interface_line_state.is_set or
                                        self.interface_link_cost.is_set or
                                        self.interface_lsa_filter.is_set or
                                        self.interface_madj_count.is_set or
                                        self.interface_mask.is_set or
                                        self.interface_name_xr.is_set or
                                        self.interface_nsf.is_set or
                                        self.interface_nsf_enabled.is_set or
                                        self.interface_priority.is_set or
                                        self.interface_retransmission_interrval.is_set or
                                        self.interface_router_id.is_set or
                                        self.interface_sid.is_set or
                                        self.interface_sid_n_flag_clear.is_set or
                                        self.interface_sid_php_off.is_set or
                                        self.interface_state.is_set or
                                        self.interface_strict_spf_sid.is_set or
                                        self.interface_strict_spf_sid_n_flag_clear.is_set or
                                        self.interface_strict_spf_sid_php_off.is_set or
                                        self.interface_tunnel_flags.is_set or
                                        self.interfaceis_madj.is_set or
                                        self.ip_mtu.is_set or
                                        self.is_loopback_stub_network.is_set or
                                        self.maximum_packet_size.is_set or
                                        self.network_lsa_flush_timer.is_set or
                                        self.network_type.is_set or
                                        self.next_hello_time.is_set or
                                        self.next_hello_time_ms.is_set or
                                        self.ospf_interface_state.is_set or
                                        self.passive_interface.is_set or
                                        self.prefix_suppress_primary_addresses.is_set or
                                        self.prefix_suppress_secondary_addresses.is_set or
                                        self.registered_for_link_down_fast_detection.is_set or
                                        self.transmission_delay.is_set or
                                        self.ttl_security_enabled.is_set or
                                        self.ttl_security_hop_count.is_set or
                                        self.wait_interval.is_set or
                                        (self.active_interface is not None and self.active_interface.has_data()) or
                                        (self.interface_bfd_information is not None and self.interface_bfd_information.has_data()))

                                def has_operation(self):
                                    for c in self.interface_madj:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.interface_neighbor:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.ipfrr_tiebreakers:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.srlg:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.backup_designated_router.yfilter != YFilter.not_set or
                                        self.backup_designated_router_address.yfilter != YFilter.not_set or
                                        self.backup_designated_router_id.yfilter != YFilter.not_set or
                                        self.cfg_cost_fallback.yfilter != YFilter.not_set or
                                        self.configured_demand_circuit.yfilter != YFilter.not_set or
                                        self.configured_ldp_sync.yfilter != YFilter.not_set or
                                        self.configured_ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                                        self.cost_fallback_active.yfilter != YFilter.not_set or
                                        self.dead_interval.yfilter != YFilter.not_set or
                                        self.designated_router.yfilter != YFilter.not_set or
                                        self.designated_router_address.yfilter != YFilter.not_set or
                                        self.designated_router_id.yfilter != YFilter.not_set or
                                        self.fast_detect_hold_down_time.yfilter != YFilter.not_set or
                                        self.fast_detect_hold_down_time_remaining.yfilter != YFilter.not_set or
                                        self.fast_reroute_topology_independent_lfa.yfilter != YFilter.not_set or
                                        self.fast_reroute_type.yfilter != YFilter.not_set or
                                        self.hello_interval.yfilter != YFilter.not_set or
                                        self.hello_interval_ms.yfilter != YFilter.not_set or
                                        self.interface_ack_list_count.yfilter != YFilter.not_set or
                                        self.interface_ack_list_high_watermark.yfilter != YFilter.not_set or
                                        self.interface_address.yfilter != YFilter.not_set or
                                        self.interface_area.yfilter != YFilter.not_set or
                                        self.interface_bandwidth.yfilter != YFilter.not_set or
                                        self.interface_cost_fallback.yfilter != YFilter.not_set or
                                        self.interface_dc_bitless_lsa_count.yfilter != YFilter.not_set or
                                        self.interface_demand_circuit.yfilter != YFilter.not_set or
                                        self.interface_fast_detect_hold_down.yfilter != YFilter.not_set or
                                        self.interface_last_nsf.yfilter != YFilter.not_set or
                                        self.interface_ldp_sync.yfilter != YFilter.not_set or
                                        self.interface_line_state.yfilter != YFilter.not_set or
                                        self.interface_link_cost.yfilter != YFilter.not_set or
                                        self.interface_lsa_filter.yfilter != YFilter.not_set or
                                        self.interface_madj_count.yfilter != YFilter.not_set or
                                        self.interface_mask.yfilter != YFilter.not_set or
                                        self.interface_name_xr.yfilter != YFilter.not_set or
                                        self.interface_nsf.yfilter != YFilter.not_set or
                                        self.interface_nsf_enabled.yfilter != YFilter.not_set or
                                        self.interface_priority.yfilter != YFilter.not_set or
                                        self.interface_retransmission_interrval.yfilter != YFilter.not_set or
                                        self.interface_router_id.yfilter != YFilter.not_set or
                                        self.interface_sid.yfilter != YFilter.not_set or
                                        self.interface_sid_n_flag_clear.yfilter != YFilter.not_set or
                                        self.interface_sid_php_off.yfilter != YFilter.not_set or
                                        self.interface_state.yfilter != YFilter.not_set or
                                        self.interface_strict_spf_sid.yfilter != YFilter.not_set or
                                        self.interface_strict_spf_sid_n_flag_clear.yfilter != YFilter.not_set or
                                        self.interface_strict_spf_sid_php_off.yfilter != YFilter.not_set or
                                        self.interface_tunnel_flags.yfilter != YFilter.not_set or
                                        self.interfaceis_madj.yfilter != YFilter.not_set or
                                        self.ip_mtu.yfilter != YFilter.not_set or
                                        self.is_loopback_stub_network.yfilter != YFilter.not_set or
                                        self.maximum_packet_size.yfilter != YFilter.not_set or
                                        self.network_lsa_flush_timer.yfilter != YFilter.not_set or
                                        self.network_type.yfilter != YFilter.not_set or
                                        self.next_hello_time.yfilter != YFilter.not_set or
                                        self.next_hello_time_ms.yfilter != YFilter.not_set or
                                        self.ospf_interface_state.yfilter != YFilter.not_set or
                                        self.passive_interface.yfilter != YFilter.not_set or
                                        self.prefix_suppress_primary_addresses.yfilter != YFilter.not_set or
                                        self.prefix_suppress_secondary_addresses.yfilter != YFilter.not_set or
                                        self.registered_for_link_down_fast_detection.yfilter != YFilter.not_set or
                                        self.transmission_delay.yfilter != YFilter.not_set or
                                        self.ttl_security_enabled.yfilter != YFilter.not_set or
                                        self.ttl_security_hop_count.yfilter != YFilter.not_set or
                                        self.wait_interval.yfilter != YFilter.not_set or
                                        (self.active_interface is not None and self.active_interface.has_operation()) or
                                        (self.interface_bfd_information is not None and self.interface_bfd_information.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.backup_designated_router.is_set or self.backup_designated_router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_designated_router.get_name_leafdata())
                                    if (self.backup_designated_router_address.is_set or self.backup_designated_router_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_designated_router_address.get_name_leafdata())
                                    if (self.backup_designated_router_id.is_set or self.backup_designated_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_designated_router_id.get_name_leafdata())
                                    if (self.cfg_cost_fallback.is_set or self.cfg_cost_fallback.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cfg_cost_fallback.get_name_leafdata())
                                    if (self.configured_demand_circuit.is_set or self.configured_demand_circuit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.configured_demand_circuit.get_name_leafdata())
                                    if (self.configured_ldp_sync.is_set or self.configured_ldp_sync.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.configured_ldp_sync.get_name_leafdata())
                                    if (self.configured_ldp_sync_igp_shortcuts.is_set or self.configured_ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.configured_ldp_sync_igp_shortcuts.get_name_leafdata())
                                    if (self.cost_fallback_active.is_set or self.cost_fallback_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cost_fallback_active.get_name_leafdata())
                                    if (self.dead_interval.is_set or self.dead_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dead_interval.get_name_leafdata())
                                    if (self.designated_router.is_set or self.designated_router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.designated_router.get_name_leafdata())
                                    if (self.designated_router_address.is_set or self.designated_router_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.designated_router_address.get_name_leafdata())
                                    if (self.designated_router_id.is_set or self.designated_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.designated_router_id.get_name_leafdata())
                                    if (self.fast_detect_hold_down_time.is_set or self.fast_detect_hold_down_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_detect_hold_down_time.get_name_leafdata())
                                    if (self.fast_detect_hold_down_time_remaining.is_set or self.fast_detect_hold_down_time_remaining.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_detect_hold_down_time_remaining.get_name_leafdata())
                                    if (self.fast_reroute_topology_independent_lfa.is_set or self.fast_reroute_topology_independent_lfa.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_reroute_topology_independent_lfa.get_name_leafdata())
                                    if (self.fast_reroute_type.is_set or self.fast_reroute_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_reroute_type.get_name_leafdata())
                                    if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                    if (self.hello_interval_ms.is_set or self.hello_interval_ms.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval_ms.get_name_leafdata())
                                    if (self.interface_ack_list_count.is_set or self.interface_ack_list_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_ack_list_count.get_name_leafdata())
                                    if (self.interface_ack_list_high_watermark.is_set or self.interface_ack_list_high_watermark.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_ack_list_high_watermark.get_name_leafdata())
                                    if (self.interface_address.is_set or self.interface_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_address.get_name_leafdata())
                                    if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_area.get_name_leafdata())
                                    if (self.interface_bandwidth.is_set or self.interface_bandwidth.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_bandwidth.get_name_leafdata())
                                    if (self.interface_cost_fallback.is_set or self.interface_cost_fallback.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_cost_fallback.get_name_leafdata())
                                    if (self.interface_dc_bitless_lsa_count.is_set or self.interface_dc_bitless_lsa_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_dc_bitless_lsa_count.get_name_leafdata())
                                    if (self.interface_demand_circuit.is_set or self.interface_demand_circuit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_demand_circuit.get_name_leafdata())
                                    if (self.interface_fast_detect_hold_down.is_set or self.interface_fast_detect_hold_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_fast_detect_hold_down.get_name_leafdata())
                                    if (self.interface_last_nsf.is_set or self.interface_last_nsf.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_last_nsf.get_name_leafdata())
                                    if (self.interface_ldp_sync.is_set or self.interface_ldp_sync.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_ldp_sync.get_name_leafdata())
                                    if (self.interface_line_state.is_set or self.interface_line_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_line_state.get_name_leafdata())
                                    if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                    if (self.interface_lsa_filter.is_set or self.interface_lsa_filter.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_lsa_filter.get_name_leafdata())
                                    if (self.interface_madj_count.is_set or self.interface_madj_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_madj_count.get_name_leafdata())
                                    if (self.interface_mask.is_set or self.interface_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_mask.get_name_leafdata())
                                    if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                    if (self.interface_nsf.is_set or self.interface_nsf.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_nsf.get_name_leafdata())
                                    if (self.interface_nsf_enabled.is_set or self.interface_nsf_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_nsf_enabled.get_name_leafdata())
                                    if (self.interface_priority.is_set or self.interface_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_priority.get_name_leafdata())
                                    if (self.interface_retransmission_interrval.is_set or self.interface_retransmission_interrval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_retransmission_interrval.get_name_leafdata())
                                    if (self.interface_router_id.is_set or self.interface_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_router_id.get_name_leafdata())
                                    if (self.interface_sid.is_set or self.interface_sid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_sid.get_name_leafdata())
                                    if (self.interface_sid_n_flag_clear.is_set or self.interface_sid_n_flag_clear.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_sid_n_flag_clear.get_name_leafdata())
                                    if (self.interface_sid_php_off.is_set or self.interface_sid_php_off.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_sid_php_off.get_name_leafdata())
                                    if (self.interface_state.is_set or self.interface_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_state.get_name_leafdata())
                                    if (self.interface_strict_spf_sid.is_set or self.interface_strict_spf_sid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_strict_spf_sid.get_name_leafdata())
                                    if (self.interface_strict_spf_sid_n_flag_clear.is_set or self.interface_strict_spf_sid_n_flag_clear.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_strict_spf_sid_n_flag_clear.get_name_leafdata())
                                    if (self.interface_strict_spf_sid_php_off.is_set or self.interface_strict_spf_sid_php_off.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_strict_spf_sid_php_off.get_name_leafdata())
                                    if (self.interface_tunnel_flags.is_set or self.interface_tunnel_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_tunnel_flags.get_name_leafdata())
                                    if (self.interfaceis_madj.is_set or self.interfaceis_madj.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interfaceis_madj.get_name_leafdata())
                                    if (self.ip_mtu.is_set or self.ip_mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ip_mtu.get_name_leafdata())
                                    if (self.is_loopback_stub_network.is_set or self.is_loopback_stub_network.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_loopback_stub_network.get_name_leafdata())
                                    if (self.maximum_packet_size.is_set or self.maximum_packet_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_packet_size.get_name_leafdata())
                                    if (self.network_lsa_flush_timer.is_set or self.network_lsa_flush_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.network_lsa_flush_timer.get_name_leafdata())
                                    if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.network_type.get_name_leafdata())
                                    if (self.next_hello_time.is_set or self.next_hello_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hello_time.get_name_leafdata())
                                    if (self.next_hello_time_ms.is_set or self.next_hello_time_ms.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hello_time_ms.get_name_leafdata())
                                    if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())
                                    if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.passive_interface.get_name_leafdata())
                                    if (self.prefix_suppress_primary_addresses.is_set or self.prefix_suppress_primary_addresses.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_suppress_primary_addresses.get_name_leafdata())
                                    if (self.prefix_suppress_secondary_addresses.is_set or self.prefix_suppress_secondary_addresses.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_suppress_secondary_addresses.get_name_leafdata())
                                    if (self.registered_for_link_down_fast_detection.is_set or self.registered_for_link_down_fast_detection.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.registered_for_link_down_fast_detection.get_name_leafdata())
                                    if (self.transmission_delay.is_set or self.transmission_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transmission_delay.get_name_leafdata())
                                    if (self.ttl_security_enabled.is_set or self.ttl_security_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl_security_enabled.get_name_leafdata())
                                    if (self.ttl_security_hop_count.is_set or self.ttl_security_hop_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl_security_hop_count.get_name_leafdata())
                                    if (self.wait_interval.is_set or self.wait_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wait_interval.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "active-interface"):
                                        if (self.active_interface is None):
                                            self.active_interface = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface()
                                            self.active_interface.parent = self
                                            self._children_name_map["active_interface"] = "active-interface"
                                        return self.active_interface

                                    if (child_yang_name == "interface-bfd-information"):
                                        if (self.interface_bfd_information is None):
                                            self.interface_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation()
                                            self.interface_bfd_information.parent = self
                                            self._children_name_map["interface_bfd_information"] = "interface-bfd-information"
                                        return self.interface_bfd_information

                                    if (child_yang_name == "interface-madj"):
                                        for c in self.interface_madj:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.interface_madj.append(c)
                                        return c

                                    if (child_yang_name == "interface-neighbor"):
                                        for c in self.interface_neighbor:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.interface_neighbor.append(c)
                                        return c

                                    if (child_yang_name == "ipfrr-tiebreakers"):
                                        for c in self.ipfrr_tiebreakers:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.ipfrr_tiebreakers.append(c)
                                        return c

                                    if (child_yang_name == "srlg"):
                                        for c in self.srlg:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.Srlg()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.srlg.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "active-interface" or name == "interface-bfd-information" or name == "interface-madj" or name == "interface-neighbor" or name == "ipfrr-tiebreakers" or name == "srlg" or name == "interface-name" or name == "backup-designated-router" or name == "backup-designated-router-address" or name == "backup-designated-router-id" or name == "cfg-cost-fallback" or name == "configured-demand-circuit" or name == "configured-ldp-sync" or name == "configured-ldp-sync-igp-shortcuts" or name == "cost-fallback-active" or name == "dead-interval" or name == "designated-router" or name == "designated-router-address" or name == "designated-router-id" or name == "fast-detect-hold-down-time" or name == "fast-detect-hold-down-time-remaining" or name == "fast-reroute-topology-independent-lfa" or name == "fast-reroute-type" or name == "hello-interval" or name == "hello-interval-ms" or name == "interface-ack-list-count" or name == "interface-ack-list-high-watermark" or name == "interface-address" or name == "interface-area" or name == "interface-bandwidth" or name == "interface-cost-fallback" or name == "interface-dc-bitless-lsa-count" or name == "interface-demand-circuit" or name == "interface-fast-detect-hold-down" or name == "interface-last-nsf" or name == "interface-ldp-sync" or name == "interface-line-state" or name == "interface-link-cost" or name == "interface-lsa-filter" or name == "interface-madj-count" or name == "interface-mask" or name == "interface-name-xr" or name == "interface-nsf" or name == "interface-nsf-enabled" or name == "interface-priority" or name == "interface-retransmission-interrval" or name == "interface-router-id" or name == "interface-sid" or name == "interface-sid-n-flag-clear" or name == "interface-sid-php-off" or name == "interface-state" or name == "interface-strict-spf-sid" or name == "interface-strict-spf-sid-n-flag-clear" or name == "interface-strict-spf-sid-php-off" or name == "interface-tunnel-flags" or name == "interfaceis-madj" or name == "ip-mtu" or name == "is-loopback-stub-network" or name == "maximum-packet-size" or name == "network-lsa-flush-timer" or name == "network-type" or name == "next-hello-time" or name == "next-hello-time-ms" or name == "ospf-interface-state" or name == "passive-interface" or name == "prefix-suppress-primary-addresses" or name == "prefix-suppress-secondary-addresses" or name == "registered-for-link-down-fast-detection" or name == "transmission-delay" or name == "ttl-security-enabled" or name == "ttl-security-hop-count" or name == "wait-interval"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-designated-router"):
                                        self.backup_designated_router = value
                                        self.backup_designated_router.value_namespace = name_space
                                        self.backup_designated_router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-designated-router-address"):
                                        self.backup_designated_router_address = value
                                        self.backup_designated_router_address.value_namespace = name_space
                                        self.backup_designated_router_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-designated-router-id"):
                                        self.backup_designated_router_id = value
                                        self.backup_designated_router_id.value_namespace = name_space
                                        self.backup_designated_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cfg-cost-fallback"):
                                        self.cfg_cost_fallback = value
                                        self.cfg_cost_fallback.value_namespace = name_space
                                        self.cfg_cost_fallback.value_namespace_prefix = name_space_prefix
                                    if(value_path == "configured-demand-circuit"):
                                        self.configured_demand_circuit = value
                                        self.configured_demand_circuit.value_namespace = name_space
                                        self.configured_demand_circuit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "configured-ldp-sync"):
                                        self.configured_ldp_sync = value
                                        self.configured_ldp_sync.value_namespace = name_space
                                        self.configured_ldp_sync.value_namespace_prefix = name_space_prefix
                                    if(value_path == "configured-ldp-sync-igp-shortcuts"):
                                        self.configured_ldp_sync_igp_shortcuts = value
                                        self.configured_ldp_sync_igp_shortcuts.value_namespace = name_space
                                        self.configured_ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cost-fallback-active"):
                                        self.cost_fallback_active = value
                                        self.cost_fallback_active.value_namespace = name_space
                                        self.cost_fallback_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dead-interval"):
                                        self.dead_interval = value
                                        self.dead_interval.value_namespace = name_space
                                        self.dead_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "designated-router"):
                                        self.designated_router = value
                                        self.designated_router.value_namespace = name_space
                                        self.designated_router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "designated-router-address"):
                                        self.designated_router_address = value
                                        self.designated_router_address.value_namespace = name_space
                                        self.designated_router_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "designated-router-id"):
                                        self.designated_router_id = value
                                        self.designated_router_id.value_namespace = name_space
                                        self.designated_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fast-detect-hold-down-time"):
                                        self.fast_detect_hold_down_time = value
                                        self.fast_detect_hold_down_time.value_namespace = name_space
                                        self.fast_detect_hold_down_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fast-detect-hold-down-time-remaining"):
                                        self.fast_detect_hold_down_time_remaining = value
                                        self.fast_detect_hold_down_time_remaining.value_namespace = name_space
                                        self.fast_detect_hold_down_time_remaining.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fast-reroute-topology-independent-lfa"):
                                        self.fast_reroute_topology_independent_lfa = value
                                        self.fast_reroute_topology_independent_lfa.value_namespace = name_space
                                        self.fast_reroute_topology_independent_lfa.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fast-reroute-type"):
                                        self.fast_reroute_type = value
                                        self.fast_reroute_type.value_namespace = name_space
                                        self.fast_reroute_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval"):
                                        self.hello_interval = value
                                        self.hello_interval.value_namespace = name_space
                                        self.hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval-ms"):
                                        self.hello_interval_ms = value
                                        self.hello_interval_ms.value_namespace = name_space
                                        self.hello_interval_ms.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-ack-list-count"):
                                        self.interface_ack_list_count = value
                                        self.interface_ack_list_count.value_namespace = name_space
                                        self.interface_ack_list_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-ack-list-high-watermark"):
                                        self.interface_ack_list_high_watermark = value
                                        self.interface_ack_list_high_watermark.value_namespace = name_space
                                        self.interface_ack_list_high_watermark.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-address"):
                                        self.interface_address = value
                                        self.interface_address.value_namespace = name_space
                                        self.interface_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-area"):
                                        self.interface_area = value
                                        self.interface_area.value_namespace = name_space
                                        self.interface_area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-bandwidth"):
                                        self.interface_bandwidth = value
                                        self.interface_bandwidth.value_namespace = name_space
                                        self.interface_bandwidth.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-cost-fallback"):
                                        self.interface_cost_fallback = value
                                        self.interface_cost_fallback.value_namespace = name_space
                                        self.interface_cost_fallback.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-dc-bitless-lsa-count"):
                                        self.interface_dc_bitless_lsa_count = value
                                        self.interface_dc_bitless_lsa_count.value_namespace = name_space
                                        self.interface_dc_bitless_lsa_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-demand-circuit"):
                                        self.interface_demand_circuit = value
                                        self.interface_demand_circuit.value_namespace = name_space
                                        self.interface_demand_circuit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-fast-detect-hold-down"):
                                        self.interface_fast_detect_hold_down = value
                                        self.interface_fast_detect_hold_down.value_namespace = name_space
                                        self.interface_fast_detect_hold_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-last-nsf"):
                                        self.interface_last_nsf = value
                                        self.interface_last_nsf.value_namespace = name_space
                                        self.interface_last_nsf.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-ldp-sync"):
                                        self.interface_ldp_sync = value
                                        self.interface_ldp_sync.value_namespace = name_space
                                        self.interface_ldp_sync.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-line-state"):
                                        self.interface_line_state = value
                                        self.interface_line_state.value_namespace = name_space
                                        self.interface_line_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-link-cost"):
                                        self.interface_link_cost = value
                                        self.interface_link_cost.value_namespace = name_space
                                        self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-lsa-filter"):
                                        self.interface_lsa_filter = value
                                        self.interface_lsa_filter.value_namespace = name_space
                                        self.interface_lsa_filter.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-madj-count"):
                                        self.interface_madj_count = value
                                        self.interface_madj_count.value_namespace = name_space
                                        self.interface_madj_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-mask"):
                                        self.interface_mask = value
                                        self.interface_mask.value_namespace = name_space
                                        self.interface_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name-xr"):
                                        self.interface_name_xr = value
                                        self.interface_name_xr.value_namespace = name_space
                                        self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-nsf"):
                                        self.interface_nsf = value
                                        self.interface_nsf.value_namespace = name_space
                                        self.interface_nsf.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-nsf-enabled"):
                                        self.interface_nsf_enabled = value
                                        self.interface_nsf_enabled.value_namespace = name_space
                                        self.interface_nsf_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-priority"):
                                        self.interface_priority = value
                                        self.interface_priority.value_namespace = name_space
                                        self.interface_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-retransmission-interrval"):
                                        self.interface_retransmission_interrval = value
                                        self.interface_retransmission_interrval.value_namespace = name_space
                                        self.interface_retransmission_interrval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-router-id"):
                                        self.interface_router_id = value
                                        self.interface_router_id.value_namespace = name_space
                                        self.interface_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-sid"):
                                        self.interface_sid = value
                                        self.interface_sid.value_namespace = name_space
                                        self.interface_sid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-sid-n-flag-clear"):
                                        self.interface_sid_n_flag_clear = value
                                        self.interface_sid_n_flag_clear.value_namespace = name_space
                                        self.interface_sid_n_flag_clear.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-sid-php-off"):
                                        self.interface_sid_php_off = value
                                        self.interface_sid_php_off.value_namespace = name_space
                                        self.interface_sid_php_off.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-state"):
                                        self.interface_state = value
                                        self.interface_state.value_namespace = name_space
                                        self.interface_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-strict-spf-sid"):
                                        self.interface_strict_spf_sid = value
                                        self.interface_strict_spf_sid.value_namespace = name_space
                                        self.interface_strict_spf_sid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-strict-spf-sid-n-flag-clear"):
                                        self.interface_strict_spf_sid_n_flag_clear = value
                                        self.interface_strict_spf_sid_n_flag_clear.value_namespace = name_space
                                        self.interface_strict_spf_sid_n_flag_clear.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-strict-spf-sid-php-off"):
                                        self.interface_strict_spf_sid_php_off = value
                                        self.interface_strict_spf_sid_php_off.value_namespace = name_space
                                        self.interface_strict_spf_sid_php_off.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-tunnel-flags"):
                                        self.interface_tunnel_flags = value
                                        self.interface_tunnel_flags.value_namespace = name_space
                                        self.interface_tunnel_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interfaceis-madj"):
                                        self.interfaceis_madj = value
                                        self.interfaceis_madj.value_namespace = name_space
                                        self.interfaceis_madj.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ip-mtu"):
                                        self.ip_mtu = value
                                        self.ip_mtu.value_namespace = name_space
                                        self.ip_mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-loopback-stub-network"):
                                        self.is_loopback_stub_network = value
                                        self.is_loopback_stub_network.value_namespace = name_space
                                        self.is_loopback_stub_network.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-packet-size"):
                                        self.maximum_packet_size = value
                                        self.maximum_packet_size.value_namespace = name_space
                                        self.maximum_packet_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "network-lsa-flush-timer"):
                                        self.network_lsa_flush_timer = value
                                        self.network_lsa_flush_timer.value_namespace = name_space
                                        self.network_lsa_flush_timer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "network-type"):
                                        self.network_type = value
                                        self.network_type.value_namespace = name_space
                                        self.network_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hello-time"):
                                        self.next_hello_time = value
                                        self.next_hello_time.value_namespace = name_space
                                        self.next_hello_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hello-time-ms"):
                                        self.next_hello_time_ms = value
                                        self.next_hello_time_ms.value_namespace = name_space
                                        self.next_hello_time_ms.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-interface-state"):
                                        self.ospf_interface_state = value
                                        self.ospf_interface_state.value_namespace = name_space
                                        self.ospf_interface_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "passive-interface"):
                                        self.passive_interface = value
                                        self.passive_interface.value_namespace = name_space
                                        self.passive_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-suppress-primary-addresses"):
                                        self.prefix_suppress_primary_addresses = value
                                        self.prefix_suppress_primary_addresses.value_namespace = name_space
                                        self.prefix_suppress_primary_addresses.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-suppress-secondary-addresses"):
                                        self.prefix_suppress_secondary_addresses = value
                                        self.prefix_suppress_secondary_addresses.value_namespace = name_space
                                        self.prefix_suppress_secondary_addresses.value_namespace_prefix = name_space_prefix
                                    if(value_path == "registered-for-link-down-fast-detection"):
                                        self.registered_for_link_down_fast_detection = value
                                        self.registered_for_link_down_fast_detection.value_namespace = name_space
                                        self.registered_for_link_down_fast_detection.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transmission-delay"):
                                        self.transmission_delay = value
                                        self.transmission_delay.value_namespace = name_space
                                        self.transmission_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl-security-enabled"):
                                        self.ttl_security_enabled = value
                                        self.ttl_security_enabled.value_namespace = name_space
                                        self.ttl_security_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl-security-hop-count"):
                                        self.ttl_security_hop_count = value
                                        self.ttl_security_hop_count.value_namespace = name_space
                                        self.ttl_security_hop_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wait-interval"):
                                        self.wait_interval = value
                                        self.wait_interval.value_namespace = name_space
                                        self.wait_interval.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.interface:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interfaces" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface"):
                                    for c in self.interface:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.interface_briefs is not None and self.interface_briefs.has_data()) or
                                (self.interfaces is not None and self.interfaces.has_data()) or
                                (self.virtual_links is not None and self.virtual_links.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.interface_briefs is not None and self.interface_briefs.has_operation()) or
                                (self.interfaces is not None and self.interfaces.has_operation()) or
                                (self.virtual_links is not None and self.virtual_links.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface-briefs"):
                                if (self.interface_briefs is None):
                                    self.interface_briefs = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs()
                                    self.interface_briefs.parent = self
                                    self._children_name_map["interface_briefs"] = "interface-briefs"
                                return self.interface_briefs

                            if (child_yang_name == "interfaces"):
                                if (self.interfaces is None):
                                    self.interfaces = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces()
                                    self.interfaces.parent = self
                                    self._children_name_map["interfaces"] = "interfaces"
                                return self.interfaces

                            if (child_yang_name == "virtual-links"):
                                if (self.virtual_links is None):
                                    self.virtual_links = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks()
                                    self.virtual_links.parent = self
                                    self._children_name_map["virtual_links"] = "virtual-links"
                                return self.virtual_links

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-briefs" or name == "interfaces" or name == "virtual-links"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class BorderRouters(Entity):
                        """
                        Border router table
                        
                        .. attribute:: border_router
                        
                        	Information for a particular border router
                        	**type**\: list of    :py:class:`BorderRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters, self).__init__()

                            self.yang_name = "border-routers"
                            self.yang_parent_name = "vrf"

                            self.border_router = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters, self).__setattr__(name, value)


                        class BorderRouter(Entity):
                            """
                            Information for a particular border router
                            
                            .. attribute:: border_router_id  <key>
                            
                            	Router address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: border_router_id_xr
                            
                            	Router ID of Border Router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: border_router_path
                            
                            	List of Border Router paths
                            	**type**\: list of    :py:class:`BorderRouterPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter, self).__init__()

                                self.yang_name = "border-router"
                                self.yang_parent_name = "border-routers"

                                self.border_router_id = YLeaf(YType.str, "border-router-id")

                                self.border_router_id_xr = YLeaf(YType.str, "border-router-id-xr")

                                self.border_router_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("border_router_id",
                                                "border_router_id_xr") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter, self).__setattr__(name, value)


                            class BorderRouterPath(Entity):
                                """
                                List of Border Router paths
                                
                                .. attribute:: border_router_area_id
                                
                                	Area string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: border_router_next_hop
                                
                                	Next hop address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: border_router_next_hop_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: border_router_route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: border_router_route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                .. attribute:: border_router_type
                                
                                	Border router type
                                	**type**\:   :py:class:`OspfBr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfBr>`
                                
                                .. attribute:: spf_version
                                
                                	SPF run instance count
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath, self).__init__()

                                    self.yang_name = "border-router-path"
                                    self.yang_parent_name = "border-router"

                                    self.border_router_area_id = YLeaf(YType.str, "border-router-area-id")

                                    self.border_router_next_hop = YLeaf(YType.str, "border-router-next-hop")

                                    self.border_router_next_hop_interface_name = YLeaf(YType.str, "border-router-next-hop-interface-name")

                                    self.border_router_route_metric = YLeaf(YType.uint32, "border-router-route-metric")

                                    self.border_router_route_type = YLeaf(YType.enumeration, "border-router-route-type")

                                    self.border_router_type = YLeaf(YType.enumeration, "border-router-type")

                                    self.spf_version = YLeaf(YType.uint64, "spf-version")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("border_router_area_id",
                                                    "border_router_next_hop",
                                                    "border_router_next_hop_interface_name",
                                                    "border_router_route_metric",
                                                    "border_router_route_type",
                                                    "border_router_type",
                                                    "spf_version") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.border_router_area_id.is_set or
                                        self.border_router_next_hop.is_set or
                                        self.border_router_next_hop_interface_name.is_set or
                                        self.border_router_route_metric.is_set or
                                        self.border_router_route_type.is_set or
                                        self.border_router_type.is_set or
                                        self.spf_version.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.border_router_area_id.yfilter != YFilter.not_set or
                                        self.border_router_next_hop.yfilter != YFilter.not_set or
                                        self.border_router_next_hop_interface_name.yfilter != YFilter.not_set or
                                        self.border_router_route_metric.yfilter != YFilter.not_set or
                                        self.border_router_route_type.yfilter != YFilter.not_set or
                                        self.border_router_type.yfilter != YFilter.not_set or
                                        self.spf_version.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "border-router-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.border_router_area_id.is_set or self.border_router_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.border_router_area_id.get_name_leafdata())
                                    if (self.border_router_next_hop.is_set or self.border_router_next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.border_router_next_hop.get_name_leafdata())
                                    if (self.border_router_next_hop_interface_name.is_set or self.border_router_next_hop_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.border_router_next_hop_interface_name.get_name_leafdata())
                                    if (self.border_router_route_metric.is_set or self.border_router_route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.border_router_route_metric.get_name_leafdata())
                                    if (self.border_router_route_type.is_set or self.border_router_route_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.border_router_route_type.get_name_leafdata())
                                    if (self.border_router_type.is_set or self.border_router_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.border_router_type.get_name_leafdata())
                                    if (self.spf_version.is_set or self.spf_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spf_version.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "border-router-area-id" or name == "border-router-next-hop" or name == "border-router-next-hop-interface-name" or name == "border-router-route-metric" or name == "border-router-route-type" or name == "border-router-type" or name == "spf-version"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "border-router-area-id"):
                                        self.border_router_area_id = value
                                        self.border_router_area_id.value_namespace = name_space
                                        self.border_router_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "border-router-next-hop"):
                                        self.border_router_next_hop = value
                                        self.border_router_next_hop.value_namespace = name_space
                                        self.border_router_next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "border-router-next-hop-interface-name"):
                                        self.border_router_next_hop_interface_name = value
                                        self.border_router_next_hop_interface_name.value_namespace = name_space
                                        self.border_router_next_hop_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "border-router-route-metric"):
                                        self.border_router_route_metric = value
                                        self.border_router_route_metric.value_namespace = name_space
                                        self.border_router_route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "border-router-route-type"):
                                        self.border_router_route_type = value
                                        self.border_router_route_type.value_namespace = name_space
                                        self.border_router_route_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "border-router-type"):
                                        self.border_router_type = value
                                        self.border_router_type.value_namespace = name_space
                                        self.border_router_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spf-version"):
                                        self.spf_version = value
                                        self.spf_version.value_namespace = name_space
                                        self.spf_version.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.border_router_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.border_router_id.is_set or
                                    self.border_router_id_xr.is_set)

                            def has_operation(self):
                                for c in self.border_router_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.border_router_id.yfilter != YFilter.not_set or
                                    self.border_router_id_xr.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "border-router" + "[border-router-id='" + self.border_router_id.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.border_router_id.is_set or self.border_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.border_router_id.get_name_leafdata())
                                if (self.border_router_id_xr.is_set or self.border_router_id_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.border_router_id_xr.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "border-router-path"):
                                    for c in self.border_router_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.border_router_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "border-router-path" or name == "border-router-id" or name == "border-router-id-xr"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "border-router-id"):
                                    self.border_router_id = value
                                    self.border_router_id.value_namespace = name_space
                                    self.border_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "border-router-id-xr"):
                                    self.border_router_id_xr = value
                                    self.border_router_id_xr.value_namespace = name_space
                                    self.border_router_id_xr.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.border_router:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.border_router:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "border-routers" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "border-router"):
                                for c in self.border_router:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.border_router.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "border-router"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class ProcessInformation(Entity):
                        """
                        Container for OSPF Process information
                        
                        .. attribute:: process_areas
                        
                        	Process Area table
                        	**type**\:   :py:class:`ProcessAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas>`
                        
                        .. attribute:: process_summary
                        
                        	Basic OSPF summary information
                        	**type**\:   :py:class:`ProcessSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary>`
                        
                        .. attribute:: protocol_areas
                        
                        	Protocol Area table
                        	**type**\:   :py:class:`ProtocolAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas>`
                        
                        .. attribute:: protocol_summary
                        
                        	Basic OSPF protocol information
                        	**type**\:   :py:class:`ProtocolSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolSummary>`
                        
                        .. attribute:: redistributions
                        
                        	Redistribution information table
                        	**type**\:   :py:class:`Redistributions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation, self).__init__()

                            self.yang_name = "process-information"
                            self.yang_parent_name = "vrf"

                            self.process_areas = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas()
                            self.process_areas.parent = self
                            self._children_name_map["process_areas"] = "process-areas"
                            self._children_yang_names.add("process-areas")

                            self.process_summary = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary()
                            self.process_summary.parent = self
                            self._children_name_map["process_summary"] = "process-summary"
                            self._children_yang_names.add("process-summary")

                            self.protocol_areas = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas()
                            self.protocol_areas.parent = self
                            self._children_name_map["protocol_areas"] = "protocol-areas"
                            self._children_yang_names.add("protocol-areas")

                            self.protocol_summary = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolSummary()
                            self.protocol_summary.parent = self
                            self._children_name_map["protocol_summary"] = "protocol-summary"
                            self._children_yang_names.add("protocol-summary")

                            self.redistributions = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions()
                            self.redistributions.parent = self
                            self._children_name_map["redistributions"] = "redistributions"
                            self._children_yang_names.add("redistributions")


                        class ProtocolAreas(Entity):
                            """
                            Protocol Area table
                            
                            .. attribute:: protocol_area
                            
                            	Area information
                            	**type**\: list of    :py:class:`ProtocolArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas, self).__init__()

                                self.yang_name = "protocol-areas"
                                self.yang_parent_name = "process-information"

                                self.protocol_area = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas, self).__setattr__(name, value)


                            class ProtocolArea(Entity):
                                """
                                Area information
                                
                                .. attribute:: address
                                
                                	Area ID if in IP address format
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_id
                                
                                	Area ID if in integer format
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: protcol_area
                                
                                	Area ID string in decimal and dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: protocol_area_dist_list_in
                                
                                	Distribute List In
                                	**type**\:  str
                                
                                .. attribute:: protocol_interface
                                
                                	Interface list
                                	**type**\: list of    :py:class:`ProtocolInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface>`
                                
                                .. attribute:: protocol_mpls
                                
                                	MPLS\-TE enabled
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea, self).__init__()

                                    self.yang_name = "protocol-area"
                                    self.yang_parent_name = "protocol-areas"

                                    self.address = YLeaf(YType.str, "address")

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.protcol_area = YLeaf(YType.str, "protcol-area")

                                    self.protocol_area_dist_list_in = YLeaf(YType.str, "protocol-area-dist-list-in")

                                    self.protocol_mpls = YLeaf(YType.boolean, "protocol-mpls")

                                    self.protocol_interface = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "area_id",
                                                    "protcol_area",
                                                    "protocol_area_dist_list_in",
                                                    "protocol_mpls") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea, self).__setattr__(name, value)


                                class ProtocolInterface(Entity):
                                    """
                                    Interface list
                                    
                                    .. attribute:: protocol_authentication_type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                    
                                    .. attribute:: protocol_interface_dist_list_in
                                    
                                    	Distribute List In
                                    	**type**\:  str
                                    
                                    .. attribute:: protocol_interface_name
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface, self).__init__()

                                        self.yang_name = "protocol-interface"
                                        self.yang_parent_name = "protocol-area"

                                        self.protocol_authentication_type = YLeaf(YType.enumeration, "protocol-authentication-type")

                                        self.protocol_interface_dist_list_in = YLeaf(YType.str, "protocol-interface-dist-list-in")

                                        self.protocol_interface_name = YLeaf(YType.str, "protocol-interface-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("protocol_authentication_type",
                                                        "protocol_interface_dist_list_in",
                                                        "protocol_interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.protocol_authentication_type.is_set or
                                            self.protocol_interface_dist_list_in.is_set or
                                            self.protocol_interface_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.protocol_authentication_type.yfilter != YFilter.not_set or
                                            self.protocol_interface_dist_list_in.yfilter != YFilter.not_set or
                                            self.protocol_interface_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "protocol-interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.protocol_authentication_type.is_set or self.protocol_authentication_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol_authentication_type.get_name_leafdata())
                                        if (self.protocol_interface_dist_list_in.is_set or self.protocol_interface_dist_list_in.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol_interface_dist_list_in.get_name_leafdata())
                                        if (self.protocol_interface_name.is_set or self.protocol_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol_interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "protocol-authentication-type" or name == "protocol-interface-dist-list-in" or name == "protocol-interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "protocol-authentication-type"):
                                            self.protocol_authentication_type = value
                                            self.protocol_authentication_type.value_namespace = name_space
                                            self.protocol_authentication_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol-interface-dist-list-in"):
                                            self.protocol_interface_dist_list_in = value
                                            self.protocol_interface_dist_list_in.value_namespace = name_space
                                            self.protocol_interface_dist_list_in.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol-interface-name"):
                                            self.protocol_interface_name = value
                                            self.protocol_interface_name.value_namespace = name_space
                                            self.protocol_interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.protocol_interface:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.address.is_set or
                                        self.area_id.is_set or
                                        self.protcol_area.is_set or
                                        self.protocol_area_dist_list_in.is_set or
                                        self.protocol_mpls.is_set)

                                def has_operation(self):
                                    for c in self.protocol_interface:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.protcol_area.yfilter != YFilter.not_set or
                                        self.protocol_area_dist_list_in.yfilter != YFilter.not_set or
                                        self.protocol_mpls.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "protocol-area" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.protcol_area.is_set or self.protcol_area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protcol_area.get_name_leafdata())
                                    if (self.protocol_area_dist_list_in.is_set or self.protocol_area_dist_list_in.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol_area_dist_list_in.get_name_leafdata())
                                    if (self.protocol_mpls.is_set or self.protocol_mpls.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol_mpls.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "protocol-interface"):
                                        for c in self.protocol_interface:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.protocol_interface.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "protocol-interface" or name == "address" or name == "area-id" or name == "protcol-area" or name == "protocol-area-dist-list-in" or name == "protocol-mpls"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protcol-area"):
                                        self.protcol_area = value
                                        self.protcol_area.value_namespace = name_space
                                        self.protcol_area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol-area-dist-list-in"):
                                        self.protocol_area_dist_list_in = value
                                        self.protocol_area_dist_list_in.value_namespace = name_space
                                        self.protocol_area_dist_list_in.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol-mpls"):
                                        self.protocol_mpls = value
                                        self.protocol_mpls.value_namespace = name_space
                                        self.protocol_mpls.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.protocol_area:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.protocol_area:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "protocol-areas" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "protocol-area"):
                                    for c in self.protocol_area:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.protocol_area.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "protocol-area"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class ProtocolSummary(Entity):
                            """
                            Basic OSPF protocol information
                            
                            .. attribute:: administrative_distance_external
                            
                            	Administrative Distance for External routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: administrative_distance_inter_area
                            
                            	Administrative Distance for Inter Area routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dist_list_in
                            
                            	Distribute List In
                            	**type**\:  str
                            
                            .. attribute:: protocol_distance
                            
                            	Administrative distance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol_nsf
                            
                            	True if NSF enabled
                            	**type**\:  bool
                            
                            .. attribute:: protocol_router_id
                            
                            	Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolSummary, self).__init__()

                                self.yang_name = "protocol-summary"
                                self.yang_parent_name = "process-information"

                                self.administrative_distance_external = YLeaf(YType.uint32, "administrative-distance-external")

                                self.administrative_distance_inter_area = YLeaf(YType.uint32, "administrative-distance-inter-area")

                                self.dist_list_in = YLeaf(YType.str, "dist-list-in")

                                self.protocol_distance = YLeaf(YType.uint32, "protocol-distance")

                                self.protocol_nsf = YLeaf(YType.boolean, "protocol-nsf")

                                self.protocol_router_id = YLeaf(YType.str, "protocol-router-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("administrative_distance_external",
                                                "administrative_distance_inter_area",
                                                "dist_list_in",
                                                "protocol_distance",
                                                "protocol_nsf",
                                                "protocol_router_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolSummary, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolSummary, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.administrative_distance_external.is_set or
                                    self.administrative_distance_inter_area.is_set or
                                    self.dist_list_in.is_set or
                                    self.protocol_distance.is_set or
                                    self.protocol_nsf.is_set or
                                    self.protocol_router_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.administrative_distance_external.yfilter != YFilter.not_set or
                                    self.administrative_distance_inter_area.yfilter != YFilter.not_set or
                                    self.dist_list_in.yfilter != YFilter.not_set or
                                    self.protocol_distance.yfilter != YFilter.not_set or
                                    self.protocol_nsf.yfilter != YFilter.not_set or
                                    self.protocol_router_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "protocol-summary" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.administrative_distance_external.is_set or self.administrative_distance_external.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.administrative_distance_external.get_name_leafdata())
                                if (self.administrative_distance_inter_area.is_set or self.administrative_distance_inter_area.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.administrative_distance_inter_area.get_name_leafdata())
                                if (self.dist_list_in.is_set or self.dist_list_in.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dist_list_in.get_name_leafdata())
                                if (self.protocol_distance.is_set or self.protocol_distance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol_distance.get_name_leafdata())
                                if (self.protocol_nsf.is_set or self.protocol_nsf.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol_nsf.get_name_leafdata())
                                if (self.protocol_router_id.is_set or self.protocol_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol_router_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "administrative-distance-external" or name == "administrative-distance-inter-area" or name == "dist-list-in" or name == "protocol-distance" or name == "protocol-nsf" or name == "protocol-router-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "administrative-distance-external"):
                                    self.administrative_distance_external = value
                                    self.administrative_distance_external.value_namespace = name_space
                                    self.administrative_distance_external.value_namespace_prefix = name_space_prefix
                                if(value_path == "administrative-distance-inter-area"):
                                    self.administrative_distance_inter_area = value
                                    self.administrative_distance_inter_area.value_namespace = name_space
                                    self.administrative_distance_inter_area.value_namespace_prefix = name_space_prefix
                                if(value_path == "dist-list-in"):
                                    self.dist_list_in = value
                                    self.dist_list_in.value_namespace = name_space
                                    self.dist_list_in.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol-distance"):
                                    self.protocol_distance = value
                                    self.protocol_distance.value_namespace = name_space
                                    self.protocol_distance.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol-nsf"):
                                    self.protocol_nsf = value
                                    self.protocol_nsf.value_namespace = name_space
                                    self.protocol_nsf.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol-router-id"):
                                    self.protocol_router_id = value
                                    self.protocol_router_id.value_namespace = name_space
                                    self.protocol_router_id.value_namespace_prefix = name_space_prefix


                        class Redistributions(Entity):
                            """
                            Redistribution information table
                            
                            .. attribute:: redistribution
                            
                            	Redistribution information
                            	**type**\: list of    :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions, self).__init__()

                                self.yang_name = "redistributions"
                                self.yang_parent_name = "process-information"

                                self.redistribution = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions, self).__setattr__(name, value)


                            class Redistribution(Entity):
                                """
                                Redistribution information
                                
                                .. attribute:: classless
                                
                                	Whether to use CIDR
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Route metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_flag
                                
                                	If true, Metric configured
                                	**type**\:  bool
                                
                                .. attribute:: nssa_only
                                
                                	To NSSA areas only
                                	**type**\:  bool
                                
                                .. attribute:: process_name
                                
                                	Process name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: protocol_name
                                
                                	Protocol name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: redistribution_protocol
                                
                                	Protocol Information
                                	**type**\:   :py:class:`RedistributionProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution, self).__init__()

                                    self.yang_name = "redistribution"
                                    self.yang_parent_name = "redistributions"

                                    self.classless = YLeaf(YType.boolean, "classless")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.metric_flag = YLeaf(YType.boolean, "metric-flag")

                                    self.nssa_only = YLeaf(YType.boolean, "nssa-only")

                                    self.process_name = YLeaf(YType.str, "process-name")

                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                    self.redistribution_protocol = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol()
                                    self.redistribution_protocol.parent = self
                                    self._children_name_map["redistribution_protocol"] = "redistribution-protocol"
                                    self._children_yang_names.add("redistribution-protocol")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("classless",
                                                    "metric",
                                                    "metric_flag",
                                                    "nssa_only",
                                                    "process_name",
                                                    "protocol_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution, self).__setattr__(name, value)


                                class RedistributionProtocol(Entity):
                                    """
                                    Protocol Information
                                    
                                    .. attribute:: bgp_as_number
                                    
                                    	BGP Autonomous System Number
                                    	**type**\:  str
                                    
                                    .. attribute:: connected_instance
                                    
                                    	Connected instance name
                                    	**type**\:  str
                                    
                                    .. attribute:: eigrp_as_number
                                    
                                    	Autonomous System Number
                                    	**type**\:  str
                                    
                                    .. attribute:: isis_instance_id
                                    
                                    	ISIS instance identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: ospf_process_id
                                    
                                    	OSPF process identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: protocol_type
                                    
                                    	ProtocolType
                                    	**type**\:   :py:class:`RedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.RedistProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol, self).__init__()

                                        self.yang_name = "redistribution-protocol"
                                        self.yang_parent_name = "redistribution"

                                        self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                        self.connected_instance = YLeaf(YType.str, "connected-instance")

                                        self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                        self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                        self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                        self.protocol_type = YLeaf(YType.enumeration, "protocol-type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_as_number",
                                                        "connected_instance",
                                                        "eigrp_as_number",
                                                        "isis_instance_id",
                                                        "ospf_process_id",
                                                        "protocol_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_as_number.is_set or
                                            self.connected_instance.is_set or
                                            self.eigrp_as_number.is_set or
                                            self.isis_instance_id.is_set or
                                            self.ospf_process_id.is_set or
                                            self.protocol_type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_as_number.yfilter != YFilter.not_set or
                                            self.connected_instance.yfilter != YFilter.not_set or
                                            self.eigrp_as_number.yfilter != YFilter.not_set or
                                            self.isis_instance_id.yfilter != YFilter.not_set or
                                            self.ospf_process_id.yfilter != YFilter.not_set or
                                            self.protocol_type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "redistribution-protocol" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_as_number.is_set or self.bgp_as_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_as_number.get_name_leafdata())
                                        if (self.connected_instance.is_set or self.connected_instance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.connected_instance.get_name_leafdata())
                                        if (self.eigrp_as_number.is_set or self.eigrp_as_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.eigrp_as_number.get_name_leafdata())
                                        if (self.isis_instance_id.is_set or self.isis_instance_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.isis_instance_id.get_name_leafdata())
                                        if (self.ospf_process_id.is_set or self.ospf_process_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_process_id.get_name_leafdata())
                                        if (self.protocol_type.is_set or self.protocol_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-as-number" or name == "connected-instance" or name == "eigrp-as-number" or name == "isis-instance-id" or name == "ospf-process-id" or name == "protocol-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-as-number"):
                                            self.bgp_as_number = value
                                            self.bgp_as_number.value_namespace = name_space
                                            self.bgp_as_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "connected-instance"):
                                            self.connected_instance = value
                                            self.connected_instance.value_namespace = name_space
                                            self.connected_instance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "eigrp-as-number"):
                                            self.eigrp_as_number = value
                                            self.eigrp_as_number.value_namespace = name_space
                                            self.eigrp_as_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "isis-instance-id"):
                                            self.isis_instance_id = value
                                            self.isis_instance_id.value_namespace = name_space
                                            self.isis_instance_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-process-id"):
                                            self.ospf_process_id = value
                                            self.ospf_process_id.value_namespace = name_space
                                            self.ospf_process_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol-type"):
                                            self.protocol_type = value
                                            self.protocol_type.value_namespace = name_space
                                            self.protocol_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.classless.is_set or
                                        self.metric.is_set or
                                        self.metric_flag.is_set or
                                        self.nssa_only.is_set or
                                        self.process_name.is_set or
                                        self.protocol_name.is_set or
                                        (self.redistribution_protocol is not None and self.redistribution_protocol.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.classless.yfilter != YFilter.not_set or
                                        self.metric.yfilter != YFilter.not_set or
                                        self.metric_flag.yfilter != YFilter.not_set or
                                        self.nssa_only.yfilter != YFilter.not_set or
                                        self.process_name.yfilter != YFilter.not_set or
                                        self.protocol_name.yfilter != YFilter.not_set or
                                        (self.redistribution_protocol is not None and self.redistribution_protocol.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "redistribution" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.classless.is_set or self.classless.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.classless.get_name_leafdata())
                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                    if (self.metric_flag.is_set or self.metric_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric_flag.get_name_leafdata())
                                    if (self.nssa_only.is_set or self.nssa_only.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nssa_only.get_name_leafdata())
                                    if (self.process_name.is_set or self.process_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.process_name.get_name_leafdata())
                                    if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "redistribution-protocol"):
                                        if (self.redistribution_protocol is None):
                                            self.redistribution_protocol = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol()
                                            self.redistribution_protocol.parent = self
                                            self._children_name_map["redistribution_protocol"] = "redistribution-protocol"
                                        return self.redistribution_protocol

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "redistribution-protocol" or name == "classless" or name == "metric" or name == "metric-flag" or name == "nssa-only" or name == "process-name" or name == "protocol-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "classless"):
                                        self.classless = value
                                        self.classless.value_namespace = name_space
                                        self.classless.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric"):
                                        self.metric = value
                                        self.metric.value_namespace = name_space
                                        self.metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric-flag"):
                                        self.metric_flag = value
                                        self.metric_flag.value_namespace = name_space
                                        self.metric_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nssa-only"):
                                        self.nssa_only = value
                                        self.nssa_only.value_namespace = name_space
                                        self.nssa_only.value_namespace_prefix = name_space_prefix
                                    if(value_path == "process-name"):
                                        self.process_name = value
                                        self.process_name.value_namespace = name_space
                                        self.process_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol-name"):
                                        self.protocol_name = value
                                        self.protocol_name.value_namespace = name_space
                                        self.protocol_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.redistribution:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.redistribution:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "redistributions" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "redistribution"):
                                    for c in self.redistribution:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.redistribution.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "redistribution"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class ProcessAreas(Entity):
                            """
                            Process Area table
                            
                            .. attribute:: process_area
                            
                            	Detailed information for a particular area
                            	**type**\: list of    :py:class:`ProcessArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas, self).__init__()

                                self.yang_name = "process-areas"
                                self.yang_parent_name = "process-information"

                                self.process_area = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas, self).__setattr__(name, value)


                            class ProcessArea(Entity):
                                """
                                Detailed information for a particular area
                                
                                .. attribute:: address
                                
                                	Area ID if in IP address format
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_adj_stag_num_nbr_forming
                                
                                	Num of nbrs currently forming
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: area_dc_bitless_lsa_count
                                
                                	Number of LSA with demand circuit bit not set
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_id
                                
                                	Area ID if in integer format
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: area_id_string
                                
                                	Area ID string
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: area_interface_count
                                
                                	Number of interfaces in the area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: area_lfa_interface_count
                                
                                	Number of LFA enabled interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_lfa_revision
                                
                                	Area LFA revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_lsa_checksum
                                
                                	Sum of all area LSAs checksum
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_lsa_count
                                
                                	Number of LSAs in the Area
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_nssa
                                
                                	If true, area is a NSSA
                                	**type**\:  bool
                                
                                .. attribute:: area_num_nbr_full
                                
                                	Num of full nbrs in area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: area_opaque_lsa_checksum
                                
                                	Sum of opaque LSA checksums
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_opaque_lsa_count
                                
                                	Number of Opaque LSAs in the Area
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_per_prefix_lfa_interface_count
                                
                                	Number of Per Prefix LFA enabled interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_policy_in
                                
                                	If true, inbound policy is configured
                                	**type**\:  bool
                                
                                .. attribute:: area_policy_in_name
                                
                                	Inbound summary lsa filtering policy
                                	**type**\:  str
                                
                                .. attribute:: area_policy_out
                                
                                	If true, outbound policy is configured
                                	**type**\:  bool
                                
                                .. attribute:: area_policy_out_name
                                
                                	Outbound summary lsa filtering policy
                                	**type**\:  str
                                
                                .. attribute:: area_range
                                
                                	List of ranges to summarize
                                	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange>`
                                
                                .. attribute:: area_stub
                                
                                	If true, stub area
                                	**type**\:  bool
                                
                                .. attribute:: area_total_stub
                                
                                	If true, totally stubby area
                                	**type**\:  bool
                                
                                .. attribute:: authentication_type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                
                                .. attribute:: backbone_area_active
                                
                                	If true, Backbone area is active
                                	**type**\:  bool
                                
                                .. attribute:: dna_lsa_count
                                
                                	Number of DoNotAge LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_out
                                
                                	If true, advertise intra\-area prefixes as external
                                	**type**\:  bool
                                
                                .. attribute:: flood_list_length
                                
                                	Number of LSAs which need to be flooded
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: indication_lsa_count
                                
                                	Number of indication LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nssa_default
                                
                                	If true, generate NSSA default route
                                	**type**\:  bool
                                
                                .. attribute:: nssa_no_redistribution
                                
                                	If true, No redistribution into this NSSA area
                                	**type**\:  bool
                                
                                .. attribute:: nssa_translate
                                
                                	If true, perform 7/5 translation
                                	**type**\:  bool
                                
                                .. attribute:: segment_routing
                                
                                	If true, Segment Routing enabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_count
                                
                                	Number of SPF calculations run
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sr_microloop_avoidance_active
                                
                                	If true, Segment routing Uloop avoidance         is currently active in this area
                                	**type**\:  bool
                                
                                .. attribute:: sr_microloop_avoidance_event_type
                                
                                	Event for which SR uloop is triggered            Link Up/Link Down
                                	**type**\:   :py:class:`SrUloopEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrUloopEvent>`
                                
                                .. attribute:: sr_microloop_avoidance_far_end_id
                                
                                	Link State ID of the far end                     of the topology change
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_near_end_id
                                
                                	Link State ID of the near end                    of the topology change
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_pseudonode_id
                                
                                	Link State ID of the pseudo node,                if the change is on a broadcast link
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_strict_spf_cap
                                
                                	If true, All routers in Area are SR Strict\-SPF Capable
                                	**type**\:  bool
                                
                                .. attribute:: sr_strict_spfsids_available
                                
                                	If true, All routers in Area have SR Strict\-SPF SIDs
                                	**type**\:  bool
                                
                                .. attribute:: stub_default_cost
                                
                                	Default cost for Stub or NSSA area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: summary_in
                                
                                	If true, advertise redistributedprefixes as summary
                                	**type**\:  bool
                                
                                .. attribute:: te_enabled
                                
                                	If true, MPLS\-TE enabled
                                	**type**\:  bool
                                
                                .. attribute:: te_topology_version
                                
                                	TE area topology version number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea, self).__init__()

                                    self.yang_name = "process-area"
                                    self.yang_parent_name = "process-areas"

                                    self.address = YLeaf(YType.str, "address")

                                    self.area_adj_stag_num_nbr_forming = YLeaf(YType.uint16, "area-adj-stag-num-nbr-forming")

                                    self.area_dc_bitless_lsa_count = YLeaf(YType.uint32, "area-dc-bitless-lsa-count")

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.area_id_string = YLeaf(YType.str, "area-id-string")

                                    self.area_interface_count = YLeaf(YType.uint16, "area-interface-count")

                                    self.area_lfa_interface_count = YLeaf(YType.uint32, "area-lfa-interface-count")

                                    self.area_lfa_revision = YLeaf(YType.uint32, "area-lfa-revision")

                                    self.area_lsa_checksum = YLeaf(YType.uint32, "area-lsa-checksum")

                                    self.area_lsa_count = YLeaf(YType.uint32, "area-lsa-count")

                                    self.area_nssa = YLeaf(YType.boolean, "area-nssa")

                                    self.area_num_nbr_full = YLeaf(YType.uint16, "area-num-nbr-full")

                                    self.area_opaque_lsa_checksum = YLeaf(YType.uint32, "area-opaque-lsa-checksum")

                                    self.area_opaque_lsa_count = YLeaf(YType.uint32, "area-opaque-lsa-count")

                                    self.area_per_prefix_lfa_interface_count = YLeaf(YType.uint32, "area-per-prefix-lfa-interface-count")

                                    self.area_policy_in = YLeaf(YType.boolean, "area-policy-in")

                                    self.area_policy_in_name = YLeaf(YType.str, "area-policy-in-name")

                                    self.area_policy_out = YLeaf(YType.boolean, "area-policy-out")

                                    self.area_policy_out_name = YLeaf(YType.str, "area-policy-out-name")

                                    self.area_stub = YLeaf(YType.boolean, "area-stub")

                                    self.area_total_stub = YLeaf(YType.boolean, "area-total-stub")

                                    self.authentication_type = YLeaf(YType.enumeration, "authentication-type")

                                    self.backbone_area_active = YLeaf(YType.boolean, "backbone-area-active")

                                    self.dna_lsa_count = YLeaf(YType.uint32, "dna-lsa-count")

                                    self.external_out = YLeaf(YType.boolean, "external-out")

                                    self.flood_list_length = YLeaf(YType.uint32, "flood-list-length")

                                    self.indication_lsa_count = YLeaf(YType.uint32, "indication-lsa-count")

                                    self.nssa_default = YLeaf(YType.boolean, "nssa-default")

                                    self.nssa_no_redistribution = YLeaf(YType.boolean, "nssa-no-redistribution")

                                    self.nssa_translate = YLeaf(YType.boolean, "nssa-translate")

                                    self.segment_routing = YLeaf(YType.uint32, "segment-routing")

                                    self.spf_count = YLeaf(YType.uint32, "spf-count")

                                    self.sr_microloop_avoidance_active = YLeaf(YType.boolean, "sr-microloop-avoidance-active")

                                    self.sr_microloop_avoidance_event_type = YLeaf(YType.enumeration, "sr-microloop-avoidance-event-type")

                                    self.sr_microloop_avoidance_far_end_id = YLeaf(YType.str, "sr-microloop-avoidance-far-end-id")

                                    self.sr_microloop_avoidance_near_end_id = YLeaf(YType.str, "sr-microloop-avoidance-near-end-id")

                                    self.sr_microloop_avoidance_pseudonode_id = YLeaf(YType.str, "sr-microloop-avoidance-pseudonode-id")

                                    self.sr_strict_spf_cap = YLeaf(YType.boolean, "sr-strict-spf-cap")

                                    self.sr_strict_spfsids_available = YLeaf(YType.boolean, "sr-strict-spfsids-available")

                                    self.stub_default_cost = YLeaf(YType.uint16, "stub-default-cost")

                                    self.summary_in = YLeaf(YType.boolean, "summary-in")

                                    self.te_enabled = YLeaf(YType.boolean, "te-enabled")

                                    self.te_topology_version = YLeaf(YType.uint32, "te-topology-version")

                                    self.area_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "area_adj_stag_num_nbr_forming",
                                                    "area_dc_bitless_lsa_count",
                                                    "area_id",
                                                    "area_id_string",
                                                    "area_interface_count",
                                                    "area_lfa_interface_count",
                                                    "area_lfa_revision",
                                                    "area_lsa_checksum",
                                                    "area_lsa_count",
                                                    "area_nssa",
                                                    "area_num_nbr_full",
                                                    "area_opaque_lsa_checksum",
                                                    "area_opaque_lsa_count",
                                                    "area_per_prefix_lfa_interface_count",
                                                    "area_policy_in",
                                                    "area_policy_in_name",
                                                    "area_policy_out",
                                                    "area_policy_out_name",
                                                    "area_stub",
                                                    "area_total_stub",
                                                    "authentication_type",
                                                    "backbone_area_active",
                                                    "dna_lsa_count",
                                                    "external_out",
                                                    "flood_list_length",
                                                    "indication_lsa_count",
                                                    "nssa_default",
                                                    "nssa_no_redistribution",
                                                    "nssa_translate",
                                                    "segment_routing",
                                                    "spf_count",
                                                    "sr_microloop_avoidance_active",
                                                    "sr_microloop_avoidance_event_type",
                                                    "sr_microloop_avoidance_far_end_id",
                                                    "sr_microloop_avoidance_near_end_id",
                                                    "sr_microloop_avoidance_pseudonode_id",
                                                    "sr_strict_spf_cap",
                                                    "sr_strict_spfsids_available",
                                                    "stub_default_cost",
                                                    "summary_in",
                                                    "te_enabled",
                                                    "te_topology_version") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea, self).__setattr__(name, value)


                                class AreaRange(Entity):
                                    """
                                    List of ranges to summarize
                                    
                                    .. attribute:: advertise_flag
                                    
                                    	Whether to advertise Summary LSAs for this range
                                    	**type**\:  bool
                                    
                                    .. attribute:: cost
                                    
                                    	Cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: range_mask
                                    
                                    	Network mask
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: range_prefix
                                    
                                    	IP prefix for summarization
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange, self).__init__()

                                        self.yang_name = "area-range"
                                        self.yang_parent_name = "process-area"

                                        self.advertise_flag = YLeaf(YType.boolean, "advertise-flag")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.range_mask = YLeaf(YType.str, "range-mask")

                                        self.range_prefix = YLeaf(YType.str, "range-prefix")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("advertise_flag",
                                                        "cost",
                                                        "range_mask",
                                                        "range_prefix") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.advertise_flag.is_set or
                                            self.cost.is_set or
                                            self.range_mask.is_set or
                                            self.range_prefix.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.advertise_flag.yfilter != YFilter.not_set or
                                            self.cost.yfilter != YFilter.not_set or
                                            self.range_mask.yfilter != YFilter.not_set or
                                            self.range_prefix.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "area-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.advertise_flag.is_set or self.advertise_flag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.advertise_flag.get_name_leafdata())
                                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost.get_name_leafdata())
                                        if (self.range_mask.is_set or self.range_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.range_mask.get_name_leafdata())
                                        if (self.range_prefix.is_set or self.range_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.range_prefix.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "advertise-flag" or name == "cost" or name == "range-mask" or name == "range-prefix"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "advertise-flag"):
                                            self.advertise_flag = value
                                            self.advertise_flag.value_namespace = name_space
                                            self.advertise_flag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cost"):
                                            self.cost = value
                                            self.cost.value_namespace = name_space
                                            self.cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "range-mask"):
                                            self.range_mask = value
                                            self.range_mask.value_namespace = name_space
                                            self.range_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "range-prefix"):
                                            self.range_prefix = value
                                            self.range_prefix.value_namespace = name_space
                                            self.range_prefix.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.area_range:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.address.is_set or
                                        self.area_adj_stag_num_nbr_forming.is_set or
                                        self.area_dc_bitless_lsa_count.is_set or
                                        self.area_id.is_set or
                                        self.area_id_string.is_set or
                                        self.area_interface_count.is_set or
                                        self.area_lfa_interface_count.is_set or
                                        self.area_lfa_revision.is_set or
                                        self.area_lsa_checksum.is_set or
                                        self.area_lsa_count.is_set or
                                        self.area_nssa.is_set or
                                        self.area_num_nbr_full.is_set or
                                        self.area_opaque_lsa_checksum.is_set or
                                        self.area_opaque_lsa_count.is_set or
                                        self.area_per_prefix_lfa_interface_count.is_set or
                                        self.area_policy_in.is_set or
                                        self.area_policy_in_name.is_set or
                                        self.area_policy_out.is_set or
                                        self.area_policy_out_name.is_set or
                                        self.area_stub.is_set or
                                        self.area_total_stub.is_set or
                                        self.authentication_type.is_set or
                                        self.backbone_area_active.is_set or
                                        self.dna_lsa_count.is_set or
                                        self.external_out.is_set or
                                        self.flood_list_length.is_set or
                                        self.indication_lsa_count.is_set or
                                        self.nssa_default.is_set or
                                        self.nssa_no_redistribution.is_set or
                                        self.nssa_translate.is_set or
                                        self.segment_routing.is_set or
                                        self.spf_count.is_set or
                                        self.sr_microloop_avoidance_active.is_set or
                                        self.sr_microloop_avoidance_event_type.is_set or
                                        self.sr_microloop_avoidance_far_end_id.is_set or
                                        self.sr_microloop_avoidance_near_end_id.is_set or
                                        self.sr_microloop_avoidance_pseudonode_id.is_set or
                                        self.sr_strict_spf_cap.is_set or
                                        self.sr_strict_spfsids_available.is_set or
                                        self.stub_default_cost.is_set or
                                        self.summary_in.is_set or
                                        self.te_enabled.is_set or
                                        self.te_topology_version.is_set)

                                def has_operation(self):
                                    for c in self.area_range:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.area_adj_stag_num_nbr_forming.yfilter != YFilter.not_set or
                                        self.area_dc_bitless_lsa_count.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.area_id_string.yfilter != YFilter.not_set or
                                        self.area_interface_count.yfilter != YFilter.not_set or
                                        self.area_lfa_interface_count.yfilter != YFilter.not_set or
                                        self.area_lfa_revision.yfilter != YFilter.not_set or
                                        self.area_lsa_checksum.yfilter != YFilter.not_set or
                                        self.area_lsa_count.yfilter != YFilter.not_set or
                                        self.area_nssa.yfilter != YFilter.not_set or
                                        self.area_num_nbr_full.yfilter != YFilter.not_set or
                                        self.area_opaque_lsa_checksum.yfilter != YFilter.not_set or
                                        self.area_opaque_lsa_count.yfilter != YFilter.not_set or
                                        self.area_per_prefix_lfa_interface_count.yfilter != YFilter.not_set or
                                        self.area_policy_in.yfilter != YFilter.not_set or
                                        self.area_policy_in_name.yfilter != YFilter.not_set or
                                        self.area_policy_out.yfilter != YFilter.not_set or
                                        self.area_policy_out_name.yfilter != YFilter.not_set or
                                        self.area_stub.yfilter != YFilter.not_set or
                                        self.area_total_stub.yfilter != YFilter.not_set or
                                        self.authentication_type.yfilter != YFilter.not_set or
                                        self.backbone_area_active.yfilter != YFilter.not_set or
                                        self.dna_lsa_count.yfilter != YFilter.not_set or
                                        self.external_out.yfilter != YFilter.not_set or
                                        self.flood_list_length.yfilter != YFilter.not_set or
                                        self.indication_lsa_count.yfilter != YFilter.not_set or
                                        self.nssa_default.yfilter != YFilter.not_set or
                                        self.nssa_no_redistribution.yfilter != YFilter.not_set or
                                        self.nssa_translate.yfilter != YFilter.not_set or
                                        self.segment_routing.yfilter != YFilter.not_set or
                                        self.spf_count.yfilter != YFilter.not_set or
                                        self.sr_microloop_avoidance_active.yfilter != YFilter.not_set or
                                        self.sr_microloop_avoidance_event_type.yfilter != YFilter.not_set or
                                        self.sr_microloop_avoidance_far_end_id.yfilter != YFilter.not_set or
                                        self.sr_microloop_avoidance_near_end_id.yfilter != YFilter.not_set or
                                        self.sr_microloop_avoidance_pseudonode_id.yfilter != YFilter.not_set or
                                        self.sr_strict_spf_cap.yfilter != YFilter.not_set or
                                        self.sr_strict_spfsids_available.yfilter != YFilter.not_set or
                                        self.stub_default_cost.yfilter != YFilter.not_set or
                                        self.summary_in.yfilter != YFilter.not_set or
                                        self.te_enabled.yfilter != YFilter.not_set or
                                        self.te_topology_version.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "process-area" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.area_adj_stag_num_nbr_forming.is_set or self.area_adj_stag_num_nbr_forming.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_adj_stag_num_nbr_forming.get_name_leafdata())
                                    if (self.area_dc_bitless_lsa_count.is_set or self.area_dc_bitless_lsa_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_dc_bitless_lsa_count.get_name_leafdata())
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.area_id_string.is_set or self.area_id_string.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id_string.get_name_leafdata())
                                    if (self.area_interface_count.is_set or self.area_interface_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_interface_count.get_name_leafdata())
                                    if (self.area_lfa_interface_count.is_set or self.area_lfa_interface_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_lfa_interface_count.get_name_leafdata())
                                    if (self.area_lfa_revision.is_set or self.area_lfa_revision.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_lfa_revision.get_name_leafdata())
                                    if (self.area_lsa_checksum.is_set or self.area_lsa_checksum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_lsa_checksum.get_name_leafdata())
                                    if (self.area_lsa_count.is_set or self.area_lsa_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_lsa_count.get_name_leafdata())
                                    if (self.area_nssa.is_set or self.area_nssa.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_nssa.get_name_leafdata())
                                    if (self.area_num_nbr_full.is_set or self.area_num_nbr_full.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_num_nbr_full.get_name_leafdata())
                                    if (self.area_opaque_lsa_checksum.is_set or self.area_opaque_lsa_checksum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_opaque_lsa_checksum.get_name_leafdata())
                                    if (self.area_opaque_lsa_count.is_set or self.area_opaque_lsa_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_opaque_lsa_count.get_name_leafdata())
                                    if (self.area_per_prefix_lfa_interface_count.is_set or self.area_per_prefix_lfa_interface_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_per_prefix_lfa_interface_count.get_name_leafdata())
                                    if (self.area_policy_in.is_set or self.area_policy_in.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_policy_in.get_name_leafdata())
                                    if (self.area_policy_in_name.is_set or self.area_policy_in_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_policy_in_name.get_name_leafdata())
                                    if (self.area_policy_out.is_set or self.area_policy_out.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_policy_out.get_name_leafdata())
                                    if (self.area_policy_out_name.is_set or self.area_policy_out_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_policy_out_name.get_name_leafdata())
                                    if (self.area_stub.is_set or self.area_stub.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_stub.get_name_leafdata())
                                    if (self.area_total_stub.is_set or self.area_total_stub.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_total_stub.get_name_leafdata())
                                    if (self.authentication_type.is_set or self.authentication_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.authentication_type.get_name_leafdata())
                                    if (self.backbone_area_active.is_set or self.backbone_area_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backbone_area_active.get_name_leafdata())
                                    if (self.dna_lsa_count.is_set or self.dna_lsa_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dna_lsa_count.get_name_leafdata())
                                    if (self.external_out.is_set or self.external_out.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.external_out.get_name_leafdata())
                                    if (self.flood_list_length.is_set or self.flood_list_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_list_length.get_name_leafdata())
                                    if (self.indication_lsa_count.is_set or self.indication_lsa_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.indication_lsa_count.get_name_leafdata())
                                    if (self.nssa_default.is_set or self.nssa_default.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nssa_default.get_name_leafdata())
                                    if (self.nssa_no_redistribution.is_set or self.nssa_no_redistribution.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nssa_no_redistribution.get_name_leafdata())
                                    if (self.nssa_translate.is_set or self.nssa_translate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nssa_translate.get_name_leafdata())
                                    if (self.segment_routing.is_set or self.segment_routing.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.segment_routing.get_name_leafdata())
                                    if (self.spf_count.is_set or self.spf_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spf_count.get_name_leafdata())
                                    if (self.sr_microloop_avoidance_active.is_set or self.sr_microloop_avoidance_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sr_microloop_avoidance_active.get_name_leafdata())
                                    if (self.sr_microloop_avoidance_event_type.is_set or self.sr_microloop_avoidance_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sr_microloop_avoidance_event_type.get_name_leafdata())
                                    if (self.sr_microloop_avoidance_far_end_id.is_set or self.sr_microloop_avoidance_far_end_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sr_microloop_avoidance_far_end_id.get_name_leafdata())
                                    if (self.sr_microloop_avoidance_near_end_id.is_set or self.sr_microloop_avoidance_near_end_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sr_microloop_avoidance_near_end_id.get_name_leafdata())
                                    if (self.sr_microloop_avoidance_pseudonode_id.is_set or self.sr_microloop_avoidance_pseudonode_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sr_microloop_avoidance_pseudonode_id.get_name_leafdata())
                                    if (self.sr_strict_spf_cap.is_set or self.sr_strict_spf_cap.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sr_strict_spf_cap.get_name_leafdata())
                                    if (self.sr_strict_spfsids_available.is_set or self.sr_strict_spfsids_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sr_strict_spfsids_available.get_name_leafdata())
                                    if (self.stub_default_cost.is_set or self.stub_default_cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.stub_default_cost.get_name_leafdata())
                                    if (self.summary_in.is_set or self.summary_in.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.summary_in.get_name_leafdata())
                                    if (self.te_enabled.is_set or self.te_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_enabled.get_name_leafdata())
                                    if (self.te_topology_version.is_set or self.te_topology_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_topology_version.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "area-range"):
                                        for c in self.area_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.area_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "area-range" or name == "address" or name == "area-adj-stag-num-nbr-forming" or name == "area-dc-bitless-lsa-count" or name == "area-id" or name == "area-id-string" or name == "area-interface-count" or name == "area-lfa-interface-count" or name == "area-lfa-revision" or name == "area-lsa-checksum" or name == "area-lsa-count" or name == "area-nssa" or name == "area-num-nbr-full" or name == "area-opaque-lsa-checksum" or name == "area-opaque-lsa-count" or name == "area-per-prefix-lfa-interface-count" or name == "area-policy-in" or name == "area-policy-in-name" or name == "area-policy-out" or name == "area-policy-out-name" or name == "area-stub" or name == "area-total-stub" or name == "authentication-type" or name == "backbone-area-active" or name == "dna-lsa-count" or name == "external-out" or name == "flood-list-length" or name == "indication-lsa-count" or name == "nssa-default" or name == "nssa-no-redistribution" or name == "nssa-translate" or name == "segment-routing" or name == "spf-count" or name == "sr-microloop-avoidance-active" or name == "sr-microloop-avoidance-event-type" or name == "sr-microloop-avoidance-far-end-id" or name == "sr-microloop-avoidance-near-end-id" or name == "sr-microloop-avoidance-pseudonode-id" or name == "sr-strict-spf-cap" or name == "sr-strict-spfsids-available" or name == "stub-default-cost" or name == "summary-in" or name == "te-enabled" or name == "te-topology-version"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-adj-stag-num-nbr-forming"):
                                        self.area_adj_stag_num_nbr_forming = value
                                        self.area_adj_stag_num_nbr_forming.value_namespace = name_space
                                        self.area_adj_stag_num_nbr_forming.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-dc-bitless-lsa-count"):
                                        self.area_dc_bitless_lsa_count = value
                                        self.area_dc_bitless_lsa_count.value_namespace = name_space
                                        self.area_dc_bitless_lsa_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-id-string"):
                                        self.area_id_string = value
                                        self.area_id_string.value_namespace = name_space
                                        self.area_id_string.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-interface-count"):
                                        self.area_interface_count = value
                                        self.area_interface_count.value_namespace = name_space
                                        self.area_interface_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-lfa-interface-count"):
                                        self.area_lfa_interface_count = value
                                        self.area_lfa_interface_count.value_namespace = name_space
                                        self.area_lfa_interface_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-lfa-revision"):
                                        self.area_lfa_revision = value
                                        self.area_lfa_revision.value_namespace = name_space
                                        self.area_lfa_revision.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-lsa-checksum"):
                                        self.area_lsa_checksum = value
                                        self.area_lsa_checksum.value_namespace = name_space
                                        self.area_lsa_checksum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-lsa-count"):
                                        self.area_lsa_count = value
                                        self.area_lsa_count.value_namespace = name_space
                                        self.area_lsa_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-nssa"):
                                        self.area_nssa = value
                                        self.area_nssa.value_namespace = name_space
                                        self.area_nssa.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-num-nbr-full"):
                                        self.area_num_nbr_full = value
                                        self.area_num_nbr_full.value_namespace = name_space
                                        self.area_num_nbr_full.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-opaque-lsa-checksum"):
                                        self.area_opaque_lsa_checksum = value
                                        self.area_opaque_lsa_checksum.value_namespace = name_space
                                        self.area_opaque_lsa_checksum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-opaque-lsa-count"):
                                        self.area_opaque_lsa_count = value
                                        self.area_opaque_lsa_count.value_namespace = name_space
                                        self.area_opaque_lsa_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-per-prefix-lfa-interface-count"):
                                        self.area_per_prefix_lfa_interface_count = value
                                        self.area_per_prefix_lfa_interface_count.value_namespace = name_space
                                        self.area_per_prefix_lfa_interface_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-policy-in"):
                                        self.area_policy_in = value
                                        self.area_policy_in.value_namespace = name_space
                                        self.area_policy_in.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-policy-in-name"):
                                        self.area_policy_in_name = value
                                        self.area_policy_in_name.value_namespace = name_space
                                        self.area_policy_in_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-policy-out"):
                                        self.area_policy_out = value
                                        self.area_policy_out.value_namespace = name_space
                                        self.area_policy_out.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-policy-out-name"):
                                        self.area_policy_out_name = value
                                        self.area_policy_out_name.value_namespace = name_space
                                        self.area_policy_out_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-stub"):
                                        self.area_stub = value
                                        self.area_stub.value_namespace = name_space
                                        self.area_stub.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-total-stub"):
                                        self.area_total_stub = value
                                        self.area_total_stub.value_namespace = name_space
                                        self.area_total_stub.value_namespace_prefix = name_space_prefix
                                    if(value_path == "authentication-type"):
                                        self.authentication_type = value
                                        self.authentication_type.value_namespace = name_space
                                        self.authentication_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backbone-area-active"):
                                        self.backbone_area_active = value
                                        self.backbone_area_active.value_namespace = name_space
                                        self.backbone_area_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dna-lsa-count"):
                                        self.dna_lsa_count = value
                                        self.dna_lsa_count.value_namespace = name_space
                                        self.dna_lsa_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "external-out"):
                                        self.external_out = value
                                        self.external_out.value_namespace = name_space
                                        self.external_out.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-list-length"):
                                        self.flood_list_length = value
                                        self.flood_list_length.value_namespace = name_space
                                        self.flood_list_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "indication-lsa-count"):
                                        self.indication_lsa_count = value
                                        self.indication_lsa_count.value_namespace = name_space
                                        self.indication_lsa_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nssa-default"):
                                        self.nssa_default = value
                                        self.nssa_default.value_namespace = name_space
                                        self.nssa_default.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nssa-no-redistribution"):
                                        self.nssa_no_redistribution = value
                                        self.nssa_no_redistribution.value_namespace = name_space
                                        self.nssa_no_redistribution.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nssa-translate"):
                                        self.nssa_translate = value
                                        self.nssa_translate.value_namespace = name_space
                                        self.nssa_translate.value_namespace_prefix = name_space_prefix
                                    if(value_path == "segment-routing"):
                                        self.segment_routing = value
                                        self.segment_routing.value_namespace = name_space
                                        self.segment_routing.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spf-count"):
                                        self.spf_count = value
                                        self.spf_count.value_namespace = name_space
                                        self.spf_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sr-microloop-avoidance-active"):
                                        self.sr_microloop_avoidance_active = value
                                        self.sr_microloop_avoidance_active.value_namespace = name_space
                                        self.sr_microloop_avoidance_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sr-microloop-avoidance-event-type"):
                                        self.sr_microloop_avoidance_event_type = value
                                        self.sr_microloop_avoidance_event_type.value_namespace = name_space
                                        self.sr_microloop_avoidance_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sr-microloop-avoidance-far-end-id"):
                                        self.sr_microloop_avoidance_far_end_id = value
                                        self.sr_microloop_avoidance_far_end_id.value_namespace = name_space
                                        self.sr_microloop_avoidance_far_end_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sr-microloop-avoidance-near-end-id"):
                                        self.sr_microloop_avoidance_near_end_id = value
                                        self.sr_microloop_avoidance_near_end_id.value_namespace = name_space
                                        self.sr_microloop_avoidance_near_end_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sr-microloop-avoidance-pseudonode-id"):
                                        self.sr_microloop_avoidance_pseudonode_id = value
                                        self.sr_microloop_avoidance_pseudonode_id.value_namespace = name_space
                                        self.sr_microloop_avoidance_pseudonode_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sr-strict-spf-cap"):
                                        self.sr_strict_spf_cap = value
                                        self.sr_strict_spf_cap.value_namespace = name_space
                                        self.sr_strict_spf_cap.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sr-strict-spfsids-available"):
                                        self.sr_strict_spfsids_available = value
                                        self.sr_strict_spfsids_available.value_namespace = name_space
                                        self.sr_strict_spfsids_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "stub-default-cost"):
                                        self.stub_default_cost = value
                                        self.stub_default_cost.value_namespace = name_space
                                        self.stub_default_cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "summary-in"):
                                        self.summary_in = value
                                        self.summary_in.value_namespace = name_space
                                        self.summary_in.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-enabled"):
                                        self.te_enabled = value
                                        self.te_enabled.value_namespace = name_space
                                        self.te_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-topology-version"):
                                        self.te_topology_version = value
                                        self.te_topology_version.value_namespace = name_space
                                        self.te_topology_version.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.process_area:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.process_area:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "process-areas" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "process-area"):
                                    for c in self.process_area:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.process_area.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "process-area"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class ProcessSummary(Entity):
                            """
                            Basic OSPF summary information
                            
                            .. attribute:: adj_stag_init_num_nbr
                            
                            	Num of nbrs brought up initially per area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: adj_stag_max_num_nbr
                            
                            	Max num of nbrs brought up simultaneously per OSPF instance
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: adj_stag_num_nbr_forming
                            
                            	Num of nbrs currently forming for OSPF instance
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: adj_stagger_enabled
                            
                            	If true, OSPF Adjacency Staggering is configured
                            	**type**\:  bool
                            
                            .. attribute:: area_border_router
                            
                            	If true, is an Area Border Router
                            	**type**\:  bool
                            
                            .. attribute:: area_count
                            
                            	Number of areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: as_border_router
                            
                            	If true, is an AS Border Router
                            	**type**\:  bool
                            
                            .. attribute:: as_dc_bitless_lsa_count
                            
                            	Number of External and AS Opaque LSAs with demand circut bit not set
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_dna_lsa_count
                            
                            	Number of External and AS Opaque LSAs with DoNotAge set 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_lsa_checksum
                            
                            	Sum of AS scope LSA checksum
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_lsa_count
                            
                            	Number of AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_lsa_flood_list_length
                            
                            	Length of AS LSAs flood list
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context_name
                            
                            	Context name
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: domain_id
                            
                            	Domain ID information
                            	**type**\:   :py:class:`DomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId>`
                            
                            .. attribute:: graceful_shutdown_retention_time
                            
                            	Amount of time routes are retained after graceful shutdown (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_state
                            
                            	State of graceful shutdown
                            	**type**\:   :py:class:`GsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.GsState>`
                            
                            .. attribute:: if_flood_pacing_interval
                            
                            	Flood pacing timer (ms)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: if_retrans_pacing_interval
                            
                            	Retransmission pacing timer (ms)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: igp_intact_on
                            
                            	If true, running in IGP\-Intact mode
                            	**type**\:  bool
                            
                            .. attribute:: last_nsf_time
                            
                            	 Length of time since the last NSF (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_hold_time
                            
                            	Second delay before generating next LSA (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_maximum_time
                            
                            	Maximum delay before generating an LSA (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_refresh_interval
                            
                            	LSA refresh interval (sec)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_start_time
                            
                            	Inital LSA throttle delay (ms)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: lsd_bound
                            
                            	True if bound to LSD
                            	**type**\:  bool
                            
                            .. attribute:: lsd_connected
                            
                            	True if connected to LSD
                            	**type**\:  bool
                            
                            .. attribute:: lsd_connection_revision
                            
                            	LSD Connection Revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsd_registered
                            
                            	True if registered with LSD
                            	**type**\:  bool
                            
                            .. attribute:: max_lsa_enabled
                            
                            	If true, max\-lsa protection enabled
                            	**type**\:  bool
                            
                            .. attribute:: max_lsa_ignore_count
                            
                            	How many times ignore state has been entered
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_ignore_limit
                            
                            	Max allowed number of entering ignore state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_ignore_time
                            
                            	Time ignoring new LSAs after max\-lsa reached
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_ignore_timer
                            
                            	Remaining time when ignore timer is running
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_limit
                            
                            	Maximum allowed number of non self\-generated LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_reset_time
                            
                            	Time after which LSA protection counter is reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_reset_timer
                            
                            	Remaining time when reset timer is running
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_treshold
                            
                            	max\-lsa protection warning threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_warning_only
                            
                            	Warning only when max\-lsa reached
                            	**type**\:  bool
                            
                            .. attribute:: maximum_interfaces
                            
                            	Maximum number of interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_metric
                            
                            	Max\-metric list
                            	**type**\: list of    :py:class:`MaximumMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric>`
                            
                            .. attribute:: maximum_metric_abr_off_buffer_time
                            
                            	Buffer time in seconds since last neighbor activity, to remain in max\-metric ABR off state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: maximum_metric_abr_off_mode
                            
                            	If true, ABR duties temporarily disabled
                            	**type**\:  bool
                            
                            .. attribute:: maximum_metric_abr_off_reasons
                            
                            	Reasons for ABR duties being temporarily disabled
                            	**type**\:   :py:class:`OspfMaxMetricAbrOffReasons <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfMaxMetricAbrOffReasons>`
                            
                            .. attribute:: maximum_metric_set_reason
                            
                            	Max\-metric set reason
                            	**type**\:   :py:class:`MaxMetricSetReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MaxMetricSetReason>`
                            
                            .. attribute:: maximum_metric_start
                            
                            	If true, originate Router LSA with maximum metric
                            	**type**\:  bool
                            
                            .. attribute:: maximum_metric_start_timer
                            
                            	Time remaining for hold down timer (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: microloop_avoidance_active
                            
                            	If true, Uloop is active
                            	**type**\:  bool
                            
                            .. attribute:: microloop_avoidance_delay
                            
                            	Microloop delay time after which actual          post convergence paths are given to RIB (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: microloop_avoidance_delay_expiry
                            
                            	Remaining time for uloop delay timer             to expire (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: microloop_avoidance_type
                            
                            	Microloop avoidance type configured
                            	**type**\:   :py:class:`UloopAvoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.UloopAvoidance>`
                            
                            .. attribute:: minimum_lsa_arrival_interval
                            
                            	Minimum time between accepting LSAs (ms) Rel 4.0 .1, deprecated by MinimumLSAArrivalIntervalU32]
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: minimum_lsa_arrival_interval_u32
                            
                            	Minimum time between accepting LSAs (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: minimum_lsa_interval
                            
                            	Minimum time between LSA regeneration (ms) Rel 4 .0.1, deprecated by MinimumLSAIntervalU32]
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: minimum_lsa_interval_u32
                            
                            	Minimum time between LSA regeneration (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: non_self_lsa_count
                            
                            	Non self\-generated LSA count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: normal_area_count
                            
                            	Number of normal Areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsf_enabled
                            
                            	If true, NSF enabled
                            	**type**\:  bool
                            
                            .. attribute:: nsf_time
                            
                            	Total time to complete NSF (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_enabled
                            
                            	If true, NSR is enabled
                            	**type**\:  bool
                            
                            .. attribute:: nsr_switchover_on_restart
                            
                            	Trigger RP Switchover on detectable process restart
                            	**type**\:  bool
                            
                            .. attribute:: nssa_area_count
                            
                            	Number of NSSA Areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: number_nbrs_full
                            
                            	Num of full nbrs
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: opaque_capable
                            
                            	Opaque LSA capable
                            	**type**\:  bool
                            
                            .. attribute:: opaque_lsa_checksum
                            
                            	Sum of opaque LSA checksum
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: opaque_lsa_count
                            
                            	Number of Opaque LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redistribution
                            
                            	Redistribution list
                            	**type**\: list of    :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution>`
                            
                            .. attribute:: redistribution_limit
                            
                            	The number of redistributed prefixes allowed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redistribution_limit_warn
                            
                            	If true, only a syslog message is printed when redistribution prefix limit is reached
                            	**type**\:  bool
                            
                            .. attribute:: redistribution_threshold
                            
                            	When the number of redistributed prefixes reaches this threshold, a warning message is issued
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: role
                            
                            	Role, V1/V2 Active/Standby
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: role_standby
                            
                            	If true, Role is Standby, Active otherwise
                            	**type**\:  bool
                            
                            .. attribute:: router_id
                            
                            	Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: snmp_trap_enabled
                            
                            	If true, snmp trap is enabled
                            	**type**\:  bool
                            
                            .. attribute:: spf_hold_time
                            
                            	Minimum delay time between SPF runs (ms) This is valid if configured below 64k Deprecated by SPFHoldTimeU32]
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: spf_hold_time_u32
                            
                            	Minimum delay time between SPF runs (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_maximum_time
                            
                            	Maximum delay time between SPF runs (ms) This is valid if configured below 64k Deprecated by SPFMaximumTimeU32]
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: spf_maximum_time_u32
                            
                            	Maximum delay time between SPF runs (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_prefix_priority
                            
                            	If true, prefix\-priority policy is configured
                            	**type**\:  bool
                            
                            .. attribute:: spf_prefix_priority_route_policy
                            
                            	SPF Prefix\-priority route policy
                            	**type**\:  str
                            
                            .. attribute:: spf_start_time
                            
                            	Scheduling delay for SPF (ms) This is valid if configured below 64k Deprecated by SPFStartTimeU32]
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: spf_start_time_u32
                            
                            	Scheduling delay for SPF (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sr_strict_spf_cap
                            
                            	True if Segment Routing Strict\-SPF capable
                            	**type**\:  bool
                            
                            .. attribute:: srgb_configured
                            
                            	True if Segment Routing Global Block configured
                            	**type**\:  bool
                            
                            .. attribute:: srgb_end
                            
                            	Segment Routing Global Block end label value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start
                            
                            	Segment Routing Global Block start label value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_status
                            
                            	Segment Routing Global Block allocation status
                            	**type**\:   :py:class:`OspfSrgbStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfSrgbStatus>`
                            
                            .. attribute:: stub_area_count
                            
                            	Number of Stub and Total Stub Areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: table_prefix_limit_reached
                            
                            	If true, prefix limit for table has been  reached
                            	**type**\:  bool
                            
                            .. attribute:: tos_options
                            
                            	Type of Service supported
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ucmp
                            
                            	If true, UCMP is enabled
                            	**type**\:  bool
                            
                            .. attribute:: ucmp_delay
                            
                            	Delay between end of SPF and start of UCMP calculation (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ucmp_prefix_list
                            
                            	UCMP Prefix\-list
                            	**type**\:  str
                            
                            .. attribute:: ucmp_variance
                            
                            	UCMP Variance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: vrf_lite_enabled
                            
                            	If true, vrf lite is enabled
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary, self).__init__()

                                self.yang_name = "process-summary"
                                self.yang_parent_name = "process-information"

                                self.adj_stag_init_num_nbr = YLeaf(YType.uint16, "adj-stag-init-num-nbr")

                                self.adj_stag_max_num_nbr = YLeaf(YType.uint16, "adj-stag-max-num-nbr")

                                self.adj_stag_num_nbr_forming = YLeaf(YType.uint16, "adj-stag-num-nbr-forming")

                                self.adj_stagger_enabled = YLeaf(YType.boolean, "adj-stagger-enabled")

                                self.area_border_router = YLeaf(YType.boolean, "area-border-router")

                                self.area_count = YLeaf(YType.uint16, "area-count")

                                self.as_border_router = YLeaf(YType.boolean, "as-border-router")

                                self.as_dc_bitless_lsa_count = YLeaf(YType.uint32, "as-dc-bitless-lsa-count")

                                self.as_dna_lsa_count = YLeaf(YType.uint32, "as-dna-lsa-count")

                                self.as_lsa_checksum = YLeaf(YType.uint32, "as-lsa-checksum")

                                self.as_lsa_count = YLeaf(YType.uint32, "as-lsa-count")

                                self.as_lsa_flood_list_length = YLeaf(YType.uint32, "as-lsa-flood-list-length")

                                self.context_name = YLeaf(YType.str, "context-name")

                                self.graceful_shutdown_retention_time = YLeaf(YType.uint32, "graceful-shutdown-retention-time")

                                self.graceful_shutdown_state = YLeaf(YType.enumeration, "graceful-shutdown-state")

                                self.if_flood_pacing_interval = YLeaf(YType.uint16, "if-flood-pacing-interval")

                                self.if_retrans_pacing_interval = YLeaf(YType.uint16, "if-retrans-pacing-interval")

                                self.igp_intact_on = YLeaf(YType.boolean, "igp-intact-on")

                                self.last_nsf_time = YLeaf(YType.uint32, "last-nsf-time")

                                self.lsa_hold_time = YLeaf(YType.uint32, "lsa-hold-time")

                                self.lsa_maximum_time = YLeaf(YType.uint32, "lsa-maximum-time")

                                self.lsa_refresh_interval = YLeaf(YType.uint32, "lsa-refresh-interval")

                                self.lsa_start_time = YLeaf(YType.int32, "lsa-start-time")

                                self.lsd_bound = YLeaf(YType.boolean, "lsd-bound")

                                self.lsd_connected = YLeaf(YType.boolean, "lsd-connected")

                                self.lsd_connection_revision = YLeaf(YType.uint32, "lsd-connection-revision")

                                self.lsd_registered = YLeaf(YType.boolean, "lsd-registered")

                                self.max_lsa_enabled = YLeaf(YType.boolean, "max-lsa-enabled")

                                self.max_lsa_ignore_count = YLeaf(YType.uint32, "max-lsa-ignore-count")

                                self.max_lsa_ignore_limit = YLeaf(YType.uint32, "max-lsa-ignore-limit")

                                self.max_lsa_ignore_time = YLeaf(YType.uint32, "max-lsa-ignore-time")

                                self.max_lsa_ignore_timer = YLeaf(YType.uint32, "max-lsa-ignore-timer")

                                self.max_lsa_limit = YLeaf(YType.uint32, "max-lsa-limit")

                                self.max_lsa_reset_time = YLeaf(YType.uint32, "max-lsa-reset-time")

                                self.max_lsa_reset_timer = YLeaf(YType.uint32, "max-lsa-reset-timer")

                                self.max_lsa_treshold = YLeaf(YType.uint32, "max-lsa-treshold")

                                self.max_lsa_warning_only = YLeaf(YType.boolean, "max-lsa-warning-only")

                                self.maximum_interfaces = YLeaf(YType.uint32, "maximum-interfaces")

                                self.maximum_metric_abr_off_buffer_time = YLeaf(YType.uint32, "maximum-metric-abr-off-buffer-time")

                                self.maximum_metric_abr_off_mode = YLeaf(YType.boolean, "maximum-metric-abr-off-mode")

                                self.maximum_metric_abr_off_reasons = YLeaf(YType.enumeration, "maximum-metric-abr-off-reasons")

                                self.maximum_metric_set_reason = YLeaf(YType.enumeration, "maximum-metric-set-reason")

                                self.maximum_metric_start = YLeaf(YType.boolean, "maximum-metric-start")

                                self.maximum_metric_start_timer = YLeaf(YType.uint32, "maximum-metric-start-timer")

                                self.microloop_avoidance_active = YLeaf(YType.boolean, "microloop-avoidance-active")

                                self.microloop_avoidance_delay = YLeaf(YType.uint32, "microloop-avoidance-delay")

                                self.microloop_avoidance_delay_expiry = YLeaf(YType.uint32, "microloop-avoidance-delay-expiry")

                                self.microloop_avoidance_type = YLeaf(YType.enumeration, "microloop-avoidance-type")

                                self.minimum_lsa_arrival_interval = YLeaf(YType.uint16, "minimum-lsa-arrival-interval")

                                self.minimum_lsa_arrival_interval_u32 = YLeaf(YType.uint32, "minimum-lsa-arrival-interval-u32")

                                self.minimum_lsa_interval = YLeaf(YType.uint16, "minimum-lsa-interval")

                                self.minimum_lsa_interval_u32 = YLeaf(YType.uint32, "minimum-lsa-interval-u32")

                                self.non_self_lsa_count = YLeaf(YType.uint32, "non-self-lsa-count")

                                self.normal_area_count = YLeaf(YType.uint16, "normal-area-count")

                                self.nsf_enabled = YLeaf(YType.boolean, "nsf-enabled")

                                self.nsf_time = YLeaf(YType.uint32, "nsf-time")

                                self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                self.nsr_switchover_on_restart = YLeaf(YType.boolean, "nsr-switchover-on-restart")

                                self.nssa_area_count = YLeaf(YType.uint16, "nssa-area-count")

                                self.number_nbrs_full = YLeaf(YType.uint16, "number-nbrs-full")

                                self.opaque_capable = YLeaf(YType.boolean, "opaque-capable")

                                self.opaque_lsa_checksum = YLeaf(YType.uint32, "opaque-lsa-checksum")

                                self.opaque_lsa_count = YLeaf(YType.uint32, "opaque-lsa-count")

                                self.redistribution_limit = YLeaf(YType.uint32, "redistribution-limit")

                                self.redistribution_limit_warn = YLeaf(YType.boolean, "redistribution-limit-warn")

                                self.redistribution_threshold = YLeaf(YType.uint32, "redistribution-threshold")

                                self.role = YLeaf(YType.uint32, "role")

                                self.role_standby = YLeaf(YType.boolean, "role-standby")

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.snmp_trap_enabled = YLeaf(YType.boolean, "snmp-trap-enabled")

                                self.spf_hold_time = YLeaf(YType.uint16, "spf-hold-time")

                                self.spf_hold_time_u32 = YLeaf(YType.uint32, "spf-hold-time-u32")

                                self.spf_maximum_time = YLeaf(YType.uint16, "spf-maximum-time")

                                self.spf_maximum_time_u32 = YLeaf(YType.uint32, "spf-maximum-time-u32")

                                self.spf_prefix_priority = YLeaf(YType.boolean, "spf-prefix-priority")

                                self.spf_prefix_priority_route_policy = YLeaf(YType.str, "spf-prefix-priority-route-policy")

                                self.spf_start_time = YLeaf(YType.uint16, "spf-start-time")

                                self.spf_start_time_u32 = YLeaf(YType.uint32, "spf-start-time-u32")

                                self.sr_strict_spf_cap = YLeaf(YType.boolean, "sr-strict-spf-cap")

                                self.srgb_configured = YLeaf(YType.boolean, "srgb-configured")

                                self.srgb_end = YLeaf(YType.uint32, "srgb-end")

                                self.srgb_start = YLeaf(YType.uint32, "srgb-start")

                                self.srgb_status = YLeaf(YType.enumeration, "srgb-status")

                                self.stub_area_count = YLeaf(YType.uint16, "stub-area-count")

                                self.table_prefix_limit_reached = YLeaf(YType.boolean, "table-prefix-limit-reached")

                                self.tos_options = YLeaf(YType.uint8, "tos-options")

                                self.ucmp = YLeaf(YType.boolean, "ucmp")

                                self.ucmp_delay = YLeaf(YType.uint32, "ucmp-delay")

                                self.ucmp_prefix_list = YLeaf(YType.str, "ucmp-prefix-list")

                                self.ucmp_variance = YLeaf(YType.int32, "ucmp-variance")

                                self.vrf_lite_enabled = YLeaf(YType.boolean, "vrf-lite-enabled")

                                self.domain_id = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId()
                                self.domain_id.parent = self
                                self._children_name_map["domain_id"] = "domain-id"
                                self._children_yang_names.add("domain-id")

                                self.maximum_metric = YList(self)
                                self.redistribution = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("adj_stag_init_num_nbr",
                                                "adj_stag_max_num_nbr",
                                                "adj_stag_num_nbr_forming",
                                                "adj_stagger_enabled",
                                                "area_border_router",
                                                "area_count",
                                                "as_border_router",
                                                "as_dc_bitless_lsa_count",
                                                "as_dna_lsa_count",
                                                "as_lsa_checksum",
                                                "as_lsa_count",
                                                "as_lsa_flood_list_length",
                                                "context_name",
                                                "graceful_shutdown_retention_time",
                                                "graceful_shutdown_state",
                                                "if_flood_pacing_interval",
                                                "if_retrans_pacing_interval",
                                                "igp_intact_on",
                                                "last_nsf_time",
                                                "lsa_hold_time",
                                                "lsa_maximum_time",
                                                "lsa_refresh_interval",
                                                "lsa_start_time",
                                                "lsd_bound",
                                                "lsd_connected",
                                                "lsd_connection_revision",
                                                "lsd_registered",
                                                "max_lsa_enabled",
                                                "max_lsa_ignore_count",
                                                "max_lsa_ignore_limit",
                                                "max_lsa_ignore_time",
                                                "max_lsa_ignore_timer",
                                                "max_lsa_limit",
                                                "max_lsa_reset_time",
                                                "max_lsa_reset_timer",
                                                "max_lsa_treshold",
                                                "max_lsa_warning_only",
                                                "maximum_interfaces",
                                                "maximum_metric_abr_off_buffer_time",
                                                "maximum_metric_abr_off_mode",
                                                "maximum_metric_abr_off_reasons",
                                                "maximum_metric_set_reason",
                                                "maximum_metric_start",
                                                "maximum_metric_start_timer",
                                                "microloop_avoidance_active",
                                                "microloop_avoidance_delay",
                                                "microloop_avoidance_delay_expiry",
                                                "microloop_avoidance_type",
                                                "minimum_lsa_arrival_interval",
                                                "minimum_lsa_arrival_interval_u32",
                                                "minimum_lsa_interval",
                                                "minimum_lsa_interval_u32",
                                                "non_self_lsa_count",
                                                "normal_area_count",
                                                "nsf_enabled",
                                                "nsf_time",
                                                "nsr_enabled",
                                                "nsr_switchover_on_restart",
                                                "nssa_area_count",
                                                "number_nbrs_full",
                                                "opaque_capable",
                                                "opaque_lsa_checksum",
                                                "opaque_lsa_count",
                                                "redistribution_limit",
                                                "redistribution_limit_warn",
                                                "redistribution_threshold",
                                                "role",
                                                "role_standby",
                                                "router_id",
                                                "snmp_trap_enabled",
                                                "spf_hold_time",
                                                "spf_hold_time_u32",
                                                "spf_maximum_time",
                                                "spf_maximum_time_u32",
                                                "spf_prefix_priority",
                                                "spf_prefix_priority_route_policy",
                                                "spf_start_time",
                                                "spf_start_time_u32",
                                                "sr_strict_spf_cap",
                                                "srgb_configured",
                                                "srgb_end",
                                                "srgb_start",
                                                "srgb_status",
                                                "stub_area_count",
                                                "table_prefix_limit_reached",
                                                "tos_options",
                                                "ucmp",
                                                "ucmp_delay",
                                                "ucmp_prefix_list",
                                                "ucmp_variance",
                                                "vrf_lite_enabled") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary, self).__setattr__(name, value)


                            class DomainId(Entity):
                                """
                                Domain ID information
                                
                                .. attribute:: primary_domain_id
                                
                                	Primary Domain ID
                                	**type**\:   :py:class:`PrimaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId>`
                                
                                .. attribute:: secondary_domain_id
                                
                                	List of secondary domain IDs
                                	**type**\: list of    :py:class:`SecondaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId, self).__init__()

                                    self.yang_name = "domain-id"
                                    self.yang_parent_name = "process-summary"

                                    self.primary_domain_id = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId()
                                    self.primary_domain_id.parent = self
                                    self._children_name_map["primary_domain_id"] = "primary-domain-id"
                                    self._children_yang_names.add("primary-domain-id")

                                    self.secondary_domain_id = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId, self).__setattr__(name, value)


                                class PrimaryDomainId(Entity):
                                    """
                                    Primary Domain ID
                                    
                                    .. attribute:: domain_id_type
                                    
                                    	Domain ID Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: domain_id_value
                                    
                                    	Domain ID value
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId, self).__init__()

                                        self.yang_name = "primary-domain-id"
                                        self.yang_parent_name = "domain-id"

                                        self.domain_id_type = YLeaf(YType.uint16, "domain-id-type")

                                        self.domain_id_value = YLeaf(YType.str, "domain-id-value")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("domain_id_type",
                                                        "domain_id_value") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.domain_id_type.is_set or
                                            self.domain_id_value.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.domain_id_type.yfilter != YFilter.not_set or
                                            self.domain_id_value.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "primary-domain-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.domain_id_type.is_set or self.domain_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.domain_id_type.get_name_leafdata())
                                        if (self.domain_id_value.is_set or self.domain_id_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.domain_id_value.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "domain-id-type" or name == "domain-id-value"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "domain-id-type"):
                                            self.domain_id_type = value
                                            self.domain_id_type.value_namespace = name_space
                                            self.domain_id_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "domain-id-value"):
                                            self.domain_id_value = value
                                            self.domain_id_value.value_namespace = name_space
                                            self.domain_id_value.value_namespace_prefix = name_space_prefix


                                class SecondaryDomainId(Entity):
                                    """
                                    List of secondary domain IDs
                                    
                                    .. attribute:: domain_id_type
                                    
                                    	Domain ID Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: domain_id_value
                                    
                                    	Domain ID value
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId, self).__init__()

                                        self.yang_name = "secondary-domain-id"
                                        self.yang_parent_name = "domain-id"

                                        self.domain_id_type = YLeaf(YType.uint16, "domain-id-type")

                                        self.domain_id_value = YLeaf(YType.str, "domain-id-value")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("domain_id_type",
                                                        "domain_id_value") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.domain_id_type.is_set or
                                            self.domain_id_value.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.domain_id_type.yfilter != YFilter.not_set or
                                            self.domain_id_value.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "secondary-domain-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.domain_id_type.is_set or self.domain_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.domain_id_type.get_name_leafdata())
                                        if (self.domain_id_value.is_set or self.domain_id_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.domain_id_value.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "domain-id-type" or name == "domain-id-value"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "domain-id-type"):
                                            self.domain_id_type = value
                                            self.domain_id_type.value_namespace = name_space
                                            self.domain_id_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "domain-id-value"):
                                            self.domain_id_value = value
                                            self.domain_id_value.value_namespace = name_space
                                            self.domain_id_value.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.secondary_domain_id:
                                        if (c.has_data()):
                                            return True
                                    return (self.primary_domain_id is not None and self.primary_domain_id.has_data())

                                def has_operation(self):
                                    for c in self.secondary_domain_id:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.primary_domain_id is not None and self.primary_domain_id.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "domain-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "primary-domain-id"):
                                        if (self.primary_domain_id is None):
                                            self.primary_domain_id = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId()
                                            self.primary_domain_id.parent = self
                                            self._children_name_map["primary_domain_id"] = "primary-domain-id"
                                        return self.primary_domain_id

                                    if (child_yang_name == "secondary-domain-id"):
                                        for c in self.secondary_domain_id:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.secondary_domain_id.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "primary-domain-id" or name == "secondary-domain-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class MaximumMetric(Entity):
                                """
                                Max\-metric list
                                
                                .. attribute:: max_metric_enabled
                                
                                	Max\-metric enabled
                                	**type**\:  bool
                                
                                .. attribute:: max_metric_reason
                                
                                	Max\-metric reason
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: maximum_metric_external_lsa
                                
                                	If true, advertise max\-metric in external\-LSAs
                                	**type**\:  bool
                                
                                .. attribute:: maximum_metric_external_lsa_metric
                                
                                	Max\-metric value to advertise in external\-LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_metric_include_stubs
                                
                                	If true, set max\-metric in stub links
                                	**type**\:  bool
                                
                                .. attribute:: maximum_metric_originated_for
                                
                                	Time max\-metric was used for
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_metric_start_time
                                
                                	Time remaining until we will start using normal metrics (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_metric_summary_lsa
                                
                                	If true, advertise max\-metric in summary\-LSAs
                                	**type**\:  bool
                                
                                .. attribute:: maximum_metric_summary_lsa_metric
                                
                                	Max\-metric value to advertise in summary\-LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_metric_time_unset
                                
                                	Time max\-metric condition was cleared
                                	**type**\:   :py:class:`MaximumMetricTimeUnset <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset>`
                                
                                .. attribute:: maximum_metric_unset_reason
                                
                                	Max\-metric unset reason
                                	**type**\:   :py:class:`MaxMetricUnsetReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MaxMetricUnsetReason>`
                                
                                .. attribute:: saved_startup_time
                                
                                	Hold time configured (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saved_unset_maximum_metric
                                
                                	Saved UnsetMaximumMetric
                                	**type**\:  bool
                                
                                .. attribute:: unset_maximum_metric
                                
                                	If true, BGP is up, no maximum metric Router LSA
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric, self).__init__()

                                    self.yang_name = "maximum-metric"
                                    self.yang_parent_name = "process-summary"

                                    self.max_metric_enabled = YLeaf(YType.boolean, "max-metric-enabled")

                                    self.max_metric_reason = YLeaf(YType.uint8, "max-metric-reason")

                                    self.maximum_metric_external_lsa = YLeaf(YType.boolean, "maximum-metric-external-lsa")

                                    self.maximum_metric_external_lsa_metric = YLeaf(YType.uint32, "maximum-metric-external-lsa-metric")

                                    self.maximum_metric_include_stubs = YLeaf(YType.boolean, "maximum-metric-include-stubs")

                                    self.maximum_metric_originated_for = YLeaf(YType.uint32, "maximum-metric-originated-for")

                                    self.maximum_metric_start_time = YLeaf(YType.uint32, "maximum-metric-start-time")

                                    self.maximum_metric_summary_lsa = YLeaf(YType.boolean, "maximum-metric-summary-lsa")

                                    self.maximum_metric_summary_lsa_metric = YLeaf(YType.uint32, "maximum-metric-summary-lsa-metric")

                                    self.maximum_metric_unset_reason = YLeaf(YType.enumeration, "maximum-metric-unset-reason")

                                    self.saved_startup_time = YLeaf(YType.uint32, "saved-startup-time")

                                    self.saved_unset_maximum_metric = YLeaf(YType.boolean, "saved-unset-maximum-metric")

                                    self.unset_maximum_metric = YLeaf(YType.boolean, "unset-maximum-metric")

                                    self.maximum_metric_time_unset = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset()
                                    self.maximum_metric_time_unset.parent = self
                                    self._children_name_map["maximum_metric_time_unset"] = "maximum-metric-time-unset"
                                    self._children_yang_names.add("maximum-metric-time-unset")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("max_metric_enabled",
                                                    "max_metric_reason",
                                                    "maximum_metric_external_lsa",
                                                    "maximum_metric_external_lsa_metric",
                                                    "maximum_metric_include_stubs",
                                                    "maximum_metric_originated_for",
                                                    "maximum_metric_start_time",
                                                    "maximum_metric_summary_lsa",
                                                    "maximum_metric_summary_lsa_metric",
                                                    "maximum_metric_unset_reason",
                                                    "saved_startup_time",
                                                    "saved_unset_maximum_metric",
                                                    "unset_maximum_metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric, self).__setattr__(name, value)


                                class MaximumMetricTimeUnset(Entity):
                                    """
                                    Time max\-metric condition was cleared
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset, self).__init__()

                                        self.yang_name = "maximum-metric-time-unset"
                                        self.yang_parent_name = "maximum-metric"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "maximum-metric-time-unset" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.max_metric_enabled.is_set or
                                        self.max_metric_reason.is_set or
                                        self.maximum_metric_external_lsa.is_set or
                                        self.maximum_metric_external_lsa_metric.is_set or
                                        self.maximum_metric_include_stubs.is_set or
                                        self.maximum_metric_originated_for.is_set or
                                        self.maximum_metric_start_time.is_set or
                                        self.maximum_metric_summary_lsa.is_set or
                                        self.maximum_metric_summary_lsa_metric.is_set or
                                        self.maximum_metric_unset_reason.is_set or
                                        self.saved_startup_time.is_set or
                                        self.saved_unset_maximum_metric.is_set or
                                        self.unset_maximum_metric.is_set or
                                        (self.maximum_metric_time_unset is not None and self.maximum_metric_time_unset.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.max_metric_enabled.yfilter != YFilter.not_set or
                                        self.max_metric_reason.yfilter != YFilter.not_set or
                                        self.maximum_metric_external_lsa.yfilter != YFilter.not_set or
                                        self.maximum_metric_external_lsa_metric.yfilter != YFilter.not_set or
                                        self.maximum_metric_include_stubs.yfilter != YFilter.not_set or
                                        self.maximum_metric_originated_for.yfilter != YFilter.not_set or
                                        self.maximum_metric_start_time.yfilter != YFilter.not_set or
                                        self.maximum_metric_summary_lsa.yfilter != YFilter.not_set or
                                        self.maximum_metric_summary_lsa_metric.yfilter != YFilter.not_set or
                                        self.maximum_metric_unset_reason.yfilter != YFilter.not_set or
                                        self.saved_startup_time.yfilter != YFilter.not_set or
                                        self.saved_unset_maximum_metric.yfilter != YFilter.not_set or
                                        self.unset_maximum_metric.yfilter != YFilter.not_set or
                                        (self.maximum_metric_time_unset is not None and self.maximum_metric_time_unset.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "maximum-metric" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.max_metric_enabled.is_set or self.max_metric_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.max_metric_enabled.get_name_leafdata())
                                    if (self.max_metric_reason.is_set or self.max_metric_reason.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.max_metric_reason.get_name_leafdata())
                                    if (self.maximum_metric_external_lsa.is_set or self.maximum_metric_external_lsa.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_metric_external_lsa.get_name_leafdata())
                                    if (self.maximum_metric_external_lsa_metric.is_set or self.maximum_metric_external_lsa_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_metric_external_lsa_metric.get_name_leafdata())
                                    if (self.maximum_metric_include_stubs.is_set or self.maximum_metric_include_stubs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_metric_include_stubs.get_name_leafdata())
                                    if (self.maximum_metric_originated_for.is_set or self.maximum_metric_originated_for.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_metric_originated_for.get_name_leafdata())
                                    if (self.maximum_metric_start_time.is_set or self.maximum_metric_start_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_metric_start_time.get_name_leafdata())
                                    if (self.maximum_metric_summary_lsa.is_set or self.maximum_metric_summary_lsa.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_metric_summary_lsa.get_name_leafdata())
                                    if (self.maximum_metric_summary_lsa_metric.is_set or self.maximum_metric_summary_lsa_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_metric_summary_lsa_metric.get_name_leafdata())
                                    if (self.maximum_metric_unset_reason.is_set or self.maximum_metric_unset_reason.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_metric_unset_reason.get_name_leafdata())
                                    if (self.saved_startup_time.is_set or self.saved_startup_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.saved_startup_time.get_name_leafdata())
                                    if (self.saved_unset_maximum_metric.is_set or self.saved_unset_maximum_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.saved_unset_maximum_metric.get_name_leafdata())
                                    if (self.unset_maximum_metric.is_set or self.unset_maximum_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unset_maximum_metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "maximum-metric-time-unset"):
                                        if (self.maximum_metric_time_unset is None):
                                            self.maximum_metric_time_unset = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset()
                                            self.maximum_metric_time_unset.parent = self
                                            self._children_name_map["maximum_metric_time_unset"] = "maximum-metric-time-unset"
                                        return self.maximum_metric_time_unset

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "maximum-metric-time-unset" or name == "max-metric-enabled" or name == "max-metric-reason" or name == "maximum-metric-external-lsa" or name == "maximum-metric-external-lsa-metric" or name == "maximum-metric-include-stubs" or name == "maximum-metric-originated-for" or name == "maximum-metric-start-time" or name == "maximum-metric-summary-lsa" or name == "maximum-metric-summary-lsa-metric" or name == "maximum-metric-unset-reason" or name == "saved-startup-time" or name == "saved-unset-maximum-metric" or name == "unset-maximum-metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "max-metric-enabled"):
                                        self.max_metric_enabled = value
                                        self.max_metric_enabled.value_namespace = name_space
                                        self.max_metric_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "max-metric-reason"):
                                        self.max_metric_reason = value
                                        self.max_metric_reason.value_namespace = name_space
                                        self.max_metric_reason.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-metric-external-lsa"):
                                        self.maximum_metric_external_lsa = value
                                        self.maximum_metric_external_lsa.value_namespace = name_space
                                        self.maximum_metric_external_lsa.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-metric-external-lsa-metric"):
                                        self.maximum_metric_external_lsa_metric = value
                                        self.maximum_metric_external_lsa_metric.value_namespace = name_space
                                        self.maximum_metric_external_lsa_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-metric-include-stubs"):
                                        self.maximum_metric_include_stubs = value
                                        self.maximum_metric_include_stubs.value_namespace = name_space
                                        self.maximum_metric_include_stubs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-metric-originated-for"):
                                        self.maximum_metric_originated_for = value
                                        self.maximum_metric_originated_for.value_namespace = name_space
                                        self.maximum_metric_originated_for.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-metric-start-time"):
                                        self.maximum_metric_start_time = value
                                        self.maximum_metric_start_time.value_namespace = name_space
                                        self.maximum_metric_start_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-metric-summary-lsa"):
                                        self.maximum_metric_summary_lsa = value
                                        self.maximum_metric_summary_lsa.value_namespace = name_space
                                        self.maximum_metric_summary_lsa.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-metric-summary-lsa-metric"):
                                        self.maximum_metric_summary_lsa_metric = value
                                        self.maximum_metric_summary_lsa_metric.value_namespace = name_space
                                        self.maximum_metric_summary_lsa_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-metric-unset-reason"):
                                        self.maximum_metric_unset_reason = value
                                        self.maximum_metric_unset_reason.value_namespace = name_space
                                        self.maximum_metric_unset_reason.value_namespace_prefix = name_space_prefix
                                    if(value_path == "saved-startup-time"):
                                        self.saved_startup_time = value
                                        self.saved_startup_time.value_namespace = name_space
                                        self.saved_startup_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "saved-unset-maximum-metric"):
                                        self.saved_unset_maximum_metric = value
                                        self.saved_unset_maximum_metric.value_namespace = name_space
                                        self.saved_unset_maximum_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unset-maximum-metric"):
                                        self.unset_maximum_metric = value
                                        self.unset_maximum_metric.value_namespace = name_space
                                        self.unset_maximum_metric.value_namespace_prefix = name_space_prefix


                            class Redistribution(Entity):
                                """
                                Redistribution list
                                
                                .. attribute:: classless
                                
                                	Whether to use CIDR
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Route metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_flag
                                
                                	If true, Metric configured
                                	**type**\:  bool
                                
                                .. attribute:: nssa_only
                                
                                	To NSSA areas only
                                	**type**\:  bool
                                
                                .. attribute:: redistribution_protocol
                                
                                	Protocol Information
                                	**type**\:   :py:class:`RedistributionProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution, self).__init__()

                                    self.yang_name = "redistribution"
                                    self.yang_parent_name = "process-summary"

                                    self.classless = YLeaf(YType.boolean, "classless")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.metric_flag = YLeaf(YType.boolean, "metric-flag")

                                    self.nssa_only = YLeaf(YType.boolean, "nssa-only")

                                    self.redistribution_protocol = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol()
                                    self.redistribution_protocol.parent = self
                                    self._children_name_map["redistribution_protocol"] = "redistribution-protocol"
                                    self._children_yang_names.add("redistribution-protocol")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("classless",
                                                    "metric",
                                                    "metric_flag",
                                                    "nssa_only") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution, self).__setattr__(name, value)


                                class RedistributionProtocol(Entity):
                                    """
                                    Protocol Information
                                    
                                    .. attribute:: bgp_as_number
                                    
                                    	BGP Autonomous System Number
                                    	**type**\:  str
                                    
                                    .. attribute:: connected_instance
                                    
                                    	Connected instance name
                                    	**type**\:  str
                                    
                                    .. attribute:: eigrp_as_number
                                    
                                    	Autonomous System Number
                                    	**type**\:  str
                                    
                                    .. attribute:: isis_instance_id
                                    
                                    	ISIS instance identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: ospf_process_id
                                    
                                    	OSPF process identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: protocol_type
                                    
                                    	ProtocolType
                                    	**type**\:   :py:class:`RedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.RedistProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol, self).__init__()

                                        self.yang_name = "redistribution-protocol"
                                        self.yang_parent_name = "redistribution"

                                        self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                        self.connected_instance = YLeaf(YType.str, "connected-instance")

                                        self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                        self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                        self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                        self.protocol_type = YLeaf(YType.enumeration, "protocol-type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_as_number",
                                                        "connected_instance",
                                                        "eigrp_as_number",
                                                        "isis_instance_id",
                                                        "ospf_process_id",
                                                        "protocol_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_as_number.is_set or
                                            self.connected_instance.is_set or
                                            self.eigrp_as_number.is_set or
                                            self.isis_instance_id.is_set or
                                            self.ospf_process_id.is_set or
                                            self.protocol_type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_as_number.yfilter != YFilter.not_set or
                                            self.connected_instance.yfilter != YFilter.not_set or
                                            self.eigrp_as_number.yfilter != YFilter.not_set or
                                            self.isis_instance_id.yfilter != YFilter.not_set or
                                            self.ospf_process_id.yfilter != YFilter.not_set or
                                            self.protocol_type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "redistribution-protocol" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_as_number.is_set or self.bgp_as_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_as_number.get_name_leafdata())
                                        if (self.connected_instance.is_set or self.connected_instance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.connected_instance.get_name_leafdata())
                                        if (self.eigrp_as_number.is_set or self.eigrp_as_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.eigrp_as_number.get_name_leafdata())
                                        if (self.isis_instance_id.is_set or self.isis_instance_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.isis_instance_id.get_name_leafdata())
                                        if (self.ospf_process_id.is_set or self.ospf_process_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_process_id.get_name_leafdata())
                                        if (self.protocol_type.is_set or self.protocol_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-as-number" or name == "connected-instance" or name == "eigrp-as-number" or name == "isis-instance-id" or name == "ospf-process-id" or name == "protocol-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-as-number"):
                                            self.bgp_as_number = value
                                            self.bgp_as_number.value_namespace = name_space
                                            self.bgp_as_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "connected-instance"):
                                            self.connected_instance = value
                                            self.connected_instance.value_namespace = name_space
                                            self.connected_instance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "eigrp-as-number"):
                                            self.eigrp_as_number = value
                                            self.eigrp_as_number.value_namespace = name_space
                                            self.eigrp_as_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "isis-instance-id"):
                                            self.isis_instance_id = value
                                            self.isis_instance_id.value_namespace = name_space
                                            self.isis_instance_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-process-id"):
                                            self.ospf_process_id = value
                                            self.ospf_process_id.value_namespace = name_space
                                            self.ospf_process_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol-type"):
                                            self.protocol_type = value
                                            self.protocol_type.value_namespace = name_space
                                            self.protocol_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.classless.is_set or
                                        self.metric.is_set or
                                        self.metric_flag.is_set or
                                        self.nssa_only.is_set or
                                        (self.redistribution_protocol is not None and self.redistribution_protocol.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.classless.yfilter != YFilter.not_set or
                                        self.metric.yfilter != YFilter.not_set or
                                        self.metric_flag.yfilter != YFilter.not_set or
                                        self.nssa_only.yfilter != YFilter.not_set or
                                        (self.redistribution_protocol is not None and self.redistribution_protocol.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "redistribution" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.classless.is_set or self.classless.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.classless.get_name_leafdata())
                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                    if (self.metric_flag.is_set or self.metric_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric_flag.get_name_leafdata())
                                    if (self.nssa_only.is_set or self.nssa_only.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nssa_only.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "redistribution-protocol"):
                                        if (self.redistribution_protocol is None):
                                            self.redistribution_protocol = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol()
                                            self.redistribution_protocol.parent = self
                                            self._children_name_map["redistribution_protocol"] = "redistribution-protocol"
                                        return self.redistribution_protocol

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "redistribution-protocol" or name == "classless" or name == "metric" or name == "metric-flag" or name == "nssa-only"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "classless"):
                                        self.classless = value
                                        self.classless.value_namespace = name_space
                                        self.classless.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric"):
                                        self.metric = value
                                        self.metric.value_namespace = name_space
                                        self.metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric-flag"):
                                        self.metric_flag = value
                                        self.metric_flag.value_namespace = name_space
                                        self.metric_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nssa-only"):
                                        self.nssa_only = value
                                        self.nssa_only.value_namespace = name_space
                                        self.nssa_only.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.maximum_metric:
                                    if (c.has_data()):
                                        return True
                                for c in self.redistribution:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.adj_stag_init_num_nbr.is_set or
                                    self.adj_stag_max_num_nbr.is_set or
                                    self.adj_stag_num_nbr_forming.is_set or
                                    self.adj_stagger_enabled.is_set or
                                    self.area_border_router.is_set or
                                    self.area_count.is_set or
                                    self.as_border_router.is_set or
                                    self.as_dc_bitless_lsa_count.is_set or
                                    self.as_dna_lsa_count.is_set or
                                    self.as_lsa_checksum.is_set or
                                    self.as_lsa_count.is_set or
                                    self.as_lsa_flood_list_length.is_set or
                                    self.context_name.is_set or
                                    self.graceful_shutdown_retention_time.is_set or
                                    self.graceful_shutdown_state.is_set or
                                    self.if_flood_pacing_interval.is_set or
                                    self.if_retrans_pacing_interval.is_set or
                                    self.igp_intact_on.is_set or
                                    self.last_nsf_time.is_set or
                                    self.lsa_hold_time.is_set or
                                    self.lsa_maximum_time.is_set or
                                    self.lsa_refresh_interval.is_set or
                                    self.lsa_start_time.is_set or
                                    self.lsd_bound.is_set or
                                    self.lsd_connected.is_set or
                                    self.lsd_connection_revision.is_set or
                                    self.lsd_registered.is_set or
                                    self.max_lsa_enabled.is_set or
                                    self.max_lsa_ignore_count.is_set or
                                    self.max_lsa_ignore_limit.is_set or
                                    self.max_lsa_ignore_time.is_set or
                                    self.max_lsa_ignore_timer.is_set or
                                    self.max_lsa_limit.is_set or
                                    self.max_lsa_reset_time.is_set or
                                    self.max_lsa_reset_timer.is_set or
                                    self.max_lsa_treshold.is_set or
                                    self.max_lsa_warning_only.is_set or
                                    self.maximum_interfaces.is_set or
                                    self.maximum_metric_abr_off_buffer_time.is_set or
                                    self.maximum_metric_abr_off_mode.is_set or
                                    self.maximum_metric_abr_off_reasons.is_set or
                                    self.maximum_metric_set_reason.is_set or
                                    self.maximum_metric_start.is_set or
                                    self.maximum_metric_start_timer.is_set or
                                    self.microloop_avoidance_active.is_set or
                                    self.microloop_avoidance_delay.is_set or
                                    self.microloop_avoidance_delay_expiry.is_set or
                                    self.microloop_avoidance_type.is_set or
                                    self.minimum_lsa_arrival_interval.is_set or
                                    self.minimum_lsa_arrival_interval_u32.is_set or
                                    self.minimum_lsa_interval.is_set or
                                    self.minimum_lsa_interval_u32.is_set or
                                    self.non_self_lsa_count.is_set or
                                    self.normal_area_count.is_set or
                                    self.nsf_enabled.is_set or
                                    self.nsf_time.is_set or
                                    self.nsr_enabled.is_set or
                                    self.nsr_switchover_on_restart.is_set or
                                    self.nssa_area_count.is_set or
                                    self.number_nbrs_full.is_set or
                                    self.opaque_capable.is_set or
                                    self.opaque_lsa_checksum.is_set or
                                    self.opaque_lsa_count.is_set or
                                    self.redistribution_limit.is_set or
                                    self.redistribution_limit_warn.is_set or
                                    self.redistribution_threshold.is_set or
                                    self.role.is_set or
                                    self.role_standby.is_set or
                                    self.router_id.is_set or
                                    self.snmp_trap_enabled.is_set or
                                    self.spf_hold_time.is_set or
                                    self.spf_hold_time_u32.is_set or
                                    self.spf_maximum_time.is_set or
                                    self.spf_maximum_time_u32.is_set or
                                    self.spf_prefix_priority.is_set or
                                    self.spf_prefix_priority_route_policy.is_set or
                                    self.spf_start_time.is_set or
                                    self.spf_start_time_u32.is_set or
                                    self.sr_strict_spf_cap.is_set or
                                    self.srgb_configured.is_set or
                                    self.srgb_end.is_set or
                                    self.srgb_start.is_set or
                                    self.srgb_status.is_set or
                                    self.stub_area_count.is_set or
                                    self.table_prefix_limit_reached.is_set or
                                    self.tos_options.is_set or
                                    self.ucmp.is_set or
                                    self.ucmp_delay.is_set or
                                    self.ucmp_prefix_list.is_set or
                                    self.ucmp_variance.is_set or
                                    self.vrf_lite_enabled.is_set or
                                    (self.domain_id is not None and self.domain_id.has_data()))

                            def has_operation(self):
                                for c in self.maximum_metric:
                                    if (c.has_operation()):
                                        return True
                                for c in self.redistribution:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.adj_stag_init_num_nbr.yfilter != YFilter.not_set or
                                    self.adj_stag_max_num_nbr.yfilter != YFilter.not_set or
                                    self.adj_stag_num_nbr_forming.yfilter != YFilter.not_set or
                                    self.adj_stagger_enabled.yfilter != YFilter.not_set or
                                    self.area_border_router.yfilter != YFilter.not_set or
                                    self.area_count.yfilter != YFilter.not_set or
                                    self.as_border_router.yfilter != YFilter.not_set or
                                    self.as_dc_bitless_lsa_count.yfilter != YFilter.not_set or
                                    self.as_dna_lsa_count.yfilter != YFilter.not_set or
                                    self.as_lsa_checksum.yfilter != YFilter.not_set or
                                    self.as_lsa_count.yfilter != YFilter.not_set or
                                    self.as_lsa_flood_list_length.yfilter != YFilter.not_set or
                                    self.context_name.yfilter != YFilter.not_set or
                                    self.graceful_shutdown_retention_time.yfilter != YFilter.not_set or
                                    self.graceful_shutdown_state.yfilter != YFilter.not_set or
                                    self.if_flood_pacing_interval.yfilter != YFilter.not_set or
                                    self.if_retrans_pacing_interval.yfilter != YFilter.not_set or
                                    self.igp_intact_on.yfilter != YFilter.not_set or
                                    self.last_nsf_time.yfilter != YFilter.not_set or
                                    self.lsa_hold_time.yfilter != YFilter.not_set or
                                    self.lsa_maximum_time.yfilter != YFilter.not_set or
                                    self.lsa_refresh_interval.yfilter != YFilter.not_set or
                                    self.lsa_start_time.yfilter != YFilter.not_set or
                                    self.lsd_bound.yfilter != YFilter.not_set or
                                    self.lsd_connected.yfilter != YFilter.not_set or
                                    self.lsd_connection_revision.yfilter != YFilter.not_set or
                                    self.lsd_registered.yfilter != YFilter.not_set or
                                    self.max_lsa_enabled.yfilter != YFilter.not_set or
                                    self.max_lsa_ignore_count.yfilter != YFilter.not_set or
                                    self.max_lsa_ignore_limit.yfilter != YFilter.not_set or
                                    self.max_lsa_ignore_time.yfilter != YFilter.not_set or
                                    self.max_lsa_ignore_timer.yfilter != YFilter.not_set or
                                    self.max_lsa_limit.yfilter != YFilter.not_set or
                                    self.max_lsa_reset_time.yfilter != YFilter.not_set or
                                    self.max_lsa_reset_timer.yfilter != YFilter.not_set or
                                    self.max_lsa_treshold.yfilter != YFilter.not_set or
                                    self.max_lsa_warning_only.yfilter != YFilter.not_set or
                                    self.maximum_interfaces.yfilter != YFilter.not_set or
                                    self.maximum_metric_abr_off_buffer_time.yfilter != YFilter.not_set or
                                    self.maximum_metric_abr_off_mode.yfilter != YFilter.not_set or
                                    self.maximum_metric_abr_off_reasons.yfilter != YFilter.not_set or
                                    self.maximum_metric_set_reason.yfilter != YFilter.not_set or
                                    self.maximum_metric_start.yfilter != YFilter.not_set or
                                    self.maximum_metric_start_timer.yfilter != YFilter.not_set or
                                    self.microloop_avoidance_active.yfilter != YFilter.not_set or
                                    self.microloop_avoidance_delay.yfilter != YFilter.not_set or
                                    self.microloop_avoidance_delay_expiry.yfilter != YFilter.not_set or
                                    self.microloop_avoidance_type.yfilter != YFilter.not_set or
                                    self.minimum_lsa_arrival_interval.yfilter != YFilter.not_set or
                                    self.minimum_lsa_arrival_interval_u32.yfilter != YFilter.not_set or
                                    self.minimum_lsa_interval.yfilter != YFilter.not_set or
                                    self.minimum_lsa_interval_u32.yfilter != YFilter.not_set or
                                    self.non_self_lsa_count.yfilter != YFilter.not_set or
                                    self.normal_area_count.yfilter != YFilter.not_set or
                                    self.nsf_enabled.yfilter != YFilter.not_set or
                                    self.nsf_time.yfilter != YFilter.not_set or
                                    self.nsr_enabled.yfilter != YFilter.not_set or
                                    self.nsr_switchover_on_restart.yfilter != YFilter.not_set or
                                    self.nssa_area_count.yfilter != YFilter.not_set or
                                    self.number_nbrs_full.yfilter != YFilter.not_set or
                                    self.opaque_capable.yfilter != YFilter.not_set or
                                    self.opaque_lsa_checksum.yfilter != YFilter.not_set or
                                    self.opaque_lsa_count.yfilter != YFilter.not_set or
                                    self.redistribution_limit.yfilter != YFilter.not_set or
                                    self.redistribution_limit_warn.yfilter != YFilter.not_set or
                                    self.redistribution_threshold.yfilter != YFilter.not_set or
                                    self.role.yfilter != YFilter.not_set or
                                    self.role_standby.yfilter != YFilter.not_set or
                                    self.router_id.yfilter != YFilter.not_set or
                                    self.snmp_trap_enabled.yfilter != YFilter.not_set or
                                    self.spf_hold_time.yfilter != YFilter.not_set or
                                    self.spf_hold_time_u32.yfilter != YFilter.not_set or
                                    self.spf_maximum_time.yfilter != YFilter.not_set or
                                    self.spf_maximum_time_u32.yfilter != YFilter.not_set or
                                    self.spf_prefix_priority.yfilter != YFilter.not_set or
                                    self.spf_prefix_priority_route_policy.yfilter != YFilter.not_set or
                                    self.spf_start_time.yfilter != YFilter.not_set or
                                    self.spf_start_time_u32.yfilter != YFilter.not_set or
                                    self.sr_strict_spf_cap.yfilter != YFilter.not_set or
                                    self.srgb_configured.yfilter != YFilter.not_set or
                                    self.srgb_end.yfilter != YFilter.not_set or
                                    self.srgb_start.yfilter != YFilter.not_set or
                                    self.srgb_status.yfilter != YFilter.not_set or
                                    self.stub_area_count.yfilter != YFilter.not_set or
                                    self.table_prefix_limit_reached.yfilter != YFilter.not_set or
                                    self.tos_options.yfilter != YFilter.not_set or
                                    self.ucmp.yfilter != YFilter.not_set or
                                    self.ucmp_delay.yfilter != YFilter.not_set or
                                    self.ucmp_prefix_list.yfilter != YFilter.not_set or
                                    self.ucmp_variance.yfilter != YFilter.not_set or
                                    self.vrf_lite_enabled.yfilter != YFilter.not_set or
                                    (self.domain_id is not None and self.domain_id.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "process-summary" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.adj_stag_init_num_nbr.is_set or self.adj_stag_init_num_nbr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adj_stag_init_num_nbr.get_name_leafdata())
                                if (self.adj_stag_max_num_nbr.is_set or self.adj_stag_max_num_nbr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adj_stag_max_num_nbr.get_name_leafdata())
                                if (self.adj_stag_num_nbr_forming.is_set or self.adj_stag_num_nbr_forming.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adj_stag_num_nbr_forming.get_name_leafdata())
                                if (self.adj_stagger_enabled.is_set or self.adj_stagger_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adj_stagger_enabled.get_name_leafdata())
                                if (self.area_border_router.is_set or self.area_border_router.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_border_router.get_name_leafdata())
                                if (self.area_count.is_set or self.area_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_count.get_name_leafdata())
                                if (self.as_border_router.is_set or self.as_border_router.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_border_router.get_name_leafdata())
                                if (self.as_dc_bitless_lsa_count.is_set or self.as_dc_bitless_lsa_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_dc_bitless_lsa_count.get_name_leafdata())
                                if (self.as_dna_lsa_count.is_set or self.as_dna_lsa_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_dna_lsa_count.get_name_leafdata())
                                if (self.as_lsa_checksum.is_set or self.as_lsa_checksum.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_lsa_checksum.get_name_leafdata())
                                if (self.as_lsa_count.is_set or self.as_lsa_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_lsa_count.get_name_leafdata())
                                if (self.as_lsa_flood_list_length.is_set or self.as_lsa_flood_list_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_lsa_flood_list_length.get_name_leafdata())
                                if (self.context_name.is_set or self.context_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.context_name.get_name_leafdata())
                                if (self.graceful_shutdown_retention_time.is_set or self.graceful_shutdown_retention_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.graceful_shutdown_retention_time.get_name_leafdata())
                                if (self.graceful_shutdown_state.is_set or self.graceful_shutdown_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.graceful_shutdown_state.get_name_leafdata())
                                if (self.if_flood_pacing_interval.is_set or self.if_flood_pacing_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.if_flood_pacing_interval.get_name_leafdata())
                                if (self.if_retrans_pacing_interval.is_set or self.if_retrans_pacing_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.if_retrans_pacing_interval.get_name_leafdata())
                                if (self.igp_intact_on.is_set or self.igp_intact_on.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igp_intact_on.get_name_leafdata())
                                if (self.last_nsf_time.is_set or self.last_nsf_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_nsf_time.get_name_leafdata())
                                if (self.lsa_hold_time.is_set or self.lsa_hold_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsa_hold_time.get_name_leafdata())
                                if (self.lsa_maximum_time.is_set or self.lsa_maximum_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsa_maximum_time.get_name_leafdata())
                                if (self.lsa_refresh_interval.is_set or self.lsa_refresh_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsa_refresh_interval.get_name_leafdata())
                                if (self.lsa_start_time.is_set or self.lsa_start_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsa_start_time.get_name_leafdata())
                                if (self.lsd_bound.is_set or self.lsd_bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsd_bound.get_name_leafdata())
                                if (self.lsd_connected.is_set or self.lsd_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsd_connected.get_name_leafdata())
                                if (self.lsd_connection_revision.is_set or self.lsd_connection_revision.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsd_connection_revision.get_name_leafdata())
                                if (self.lsd_registered.is_set or self.lsd_registered.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsd_registered.get_name_leafdata())
                                if (self.max_lsa_enabled.is_set or self.max_lsa_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_lsa_enabled.get_name_leafdata())
                                if (self.max_lsa_ignore_count.is_set or self.max_lsa_ignore_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_lsa_ignore_count.get_name_leafdata())
                                if (self.max_lsa_ignore_limit.is_set or self.max_lsa_ignore_limit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_lsa_ignore_limit.get_name_leafdata())
                                if (self.max_lsa_ignore_time.is_set or self.max_lsa_ignore_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_lsa_ignore_time.get_name_leafdata())
                                if (self.max_lsa_ignore_timer.is_set or self.max_lsa_ignore_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_lsa_ignore_timer.get_name_leafdata())
                                if (self.max_lsa_limit.is_set or self.max_lsa_limit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_lsa_limit.get_name_leafdata())
                                if (self.max_lsa_reset_time.is_set or self.max_lsa_reset_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_lsa_reset_time.get_name_leafdata())
                                if (self.max_lsa_reset_timer.is_set or self.max_lsa_reset_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_lsa_reset_timer.get_name_leafdata())
                                if (self.max_lsa_treshold.is_set or self.max_lsa_treshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_lsa_treshold.get_name_leafdata())
                                if (self.max_lsa_warning_only.is_set or self.max_lsa_warning_only.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_lsa_warning_only.get_name_leafdata())
                                if (self.maximum_interfaces.is_set or self.maximum_interfaces.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_interfaces.get_name_leafdata())
                                if (self.maximum_metric_abr_off_buffer_time.is_set or self.maximum_metric_abr_off_buffer_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_abr_off_buffer_time.get_name_leafdata())
                                if (self.maximum_metric_abr_off_mode.is_set or self.maximum_metric_abr_off_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_abr_off_mode.get_name_leafdata())
                                if (self.maximum_metric_abr_off_reasons.is_set or self.maximum_metric_abr_off_reasons.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_abr_off_reasons.get_name_leafdata())
                                if (self.maximum_metric_set_reason.is_set or self.maximum_metric_set_reason.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_set_reason.get_name_leafdata())
                                if (self.maximum_metric_start.is_set or self.maximum_metric_start.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_start.get_name_leafdata())
                                if (self.maximum_metric_start_timer.is_set or self.maximum_metric_start_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_start_timer.get_name_leafdata())
                                if (self.microloop_avoidance_active.is_set or self.microloop_avoidance_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.microloop_avoidance_active.get_name_leafdata())
                                if (self.microloop_avoidance_delay.is_set or self.microloop_avoidance_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.microloop_avoidance_delay.get_name_leafdata())
                                if (self.microloop_avoidance_delay_expiry.is_set or self.microloop_avoidance_delay_expiry.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.microloop_avoidance_delay_expiry.get_name_leafdata())
                                if (self.microloop_avoidance_type.is_set or self.microloop_avoidance_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.microloop_avoidance_type.get_name_leafdata())
                                if (self.minimum_lsa_arrival_interval.is_set or self.minimum_lsa_arrival_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.minimum_lsa_arrival_interval.get_name_leafdata())
                                if (self.minimum_lsa_arrival_interval_u32.is_set or self.minimum_lsa_arrival_interval_u32.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.minimum_lsa_arrival_interval_u32.get_name_leafdata())
                                if (self.minimum_lsa_interval.is_set or self.minimum_lsa_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.minimum_lsa_interval.get_name_leafdata())
                                if (self.minimum_lsa_interval_u32.is_set or self.minimum_lsa_interval_u32.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.minimum_lsa_interval_u32.get_name_leafdata())
                                if (self.non_self_lsa_count.is_set or self.non_self_lsa_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.non_self_lsa_count.get_name_leafdata())
                                if (self.normal_area_count.is_set or self.normal_area_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.normal_area_count.get_name_leafdata())
                                if (self.nsf_enabled.is_set or self.nsf_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsf_enabled.get_name_leafdata())
                                if (self.nsf_time.is_set or self.nsf_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsf_time.get_name_leafdata())
                                if (self.nsr_enabled.is_set or self.nsr_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_enabled.get_name_leafdata())
                                if (self.nsr_switchover_on_restart.is_set or self.nsr_switchover_on_restart.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_switchover_on_restart.get_name_leafdata())
                                if (self.nssa_area_count.is_set or self.nssa_area_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nssa_area_count.get_name_leafdata())
                                if (self.number_nbrs_full.is_set or self.number_nbrs_full.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_nbrs_full.get_name_leafdata())
                                if (self.opaque_capable.is_set or self.opaque_capable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.opaque_capable.get_name_leafdata())
                                if (self.opaque_lsa_checksum.is_set or self.opaque_lsa_checksum.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.opaque_lsa_checksum.get_name_leafdata())
                                if (self.opaque_lsa_count.is_set or self.opaque_lsa_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.opaque_lsa_count.get_name_leafdata())
                                if (self.redistribution_limit.is_set or self.redistribution_limit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redistribution_limit.get_name_leafdata())
                                if (self.redistribution_limit_warn.is_set or self.redistribution_limit_warn.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redistribution_limit_warn.get_name_leafdata())
                                if (self.redistribution_threshold.is_set or self.redistribution_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redistribution_threshold.get_name_leafdata())
                                if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.role.get_name_leafdata())
                                if (self.role_standby.is_set or self.role_standby.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.role_standby.get_name_leafdata())
                                if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_id.get_name_leafdata())
                                if (self.snmp_trap_enabled.is_set or self.snmp_trap_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.snmp_trap_enabled.get_name_leafdata())
                                if (self.spf_hold_time.is_set or self.spf_hold_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spf_hold_time.get_name_leafdata())
                                if (self.spf_hold_time_u32.is_set or self.spf_hold_time_u32.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spf_hold_time_u32.get_name_leafdata())
                                if (self.spf_maximum_time.is_set or self.spf_maximum_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spf_maximum_time.get_name_leafdata())
                                if (self.spf_maximum_time_u32.is_set or self.spf_maximum_time_u32.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spf_maximum_time_u32.get_name_leafdata())
                                if (self.spf_prefix_priority.is_set or self.spf_prefix_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spf_prefix_priority.get_name_leafdata())
                                if (self.spf_prefix_priority_route_policy.is_set or self.spf_prefix_priority_route_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spf_prefix_priority_route_policy.get_name_leafdata())
                                if (self.spf_start_time.is_set or self.spf_start_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spf_start_time.get_name_leafdata())
                                if (self.spf_start_time_u32.is_set or self.spf_start_time_u32.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spf_start_time_u32.get_name_leafdata())
                                if (self.sr_strict_spf_cap.is_set or self.sr_strict_spf_cap.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sr_strict_spf_cap.get_name_leafdata())
                                if (self.srgb_configured.is_set or self.srgb_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.srgb_configured.get_name_leafdata())
                                if (self.srgb_end.is_set or self.srgb_end.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.srgb_end.get_name_leafdata())
                                if (self.srgb_start.is_set or self.srgb_start.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.srgb_start.get_name_leafdata())
                                if (self.srgb_status.is_set or self.srgb_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.srgb_status.get_name_leafdata())
                                if (self.stub_area_count.is_set or self.stub_area_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.stub_area_count.get_name_leafdata())
                                if (self.table_prefix_limit_reached.is_set or self.table_prefix_limit_reached.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_prefix_limit_reached.get_name_leafdata())
                                if (self.tos_options.is_set or self.tos_options.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tos_options.get_name_leafdata())
                                if (self.ucmp.is_set or self.ucmp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ucmp.get_name_leafdata())
                                if (self.ucmp_delay.is_set or self.ucmp_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ucmp_delay.get_name_leafdata())
                                if (self.ucmp_prefix_list.is_set or self.ucmp_prefix_list.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ucmp_prefix_list.get_name_leafdata())
                                if (self.ucmp_variance.is_set or self.ucmp_variance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ucmp_variance.get_name_leafdata())
                                if (self.vrf_lite_enabled.is_set or self.vrf_lite_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_lite_enabled.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "domain-id"):
                                    if (self.domain_id is None):
                                        self.domain_id = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId()
                                        self.domain_id.parent = self
                                        self._children_name_map["domain_id"] = "domain-id"
                                    return self.domain_id

                                if (child_yang_name == "maximum-metric"):
                                    for c in self.maximum_metric:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.maximum_metric.append(c)
                                    return c

                                if (child_yang_name == "redistribution"):
                                    for c in self.redistribution:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.redistribution.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "domain-id" or name == "maximum-metric" or name == "redistribution" or name == "adj-stag-init-num-nbr" or name == "adj-stag-max-num-nbr" or name == "adj-stag-num-nbr-forming" or name == "adj-stagger-enabled" or name == "area-border-router" or name == "area-count" or name == "as-border-router" or name == "as-dc-bitless-lsa-count" or name == "as-dna-lsa-count" or name == "as-lsa-checksum" or name == "as-lsa-count" or name == "as-lsa-flood-list-length" or name == "context-name" or name == "graceful-shutdown-retention-time" or name == "graceful-shutdown-state" or name == "if-flood-pacing-interval" or name == "if-retrans-pacing-interval" or name == "igp-intact-on" or name == "last-nsf-time" or name == "lsa-hold-time" or name == "lsa-maximum-time" or name == "lsa-refresh-interval" or name == "lsa-start-time" or name == "lsd-bound" or name == "lsd-connected" or name == "lsd-connection-revision" or name == "lsd-registered" or name == "max-lsa-enabled" or name == "max-lsa-ignore-count" or name == "max-lsa-ignore-limit" or name == "max-lsa-ignore-time" or name == "max-lsa-ignore-timer" or name == "max-lsa-limit" or name == "max-lsa-reset-time" or name == "max-lsa-reset-timer" or name == "max-lsa-treshold" or name == "max-lsa-warning-only" or name == "maximum-interfaces" or name == "maximum-metric-abr-off-buffer-time" or name == "maximum-metric-abr-off-mode" or name == "maximum-metric-abr-off-reasons" or name == "maximum-metric-set-reason" or name == "maximum-metric-start" or name == "maximum-metric-start-timer" or name == "microloop-avoidance-active" or name == "microloop-avoidance-delay" or name == "microloop-avoidance-delay-expiry" or name == "microloop-avoidance-type" or name == "minimum-lsa-arrival-interval" or name == "minimum-lsa-arrival-interval-u32" or name == "minimum-lsa-interval" or name == "minimum-lsa-interval-u32" or name == "non-self-lsa-count" or name == "normal-area-count" or name == "nsf-enabled" or name == "nsf-time" or name == "nsr-enabled" or name == "nsr-switchover-on-restart" or name == "nssa-area-count" or name == "number-nbrs-full" or name == "opaque-capable" or name == "opaque-lsa-checksum" or name == "opaque-lsa-count" or name == "redistribution-limit" or name == "redistribution-limit-warn" or name == "redistribution-threshold" or name == "role" or name == "role-standby" or name == "router-id" or name == "snmp-trap-enabled" or name == "spf-hold-time" or name == "spf-hold-time-u32" or name == "spf-maximum-time" or name == "spf-maximum-time-u32" or name == "spf-prefix-priority" or name == "spf-prefix-priority-route-policy" or name == "spf-start-time" or name == "spf-start-time-u32" or name == "sr-strict-spf-cap" or name == "srgb-configured" or name == "srgb-end" or name == "srgb-start" or name == "srgb-status" or name == "stub-area-count" or name == "table-prefix-limit-reached" or name == "tos-options" or name == "ucmp" or name == "ucmp-delay" or name == "ucmp-prefix-list" or name == "ucmp-variance" or name == "vrf-lite-enabled"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "adj-stag-init-num-nbr"):
                                    self.adj_stag_init_num_nbr = value
                                    self.adj_stag_init_num_nbr.value_namespace = name_space
                                    self.adj_stag_init_num_nbr.value_namespace_prefix = name_space_prefix
                                if(value_path == "adj-stag-max-num-nbr"):
                                    self.adj_stag_max_num_nbr = value
                                    self.adj_stag_max_num_nbr.value_namespace = name_space
                                    self.adj_stag_max_num_nbr.value_namespace_prefix = name_space_prefix
                                if(value_path == "adj-stag-num-nbr-forming"):
                                    self.adj_stag_num_nbr_forming = value
                                    self.adj_stag_num_nbr_forming.value_namespace = name_space
                                    self.adj_stag_num_nbr_forming.value_namespace_prefix = name_space_prefix
                                if(value_path == "adj-stagger-enabled"):
                                    self.adj_stagger_enabled = value
                                    self.adj_stagger_enabled.value_namespace = name_space
                                    self.adj_stagger_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-border-router"):
                                    self.area_border_router = value
                                    self.area_border_router.value_namespace = name_space
                                    self.area_border_router.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-count"):
                                    self.area_count = value
                                    self.area_count.value_namespace = name_space
                                    self.area_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "as-border-router"):
                                    self.as_border_router = value
                                    self.as_border_router.value_namespace = name_space
                                    self.as_border_router.value_namespace_prefix = name_space_prefix
                                if(value_path == "as-dc-bitless-lsa-count"):
                                    self.as_dc_bitless_lsa_count = value
                                    self.as_dc_bitless_lsa_count.value_namespace = name_space
                                    self.as_dc_bitless_lsa_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "as-dna-lsa-count"):
                                    self.as_dna_lsa_count = value
                                    self.as_dna_lsa_count.value_namespace = name_space
                                    self.as_dna_lsa_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "as-lsa-checksum"):
                                    self.as_lsa_checksum = value
                                    self.as_lsa_checksum.value_namespace = name_space
                                    self.as_lsa_checksum.value_namespace_prefix = name_space_prefix
                                if(value_path == "as-lsa-count"):
                                    self.as_lsa_count = value
                                    self.as_lsa_count.value_namespace = name_space
                                    self.as_lsa_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "as-lsa-flood-list-length"):
                                    self.as_lsa_flood_list_length = value
                                    self.as_lsa_flood_list_length.value_namespace = name_space
                                    self.as_lsa_flood_list_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "context-name"):
                                    self.context_name = value
                                    self.context_name.value_namespace = name_space
                                    self.context_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "graceful-shutdown-retention-time"):
                                    self.graceful_shutdown_retention_time = value
                                    self.graceful_shutdown_retention_time.value_namespace = name_space
                                    self.graceful_shutdown_retention_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "graceful-shutdown-state"):
                                    self.graceful_shutdown_state = value
                                    self.graceful_shutdown_state.value_namespace = name_space
                                    self.graceful_shutdown_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "if-flood-pacing-interval"):
                                    self.if_flood_pacing_interval = value
                                    self.if_flood_pacing_interval.value_namespace = name_space
                                    self.if_flood_pacing_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "if-retrans-pacing-interval"):
                                    self.if_retrans_pacing_interval = value
                                    self.if_retrans_pacing_interval.value_namespace = name_space
                                    self.if_retrans_pacing_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "igp-intact-on"):
                                    self.igp_intact_on = value
                                    self.igp_intact_on.value_namespace = name_space
                                    self.igp_intact_on.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-nsf-time"):
                                    self.last_nsf_time = value
                                    self.last_nsf_time.value_namespace = name_space
                                    self.last_nsf_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsa-hold-time"):
                                    self.lsa_hold_time = value
                                    self.lsa_hold_time.value_namespace = name_space
                                    self.lsa_hold_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsa-maximum-time"):
                                    self.lsa_maximum_time = value
                                    self.lsa_maximum_time.value_namespace = name_space
                                    self.lsa_maximum_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsa-refresh-interval"):
                                    self.lsa_refresh_interval = value
                                    self.lsa_refresh_interval.value_namespace = name_space
                                    self.lsa_refresh_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsa-start-time"):
                                    self.lsa_start_time = value
                                    self.lsa_start_time.value_namespace = name_space
                                    self.lsa_start_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsd-bound"):
                                    self.lsd_bound = value
                                    self.lsd_bound.value_namespace = name_space
                                    self.lsd_bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsd-connected"):
                                    self.lsd_connected = value
                                    self.lsd_connected.value_namespace = name_space
                                    self.lsd_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsd-connection-revision"):
                                    self.lsd_connection_revision = value
                                    self.lsd_connection_revision.value_namespace = name_space
                                    self.lsd_connection_revision.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsd-registered"):
                                    self.lsd_registered = value
                                    self.lsd_registered.value_namespace = name_space
                                    self.lsd_registered.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-lsa-enabled"):
                                    self.max_lsa_enabled = value
                                    self.max_lsa_enabled.value_namespace = name_space
                                    self.max_lsa_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-lsa-ignore-count"):
                                    self.max_lsa_ignore_count = value
                                    self.max_lsa_ignore_count.value_namespace = name_space
                                    self.max_lsa_ignore_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-lsa-ignore-limit"):
                                    self.max_lsa_ignore_limit = value
                                    self.max_lsa_ignore_limit.value_namespace = name_space
                                    self.max_lsa_ignore_limit.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-lsa-ignore-time"):
                                    self.max_lsa_ignore_time = value
                                    self.max_lsa_ignore_time.value_namespace = name_space
                                    self.max_lsa_ignore_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-lsa-ignore-timer"):
                                    self.max_lsa_ignore_timer = value
                                    self.max_lsa_ignore_timer.value_namespace = name_space
                                    self.max_lsa_ignore_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-lsa-limit"):
                                    self.max_lsa_limit = value
                                    self.max_lsa_limit.value_namespace = name_space
                                    self.max_lsa_limit.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-lsa-reset-time"):
                                    self.max_lsa_reset_time = value
                                    self.max_lsa_reset_time.value_namespace = name_space
                                    self.max_lsa_reset_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-lsa-reset-timer"):
                                    self.max_lsa_reset_timer = value
                                    self.max_lsa_reset_timer.value_namespace = name_space
                                    self.max_lsa_reset_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-lsa-treshold"):
                                    self.max_lsa_treshold = value
                                    self.max_lsa_treshold.value_namespace = name_space
                                    self.max_lsa_treshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-lsa-warning-only"):
                                    self.max_lsa_warning_only = value
                                    self.max_lsa_warning_only.value_namespace = name_space
                                    self.max_lsa_warning_only.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-interfaces"):
                                    self.maximum_interfaces = value
                                    self.maximum_interfaces.value_namespace = name_space
                                    self.maximum_interfaces.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-abr-off-buffer-time"):
                                    self.maximum_metric_abr_off_buffer_time = value
                                    self.maximum_metric_abr_off_buffer_time.value_namespace = name_space
                                    self.maximum_metric_abr_off_buffer_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-abr-off-mode"):
                                    self.maximum_metric_abr_off_mode = value
                                    self.maximum_metric_abr_off_mode.value_namespace = name_space
                                    self.maximum_metric_abr_off_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-abr-off-reasons"):
                                    self.maximum_metric_abr_off_reasons = value
                                    self.maximum_metric_abr_off_reasons.value_namespace = name_space
                                    self.maximum_metric_abr_off_reasons.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-set-reason"):
                                    self.maximum_metric_set_reason = value
                                    self.maximum_metric_set_reason.value_namespace = name_space
                                    self.maximum_metric_set_reason.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-start"):
                                    self.maximum_metric_start = value
                                    self.maximum_metric_start.value_namespace = name_space
                                    self.maximum_metric_start.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-start-timer"):
                                    self.maximum_metric_start_timer = value
                                    self.maximum_metric_start_timer.value_namespace = name_space
                                    self.maximum_metric_start_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "microloop-avoidance-active"):
                                    self.microloop_avoidance_active = value
                                    self.microloop_avoidance_active.value_namespace = name_space
                                    self.microloop_avoidance_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "microloop-avoidance-delay"):
                                    self.microloop_avoidance_delay = value
                                    self.microloop_avoidance_delay.value_namespace = name_space
                                    self.microloop_avoidance_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "microloop-avoidance-delay-expiry"):
                                    self.microloop_avoidance_delay_expiry = value
                                    self.microloop_avoidance_delay_expiry.value_namespace = name_space
                                    self.microloop_avoidance_delay_expiry.value_namespace_prefix = name_space_prefix
                                if(value_path == "microloop-avoidance-type"):
                                    self.microloop_avoidance_type = value
                                    self.microloop_avoidance_type.value_namespace = name_space
                                    self.microloop_avoidance_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "minimum-lsa-arrival-interval"):
                                    self.minimum_lsa_arrival_interval = value
                                    self.minimum_lsa_arrival_interval.value_namespace = name_space
                                    self.minimum_lsa_arrival_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "minimum-lsa-arrival-interval-u32"):
                                    self.minimum_lsa_arrival_interval_u32 = value
                                    self.minimum_lsa_arrival_interval_u32.value_namespace = name_space
                                    self.minimum_lsa_arrival_interval_u32.value_namespace_prefix = name_space_prefix
                                if(value_path == "minimum-lsa-interval"):
                                    self.minimum_lsa_interval = value
                                    self.minimum_lsa_interval.value_namespace = name_space
                                    self.minimum_lsa_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "minimum-lsa-interval-u32"):
                                    self.minimum_lsa_interval_u32 = value
                                    self.minimum_lsa_interval_u32.value_namespace = name_space
                                    self.minimum_lsa_interval_u32.value_namespace_prefix = name_space_prefix
                                if(value_path == "non-self-lsa-count"):
                                    self.non_self_lsa_count = value
                                    self.non_self_lsa_count.value_namespace = name_space
                                    self.non_self_lsa_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "normal-area-count"):
                                    self.normal_area_count = value
                                    self.normal_area_count.value_namespace = name_space
                                    self.normal_area_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsf-enabled"):
                                    self.nsf_enabled = value
                                    self.nsf_enabled.value_namespace = name_space
                                    self.nsf_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsf-time"):
                                    self.nsf_time = value
                                    self.nsf_time.value_namespace = name_space
                                    self.nsf_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-enabled"):
                                    self.nsr_enabled = value
                                    self.nsr_enabled.value_namespace = name_space
                                    self.nsr_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-switchover-on-restart"):
                                    self.nsr_switchover_on_restart = value
                                    self.nsr_switchover_on_restart.value_namespace = name_space
                                    self.nsr_switchover_on_restart.value_namespace_prefix = name_space_prefix
                                if(value_path == "nssa-area-count"):
                                    self.nssa_area_count = value
                                    self.nssa_area_count.value_namespace = name_space
                                    self.nssa_area_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-nbrs-full"):
                                    self.number_nbrs_full = value
                                    self.number_nbrs_full.value_namespace = name_space
                                    self.number_nbrs_full.value_namespace_prefix = name_space_prefix
                                if(value_path == "opaque-capable"):
                                    self.opaque_capable = value
                                    self.opaque_capable.value_namespace = name_space
                                    self.opaque_capable.value_namespace_prefix = name_space_prefix
                                if(value_path == "opaque-lsa-checksum"):
                                    self.opaque_lsa_checksum = value
                                    self.opaque_lsa_checksum.value_namespace = name_space
                                    self.opaque_lsa_checksum.value_namespace_prefix = name_space_prefix
                                if(value_path == "opaque-lsa-count"):
                                    self.opaque_lsa_count = value
                                    self.opaque_lsa_count.value_namespace = name_space
                                    self.opaque_lsa_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "redistribution-limit"):
                                    self.redistribution_limit = value
                                    self.redistribution_limit.value_namespace = name_space
                                    self.redistribution_limit.value_namespace_prefix = name_space_prefix
                                if(value_path == "redistribution-limit-warn"):
                                    self.redistribution_limit_warn = value
                                    self.redistribution_limit_warn.value_namespace = name_space
                                    self.redistribution_limit_warn.value_namespace_prefix = name_space_prefix
                                if(value_path == "redistribution-threshold"):
                                    self.redistribution_threshold = value
                                    self.redistribution_threshold.value_namespace = name_space
                                    self.redistribution_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "role"):
                                    self.role = value
                                    self.role.value_namespace = name_space
                                    self.role.value_namespace_prefix = name_space_prefix
                                if(value_path == "role-standby"):
                                    self.role_standby = value
                                    self.role_standby.value_namespace = name_space
                                    self.role_standby.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-id"):
                                    self.router_id = value
                                    self.router_id.value_namespace = name_space
                                    self.router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "snmp-trap-enabled"):
                                    self.snmp_trap_enabled = value
                                    self.snmp_trap_enabled.value_namespace = name_space
                                    self.snmp_trap_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "spf-hold-time"):
                                    self.spf_hold_time = value
                                    self.spf_hold_time.value_namespace = name_space
                                    self.spf_hold_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "spf-hold-time-u32"):
                                    self.spf_hold_time_u32 = value
                                    self.spf_hold_time_u32.value_namespace = name_space
                                    self.spf_hold_time_u32.value_namespace_prefix = name_space_prefix
                                if(value_path == "spf-maximum-time"):
                                    self.spf_maximum_time = value
                                    self.spf_maximum_time.value_namespace = name_space
                                    self.spf_maximum_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "spf-maximum-time-u32"):
                                    self.spf_maximum_time_u32 = value
                                    self.spf_maximum_time_u32.value_namespace = name_space
                                    self.spf_maximum_time_u32.value_namespace_prefix = name_space_prefix
                                if(value_path == "spf-prefix-priority"):
                                    self.spf_prefix_priority = value
                                    self.spf_prefix_priority.value_namespace = name_space
                                    self.spf_prefix_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "spf-prefix-priority-route-policy"):
                                    self.spf_prefix_priority_route_policy = value
                                    self.spf_prefix_priority_route_policy.value_namespace = name_space
                                    self.spf_prefix_priority_route_policy.value_namespace_prefix = name_space_prefix
                                if(value_path == "spf-start-time"):
                                    self.spf_start_time = value
                                    self.spf_start_time.value_namespace = name_space
                                    self.spf_start_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "spf-start-time-u32"):
                                    self.spf_start_time_u32 = value
                                    self.spf_start_time_u32.value_namespace = name_space
                                    self.spf_start_time_u32.value_namespace_prefix = name_space_prefix
                                if(value_path == "sr-strict-spf-cap"):
                                    self.sr_strict_spf_cap = value
                                    self.sr_strict_spf_cap.value_namespace = name_space
                                    self.sr_strict_spf_cap.value_namespace_prefix = name_space_prefix
                                if(value_path == "srgb-configured"):
                                    self.srgb_configured = value
                                    self.srgb_configured.value_namespace = name_space
                                    self.srgb_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "srgb-end"):
                                    self.srgb_end = value
                                    self.srgb_end.value_namespace = name_space
                                    self.srgb_end.value_namespace_prefix = name_space_prefix
                                if(value_path == "srgb-start"):
                                    self.srgb_start = value
                                    self.srgb_start.value_namespace = name_space
                                    self.srgb_start.value_namespace_prefix = name_space_prefix
                                if(value_path == "srgb-status"):
                                    self.srgb_status = value
                                    self.srgb_status.value_namespace = name_space
                                    self.srgb_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "stub-area-count"):
                                    self.stub_area_count = value
                                    self.stub_area_count.value_namespace = name_space
                                    self.stub_area_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-prefix-limit-reached"):
                                    self.table_prefix_limit_reached = value
                                    self.table_prefix_limit_reached.value_namespace = name_space
                                    self.table_prefix_limit_reached.value_namespace_prefix = name_space_prefix
                                if(value_path == "tos-options"):
                                    self.tos_options = value
                                    self.tos_options.value_namespace = name_space
                                    self.tos_options.value_namespace_prefix = name_space_prefix
                                if(value_path == "ucmp"):
                                    self.ucmp = value
                                    self.ucmp.value_namespace = name_space
                                    self.ucmp.value_namespace_prefix = name_space_prefix
                                if(value_path == "ucmp-delay"):
                                    self.ucmp_delay = value
                                    self.ucmp_delay.value_namespace = name_space
                                    self.ucmp_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "ucmp-prefix-list"):
                                    self.ucmp_prefix_list = value
                                    self.ucmp_prefix_list.value_namespace = name_space
                                    self.ucmp_prefix_list.value_namespace_prefix = name_space_prefix
                                if(value_path == "ucmp-variance"):
                                    self.ucmp_variance = value
                                    self.ucmp_variance.value_namespace = name_space
                                    self.ucmp_variance.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-lite-enabled"):
                                    self.vrf_lite_enabled = value
                                    self.vrf_lite_enabled.value_namespace = name_space
                                    self.vrf_lite_enabled.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.process_areas is not None and self.process_areas.has_data()) or
                                (self.process_summary is not None and self.process_summary.has_data()) or
                                (self.protocol_areas is not None and self.protocol_areas.has_data()) or
                                (self.protocol_summary is not None and self.protocol_summary.has_data()) or
                                (self.redistributions is not None and self.redistributions.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.process_areas is not None and self.process_areas.has_operation()) or
                                (self.process_summary is not None and self.process_summary.has_operation()) or
                                (self.protocol_areas is not None and self.protocol_areas.has_operation()) or
                                (self.protocol_summary is not None and self.protocol_summary.has_operation()) or
                                (self.redistributions is not None and self.redistributions.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "process-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "process-areas"):
                                if (self.process_areas is None):
                                    self.process_areas = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas()
                                    self.process_areas.parent = self
                                    self._children_name_map["process_areas"] = "process-areas"
                                return self.process_areas

                            if (child_yang_name == "process-summary"):
                                if (self.process_summary is None):
                                    self.process_summary = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary()
                                    self.process_summary.parent = self
                                    self._children_name_map["process_summary"] = "process-summary"
                                return self.process_summary

                            if (child_yang_name == "protocol-areas"):
                                if (self.protocol_areas is None):
                                    self.protocol_areas = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas()
                                    self.protocol_areas.parent = self
                                    self._children_name_map["protocol_areas"] = "protocol-areas"
                                return self.protocol_areas

                            if (child_yang_name == "protocol-summary"):
                                if (self.protocol_summary is None):
                                    self.protocol_summary = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolSummary()
                                    self.protocol_summary.parent = self
                                    self._children_name_map["protocol_summary"] = "protocol-summary"
                                return self.protocol_summary

                            if (child_yang_name == "redistributions"):
                                if (self.redistributions is None):
                                    self.redistributions = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions()
                                    self.redistributions.parent = self
                                    self._children_name_map["redistributions"] = "redistributions"
                                return self.redistributions

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "process-areas" or name == "process-summary" or name == "protocol-areas" or name == "protocol-summary" or name == "redistributions"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Areas(Entity):
                        """
                        Area table
                        
                        .. attribute:: area
                        
                        	Container for per area data
                        	**type**\: list of    :py:class:`Area <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas, self).__init__()

                            self.yang_name = "areas"
                            self.yang_parent_name = "vrf"

                            self.area = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas, self).__setattr__(name, value)


                        class Area(Entity):
                            """
                            Container for per area data
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: area_statistics
                            
                            	Container for Statistics
                            	**type**\:   :py:class:`AreaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics>`
                            
                            .. attribute:: flood_list_area_table
                            
                            	Area specific flood list table
                            	**type**\:   :py:class:`FloodListAreaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable>`
                            
                            .. attribute:: interface_briefs
                            
                            	OSPF Interface Brief Table
                            	**type**\:   :py:class:`InterfaceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs>`
                            
                            .. attribute:: interfaces
                            
                            	OSPF Interface Table
                            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces>`
                            
                            .. attribute:: neighbor_details
                            
                            	Neighbor detail table
                            	**type**\:   :py:class:`NeighborDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails>`
                            
                            .. attribute:: neighbors
                            
                            	Neighbor table
                            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors>`
                            
                            .. attribute:: requests
                            
                            	Request List table
                            	**type**\:   :py:class:`Requests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests>`
                            
                            .. attribute:: retransmissions
                            
                            	Retransmission list table
                            	**type**\:   :py:class:`Retransmissions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "areas"

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.area_statistics = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics()
                                self.area_statistics.parent = self
                                self._children_name_map["area_statistics"] = "area-statistics"
                                self._children_yang_names.add("area-statistics")

                                self.flood_list_area_table = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable()
                                self.flood_list_area_table.parent = self
                                self._children_name_map["flood_list_area_table"] = "flood-list-area-table"
                                self._children_yang_names.add("flood-list-area-table")

                                self.interface_briefs = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs()
                                self.interface_briefs.parent = self
                                self._children_name_map["interface_briefs"] = "interface-briefs"
                                self._children_yang_names.add("interface-briefs")

                                self.interfaces = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces()
                                self.interfaces.parent = self
                                self._children_name_map["interfaces"] = "interfaces"
                                self._children_yang_names.add("interfaces")

                                self.neighbor_details = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails()
                                self.neighbor_details.parent = self
                                self._children_name_map["neighbor_details"] = "neighbor-details"
                                self._children_yang_names.add("neighbor-details")

                                self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors()
                                self.neighbors.parent = self
                                self._children_name_map["neighbors"] = "neighbors"
                                self._children_yang_names.add("neighbors")

                                self.requests = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests()
                                self.requests.parent = self
                                self._children_name_map["requests"] = "requests"
                                self._children_yang_names.add("requests")

                                self.retransmissions = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions()
                                self.retransmissions.parent = self
                                self._children_name_map["retransmissions"] = "retransmissions"
                                self._children_yang_names.add("retransmissions")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("area_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area, self).__setattr__(name, value)


                            class FloodListAreaTable(Entity):
                                """
                                Area specific flood list table
                                
                                .. attribute:: flood
                                
                                	Flooding information for a specific interface
                                	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable, self).__init__()

                                    self.yang_name = "flood-list-area-table"
                                    self.yang_parent_name = "area"

                                    self.flood = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable, self).__setattr__(name, value)


                                class Flood(Entity):
                                    """
                                    Flooding information for a specific interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: area_flood
                                    
                                    	Area scope floodlist
                                    	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood>`
                                    
                                    .. attribute:: as_flood
                                    
                                    	AS scope floodlist
                                    	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AsFlood>`
                                    
                                    .. attribute:: flood_interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: flood_lsa_count
                                    
                                    	Number of LSAs currently being flooded
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flood_pacing_timer
                                    
                                    	Time until next LS update due (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood, self).__init__()

                                        self.yang_name = "flood"
                                        self.yang_parent_name = "flood-list-area-table"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.flood_interface_name = YLeaf(YType.str, "flood-interface-name")

                                        self.flood_lsa_count = YLeaf(YType.uint32, "flood-lsa-count")

                                        self.flood_pacing_timer = YLeaf(YType.uint32, "flood-pacing-timer")

                                        self.area_flood = YList(self)
                                        self.as_flood = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name",
                                                        "flood_interface_name",
                                                        "flood_lsa_count",
                                                        "flood_pacing_timer") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood, self).__setattr__(name, value)


                                    class AreaFlood(Entity):
                                        """
                                        Area scope floodlist
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_ls_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_checksum
                                        
                                        	Checksum of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA Type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood, self).__init__()

                                            self.yang_name = "area-flood"
                                            self.yang_parent_name = "flood"

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("header_advertising_router",
                                                            "header_ls_id",
                                                            "header_lsa_age",
                                                            "header_lsa_checksum",
                                                            "header_lsa_type",
                                                            "header_sequence_number") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.header_advertising_router.is_set or
                                                self.header_ls_id.is_set or
                                                self.header_lsa_age.is_set or
                                                self.header_lsa_checksum.is_set or
                                                self.header_lsa_type.is_set or
                                                self.header_sequence_number.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.header_advertising_router.yfilter != YFilter.not_set or
                                                self.header_ls_id.yfilter != YFilter.not_set or
                                                self.header_lsa_age.yfilter != YFilter.not_set or
                                                self.header_lsa_checksum.yfilter != YFilter.not_set or
                                                self.header_lsa_type.yfilter != YFilter.not_set or
                                                self.header_sequence_number.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "area-flood" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                            if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                            if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                            if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                            if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                            if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "header-advertising-router"):
                                                self.header_advertising_router = value
                                                self.header_advertising_router.value_namespace = name_space
                                                self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-ls-id"):
                                                self.header_ls_id = value
                                                self.header_ls_id.value_namespace = name_space
                                                self.header_ls_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-age"):
                                                self.header_lsa_age = value
                                                self.header_lsa_age.value_namespace = name_space
                                                self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-checksum"):
                                                self.header_lsa_checksum = value
                                                self.header_lsa_checksum.value_namespace = name_space
                                                self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-type"):
                                                self.header_lsa_type = value
                                                self.header_lsa_type.value_namespace = name_space
                                                self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-sequence-number"):
                                                self.header_sequence_number = value
                                                self.header_sequence_number.value_namespace = name_space
                                                self.header_sequence_number.value_namespace_prefix = name_space_prefix


                                    class AsFlood(Entity):
                                        """
                                        AS scope floodlist
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_ls_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_checksum
                                        
                                        	Checksum of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA Type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AsFlood, self).__init__()

                                            self.yang_name = "as-flood"
                                            self.yang_parent_name = "flood"

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("header_advertising_router",
                                                            "header_ls_id",
                                                            "header_lsa_age",
                                                            "header_lsa_checksum",
                                                            "header_lsa_type",
                                                            "header_sequence_number") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AsFlood, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AsFlood, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.header_advertising_router.is_set or
                                                self.header_ls_id.is_set or
                                                self.header_lsa_age.is_set or
                                                self.header_lsa_checksum.is_set or
                                                self.header_lsa_type.is_set or
                                                self.header_sequence_number.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.header_advertising_router.yfilter != YFilter.not_set or
                                                self.header_ls_id.yfilter != YFilter.not_set or
                                                self.header_lsa_age.yfilter != YFilter.not_set or
                                                self.header_lsa_checksum.yfilter != YFilter.not_set or
                                                self.header_lsa_type.yfilter != YFilter.not_set or
                                                self.header_sequence_number.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "as-flood" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                            if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                            if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                            if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                            if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                            if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "header-advertising-router"):
                                                self.header_advertising_router = value
                                                self.header_advertising_router.value_namespace = name_space
                                                self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-ls-id"):
                                                self.header_ls_id = value
                                                self.header_ls_id.value_namespace = name_space
                                                self.header_ls_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-age"):
                                                self.header_lsa_age = value
                                                self.header_lsa_age.value_namespace = name_space
                                                self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-checksum"):
                                                self.header_lsa_checksum = value
                                                self.header_lsa_checksum.value_namespace = name_space
                                                self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-type"):
                                                self.header_lsa_type = value
                                                self.header_lsa_type.value_namespace = name_space
                                                self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-sequence-number"):
                                                self.header_sequence_number = value
                                                self.header_sequence_number.value_namespace = name_space
                                                self.header_sequence_number.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.area_flood:
                                            if (c.has_data()):
                                                return True
                                        for c in self.as_flood:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_name.is_set or
                                            self.flood_interface_name.is_set or
                                            self.flood_lsa_count.is_set or
                                            self.flood_pacing_timer.is_set)

                                    def has_operation(self):
                                        for c in self.area_flood:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.as_flood:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.flood_interface_name.yfilter != YFilter.not_set or
                                            self.flood_lsa_count.yfilter != YFilter.not_set or
                                            self.flood_pacing_timer.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "flood" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.flood_interface_name.is_set or self.flood_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_interface_name.get_name_leafdata())
                                        if (self.flood_lsa_count.is_set or self.flood_lsa_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_lsa_count.get_name_leafdata())
                                        if (self.flood_pacing_timer.is_set or self.flood_pacing_timer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_pacing_timer.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "area-flood"):
                                            for c in self.area_flood:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.area_flood.append(c)
                                            return c

                                        if (child_yang_name == "as-flood"):
                                            for c in self.as_flood:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AsFlood()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.as_flood.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "area-flood" or name == "as-flood" or name == "interface-name" or name == "flood-interface-name" or name == "flood-lsa-count" or name == "flood-pacing-timer"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-interface-name"):
                                            self.flood_interface_name = value
                                            self.flood_interface_name.value_namespace = name_space
                                            self.flood_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-lsa-count"):
                                            self.flood_lsa_count = value
                                            self.flood_lsa_count.value_namespace = name_space
                                            self.flood_lsa_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-pacing-timer"):
                                            self.flood_pacing_timer = value
                                            self.flood_pacing_timer.value_namespace = name_space
                                            self.flood_pacing_timer.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.flood:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.flood:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flood-list-area-table" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "flood"):
                                        for c in self.flood:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.flood.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "flood"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class Neighbors(Entity):
                                """
                                Neighbor table
                                
                                .. attribute:: neighbor
                                
                                	Neighbor information
                                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors, self).__init__()

                                    self.yang_name = "neighbors"
                                    self.yang_parent_name = "area"

                                    self.neighbor = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors, self).__setattr__(name, value)


                                class Neighbor(Entity):
                                    """
                                    Neighbor information
                                    
                                    .. attribute:: dr_bdr_state
                                    
                                    	Designated Router state
                                    	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bfd_information
                                    
                                    	Neighbor BFD information
                                    	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation>`
                                    
                                    .. attribute:: neighbor_dead_timer
                                    
                                    	Time until neighbor's dead timer expires (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_dr_priority
                                    
                                    	Neighbor's DR priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_id
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_interface_name
                                    
                                    	Interface via which the neighbor is seen
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: neighbor_madj_interface
                                    
                                    	Interface is MADJ
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_state
                                    
                                    	Neighbor's state
                                    	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                    
                                    .. attribute:: neighbor_up_time
                                    
                                    	Amount of time since the adjacency is up (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "neighbors"

                                        self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                        self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                        self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                        self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                        self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                        self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                        self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                        self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                        self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation()
                                        self.neighbor_bfd_information.parent = self
                                        self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                        self._children_yang_names.add("neighbor-bfd-information")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dr_bdr_state",
                                                        "interface_name",
                                                        "neighbor_address",
                                                        "neighbor_address_xr",
                                                        "neighbor_dead_timer",
                                                        "neighbor_dr_priority",
                                                        "neighbor_id",
                                                        "neighbor_interface_name",
                                                        "neighbor_madj_interface",
                                                        "neighbor_state",
                                                        "neighbor_up_time") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor, self).__setattr__(name, value)


                                    class NeighborBfdInformation(Entity):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation, self).__init__()

                                            self.yang_name = "neighbor-bfd-information"
                                            self.yang_parent_name = "neighbor"

                                            self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                            self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bfd_intf_enable_mode",
                                                            "bfd_status_flag") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bfd_intf_enable_mode.is_set or
                                                self.bfd_status_flag.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                                self.bfd_status_flag.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor-bfd-information" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                            if (self.bfd_status_flag.is_set or self.bfd_status_flag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_status_flag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bfd-intf-enable-mode" or name == "bfd-status-flag"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bfd-intf-enable-mode"):
                                                self.bfd_intf_enable_mode = value
                                                self.bfd_intf_enable_mode.value_namespace = name_space
                                                self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-status-flag"):
                                                self.bfd_status_flag = value
                                                self.bfd_status_flag.value_namespace = name_space
                                                self.bfd_status_flag.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.dr_bdr_state.is_set or
                                            self.interface_name.is_set or
                                            self.neighbor_address.is_set or
                                            self.neighbor_address_xr.is_set or
                                            self.neighbor_dead_timer.is_set or
                                            self.neighbor_dr_priority.is_set or
                                            self.neighbor_id.is_set or
                                            self.neighbor_interface_name.is_set or
                                            self.neighbor_madj_interface.is_set or
                                            self.neighbor_state.is_set or
                                            self.neighbor_up_time.is_set or
                                            (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dr_bdr_state.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.neighbor_address.yfilter != YFilter.not_set or
                                            self.neighbor_address_xr.yfilter != YFilter.not_set or
                                            self.neighbor_dead_timer.yfilter != YFilter.not_set or
                                            self.neighbor_dr_priority.yfilter != YFilter.not_set or
                                            self.neighbor_id.yfilter != YFilter.not_set or
                                            self.neighbor_interface_name.yfilter != YFilter.not_set or
                                            self.neighbor_madj_interface.yfilter != YFilter.not_set or
                                            self.neighbor_state.yfilter != YFilter.not_set or
                                            self.neighbor_up_time.yfilter != YFilter.not_set or
                                            (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dr_bdr_state.is_set or self.dr_bdr_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dr_bdr_state.get_name_leafdata())
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                        if (self.neighbor_address_xr.is_set or self.neighbor_address_xr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_address_xr.get_name_leafdata())
                                        if (self.neighbor_dead_timer.is_set or self.neighbor_dead_timer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_dead_timer.get_name_leafdata())
                                        if (self.neighbor_dr_priority.is_set or self.neighbor_dr_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_dr_priority.get_name_leafdata())
                                        if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                        if (self.neighbor_interface_name.is_set or self.neighbor_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_interface_name.get_name_leafdata())
                                        if (self.neighbor_madj_interface.is_set or self.neighbor_madj_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_madj_interface.get_name_leafdata())
                                        if (self.neighbor_state.is_set or self.neighbor_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_state.get_name_leafdata())
                                        if (self.neighbor_up_time.is_set or self.neighbor_up_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_up_time.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "neighbor-bfd-information"):
                                            if (self.neighbor_bfd_information is None):
                                                self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation()
                                                self.neighbor_bfd_information.parent = self
                                                self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                            return self.neighbor_bfd_information

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "neighbor-bfd-information" or name == "dr-bdr-state" or name == "interface-name" or name == "neighbor-address" or name == "neighbor-address-xr" or name == "neighbor-dead-timer" or name == "neighbor-dr-priority" or name == "neighbor-id" or name == "neighbor-interface-name" or name == "neighbor-madj-interface" or name == "neighbor-state" or name == "neighbor-up-time"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dr-bdr-state"):
                                            self.dr_bdr_state = value
                                            self.dr_bdr_state.value_namespace = name_space
                                            self.dr_bdr_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-address"):
                                            self.neighbor_address = value
                                            self.neighbor_address.value_namespace = name_space
                                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-address-xr"):
                                            self.neighbor_address_xr = value
                                            self.neighbor_address_xr.value_namespace = name_space
                                            self.neighbor_address_xr.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-dead-timer"):
                                            self.neighbor_dead_timer = value
                                            self.neighbor_dead_timer.value_namespace = name_space
                                            self.neighbor_dead_timer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-dr-priority"):
                                            self.neighbor_dr_priority = value
                                            self.neighbor_dr_priority.value_namespace = name_space
                                            self.neighbor_dr_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-id"):
                                            self.neighbor_id = value
                                            self.neighbor_id.value_namespace = name_space
                                            self.neighbor_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-interface-name"):
                                            self.neighbor_interface_name = value
                                            self.neighbor_interface_name.value_namespace = name_space
                                            self.neighbor_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-madj-interface"):
                                            self.neighbor_madj_interface = value
                                            self.neighbor_madj_interface.value_namespace = name_space
                                            self.neighbor_madj_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-state"):
                                            self.neighbor_state = value
                                            self.neighbor_state.value_namespace = name_space
                                            self.neighbor_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-up-time"):
                                            self.neighbor_up_time = value
                                            self.neighbor_up_time.value_namespace = name_space
                                            self.neighbor_up_time.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.neighbor:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.neighbor:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "neighbors" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "neighbor"):
                                        for c in self.neighbor:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.neighbor.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "neighbor"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class InterfaceBriefs(Entity):
                                """
                                OSPF Interface Brief Table
                                
                                .. attribute:: interface_brief
                                
                                	OSPF interface brief information
                                	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs, self).__init__()

                                    self.yang_name = "interface-briefs"
                                    self.yang_parent_name = "area"

                                    self.interface_brief = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs, self).__setattr__(name, value)


                                class InterfaceBrief(Entity):
                                    """
                                    OSPF interface brief information
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: interface_address
                                    
                                    	Interface IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_adj_neighbor_count
                                    
                                    	Total number of Adjacent Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_area
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: interface_fast_detect_hold_down
                                    
                                    	Interface in fast detect hold down state
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_madj
                                    
                                    	Information for multi\-area on the interface
                                    	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj>`
                                    
                                    .. attribute:: interface_madj_count
                                    
                                    	Total number of multi\-area
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_mask
                                    
                                    	Interface IP Mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Total number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interfaceis_madj
                                    
                                    	If true, interface is multi\-area
                                    	**type**\:  bool
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief, self).__init__()

                                        self.yang_name = "interface-brief"
                                        self.yang_parent_name = "interface-briefs"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.interface_address = YLeaf(YType.str, "interface-address")

                                        self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                        self.interface_area = YLeaf(YType.str, "interface-area")

                                        self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                        self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                        self.interface_madj = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name",
                                                        "interface_address",
                                                        "interface_adj_neighbor_count",
                                                        "interface_area",
                                                        "interface_fast_detect_hold_down",
                                                        "interface_link_cost",
                                                        "interface_madj_count",
                                                        "interface_mask",
                                                        "interface_name_xr",
                                                        "interface_neighbor_count",
                                                        "interfaceis_madj",
                                                        "ospf_interface_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief, self).__setattr__(name, value)


                                    class InterfaceMadj(Entity):
                                        """
                                        Information for multi\-area on the interface
                                        
                                        .. attribute:: interface_adj_neighbor_count
                                        
                                        	Total number of Adjacent Neighbors
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: interface_area
                                        
                                        	Area ID string in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: interface_link_cost
                                        
                                        	Interface link cost
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: interface_neighbor_count
                                        
                                        	Number of Neighbors
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: madj_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ospf_interface_state
                                        
                                        	Interface OSPF state
                                        	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__init__()

                                            self.yang_name = "interface-madj"
                                            self.yang_parent_name = "interface-brief"

                                            self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                            self.interface_area = YLeaf(YType.str, "interface-area")

                                            self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                            self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                            self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                            self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_adj_neighbor_count",
                                                            "interface_area",
                                                            "interface_link_cost",
                                                            "interface_neighbor_count",
                                                            "madj_area_id",
                                                            "ospf_interface_state") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_adj_neighbor_count.is_set or
                                                self.interface_area.is_set or
                                                self.interface_link_cost.is_set or
                                                self.interface_neighbor_count.is_set or
                                                self.madj_area_id.is_set or
                                                self.ospf_interface_state.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_adj_neighbor_count.yfilter != YFilter.not_set or
                                                self.interface_area.yfilter != YFilter.not_set or
                                                self.interface_link_cost.yfilter != YFilter.not_set or
                                                self.interface_neighbor_count.yfilter != YFilter.not_set or
                                                self.madj_area_id.yfilter != YFilter.not_set or
                                                self.ospf_interface_state.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-madj" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_adj_neighbor_count.is_set or self.interface_adj_neighbor_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_adj_neighbor_count.get_name_leafdata())
                                            if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_area.get_name_leafdata())
                                            if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                            if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                            if (self.madj_area_id.is_set or self.madj_area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.madj_area_id.get_name_leafdata())
                                            if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-adj-neighbor-count" or name == "interface-area" or name == "interface-link-cost" or name == "interface-neighbor-count" or name == "madj-area-id" or name == "ospf-interface-state"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-adj-neighbor-count"):
                                                self.interface_adj_neighbor_count = value
                                                self.interface_adj_neighbor_count.value_namespace = name_space
                                                self.interface_adj_neighbor_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-area"):
                                                self.interface_area = value
                                                self.interface_area.value_namespace = name_space
                                                self.interface_area.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-link-cost"):
                                                self.interface_link_cost = value
                                                self.interface_link_cost.value_namespace = name_space
                                                self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-neighbor-count"):
                                                self.interface_neighbor_count = value
                                                self.interface_neighbor_count.value_namespace = name_space
                                                self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "madj-area-id"):
                                                self.madj_area_id = value
                                                self.madj_area_id.value_namespace = name_space
                                                self.madj_area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ospf-interface-state"):
                                                self.ospf_interface_state = value
                                                self.ospf_interface_state.value_namespace = name_space
                                                self.ospf_interface_state.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface_madj:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_name.is_set or
                                            self.interface_address.is_set or
                                            self.interface_adj_neighbor_count.is_set or
                                            self.interface_area.is_set or
                                            self.interface_fast_detect_hold_down.is_set or
                                            self.interface_link_cost.is_set or
                                            self.interface_madj_count.is_set or
                                            self.interface_mask.is_set or
                                            self.interface_name_xr.is_set or
                                            self.interface_neighbor_count.is_set or
                                            self.interfaceis_madj.is_set or
                                            self.ospf_interface_state.is_set)

                                    def has_operation(self):
                                        for c in self.interface_madj:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.interface_address.yfilter != YFilter.not_set or
                                            self.interface_adj_neighbor_count.yfilter != YFilter.not_set or
                                            self.interface_area.yfilter != YFilter.not_set or
                                            self.interface_fast_detect_hold_down.yfilter != YFilter.not_set or
                                            self.interface_link_cost.yfilter != YFilter.not_set or
                                            self.interface_madj_count.yfilter != YFilter.not_set or
                                            self.interface_mask.yfilter != YFilter.not_set or
                                            self.interface_name_xr.yfilter != YFilter.not_set or
                                            self.interface_neighbor_count.yfilter != YFilter.not_set or
                                            self.interfaceis_madj.yfilter != YFilter.not_set or
                                            self.ospf_interface_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-brief" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.interface_address.is_set or self.interface_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_address.get_name_leafdata())
                                        if (self.interface_adj_neighbor_count.is_set or self.interface_adj_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_adj_neighbor_count.get_name_leafdata())
                                        if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_area.get_name_leafdata())
                                        if (self.interface_fast_detect_hold_down.is_set or self.interface_fast_detect_hold_down.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_fast_detect_hold_down.get_name_leafdata())
                                        if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                        if (self.interface_madj_count.is_set or self.interface_madj_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_madj_count.get_name_leafdata())
                                        if (self.interface_mask.is_set or self.interface_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_mask.get_name_leafdata())
                                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                        if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                        if (self.interfaceis_madj.is_set or self.interfaceis_madj.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interfaceis_madj.get_name_leafdata())
                                        if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-madj"):
                                            for c in self.interface_madj:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface_madj.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-madj" or name == "interface-name" or name == "interface-address" or name == "interface-adj-neighbor-count" or name == "interface-area" or name == "interface-fast-detect-hold-down" or name == "interface-link-cost" or name == "interface-madj-count" or name == "interface-mask" or name == "interface-name-xr" or name == "interface-neighbor-count" or name == "interfaceis-madj" or name == "ospf-interface-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-address"):
                                            self.interface_address = value
                                            self.interface_address.value_namespace = name_space
                                            self.interface_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-adj-neighbor-count"):
                                            self.interface_adj_neighbor_count = value
                                            self.interface_adj_neighbor_count.value_namespace = name_space
                                            self.interface_adj_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-area"):
                                            self.interface_area = value
                                            self.interface_area.value_namespace = name_space
                                            self.interface_area.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-fast-detect-hold-down"):
                                            self.interface_fast_detect_hold_down = value
                                            self.interface_fast_detect_hold_down.value_namespace = name_space
                                            self.interface_fast_detect_hold_down.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-link-cost"):
                                            self.interface_link_cost = value
                                            self.interface_link_cost.value_namespace = name_space
                                            self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-madj-count"):
                                            self.interface_madj_count = value
                                            self.interface_madj_count.value_namespace = name_space
                                            self.interface_madj_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-mask"):
                                            self.interface_mask = value
                                            self.interface_mask.value_namespace = name_space
                                            self.interface_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-name-xr"):
                                            self.interface_name_xr = value
                                            self.interface_name_xr.value_namespace = name_space
                                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-neighbor-count"):
                                            self.interface_neighbor_count = value
                                            self.interface_neighbor_count.value_namespace = name_space
                                            self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interfaceis-madj"):
                                            self.interfaceis_madj = value
                                            self.interfaceis_madj.value_namespace = name_space
                                            self.interfaceis_madj.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-interface-state"):
                                            self.ospf_interface_state = value
                                            self.ospf_interface_state.value_namespace = name_space
                                            self.ospf_interface_state.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.interface_brief:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.interface_brief:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface-briefs" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-brief"):
                                        for c in self.interface_brief:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.interface_brief.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-brief"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class Requests(Entity):
                                """
                                Request List table
                                
                                .. attribute:: request
                                
                                	Request list for a particular adjacency
                                	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests, self).__init__()

                                    self.yang_name = "requests"
                                    self.yang_parent_name = "area"

                                    self.request = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests, self).__setattr__(name, value)


                                class Request(Entity):
                                    """
                                    Request list for a particular adjacency
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: request
                                    
                                    	List of request list entries
                                    	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request.Request>`
                                    
                                    .. attribute:: request_interface_name
                                    
                                    	Request list interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: request_neighbor_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: request_neighbor_id
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request, self).__init__()

                                        self.yang_name = "request"
                                        self.yang_parent_name = "requests"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.request_interface_name = YLeaf(YType.str, "request-interface-name")

                                        self.request_neighbor_address = YLeaf(YType.str, "request-neighbor-address")

                                        self.request_neighbor_id = YLeaf(YType.str, "request-neighbor-id")

                                        self.request = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name",
                                                        "neighbor_address",
                                                        "request_interface_name",
                                                        "request_neighbor_address",
                                                        "request_neighbor_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request, self).__setattr__(name, value)


                                    class Request(Entity):
                                        """
                                        List of request list entries
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_ls_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_checksum
                                        
                                        	Checksum of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA Type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request.Request, self).__init__()

                                            self.yang_name = "request"
                                            self.yang_parent_name = "request"

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("header_advertising_router",
                                                            "header_ls_id",
                                                            "header_lsa_age",
                                                            "header_lsa_checksum",
                                                            "header_lsa_type",
                                                            "header_sequence_number") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request.Request, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request.Request, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.header_advertising_router.is_set or
                                                self.header_ls_id.is_set or
                                                self.header_lsa_age.is_set or
                                                self.header_lsa_checksum.is_set or
                                                self.header_lsa_type.is_set or
                                                self.header_sequence_number.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.header_advertising_router.yfilter != YFilter.not_set or
                                                self.header_ls_id.yfilter != YFilter.not_set or
                                                self.header_lsa_age.yfilter != YFilter.not_set or
                                                self.header_lsa_checksum.yfilter != YFilter.not_set or
                                                self.header_lsa_type.yfilter != YFilter.not_set or
                                                self.header_sequence_number.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "request" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                            if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                            if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                            if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                            if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                            if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "header-advertising-router"):
                                                self.header_advertising_router = value
                                                self.header_advertising_router.value_namespace = name_space
                                                self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-ls-id"):
                                                self.header_ls_id = value
                                                self.header_ls_id.value_namespace = name_space
                                                self.header_ls_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-age"):
                                                self.header_lsa_age = value
                                                self.header_lsa_age.value_namespace = name_space
                                                self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-checksum"):
                                                self.header_lsa_checksum = value
                                                self.header_lsa_checksum.value_namespace = name_space
                                                self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-type"):
                                                self.header_lsa_type = value
                                                self.header_lsa_type.value_namespace = name_space
                                                self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-sequence-number"):
                                                self.header_sequence_number = value
                                                self.header_sequence_number.value_namespace = name_space
                                                self.header_sequence_number.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.request:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_name.is_set or
                                            self.neighbor_address.is_set or
                                            self.request_interface_name.is_set or
                                            self.request_neighbor_address.is_set or
                                            self.request_neighbor_id.is_set)

                                    def has_operation(self):
                                        for c in self.request:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.neighbor_address.yfilter != YFilter.not_set or
                                            self.request_interface_name.yfilter != YFilter.not_set or
                                            self.request_neighbor_address.yfilter != YFilter.not_set or
                                            self.request_neighbor_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "request" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                        if (self.request_interface_name.is_set or self.request_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.request_interface_name.get_name_leafdata())
                                        if (self.request_neighbor_address.is_set or self.request_neighbor_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.request_neighbor_address.get_name_leafdata())
                                        if (self.request_neighbor_id.is_set or self.request_neighbor_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.request_neighbor_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "request"):
                                            for c in self.request:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request.Request()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.request.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "request" or name == "interface-name" or name == "neighbor-address" or name == "request-interface-name" or name == "request-neighbor-address" or name == "request-neighbor-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-address"):
                                            self.neighbor_address = value
                                            self.neighbor_address.value_namespace = name_space
                                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "request-interface-name"):
                                            self.request_interface_name = value
                                            self.request_interface_name.value_namespace = name_space
                                            self.request_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "request-neighbor-address"):
                                            self.request_neighbor_address = value
                                            self.request_neighbor_address.value_namespace = name_space
                                            self.request_neighbor_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "request-neighbor-id"):
                                            self.request_neighbor_id = value
                                            self.request_neighbor_id.value_namespace = name_space
                                            self.request_neighbor_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.request:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.request:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "requests" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "request"):
                                        for c in self.request:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.request.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "request"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class Retransmissions(Entity):
                                """
                                Retransmission list table
                                
                                .. attribute:: retransmission
                                
                                	Retransmission list for a particular adjacency
                                	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions, self).__init__()

                                    self.yang_name = "retransmissions"
                                    self.yang_parent_name = "area"

                                    self.retransmission = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions, self).__setattr__(name, value)


                                class Retransmission(Entity):
                                    """
                                    Retransmission list for a particular adjacency
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: retransmission_area_db
                                    
                                    	List of Area scope entries
                                    	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb>`
                                    
                                    .. attribute:: retransmission_asdb
                                    
                                    	List of AS Scope entries
                                    	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb>`
                                    
                                    .. attribute:: retransmission_count
                                    
                                    	Retransmission queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmission_interface_name
                                    
                                    	Retransmission list interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: retransmission_neighbor_id
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: retransmission_neighbor_ip_address
                                    
                                    	Neighbor IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: retransmission_timer
                                    
                                    	Amount of time remaining on retransmission timer (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission, self).__init__()

                                        self.yang_name = "retransmission"
                                        self.yang_parent_name = "retransmissions"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.retransmission_count = YLeaf(YType.uint32, "retransmission-count")

                                        self.retransmission_interface_name = YLeaf(YType.str, "retransmission-interface-name")

                                        self.retransmission_neighbor_id = YLeaf(YType.str, "retransmission-neighbor-id")

                                        self.retransmission_neighbor_ip_address = YLeaf(YType.str, "retransmission-neighbor-ip-address")

                                        self.retransmission_timer = YLeaf(YType.uint32, "retransmission-timer")

                                        self.retransmission_area_db = YList(self)
                                        self.retransmission_asdb = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name",
                                                        "neighbor_address",
                                                        "retransmission_count",
                                                        "retransmission_interface_name",
                                                        "retransmission_neighbor_id",
                                                        "retransmission_neighbor_ip_address",
                                                        "retransmission_timer") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission, self).__setattr__(name, value)


                                    class RetransmissionAreaDb(Entity):
                                        """
                                        List of Area scope entries
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_ls_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_checksum
                                        
                                        	Checksum of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA Type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb, self).__init__()

                                            self.yang_name = "retransmission-area-db"
                                            self.yang_parent_name = "retransmission"

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("header_advertising_router",
                                                            "header_ls_id",
                                                            "header_lsa_age",
                                                            "header_lsa_checksum",
                                                            "header_lsa_type",
                                                            "header_sequence_number") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.header_advertising_router.is_set or
                                                self.header_ls_id.is_set or
                                                self.header_lsa_age.is_set or
                                                self.header_lsa_checksum.is_set or
                                                self.header_lsa_type.is_set or
                                                self.header_sequence_number.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.header_advertising_router.yfilter != YFilter.not_set or
                                                self.header_ls_id.yfilter != YFilter.not_set or
                                                self.header_lsa_age.yfilter != YFilter.not_set or
                                                self.header_lsa_checksum.yfilter != YFilter.not_set or
                                                self.header_lsa_type.yfilter != YFilter.not_set or
                                                self.header_sequence_number.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "retransmission-area-db" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                            if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                            if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                            if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                            if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                            if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "header-advertising-router"):
                                                self.header_advertising_router = value
                                                self.header_advertising_router.value_namespace = name_space
                                                self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-ls-id"):
                                                self.header_ls_id = value
                                                self.header_ls_id.value_namespace = name_space
                                                self.header_ls_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-age"):
                                                self.header_lsa_age = value
                                                self.header_lsa_age.value_namespace = name_space
                                                self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-checksum"):
                                                self.header_lsa_checksum = value
                                                self.header_lsa_checksum.value_namespace = name_space
                                                self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-type"):
                                                self.header_lsa_type = value
                                                self.header_lsa_type.value_namespace = name_space
                                                self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-sequence-number"):
                                                self.header_sequence_number = value
                                                self.header_sequence_number.value_namespace = name_space
                                                self.header_sequence_number.value_namespace_prefix = name_space_prefix


                                    class RetransmissionAsdb(Entity):
                                        """
                                        List of AS Scope entries
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_ls_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_checksum
                                        
                                        	Checksum of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA Type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb, self).__init__()

                                            self.yang_name = "retransmission-asdb"
                                            self.yang_parent_name = "retransmission"

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("header_advertising_router",
                                                            "header_ls_id",
                                                            "header_lsa_age",
                                                            "header_lsa_checksum",
                                                            "header_lsa_type",
                                                            "header_sequence_number") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.header_advertising_router.is_set or
                                                self.header_ls_id.is_set or
                                                self.header_lsa_age.is_set or
                                                self.header_lsa_checksum.is_set or
                                                self.header_lsa_type.is_set or
                                                self.header_sequence_number.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.header_advertising_router.yfilter != YFilter.not_set or
                                                self.header_ls_id.yfilter != YFilter.not_set or
                                                self.header_lsa_age.yfilter != YFilter.not_set or
                                                self.header_lsa_checksum.yfilter != YFilter.not_set or
                                                self.header_lsa_type.yfilter != YFilter.not_set or
                                                self.header_sequence_number.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "retransmission-asdb" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                            if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                            if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                            if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                            if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                            if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "header-advertising-router"):
                                                self.header_advertising_router = value
                                                self.header_advertising_router.value_namespace = name_space
                                                self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-ls-id"):
                                                self.header_ls_id = value
                                                self.header_ls_id.value_namespace = name_space
                                                self.header_ls_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-age"):
                                                self.header_lsa_age = value
                                                self.header_lsa_age.value_namespace = name_space
                                                self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-checksum"):
                                                self.header_lsa_checksum = value
                                                self.header_lsa_checksum.value_namespace = name_space
                                                self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-lsa-type"):
                                                self.header_lsa_type = value
                                                self.header_lsa_type.value_namespace = name_space
                                                self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "header-sequence-number"):
                                                self.header_sequence_number = value
                                                self.header_sequence_number.value_namespace = name_space
                                                self.header_sequence_number.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.retransmission_area_db:
                                            if (c.has_data()):
                                                return True
                                        for c in self.retransmission_asdb:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_name.is_set or
                                            self.neighbor_address.is_set or
                                            self.retransmission_count.is_set or
                                            self.retransmission_interface_name.is_set or
                                            self.retransmission_neighbor_id.is_set or
                                            self.retransmission_neighbor_ip_address.is_set or
                                            self.retransmission_timer.is_set)

                                    def has_operation(self):
                                        for c in self.retransmission_area_db:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.retransmission_asdb:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.neighbor_address.yfilter != YFilter.not_set or
                                            self.retransmission_count.yfilter != YFilter.not_set or
                                            self.retransmission_interface_name.yfilter != YFilter.not_set or
                                            self.retransmission_neighbor_id.yfilter != YFilter.not_set or
                                            self.retransmission_neighbor_ip_address.yfilter != YFilter.not_set or
                                            self.retransmission_timer.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "retransmission" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                        if (self.retransmission_count.is_set or self.retransmission_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.retransmission_count.get_name_leafdata())
                                        if (self.retransmission_interface_name.is_set or self.retransmission_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.retransmission_interface_name.get_name_leafdata())
                                        if (self.retransmission_neighbor_id.is_set or self.retransmission_neighbor_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.retransmission_neighbor_id.get_name_leafdata())
                                        if (self.retransmission_neighbor_ip_address.is_set or self.retransmission_neighbor_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.retransmission_neighbor_ip_address.get_name_leafdata())
                                        if (self.retransmission_timer.is_set or self.retransmission_timer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.retransmission_timer.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "retransmission-area-db"):
                                            for c in self.retransmission_area_db:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.retransmission_area_db.append(c)
                                            return c

                                        if (child_yang_name == "retransmission-asdb"):
                                            for c in self.retransmission_asdb:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.retransmission_asdb.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "retransmission-area-db" or name == "retransmission-asdb" or name == "interface-name" or name == "neighbor-address" or name == "retransmission-count" or name == "retransmission-interface-name" or name == "retransmission-neighbor-id" or name == "retransmission-neighbor-ip-address" or name == "retransmission-timer"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-address"):
                                            self.neighbor_address = value
                                            self.neighbor_address.value_namespace = name_space
                                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "retransmission-count"):
                                            self.retransmission_count = value
                                            self.retransmission_count.value_namespace = name_space
                                            self.retransmission_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "retransmission-interface-name"):
                                            self.retransmission_interface_name = value
                                            self.retransmission_interface_name.value_namespace = name_space
                                            self.retransmission_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "retransmission-neighbor-id"):
                                            self.retransmission_neighbor_id = value
                                            self.retransmission_neighbor_id.value_namespace = name_space
                                            self.retransmission_neighbor_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "retransmission-neighbor-ip-address"):
                                            self.retransmission_neighbor_ip_address = value
                                            self.retransmission_neighbor_ip_address.value_namespace = name_space
                                            self.retransmission_neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "retransmission-timer"):
                                            self.retransmission_timer = value
                                            self.retransmission_timer.value_namespace = name_space
                                            self.retransmission_timer.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.retransmission:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.retransmission:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "retransmissions" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "retransmission"):
                                        for c in self.retransmission:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.retransmission.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "retransmission"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class AreaStatistics(Entity):
                                """
                                Container for Statistics
                                
                                .. attribute:: interface_stats_entries
                                
                                	Statistics innformation Interface table
                                	**type**\:   :py:class:`InterfaceStatsEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics, self).__init__()

                                    self.yang_name = "area-statistics"
                                    self.yang_parent_name = "area"

                                    self.interface_stats_entries = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries()
                                    self.interface_stats_entries.parent = self
                                    self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                                    self._children_yang_names.add("interface-stats-entries")


                                class InterfaceStatsEntries(Entity):
                                    """
                                    Statistics innformation Interface table
                                    
                                    .. attribute:: interface_stats_entry
                                    
                                    	Statistics information for a specific interface
                                    	**type**\: list of    :py:class:`InterfaceStatsEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries, self).__init__()

                                        self.yang_name = "interface-stats-entries"
                                        self.yang_parent_name = "area-statistics"

                                        self.interface_stats_entry = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries, self).__setattr__(name, value)


                                    class InterfaceStatsEntry(Entity):
                                        """
                                        Statistics information for a specific interface
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: handle
                                        
                                        	interface handle type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: if_entry
                                        
                                        	interface entry
                                        	**type**\: list of    :py:class:`IfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry>`
                                        
                                        .. attribute:: if_name_str
                                        
                                        	interface name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__init__()

                                            self.yang_name = "interface-stats-entry"
                                            self.yang_parent_name = "interface-stats-entries"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.handle = YLeaf(YType.str, "handle")

                                            self.if_name_str = YLeaf(YType.str, "if-name-str")

                                            self.if_entry = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "handle",
                                                            "if_name_str") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__setattr__(name, value)


                                        class IfEntry(Entity):
                                            """
                                            interface entry
                                            
                                            .. attribute:: area_id
                                            
                                            	OSPF area id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_id_str
                                            
                                            	OSPF aread id string
                                            	**type**\:  str
                                            
                                            .. attribute:: if_stat
                                            
                                            	OSPF interface statistics
                                            	**type**\: list of    :py:class:`IfStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat>`
                                            
                                            .. attribute:: madj_intf
                                            
                                            	OSPF madj interface
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__init__()

                                                self.yang_name = "if-entry"
                                                self.yang_parent_name = "interface-stats-entry"

                                                self.area_id = YLeaf(YType.uint32, "area-id")

                                                self.area_id_str = YLeaf(YType.str, "area-id-str")

                                                self.madj_intf = YLeaf(YType.boolean, "madj-intf")

                                                self.if_stat = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("area_id",
                                                                "area_id_str",
                                                                "madj_intf") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__setattr__(name, value)


                                            class IfStat(Entity):
                                                """
                                                OSPF interface statistics
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__init__()

                                                    self.yang_name = "if-stat"
                                                    self.yang_parent_name = "if-entry"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "if-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.if_stat:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.area_id.is_set or
                                                    self.area_id_str.is_set or
                                                    self.madj_intf.is_set)

                                            def has_operation(self):
                                                for c in self.if_stat:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.area_id.yfilter != YFilter.not_set or
                                                    self.area_id_str.yfilter != YFilter.not_set or
                                                    self.madj_intf.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "if-entry" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                                if (self.area_id_str.is_set or self.area_id_str.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.area_id_str.get_name_leafdata())
                                                if (self.madj_intf.is_set or self.madj_intf.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.madj_intf.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "if-stat"):
                                                    for c in self.if_stat:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.if_stat.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "if-stat" or name == "area-id" or name == "area-id-str" or name == "madj-intf"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "area-id"):
                                                    self.area_id = value
                                                    self.area_id.value_namespace = name_space
                                                    self.area_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "area-id-str"):
                                                    self.area_id_str = value
                                                    self.area_id_str.value_namespace = name_space
                                                    self.area_id_str.value_namespace_prefix = name_space_prefix
                                                if(value_path == "madj-intf"):
                                                    self.madj_intf = value
                                                    self.madj_intf.value_namespace = name_space
                                                    self.madj_intf.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.if_entry:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_name.is_set or
                                                self.handle.is_set or
                                                self.if_name_str.is_set)

                                        def has_operation(self):
                                            for c in self.if_entry:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.handle.yfilter != YFilter.not_set or
                                                self.if_name_str.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-stats-entry" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.handle.is_set or self.handle.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.handle.get_name_leafdata())
                                            if (self.if_name_str.is_set or self.if_name_str.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.if_name_str.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "if-entry"):
                                                for c in self.if_entry:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.if_entry.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "if-entry" or name == "interface-name" or name == "handle" or name == "if-name-str"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "handle"):
                                                self.handle = value
                                                self.handle.value_namespace = name_space
                                                self.handle.value_namespace_prefix = name_space_prefix
                                            if(value_path == "if-name-str"):
                                                self.if_name_str = value
                                                self.if_name_str.value_namespace = name_space
                                                self.if_name_str.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface_stats_entry:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.interface_stats_entry:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-stats-entries" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-stats-entry"):
                                            for c in self.interface_stats_entry:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface_stats_entry.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-stats-entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (self.interface_stats_entries is not None and self.interface_stats_entries.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.interface_stats_entries is not None and self.interface_stats_entries.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "area-statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-stats-entries"):
                                        if (self.interface_stats_entries is None):
                                            self.interface_stats_entries = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries()
                                            self.interface_stats_entries.parent = self
                                            self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                                        return self.interface_stats_entries

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-stats-entries"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class NeighborDetails(Entity):
                                """
                                Neighbor detail table
                                
                                .. attribute:: neighbor_detail
                                
                                	A single neighbor's detail information
                                	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails, self).__init__()

                                    self.yang_name = "neighbor-details"
                                    self.yang_parent_name = "area"

                                    self.neighbor_detail = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails, self).__setattr__(name, value)


                                class NeighborDetail(Entity):
                                    """
                                    A single neighbor's detail information
                                    
                                    .. attribute:: adjacency_sid_label
                                    
                                    	SR Adjacency SID Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: adjacency_sid_protected
                                    
                                    	SR Adjacency SID Protected
                                    	**type**\:  bool
                                    
                                    .. attribute:: adjacency_sid_unprotected_label
                                    
                                    	SR Adjacency SID Unprotected Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: interface_type
                                    
                                    	Interface type
                                    	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                                    
                                    .. attribute:: last_oob_time
                                    
                                    	The amount of time in seconds since last time Out\-Of\-Band resynchronization was done with this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: lfa_interface
                                    
                                    	LFA Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: lfa_neighbor_id
                                    
                                    	LFA Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lfa_neighbor_revision
                                    
                                    	LFA Neighbor Revision
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lfa_next_hop
                                    
                                    	LFA Next Hop
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_ack_list_count
                                    
                                    	Ack List Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_ack_list_high_watermark
                                    
                                    	Ack List High Watermark
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_area_id
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: neighbor_backup_designated_router_address
                                    
                                    	Address of backup designated router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bfd_information
                                    
                                    	Neighbor BFD information
                                    	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation>`
                                    
                                    .. attribute:: neighbor_cost
                                    
                                    	Cost of path to this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_designated_router_address
                                    
                                    	Address of designated router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_filter
                                    
                                    	If true, filter outgoing LSAs
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_lls_option
                                    
                                    	This is a bitmask of Link Local signalling options received from the neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_option
                                    
                                    	 This is bitmaks of neighbor's option field received
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_retransmission_information
                                    
                                    	Retransmission information with this neighbor
                                    	**type**\:   :py:class:`NeighborRetransmissionInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation>`
                                    
                                    .. attribute:: neighbor_summary
                                    
                                    	Neighbor summary information
                                    	**type**\:   :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary>`
                                    
                                    .. attribute:: next_poll_interval
                                    
                                    	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nsf_router_state
                                    
                                    	For cisco NSF, the router is either Requester or Receiver
                                    	**type**\:   :py:class:`NsfRtr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NsfRtr>`
                                    
                                    .. attribute:: oob_resynchronization
                                    
                                    	Out\-Of\-Bound resynchronization in progress
                                    	**type**\:  bool
                                    
                                    .. attribute:: pending_events
                                    
                                    	Number of pending events
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: poll_interval
                                    
                                    	Poll interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_change_count
                                    
                                    	Number of state changes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail, self).__init__()

                                        self.yang_name = "neighbor-detail"
                                        self.yang_parent_name = "neighbor-details"

                                        self.adjacency_sid_label = YLeaf(YType.uint32, "adjacency-sid-label")

                                        self.adjacency_sid_protected = YLeaf(YType.boolean, "adjacency-sid-protected")

                                        self.adjacency_sid_unprotected_label = YLeaf(YType.uint32, "adjacency-sid-unprotected-label")

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                        self.last_oob_time = YLeaf(YType.uint32, "last-oob-time")

                                        self.lfa_interface = YLeaf(YType.str, "lfa-interface")

                                        self.lfa_neighbor_id = YLeaf(YType.str, "lfa-neighbor-id")

                                        self.lfa_neighbor_revision = YLeaf(YType.uint32, "lfa-neighbor-revision")

                                        self.lfa_next_hop = YLeaf(YType.str, "lfa-next-hop")

                                        self.neighbor_ack_list_count = YLeaf(YType.uint32, "neighbor-ack-list-count")

                                        self.neighbor_ack_list_high_watermark = YLeaf(YType.uint32, "neighbor-ack-list-high-watermark")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.neighbor_area_id = YLeaf(YType.str, "neighbor-area-id")

                                        self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                        self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                        self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                        self.neighbor_filter = YLeaf(YType.boolean, "neighbor-filter")

                                        self.neighbor_lls_option = YLeaf(YType.uint16, "neighbor-lls-option")

                                        self.neighbor_option = YLeaf(YType.uint8, "neighbor-option")

                                        self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                        self.nsf_router_state = YLeaf(YType.enumeration, "nsf-router-state")

                                        self.oob_resynchronization = YLeaf(YType.boolean, "oob-resynchronization")

                                        self.pending_events = YLeaf(YType.uint16, "pending-events")

                                        self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                        self.state_change_count = YLeaf(YType.uint16, "state-change-count")

                                        self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation()
                                        self.neighbor_bfd_information.parent = self
                                        self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                        self._children_yang_names.add("neighbor-bfd-information")

                                        self.neighbor_retransmission_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation()
                                        self.neighbor_retransmission_information.parent = self
                                        self._children_name_map["neighbor_retransmission_information"] = "neighbor-retransmission-information"
                                        self._children_yang_names.add("neighbor-retransmission-information")

                                        self.neighbor_summary = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary()
                                        self.neighbor_summary.parent = self
                                        self._children_name_map["neighbor_summary"] = "neighbor-summary"
                                        self._children_yang_names.add("neighbor-summary")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("adjacency_sid_label",
                                                        "adjacency_sid_protected",
                                                        "adjacency_sid_unprotected_label",
                                                        "interface_name",
                                                        "interface_type",
                                                        "last_oob_time",
                                                        "lfa_interface",
                                                        "lfa_neighbor_id",
                                                        "lfa_neighbor_revision",
                                                        "lfa_next_hop",
                                                        "neighbor_ack_list_count",
                                                        "neighbor_ack_list_high_watermark",
                                                        "neighbor_address",
                                                        "neighbor_area_id",
                                                        "neighbor_backup_designated_router_address",
                                                        "neighbor_cost",
                                                        "neighbor_designated_router_address",
                                                        "neighbor_filter",
                                                        "neighbor_lls_option",
                                                        "neighbor_option",
                                                        "next_poll_interval",
                                                        "nsf_router_state",
                                                        "oob_resynchronization",
                                                        "pending_events",
                                                        "poll_interval",
                                                        "state_change_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail, self).__setattr__(name, value)


                                    class NeighborSummary(Entity):
                                        """
                                        Neighbor summary information
                                        
                                        .. attribute:: dr_bdr_state
                                        
                                        	Designated Router state
                                        	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor IP Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_bfd_information
                                        
                                        	Neighbor BFD information
                                        	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation>`
                                        
                                        .. attribute:: neighbor_dead_timer
                                        
                                        	Time until neighbor's dead timer expires (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_dr_priority
                                        
                                        	Neighbor's DR priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: neighbor_id
                                        
                                        	Neighbor ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_interface_name
                                        
                                        	Interface via which the neighbor is seen
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: neighbor_madj_interface
                                        
                                        	Interface is MADJ
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_state
                                        
                                        	Neighbor's state
                                        	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                        
                                        .. attribute:: neighbor_up_time
                                        
                                        	Amount of time since the adjacency is up (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary, self).__init__()

                                            self.yang_name = "neighbor-summary"
                                            self.yang_parent_name = "neighbor-detail"

                                            self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                            self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                            self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                            self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                            self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                            self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                            self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                            self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                            self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                            self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation()
                                            self.neighbor_bfd_information.parent = self
                                            self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                            self._children_yang_names.add("neighbor-bfd-information")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dr_bdr_state",
                                                            "neighbor_address_xr",
                                                            "neighbor_dead_timer",
                                                            "neighbor_dr_priority",
                                                            "neighbor_id",
                                                            "neighbor_interface_name",
                                                            "neighbor_madj_interface",
                                                            "neighbor_state",
                                                            "neighbor_up_time") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary, self).__setattr__(name, value)


                                        class NeighborBfdInformation(Entity):
                                            """
                                            Neighbor BFD information
                                            
                                            .. attribute:: bfd_intf_enable_mode
                                            
                                            	BFD enable mode \- Default/Strict
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bfd_status_flag
                                            
                                            	Status of the BFD Session
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__init__()

                                                self.yang_name = "neighbor-bfd-information"
                                                self.yang_parent_name = "neighbor-summary"

                                                self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                                self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bfd_intf_enable_mode",
                                                                "bfd_status_flag") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bfd_intf_enable_mode.is_set or
                                                    self.bfd_status_flag.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                                    self.bfd_status_flag.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "neighbor-bfd-information" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                                if (self.bfd_status_flag.is_set or self.bfd_status_flag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bfd_status_flag.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bfd-intf-enable-mode" or name == "bfd-status-flag"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bfd-intf-enable-mode"):
                                                    self.bfd_intf_enable_mode = value
                                                    self.bfd_intf_enable_mode.value_namespace = name_space
                                                    self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bfd-status-flag"):
                                                    self.bfd_status_flag = value
                                                    self.bfd_status_flag.value_namespace = name_space
                                                    self.bfd_status_flag.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.dr_bdr_state.is_set or
                                                self.neighbor_address_xr.is_set or
                                                self.neighbor_dead_timer.is_set or
                                                self.neighbor_dr_priority.is_set or
                                                self.neighbor_id.is_set or
                                                self.neighbor_interface_name.is_set or
                                                self.neighbor_madj_interface.is_set or
                                                self.neighbor_state.is_set or
                                                self.neighbor_up_time.is_set or
                                                (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dr_bdr_state.yfilter != YFilter.not_set or
                                                self.neighbor_address_xr.yfilter != YFilter.not_set or
                                                self.neighbor_dead_timer.yfilter != YFilter.not_set or
                                                self.neighbor_dr_priority.yfilter != YFilter.not_set or
                                                self.neighbor_id.yfilter != YFilter.not_set or
                                                self.neighbor_interface_name.yfilter != YFilter.not_set or
                                                self.neighbor_madj_interface.yfilter != YFilter.not_set or
                                                self.neighbor_state.yfilter != YFilter.not_set or
                                                self.neighbor_up_time.yfilter != YFilter.not_set or
                                                (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor-summary" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dr_bdr_state.is_set or self.dr_bdr_state.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dr_bdr_state.get_name_leafdata())
                                            if (self.neighbor_address_xr.is_set or self.neighbor_address_xr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_address_xr.get_name_leafdata())
                                            if (self.neighbor_dead_timer.is_set or self.neighbor_dead_timer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_dead_timer.get_name_leafdata())
                                            if (self.neighbor_dr_priority.is_set or self.neighbor_dr_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_dr_priority.get_name_leafdata())
                                            if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                            if (self.neighbor_interface_name.is_set or self.neighbor_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_interface_name.get_name_leafdata())
                                            if (self.neighbor_madj_interface.is_set or self.neighbor_madj_interface.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_madj_interface.get_name_leafdata())
                                            if (self.neighbor_state.is_set or self.neighbor_state.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_state.get_name_leafdata())
                                            if (self.neighbor_up_time.is_set or self.neighbor_up_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_up_time.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "neighbor-bfd-information"):
                                                if (self.neighbor_bfd_information is None):
                                                    self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation()
                                                    self.neighbor_bfd_information.parent = self
                                                    self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                                return self.neighbor_bfd_information

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "neighbor-bfd-information" or name == "dr-bdr-state" or name == "neighbor-address-xr" or name == "neighbor-dead-timer" or name == "neighbor-dr-priority" or name == "neighbor-id" or name == "neighbor-interface-name" or name == "neighbor-madj-interface" or name == "neighbor-state" or name == "neighbor-up-time"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dr-bdr-state"):
                                                self.dr_bdr_state = value
                                                self.dr_bdr_state.value_namespace = name_space
                                                self.dr_bdr_state.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-address-xr"):
                                                self.neighbor_address_xr = value
                                                self.neighbor_address_xr.value_namespace = name_space
                                                self.neighbor_address_xr.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-dead-timer"):
                                                self.neighbor_dead_timer = value
                                                self.neighbor_dead_timer.value_namespace = name_space
                                                self.neighbor_dead_timer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-dr-priority"):
                                                self.neighbor_dr_priority = value
                                                self.neighbor_dr_priority.value_namespace = name_space
                                                self.neighbor_dr_priority.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-id"):
                                                self.neighbor_id = value
                                                self.neighbor_id.value_namespace = name_space
                                                self.neighbor_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-interface-name"):
                                                self.neighbor_interface_name = value
                                                self.neighbor_interface_name.value_namespace = name_space
                                                self.neighbor_interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-madj-interface"):
                                                self.neighbor_madj_interface = value
                                                self.neighbor_madj_interface.value_namespace = name_space
                                                self.neighbor_madj_interface.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-state"):
                                                self.neighbor_state = value
                                                self.neighbor_state.value_namespace = name_space
                                                self.neighbor_state.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-up-time"):
                                                self.neighbor_up_time = value
                                                self.neighbor_up_time.value_namespace = name_space
                                                self.neighbor_up_time.value_namespace_prefix = name_space_prefix


                                    class NeighborBfdInformation(Entity):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__init__()

                                            self.yang_name = "neighbor-bfd-information"
                                            self.yang_parent_name = "neighbor-detail"

                                            self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                            self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bfd_intf_enable_mode",
                                                            "bfd_status_flag") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bfd_intf_enable_mode.is_set or
                                                self.bfd_status_flag.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                                self.bfd_status_flag.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor-bfd-information" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                            if (self.bfd_status_flag.is_set or self.bfd_status_flag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_status_flag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bfd-intf-enable-mode" or name == "bfd-status-flag"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bfd-intf-enable-mode"):
                                                self.bfd_intf_enable_mode = value
                                                self.bfd_intf_enable_mode.value_namespace = name_space
                                                self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-status-flag"):
                                                self.bfd_status_flag = value
                                                self.bfd_status_flag.value_namespace = name_space
                                                self.bfd_status_flag.value_namespace_prefix = name_space_prefix


                                    class NeighborRetransmissionInformation(Entity):
                                        """
                                        Retransmission information with this neighbor
                                        
                                        .. attribute:: area_first_flood_information
                                        
                                        	First flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood_information_index
                                        
                                        	Index of the first flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_flooding_index
                                        
                                        	Area scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_information
                                        
                                        	Next flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_information_index
                                        
                                        	Index of next flood item for Area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_information
                                        
                                        	First flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_information_index
                                        
                                        	Index for first flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_flood_index
                                        
                                        	AS scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_information
                                        
                                        	Next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_information_index
                                        
                                        	Index of next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dbd_retransmission_count
                                        
                                        	Number of DBD retransmissions during last exchange
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dbd_retransmission_total_count
                                        
                                        	Total number of DBD retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_length
                                        
                                        	Number of LSAs sent in last retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_time
                                        
                                        	Last retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_retransmission_timer
                                        
                                        	Time until next LSA retransmission (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_length
                                        
                                        	Maximum number of LSAs sent in a retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_time
                                        
                                        	Maximum retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmission_count
                                        
                                        	Retransmission queue length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_retransmissions
                                        
                                        	Number of retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__init__()

                                            self.yang_name = "neighbor-retransmission-information"
                                            self.yang_parent_name = "neighbor-detail"

                                            self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                            self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                            self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                            self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                            self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                            self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                            self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                            self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                            self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                            self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                            self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                            self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                            self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                            self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                            self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                            self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                            self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                            self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                            self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("area_first_flood_information",
                                                            "area_first_flood_information_index",
                                                            "area_flooding_index",
                                                            "area_next_flood_information",
                                                            "area_next_flood_information_index",
                                                            "as_first_flood_information",
                                                            "as_first_flood_information_index",
                                                            "as_flood_index",
                                                            "as_next_flood_information",
                                                            "as_next_flood_information_index",
                                                            "dbd_retransmission_count",
                                                            "dbd_retransmission_total_count",
                                                            "last_retransmission_length",
                                                            "last_retransmission_time",
                                                            "lsa_retransmission_timer",
                                                            "maximum_retransmission_length",
                                                            "maximum_retransmission_time",
                                                            "neighbor_retransmission_count",
                                                            "number_of_retransmissions") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.area_first_flood_information.is_set or
                                                self.area_first_flood_information_index.is_set or
                                                self.area_flooding_index.is_set or
                                                self.area_next_flood_information.is_set or
                                                self.area_next_flood_information_index.is_set or
                                                self.as_first_flood_information.is_set or
                                                self.as_first_flood_information_index.is_set or
                                                self.as_flood_index.is_set or
                                                self.as_next_flood_information.is_set or
                                                self.as_next_flood_information_index.is_set or
                                                self.dbd_retransmission_count.is_set or
                                                self.dbd_retransmission_total_count.is_set or
                                                self.last_retransmission_length.is_set or
                                                self.last_retransmission_time.is_set or
                                                self.lsa_retransmission_timer.is_set or
                                                self.maximum_retransmission_length.is_set or
                                                self.maximum_retransmission_time.is_set or
                                                self.neighbor_retransmission_count.is_set or
                                                self.number_of_retransmissions.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.area_first_flood_information.yfilter != YFilter.not_set or
                                                self.area_first_flood_information_index.yfilter != YFilter.not_set or
                                                self.area_flooding_index.yfilter != YFilter.not_set or
                                                self.area_next_flood_information.yfilter != YFilter.not_set or
                                                self.area_next_flood_information_index.yfilter != YFilter.not_set or
                                                self.as_first_flood_information.yfilter != YFilter.not_set or
                                                self.as_first_flood_information_index.yfilter != YFilter.not_set or
                                                self.as_flood_index.yfilter != YFilter.not_set or
                                                self.as_next_flood_information.yfilter != YFilter.not_set or
                                                self.as_next_flood_information_index.yfilter != YFilter.not_set or
                                                self.dbd_retransmission_count.yfilter != YFilter.not_set or
                                                self.dbd_retransmission_total_count.yfilter != YFilter.not_set or
                                                self.last_retransmission_length.yfilter != YFilter.not_set or
                                                self.last_retransmission_time.yfilter != YFilter.not_set or
                                                self.lsa_retransmission_timer.yfilter != YFilter.not_set or
                                                self.maximum_retransmission_length.yfilter != YFilter.not_set or
                                                self.maximum_retransmission_time.yfilter != YFilter.not_set or
                                                self.neighbor_retransmission_count.yfilter != YFilter.not_set or
                                                self.number_of_retransmissions.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor-retransmission-information" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.area_first_flood_information.is_set or self.area_first_flood_information.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_first_flood_information.get_name_leafdata())
                                            if (self.area_first_flood_information_index.is_set or self.area_first_flood_information_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_first_flood_information_index.get_name_leafdata())
                                            if (self.area_flooding_index.is_set or self.area_flooding_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_flooding_index.get_name_leafdata())
                                            if (self.area_next_flood_information.is_set or self.area_next_flood_information.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_next_flood_information.get_name_leafdata())
                                            if (self.area_next_flood_information_index.is_set or self.area_next_flood_information_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_next_flood_information_index.get_name_leafdata())
                                            if (self.as_first_flood_information.is_set or self.as_first_flood_information.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_first_flood_information.get_name_leafdata())
                                            if (self.as_first_flood_information_index.is_set or self.as_first_flood_information_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_first_flood_information_index.get_name_leafdata())
                                            if (self.as_flood_index.is_set or self.as_flood_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_flood_index.get_name_leafdata())
                                            if (self.as_next_flood_information.is_set or self.as_next_flood_information.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_next_flood_information.get_name_leafdata())
                                            if (self.as_next_flood_information_index.is_set or self.as_next_flood_information_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.as_next_flood_information_index.get_name_leafdata())
                                            if (self.dbd_retransmission_count.is_set or self.dbd_retransmission_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dbd_retransmission_count.get_name_leafdata())
                                            if (self.dbd_retransmission_total_count.is_set or self.dbd_retransmission_total_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dbd_retransmission_total_count.get_name_leafdata())
                                            if (self.last_retransmission_length.is_set or self.last_retransmission_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.last_retransmission_length.get_name_leafdata())
                                            if (self.last_retransmission_time.is_set or self.last_retransmission_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.last_retransmission_time.get_name_leafdata())
                                            if (self.lsa_retransmission_timer.is_set or self.lsa_retransmission_timer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_retransmission_timer.get_name_leafdata())
                                            if (self.maximum_retransmission_length.is_set or self.maximum_retransmission_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_retransmission_length.get_name_leafdata())
                                            if (self.maximum_retransmission_time.is_set or self.maximum_retransmission_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_retransmission_time.get_name_leafdata())
                                            if (self.neighbor_retransmission_count.is_set or self.neighbor_retransmission_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_retransmission_count.get_name_leafdata())
                                            if (self.number_of_retransmissions.is_set or self.number_of_retransmissions.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.number_of_retransmissions.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "area-first-flood-information" or name == "area-first-flood-information-index" or name == "area-flooding-index" or name == "area-next-flood-information" or name == "area-next-flood-information-index" or name == "as-first-flood-information" or name == "as-first-flood-information-index" or name == "as-flood-index" or name == "as-next-flood-information" or name == "as-next-flood-information-index" or name == "dbd-retransmission-count" or name == "dbd-retransmission-total-count" or name == "last-retransmission-length" or name == "last-retransmission-time" or name == "lsa-retransmission-timer" or name == "maximum-retransmission-length" or name == "maximum-retransmission-time" or name == "neighbor-retransmission-count" or name == "number-of-retransmissions"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "area-first-flood-information"):
                                                self.area_first_flood_information = value
                                                self.area_first_flood_information.value_namespace = name_space
                                                self.area_first_flood_information.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-first-flood-information-index"):
                                                self.area_first_flood_information_index = value
                                                self.area_first_flood_information_index.value_namespace = name_space
                                                self.area_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-flooding-index"):
                                                self.area_flooding_index = value
                                                self.area_flooding_index.value_namespace = name_space
                                                self.area_flooding_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-next-flood-information"):
                                                self.area_next_flood_information = value
                                                self.area_next_flood_information.value_namespace = name_space
                                                self.area_next_flood_information.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-next-flood-information-index"):
                                                self.area_next_flood_information_index = value
                                                self.area_next_flood_information_index.value_namespace = name_space
                                                self.area_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-first-flood-information"):
                                                self.as_first_flood_information = value
                                                self.as_first_flood_information.value_namespace = name_space
                                                self.as_first_flood_information.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-first-flood-information-index"):
                                                self.as_first_flood_information_index = value
                                                self.as_first_flood_information_index.value_namespace = name_space
                                                self.as_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-flood-index"):
                                                self.as_flood_index = value
                                                self.as_flood_index.value_namespace = name_space
                                                self.as_flood_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-next-flood-information"):
                                                self.as_next_flood_information = value
                                                self.as_next_flood_information.value_namespace = name_space
                                                self.as_next_flood_information.value_namespace_prefix = name_space_prefix
                                            if(value_path == "as-next-flood-information-index"):
                                                self.as_next_flood_information_index = value
                                                self.as_next_flood_information_index.value_namespace = name_space
                                                self.as_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dbd-retransmission-count"):
                                                self.dbd_retransmission_count = value
                                                self.dbd_retransmission_count.value_namespace = name_space
                                                self.dbd_retransmission_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dbd-retransmission-total-count"):
                                                self.dbd_retransmission_total_count = value
                                                self.dbd_retransmission_total_count.value_namespace = name_space
                                                self.dbd_retransmission_total_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "last-retransmission-length"):
                                                self.last_retransmission_length = value
                                                self.last_retransmission_length.value_namespace = name_space
                                                self.last_retransmission_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "last-retransmission-time"):
                                                self.last_retransmission_time = value
                                                self.last_retransmission_time.value_namespace = name_space
                                                self.last_retransmission_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-retransmission-timer"):
                                                self.lsa_retransmission_timer = value
                                                self.lsa_retransmission_timer.value_namespace = name_space
                                                self.lsa_retransmission_timer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-retransmission-length"):
                                                self.maximum_retransmission_length = value
                                                self.maximum_retransmission_length.value_namespace = name_space
                                                self.maximum_retransmission_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-retransmission-time"):
                                                self.maximum_retransmission_time = value
                                                self.maximum_retransmission_time.value_namespace = name_space
                                                self.maximum_retransmission_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-retransmission-count"):
                                                self.neighbor_retransmission_count = value
                                                self.neighbor_retransmission_count.value_namespace = name_space
                                                self.neighbor_retransmission_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "number-of-retransmissions"):
                                                self.number_of_retransmissions = value
                                                self.number_of_retransmissions.value_namespace = name_space
                                                self.number_of_retransmissions.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.adjacency_sid_label.is_set or
                                            self.adjacency_sid_protected.is_set or
                                            self.adjacency_sid_unprotected_label.is_set or
                                            self.interface_name.is_set or
                                            self.interface_type.is_set or
                                            self.last_oob_time.is_set or
                                            self.lfa_interface.is_set or
                                            self.lfa_neighbor_id.is_set or
                                            self.lfa_neighbor_revision.is_set or
                                            self.lfa_next_hop.is_set or
                                            self.neighbor_ack_list_count.is_set or
                                            self.neighbor_ack_list_high_watermark.is_set or
                                            self.neighbor_address.is_set or
                                            self.neighbor_area_id.is_set or
                                            self.neighbor_backup_designated_router_address.is_set or
                                            self.neighbor_cost.is_set or
                                            self.neighbor_designated_router_address.is_set or
                                            self.neighbor_filter.is_set or
                                            self.neighbor_lls_option.is_set or
                                            self.neighbor_option.is_set or
                                            self.next_poll_interval.is_set or
                                            self.nsf_router_state.is_set or
                                            self.oob_resynchronization.is_set or
                                            self.pending_events.is_set or
                                            self.poll_interval.is_set or
                                            self.state_change_count.is_set or
                                            (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_data()) or
                                            (self.neighbor_retransmission_information is not None and self.neighbor_retransmission_information.has_data()) or
                                            (self.neighbor_summary is not None and self.neighbor_summary.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.adjacency_sid_label.yfilter != YFilter.not_set or
                                            self.adjacency_sid_protected.yfilter != YFilter.not_set or
                                            self.adjacency_sid_unprotected_label.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.interface_type.yfilter != YFilter.not_set or
                                            self.last_oob_time.yfilter != YFilter.not_set or
                                            self.lfa_interface.yfilter != YFilter.not_set or
                                            self.lfa_neighbor_id.yfilter != YFilter.not_set or
                                            self.lfa_neighbor_revision.yfilter != YFilter.not_set or
                                            self.lfa_next_hop.yfilter != YFilter.not_set or
                                            self.neighbor_ack_list_count.yfilter != YFilter.not_set or
                                            self.neighbor_ack_list_high_watermark.yfilter != YFilter.not_set or
                                            self.neighbor_address.yfilter != YFilter.not_set or
                                            self.neighbor_area_id.yfilter != YFilter.not_set or
                                            self.neighbor_backup_designated_router_address.yfilter != YFilter.not_set or
                                            self.neighbor_cost.yfilter != YFilter.not_set or
                                            self.neighbor_designated_router_address.yfilter != YFilter.not_set or
                                            self.neighbor_filter.yfilter != YFilter.not_set or
                                            self.neighbor_lls_option.yfilter != YFilter.not_set or
                                            self.neighbor_option.yfilter != YFilter.not_set or
                                            self.next_poll_interval.yfilter != YFilter.not_set or
                                            self.nsf_router_state.yfilter != YFilter.not_set or
                                            self.oob_resynchronization.yfilter != YFilter.not_set or
                                            self.pending_events.yfilter != YFilter.not_set or
                                            self.poll_interval.yfilter != YFilter.not_set or
                                            self.state_change_count.yfilter != YFilter.not_set or
                                            (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_operation()) or
                                            (self.neighbor_retransmission_information is not None and self.neighbor_retransmission_information.has_operation()) or
                                            (self.neighbor_summary is not None and self.neighbor_summary.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-detail" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.adjacency_sid_label.is_set or self.adjacency_sid_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.adjacency_sid_label.get_name_leafdata())
                                        if (self.adjacency_sid_protected.is_set or self.adjacency_sid_protected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.adjacency_sid_protected.get_name_leafdata())
                                        if (self.adjacency_sid_unprotected_label.is_set or self.adjacency_sid_unprotected_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.adjacency_sid_unprotected_label.get_name_leafdata())
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.interface_type.is_set or self.interface_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_type.get_name_leafdata())
                                        if (self.last_oob_time.is_set or self.last_oob_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_oob_time.get_name_leafdata())
                                        if (self.lfa_interface.is_set or self.lfa_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lfa_interface.get_name_leafdata())
                                        if (self.lfa_neighbor_id.is_set or self.lfa_neighbor_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lfa_neighbor_id.get_name_leafdata())
                                        if (self.lfa_neighbor_revision.is_set or self.lfa_neighbor_revision.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lfa_neighbor_revision.get_name_leafdata())
                                        if (self.lfa_next_hop.is_set or self.lfa_next_hop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lfa_next_hop.get_name_leafdata())
                                        if (self.neighbor_ack_list_count.is_set or self.neighbor_ack_list_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_ack_list_count.get_name_leafdata())
                                        if (self.neighbor_ack_list_high_watermark.is_set or self.neighbor_ack_list_high_watermark.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_ack_list_high_watermark.get_name_leafdata())
                                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                        if (self.neighbor_area_id.is_set or self.neighbor_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_area_id.get_name_leafdata())
                                        if (self.neighbor_backup_designated_router_address.is_set or self.neighbor_backup_designated_router_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_backup_designated_router_address.get_name_leafdata())
                                        if (self.neighbor_cost.is_set or self.neighbor_cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_cost.get_name_leafdata())
                                        if (self.neighbor_designated_router_address.is_set or self.neighbor_designated_router_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_designated_router_address.get_name_leafdata())
                                        if (self.neighbor_filter.is_set or self.neighbor_filter.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_filter.get_name_leafdata())
                                        if (self.neighbor_lls_option.is_set or self.neighbor_lls_option.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_lls_option.get_name_leafdata())
                                        if (self.neighbor_option.is_set or self.neighbor_option.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_option.get_name_leafdata())
                                        if (self.next_poll_interval.is_set or self.next_poll_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_poll_interval.get_name_leafdata())
                                        if (self.nsf_router_state.is_set or self.nsf_router_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsf_router_state.get_name_leafdata())
                                        if (self.oob_resynchronization.is_set or self.oob_resynchronization.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.oob_resynchronization.get_name_leafdata())
                                        if (self.pending_events.is_set or self.pending_events.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pending_events.get_name_leafdata())
                                        if (self.poll_interval.is_set or self.poll_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.poll_interval.get_name_leafdata())
                                        if (self.state_change_count.is_set or self.state_change_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_change_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "neighbor-bfd-information"):
                                            if (self.neighbor_bfd_information is None):
                                                self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation()
                                                self.neighbor_bfd_information.parent = self
                                                self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                            return self.neighbor_bfd_information

                                        if (child_yang_name == "neighbor-retransmission-information"):
                                            if (self.neighbor_retransmission_information is None):
                                                self.neighbor_retransmission_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation()
                                                self.neighbor_retransmission_information.parent = self
                                                self._children_name_map["neighbor_retransmission_information"] = "neighbor-retransmission-information"
                                            return self.neighbor_retransmission_information

                                        if (child_yang_name == "neighbor-summary"):
                                            if (self.neighbor_summary is None):
                                                self.neighbor_summary = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary()
                                                self.neighbor_summary.parent = self
                                                self._children_name_map["neighbor_summary"] = "neighbor-summary"
                                            return self.neighbor_summary

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "neighbor-bfd-information" or name == "neighbor-retransmission-information" or name == "neighbor-summary" or name == "adjacency-sid-label" or name == "adjacency-sid-protected" or name == "adjacency-sid-unprotected-label" or name == "interface-name" or name == "interface-type" or name == "last-oob-time" or name == "lfa-interface" or name == "lfa-neighbor-id" or name == "lfa-neighbor-revision" or name == "lfa-next-hop" or name == "neighbor-ack-list-count" or name == "neighbor-ack-list-high-watermark" or name == "neighbor-address" or name == "neighbor-area-id" or name == "neighbor-backup-designated-router-address" or name == "neighbor-cost" or name == "neighbor-designated-router-address" or name == "neighbor-filter" or name == "neighbor-lls-option" or name == "neighbor-option" or name == "next-poll-interval" or name == "nsf-router-state" or name == "oob-resynchronization" or name == "pending-events" or name == "poll-interval" or name == "state-change-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "adjacency-sid-label"):
                                            self.adjacency_sid_label = value
                                            self.adjacency_sid_label.value_namespace = name_space
                                            self.adjacency_sid_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "adjacency-sid-protected"):
                                            self.adjacency_sid_protected = value
                                            self.adjacency_sid_protected.value_namespace = name_space
                                            self.adjacency_sid_protected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "adjacency-sid-unprotected-label"):
                                            self.adjacency_sid_unprotected_label = value
                                            self.adjacency_sid_unprotected_label.value_namespace = name_space
                                            self.adjacency_sid_unprotected_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-type"):
                                            self.interface_type = value
                                            self.interface_type.value_namespace = name_space
                                            self.interface_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-oob-time"):
                                            self.last_oob_time = value
                                            self.last_oob_time.value_namespace = name_space
                                            self.last_oob_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lfa-interface"):
                                            self.lfa_interface = value
                                            self.lfa_interface.value_namespace = name_space
                                            self.lfa_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lfa-neighbor-id"):
                                            self.lfa_neighbor_id = value
                                            self.lfa_neighbor_id.value_namespace = name_space
                                            self.lfa_neighbor_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lfa-neighbor-revision"):
                                            self.lfa_neighbor_revision = value
                                            self.lfa_neighbor_revision.value_namespace = name_space
                                            self.lfa_neighbor_revision.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lfa-next-hop"):
                                            self.lfa_next_hop = value
                                            self.lfa_next_hop.value_namespace = name_space
                                            self.lfa_next_hop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-ack-list-count"):
                                            self.neighbor_ack_list_count = value
                                            self.neighbor_ack_list_count.value_namespace = name_space
                                            self.neighbor_ack_list_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-ack-list-high-watermark"):
                                            self.neighbor_ack_list_high_watermark = value
                                            self.neighbor_ack_list_high_watermark.value_namespace = name_space
                                            self.neighbor_ack_list_high_watermark.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-address"):
                                            self.neighbor_address = value
                                            self.neighbor_address.value_namespace = name_space
                                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-area-id"):
                                            self.neighbor_area_id = value
                                            self.neighbor_area_id.value_namespace = name_space
                                            self.neighbor_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-backup-designated-router-address"):
                                            self.neighbor_backup_designated_router_address = value
                                            self.neighbor_backup_designated_router_address.value_namespace = name_space
                                            self.neighbor_backup_designated_router_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-cost"):
                                            self.neighbor_cost = value
                                            self.neighbor_cost.value_namespace = name_space
                                            self.neighbor_cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-designated-router-address"):
                                            self.neighbor_designated_router_address = value
                                            self.neighbor_designated_router_address.value_namespace = name_space
                                            self.neighbor_designated_router_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-filter"):
                                            self.neighbor_filter = value
                                            self.neighbor_filter.value_namespace = name_space
                                            self.neighbor_filter.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-lls-option"):
                                            self.neighbor_lls_option = value
                                            self.neighbor_lls_option.value_namespace = name_space
                                            self.neighbor_lls_option.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-option"):
                                            self.neighbor_option = value
                                            self.neighbor_option.value_namespace = name_space
                                            self.neighbor_option.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-poll-interval"):
                                            self.next_poll_interval = value
                                            self.next_poll_interval.value_namespace = name_space
                                            self.next_poll_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsf-router-state"):
                                            self.nsf_router_state = value
                                            self.nsf_router_state.value_namespace = name_space
                                            self.nsf_router_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "oob-resynchronization"):
                                            self.oob_resynchronization = value
                                            self.oob_resynchronization.value_namespace = name_space
                                            self.oob_resynchronization.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pending-events"):
                                            self.pending_events = value
                                            self.pending_events.value_namespace = name_space
                                            self.pending_events.value_namespace_prefix = name_space_prefix
                                        if(value_path == "poll-interval"):
                                            self.poll_interval = value
                                            self.poll_interval.value_namespace = name_space
                                            self.poll_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-change-count"):
                                            self.state_change_count = value
                                            self.state_change_count.value_namespace = name_space
                                            self.state_change_count.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.neighbor_detail:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.neighbor_detail:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "neighbor-details" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "neighbor-detail"):
                                        for c in self.neighbor_detail:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.neighbor_detail.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "neighbor-detail"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class Interfaces(Entity):
                                """
                                OSPF Interface Table
                                
                                .. attribute:: interface
                                
                                	OSPF interface information
                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces, self).__init__()

                                    self.yang_name = "interfaces"
                                    self.yang_parent_name = "area"

                                    self.interface = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces, self).__setattr__(name, value)


                                class Interface(Entity):
                                    """
                                    OSPF interface information
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: active_interface
                                    
                                    	Active interface details
                                    	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface>`
                                    
                                    .. attribute:: backup_designated_router
                                    
                                    	If true, backup designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_designated_router_address
                                    
                                    	Backup designated router interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_designated_router_id
                                    
                                    	Backup designated router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cfg_cost_fallback
                                    
                                    	If true, cost fallback is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: configured_demand_circuit
                                    
                                    	If true, configured as demand circuit
                                    	**type**\:  bool
                                    
                                    .. attribute:: configured_ldp_sync
                                    
                                    	If true, configured as LDP sync
                                    	**type**\:  bool
                                    
                                    .. attribute:: configured_ldp_sync_igp_shortcuts
                                    
                                    	If true, sync igp shortcuts
                                    	**type**\:  bool
                                    
                                    .. attribute:: cost_fallback_active
                                    
                                    	If true, cost fallback is active
                                    	**type**\:  bool
                                    
                                    .. attribute:: dead_interval
                                    
                                    	Configured dead interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: designated_router
                                    
                                    	If true, designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: designated_router_address
                                    
                                    	Designated router interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: designated_router_id
                                    
                                    	Designated router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: fast_detect_hold_down_time
                                    
                                    	Hold\-down time in ms for fast\-detect event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fast_detect_hold_down_time_remaining
                                    
                                    	Remaining hold down time in ms
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fast_reroute_topology_independent_lfa
                                    
                                    	Topology Independent LFA
                                    	**type**\:  bool
                                    
                                    .. attribute:: fast_reroute_type
                                    
                                    	IP Fast Reroute Type
                                    	**type**\:   :py:class:`Ipfrr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ipfrr>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Configured hello interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: hello_interval_ms
                                    
                                    	Configured hello interval (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_ack_list_count
                                    
                                    	Ack List Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_ack_list_high_watermark
                                    
                                    	Ack List High Watermark
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_address
                                    
                                    	Interface IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_area
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: interface_bandwidth
                                    
                                    	Interface bandwidth
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_bfd_information
                                    
                                    	BFD information
                                    	**type**\:   :py:class:`InterfaceBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation>`
                                    
                                    .. attribute:: interface_cost_fallback
                                    
                                    	Interface fallback cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_dc_bitless_lsa_count
                                    
                                    	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_demand_circuit
                                    
                                    	If true, interface running as demand circuit
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_fast_detect_hold_down
                                    
                                    	Link in hold\-down state due to fast detect event
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_last_nsf
                                    
                                    	Time since last NSF restart (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_ldp_sync
                                    
                                    	If true, interface LDP sync is achieved
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_line_state
                                    
                                    	If true, line protocol is up
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_lsa_filter
                                    
                                    	Filter is configured for out going LSAs
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_madj
                                    
                                    	Information for multi\-area on the interface
                                    	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceMadj>`
                                    
                                    .. attribute:: interface_madj_count
                                    
                                    	Total number of multi\-area
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_mask
                                    
                                    	Interface IP Mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: interface_neighbor
                                    
                                    	Information for neighbors on the interface
                                    	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor>`
                                    
                                    .. attribute:: interface_nsf
                                    
                                    	If true, NSF restart in progress on this interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_nsf_enabled
                                    
                                    	If true, NSF is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_priority
                                    
                                    	Interface priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: interface_retransmission_interrval
                                    
                                    	Configured retransmit interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_router_id
                                    
                                    	Interface Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_sid
                                    
                                    	Interface SID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_sid_n_flag_clear
                                    
                                    	SID N\-Flag Clear
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_sid_php_off
                                    
                                    	SID PHP Off
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_state
                                    
                                    	Interface state
                                    	**type**\:   :py:class:`InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.InterfaceState>`
                                    
                                    .. attribute:: interface_strict_spf_sid
                                    
                                    	Interface Strict\-SPF SID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_strict_spf_sid_n_flag_clear
                                    
                                    	Strict\-SPF SID N\-Flag Clear
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_strict_spf_sid_php_off
                                    
                                    	Strict\-SPF SID PHP Off
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_tunnel_flags
                                    
                                    	Interface tunnel flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interfaceis_madj
                                    
                                    	If true, interface is multi\-area
                                    	**type**\:  bool
                                    
                                    .. attribute:: ip_mtu
                                    
                                    	IP MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ipfrr_tiebreakers
                                    
                                    	IPFRR\-Tiebreakers list
                                    	**type**\: list of    :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers>`
                                    
                                    .. attribute:: is_loopback_stub_network
                                    
                                    	If true, loopback interface is advertised as a stub network
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_packet_size
                                    
                                    	Maximum Packet Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: network_lsa_flush_timer
                                    
                                    	The amount of time in seconds before flush timer for old network LSA expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: network_type
                                    
                                    	Network type
                                    	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                                    
                                    .. attribute:: next_hello_time
                                    
                                    	Time until next Hello (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hello_time_ms
                                    
                                    	Time until next Hello (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                    
                                    .. attribute:: passive_interface
                                    
                                    	If true, passive interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: prefix_suppress_primary_addresses
                                    
                                    	Prefix Suppression for primary addresses
                                    	**type**\:  bool
                                    
                                    .. attribute:: prefix_suppress_secondary_addresses
                                    
                                    	Prefix Suppression for secondary addresses
                                    	**type**\:  bool
                                    
                                    .. attribute:: registered_for_link_down_fast_detection
                                    
                                    	Registered for Link Down Fast Detection
                                    	**type**\:  bool
                                    
                                    .. attribute:: srlg
                                    
                                    	SRLG Values
                                    	**type**\: list of    :py:class:`Srlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.Srlg>`
                                    
                                    .. attribute:: transmission_delay
                                    
                                    	Interface Transmission delay
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ttl_security_enabled
                                    
                                    	TTL security enabled on the interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: ttl_security_hop_count
                                    
                                    	TTL security hop counts
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: wait_interval
                                    
                                    	Configured wait interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "interfaces"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.backup_designated_router = YLeaf(YType.boolean, "backup-designated-router")

                                        self.backup_designated_router_address = YLeaf(YType.str, "backup-designated-router-address")

                                        self.backup_designated_router_id = YLeaf(YType.str, "backup-designated-router-id")

                                        self.cfg_cost_fallback = YLeaf(YType.boolean, "cfg-cost-fallback")

                                        self.configured_demand_circuit = YLeaf(YType.boolean, "configured-demand-circuit")

                                        self.configured_ldp_sync = YLeaf(YType.boolean, "configured-ldp-sync")

                                        self.configured_ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "configured-ldp-sync-igp-shortcuts")

                                        self.cost_fallback_active = YLeaf(YType.boolean, "cost-fallback-active")

                                        self.dead_interval = YLeaf(YType.uint32, "dead-interval")

                                        self.designated_router = YLeaf(YType.boolean, "designated-router")

                                        self.designated_router_address = YLeaf(YType.str, "designated-router-address")

                                        self.designated_router_id = YLeaf(YType.str, "designated-router-id")

                                        self.fast_detect_hold_down_time = YLeaf(YType.uint32, "fast-detect-hold-down-time")

                                        self.fast_detect_hold_down_time_remaining = YLeaf(YType.uint32, "fast-detect-hold-down-time-remaining")

                                        self.fast_reroute_topology_independent_lfa = YLeaf(YType.boolean, "fast-reroute-topology-independent-lfa")

                                        self.fast_reroute_type = YLeaf(YType.enumeration, "fast-reroute-type")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.hello_interval_ms = YLeaf(YType.uint32, "hello-interval-ms")

                                        self.interface_ack_list_count = YLeaf(YType.uint32, "interface-ack-list-count")

                                        self.interface_ack_list_high_watermark = YLeaf(YType.uint32, "interface-ack-list-high-watermark")

                                        self.interface_address = YLeaf(YType.str, "interface-address")

                                        self.interface_area = YLeaf(YType.str, "interface-area")

                                        self.interface_bandwidth = YLeaf(YType.uint32, "interface-bandwidth")

                                        self.interface_cost_fallback = YLeaf(YType.uint16, "interface-cost-fallback")

                                        self.interface_dc_bitless_lsa_count = YLeaf(YType.uint32, "interface-dc-bitless-lsa-count")

                                        self.interface_demand_circuit = YLeaf(YType.boolean, "interface-demand-circuit")

                                        self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                        self.interface_last_nsf = YLeaf(YType.uint32, "interface-last-nsf")

                                        self.interface_ldp_sync = YLeaf(YType.boolean, "interface-ldp-sync")

                                        self.interface_line_state = YLeaf(YType.boolean, "interface-line-state")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_lsa_filter = YLeaf(YType.boolean, "interface-lsa-filter")

                                        self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                        self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                        self.interface_nsf = YLeaf(YType.boolean, "interface-nsf")

                                        self.interface_nsf_enabled = YLeaf(YType.boolean, "interface-nsf-enabled")

                                        self.interface_priority = YLeaf(YType.uint8, "interface-priority")

                                        self.interface_retransmission_interrval = YLeaf(YType.uint32, "interface-retransmission-interrval")

                                        self.interface_router_id = YLeaf(YType.str, "interface-router-id")

                                        self.interface_sid = YLeaf(YType.uint32, "interface-sid")

                                        self.interface_sid_n_flag_clear = YLeaf(YType.boolean, "interface-sid-n-flag-clear")

                                        self.interface_sid_php_off = YLeaf(YType.boolean, "interface-sid-php-off")

                                        self.interface_state = YLeaf(YType.enumeration, "interface-state")

                                        self.interface_strict_spf_sid = YLeaf(YType.uint32, "interface-strict-spf-sid")

                                        self.interface_strict_spf_sid_n_flag_clear = YLeaf(YType.boolean, "interface-strict-spf-sid-n-flag-clear")

                                        self.interface_strict_spf_sid_php_off = YLeaf(YType.boolean, "interface-strict-spf-sid-php-off")

                                        self.interface_tunnel_flags = YLeaf(YType.uint32, "interface-tunnel-flags")

                                        self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                        self.ip_mtu = YLeaf(YType.uint16, "ip-mtu")

                                        self.is_loopback_stub_network = YLeaf(YType.boolean, "is-loopback-stub-network")

                                        self.maximum_packet_size = YLeaf(YType.uint16, "maximum-packet-size")

                                        self.network_lsa_flush_timer = YLeaf(YType.uint32, "network-lsa-flush-timer")

                                        self.network_type = YLeaf(YType.enumeration, "network-type")

                                        self.next_hello_time = YLeaf(YType.uint32, "next-hello-time")

                                        self.next_hello_time_ms = YLeaf(YType.uint32, "next-hello-time-ms")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                                        self.prefix_suppress_primary_addresses = YLeaf(YType.boolean, "prefix-suppress-primary-addresses")

                                        self.prefix_suppress_secondary_addresses = YLeaf(YType.boolean, "prefix-suppress-secondary-addresses")

                                        self.registered_for_link_down_fast_detection = YLeaf(YType.boolean, "registered-for-link-down-fast-detection")

                                        self.transmission_delay = YLeaf(YType.uint16, "transmission-delay")

                                        self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                        self.ttl_security_hop_count = YLeaf(YType.uint32, "ttl-security-hop-count")

                                        self.wait_interval = YLeaf(YType.uint32, "wait-interval")

                                        self.active_interface = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface()
                                        self.active_interface.parent = self
                                        self._children_name_map["active_interface"] = "active-interface"
                                        self._children_yang_names.add("active-interface")

                                        self.interface_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation()
                                        self.interface_bfd_information.parent = self
                                        self._children_name_map["interface_bfd_information"] = "interface-bfd-information"
                                        self._children_yang_names.add("interface-bfd-information")

                                        self.interface_madj = YList(self)
                                        self.interface_neighbor = YList(self)
                                        self.ipfrr_tiebreakers = YList(self)
                                        self.srlg = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name",
                                                        "backup_designated_router",
                                                        "backup_designated_router_address",
                                                        "backup_designated_router_id",
                                                        "cfg_cost_fallback",
                                                        "configured_demand_circuit",
                                                        "configured_ldp_sync",
                                                        "configured_ldp_sync_igp_shortcuts",
                                                        "cost_fallback_active",
                                                        "dead_interval",
                                                        "designated_router",
                                                        "designated_router_address",
                                                        "designated_router_id",
                                                        "fast_detect_hold_down_time",
                                                        "fast_detect_hold_down_time_remaining",
                                                        "fast_reroute_topology_independent_lfa",
                                                        "fast_reroute_type",
                                                        "hello_interval",
                                                        "hello_interval_ms",
                                                        "interface_ack_list_count",
                                                        "interface_ack_list_high_watermark",
                                                        "interface_address",
                                                        "interface_area",
                                                        "interface_bandwidth",
                                                        "interface_cost_fallback",
                                                        "interface_dc_bitless_lsa_count",
                                                        "interface_demand_circuit",
                                                        "interface_fast_detect_hold_down",
                                                        "interface_last_nsf",
                                                        "interface_ldp_sync",
                                                        "interface_line_state",
                                                        "interface_link_cost",
                                                        "interface_lsa_filter",
                                                        "interface_madj_count",
                                                        "interface_mask",
                                                        "interface_name_xr",
                                                        "interface_nsf",
                                                        "interface_nsf_enabled",
                                                        "interface_priority",
                                                        "interface_retransmission_interrval",
                                                        "interface_router_id",
                                                        "interface_sid",
                                                        "interface_sid_n_flag_clear",
                                                        "interface_sid_php_off",
                                                        "interface_state",
                                                        "interface_strict_spf_sid",
                                                        "interface_strict_spf_sid_n_flag_clear",
                                                        "interface_strict_spf_sid_php_off",
                                                        "interface_tunnel_flags",
                                                        "interfaceis_madj",
                                                        "ip_mtu",
                                                        "is_loopback_stub_network",
                                                        "maximum_packet_size",
                                                        "network_lsa_flush_timer",
                                                        "network_type",
                                                        "next_hello_time",
                                                        "next_hello_time_ms",
                                                        "ospf_interface_state",
                                                        "passive_interface",
                                                        "prefix_suppress_primary_addresses",
                                                        "prefix_suppress_secondary_addresses",
                                                        "registered_for_link_down_fast_detection",
                                                        "transmission_delay",
                                                        "ttl_security_enabled",
                                                        "ttl_security_hop_count",
                                                        "wait_interval") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface, self).__setattr__(name, value)


                                    class InterfaceBfdInformation(Entity):
                                        """
                                        BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: detection_multiplier
                                        
                                        	BFD detection multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interval
                                        
                                        	BFD interval (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation, self).__init__()

                                            self.yang_name = "interface-bfd-information"
                                            self.yang_parent_name = "interface"

                                            self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                            self.interval = YLeaf(YType.uint32, "interval")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bfd_intf_enable_mode",
                                                            "detection_multiplier",
                                                            "interval") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bfd_intf_enable_mode.is_set or
                                                self.detection_multiplier.is_set or
                                                self.interval.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                                self.detection_multiplier.yfilter != YFilter.not_set or
                                                self.interval.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-bfd-information" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                            if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interval.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bfd-intf-enable-mode" or name == "detection-multiplier" or name == "interval"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bfd-intf-enable-mode"):
                                                self.bfd_intf_enable_mode = value
                                                self.bfd_intf_enable_mode.value_namespace = name_space
                                                self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "detection-multiplier"):
                                                self.detection_multiplier = value
                                                self.detection_multiplier.value_namespace = name_space
                                                self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interval"):
                                                self.interval = value
                                                self.interval.value_namespace = name_space
                                                self.interval.value_namespace_prefix = name_space_prefix


                                    class ActiveInterface(Entity):
                                        """
                                        Active interface details
                                        
                                        .. attribute:: flood_scan_length
                                        
                                        	Last flood scan length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_flood_index
                                        
                                        	Area scope LSAs flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_next_flood
                                        
                                        	Next LSA to flood (Area scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_next_flood_index
                                        
                                        	Index of next LSA to flood (Area scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_flood_index
                                        
                                        	AS scope LSAs flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_next_flood
                                        
                                        	Next LSA to flood (AS scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_next_flood_index
                                        
                                        	Index of next LSA to flood (AS scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_authentication_type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                        
                                        .. attribute:: interface_flood_length
                                        
                                        	Flood queue length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_flood_pacing_timer
                                        
                                        	Time until next flood pacing timer (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_neighbor_count
                                        
                                        	Total number of Neighbors
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: keychain_id
                                        
                                        	Keychain ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_flood_time
                                        
                                        	Last flood scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_flood_length
                                        
                                        	Maximum flood length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_flood_time
                                        
                                        	Maximum flood time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: md_keys
                                        
                                        	List of old MD keys
                                        	**type**\: list of    :py:class:`MdKeys <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys>`
                                        
                                        .. attribute:: old_md5_key_neighbor_count
                                        
                                        	Number of neighbors using the old key (if rollover in progress)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_hello_count
                                        
                                        	Number of neighbors for which hellos are suppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: wait_time
                                        
                                        	Wait time for DR/BDR selection (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: youngest_md_key
                                        
                                        	If true, MD key is configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: youngest_md_key_id
                                        
                                        	Youngest MD key ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface, self).__init__()

                                            self.yang_name = "active-interface"
                                            self.yang_parent_name = "interface"

                                            self.flood_scan_length = YLeaf(YType.uint32, "flood-scan-length")

                                            self.interface_area_flood_index = YLeaf(YType.uint32, "interface-area-flood-index")

                                            self.interface_area_next_flood = YLeaf(YType.uint32, "interface-area-next-flood")

                                            self.interface_area_next_flood_index = YLeaf(YType.uint32, "interface-area-next-flood-index")

                                            self.interface_as_flood_index = YLeaf(YType.uint32, "interface-as-flood-index")

                                            self.interface_as_next_flood = YLeaf(YType.uint32, "interface-as-next-flood")

                                            self.interface_as_next_flood_index = YLeaf(YType.uint32, "interface-as-next-flood-index")

                                            self.interface_authentication_type = YLeaf(YType.enumeration, "interface-authentication-type")

                                            self.interface_flood_length = YLeaf(YType.uint32, "interface-flood-length")

                                            self.interface_flood_pacing_timer = YLeaf(YType.uint32, "interface-flood-pacing-timer")

                                            self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                            self.keychain_id = YLeaf(YType.uint64, "keychain-id")

                                            self.last_flood_time = YLeaf(YType.uint32, "last-flood-time")

                                            self.maximum_flood_length = YLeaf(YType.uint32, "maximum-flood-length")

                                            self.maximum_flood_time = YLeaf(YType.uint32, "maximum-flood-time")

                                            self.old_md5_key_neighbor_count = YLeaf(YType.uint32, "old-md5-key-neighbor-count")

                                            self.suppress_hello_count = YLeaf(YType.uint16, "suppress-hello-count")

                                            self.wait_time = YLeaf(YType.uint32, "wait-time")

                                            self.youngest_md_key = YLeaf(YType.boolean, "youngest-md-key")

                                            self.youngest_md_key_id = YLeaf(YType.uint16, "youngest-md-key-id")

                                            self.md_keys = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("flood_scan_length",
                                                            "interface_area_flood_index",
                                                            "interface_area_next_flood",
                                                            "interface_area_next_flood_index",
                                                            "interface_as_flood_index",
                                                            "interface_as_next_flood",
                                                            "interface_as_next_flood_index",
                                                            "interface_authentication_type",
                                                            "interface_flood_length",
                                                            "interface_flood_pacing_timer",
                                                            "interface_neighbor_count",
                                                            "keychain_id",
                                                            "last_flood_time",
                                                            "maximum_flood_length",
                                                            "maximum_flood_time",
                                                            "old_md5_key_neighbor_count",
                                                            "suppress_hello_count",
                                                            "wait_time",
                                                            "youngest_md_key",
                                                            "youngest_md_key_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface, self).__setattr__(name, value)


                                        class MdKeys(Entity):
                                            """
                                            List of old MD keys
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys, self).__init__()

                                                self.yang_name = "md-keys"
                                                self.yang_parent_name = "active-interface"

                                                self.entry = YLeaf(YType.uint16, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "md-keys" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.md_keys:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.flood_scan_length.is_set or
                                                self.interface_area_flood_index.is_set or
                                                self.interface_area_next_flood.is_set or
                                                self.interface_area_next_flood_index.is_set or
                                                self.interface_as_flood_index.is_set or
                                                self.interface_as_next_flood.is_set or
                                                self.interface_as_next_flood_index.is_set or
                                                self.interface_authentication_type.is_set or
                                                self.interface_flood_length.is_set or
                                                self.interface_flood_pacing_timer.is_set or
                                                self.interface_neighbor_count.is_set or
                                                self.keychain_id.is_set or
                                                self.last_flood_time.is_set or
                                                self.maximum_flood_length.is_set or
                                                self.maximum_flood_time.is_set or
                                                self.old_md5_key_neighbor_count.is_set or
                                                self.suppress_hello_count.is_set or
                                                self.wait_time.is_set or
                                                self.youngest_md_key.is_set or
                                                self.youngest_md_key_id.is_set)

                                        def has_operation(self):
                                            for c in self.md_keys:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.flood_scan_length.yfilter != YFilter.not_set or
                                                self.interface_area_flood_index.yfilter != YFilter.not_set or
                                                self.interface_area_next_flood.yfilter != YFilter.not_set or
                                                self.interface_area_next_flood_index.yfilter != YFilter.not_set or
                                                self.interface_as_flood_index.yfilter != YFilter.not_set or
                                                self.interface_as_next_flood.yfilter != YFilter.not_set or
                                                self.interface_as_next_flood_index.yfilter != YFilter.not_set or
                                                self.interface_authentication_type.yfilter != YFilter.not_set or
                                                self.interface_flood_length.yfilter != YFilter.not_set or
                                                self.interface_flood_pacing_timer.yfilter != YFilter.not_set or
                                                self.interface_neighbor_count.yfilter != YFilter.not_set or
                                                self.keychain_id.yfilter != YFilter.not_set or
                                                self.last_flood_time.yfilter != YFilter.not_set or
                                                self.maximum_flood_length.yfilter != YFilter.not_set or
                                                self.maximum_flood_time.yfilter != YFilter.not_set or
                                                self.old_md5_key_neighbor_count.yfilter != YFilter.not_set or
                                                self.suppress_hello_count.yfilter != YFilter.not_set or
                                                self.wait_time.yfilter != YFilter.not_set or
                                                self.youngest_md_key.yfilter != YFilter.not_set or
                                                self.youngest_md_key_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "active-interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.flood_scan_length.is_set or self.flood_scan_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_scan_length.get_name_leafdata())
                                            if (self.interface_area_flood_index.is_set or self.interface_area_flood_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_area_flood_index.get_name_leafdata())
                                            if (self.interface_area_next_flood.is_set or self.interface_area_next_flood.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_area_next_flood.get_name_leafdata())
                                            if (self.interface_area_next_flood_index.is_set or self.interface_area_next_flood_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_area_next_flood_index.get_name_leafdata())
                                            if (self.interface_as_flood_index.is_set or self.interface_as_flood_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_as_flood_index.get_name_leafdata())
                                            if (self.interface_as_next_flood.is_set or self.interface_as_next_flood.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_as_next_flood.get_name_leafdata())
                                            if (self.interface_as_next_flood_index.is_set or self.interface_as_next_flood_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_as_next_flood_index.get_name_leafdata())
                                            if (self.interface_authentication_type.is_set or self.interface_authentication_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_authentication_type.get_name_leafdata())
                                            if (self.interface_flood_length.is_set or self.interface_flood_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_flood_length.get_name_leafdata())
                                            if (self.interface_flood_pacing_timer.is_set or self.interface_flood_pacing_timer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_flood_pacing_timer.get_name_leafdata())
                                            if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                            if (self.keychain_id.is_set or self.keychain_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_id.get_name_leafdata())
                                            if (self.last_flood_time.is_set or self.last_flood_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.last_flood_time.get_name_leafdata())
                                            if (self.maximum_flood_length.is_set or self.maximum_flood_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_flood_length.get_name_leafdata())
                                            if (self.maximum_flood_time.is_set or self.maximum_flood_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_flood_time.get_name_leafdata())
                                            if (self.old_md5_key_neighbor_count.is_set or self.old_md5_key_neighbor_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.old_md5_key_neighbor_count.get_name_leafdata())
                                            if (self.suppress_hello_count.is_set or self.suppress_hello_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.suppress_hello_count.get_name_leafdata())
                                            if (self.wait_time.is_set or self.wait_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.wait_time.get_name_leafdata())
                                            if (self.youngest_md_key.is_set or self.youngest_md_key.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.youngest_md_key.get_name_leafdata())
                                            if (self.youngest_md_key_id.is_set or self.youngest_md_key_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.youngest_md_key_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "md-keys"):
                                                for c in self.md_keys:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.md_keys.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "md-keys" or name == "flood-scan-length" or name == "interface-area-flood-index" or name == "interface-area-next-flood" or name == "interface-area-next-flood-index" or name == "interface-as-flood-index" or name == "interface-as-next-flood" or name == "interface-as-next-flood-index" or name == "interface-authentication-type" or name == "interface-flood-length" or name == "interface-flood-pacing-timer" or name == "interface-neighbor-count" or name == "keychain-id" or name == "last-flood-time" or name == "maximum-flood-length" or name == "maximum-flood-time" or name == "old-md5-key-neighbor-count" or name == "suppress-hello-count" or name == "wait-time" or name == "youngest-md-key" or name == "youngest-md-key-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "flood-scan-length"):
                                                self.flood_scan_length = value
                                                self.flood_scan_length.value_namespace = name_space
                                                self.flood_scan_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-area-flood-index"):
                                                self.interface_area_flood_index = value
                                                self.interface_area_flood_index.value_namespace = name_space
                                                self.interface_area_flood_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-area-next-flood"):
                                                self.interface_area_next_flood = value
                                                self.interface_area_next_flood.value_namespace = name_space
                                                self.interface_area_next_flood.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-area-next-flood-index"):
                                                self.interface_area_next_flood_index = value
                                                self.interface_area_next_flood_index.value_namespace = name_space
                                                self.interface_area_next_flood_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-as-flood-index"):
                                                self.interface_as_flood_index = value
                                                self.interface_as_flood_index.value_namespace = name_space
                                                self.interface_as_flood_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-as-next-flood"):
                                                self.interface_as_next_flood = value
                                                self.interface_as_next_flood.value_namespace = name_space
                                                self.interface_as_next_flood.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-as-next-flood-index"):
                                                self.interface_as_next_flood_index = value
                                                self.interface_as_next_flood_index.value_namespace = name_space
                                                self.interface_as_next_flood_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-authentication-type"):
                                                self.interface_authentication_type = value
                                                self.interface_authentication_type.value_namespace = name_space
                                                self.interface_authentication_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-flood-length"):
                                                self.interface_flood_length = value
                                                self.interface_flood_length.value_namespace = name_space
                                                self.interface_flood_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-flood-pacing-timer"):
                                                self.interface_flood_pacing_timer = value
                                                self.interface_flood_pacing_timer.value_namespace = name_space
                                                self.interface_flood_pacing_timer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-neighbor-count"):
                                                self.interface_neighbor_count = value
                                                self.interface_neighbor_count.value_namespace = name_space
                                                self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-id"):
                                                self.keychain_id = value
                                                self.keychain_id.value_namespace = name_space
                                                self.keychain_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "last-flood-time"):
                                                self.last_flood_time = value
                                                self.last_flood_time.value_namespace = name_space
                                                self.last_flood_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-flood-length"):
                                                self.maximum_flood_length = value
                                                self.maximum_flood_length.value_namespace = name_space
                                                self.maximum_flood_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-flood-time"):
                                                self.maximum_flood_time = value
                                                self.maximum_flood_time.value_namespace = name_space
                                                self.maximum_flood_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "old-md5-key-neighbor-count"):
                                                self.old_md5_key_neighbor_count = value
                                                self.old_md5_key_neighbor_count.value_namespace = name_space
                                                self.old_md5_key_neighbor_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "suppress-hello-count"):
                                                self.suppress_hello_count = value
                                                self.suppress_hello_count.value_namespace = name_space
                                                self.suppress_hello_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "wait-time"):
                                                self.wait_time = value
                                                self.wait_time.value_namespace = name_space
                                                self.wait_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "youngest-md-key"):
                                                self.youngest_md_key = value
                                                self.youngest_md_key.value_namespace = name_space
                                                self.youngest_md_key.value_namespace_prefix = name_space_prefix
                                            if(value_path == "youngest-md-key-id"):
                                                self.youngest_md_key_id = value
                                                self.youngest_md_key_id.value_namespace = name_space
                                                self.youngest_md_key_id.value_namespace_prefix = name_space_prefix


                                    class Srlg(Entity):
                                        """
                                        SRLG Values
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.Srlg, self).__init__()

                                            self.yang_name = "srlg"
                                            self.yang_parent_name = "interface"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.Srlg, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.Srlg, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "srlg" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix


                                    class InterfaceNeighbor(Entity):
                                        """
                                        Information for neighbors on the interface
                                        
                                        .. attribute:: interface_neighbor_cost
                                        
                                        	Cost of link to neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_neighbor_id
                                        
                                        	Neighbor Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_bdr
                                        
                                        	If true, Backup designated router
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_dr
                                        
                                        	If true, Designated router
                                        	**type**\:  bool
                                        
                                        .. attribute:: suppress_hello
                                        
                                        	If true, hellos suppressed
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor, self).__init__()

                                            self.yang_name = "interface-neighbor"
                                            self.yang_parent_name = "interface"

                                            self.interface_neighbor_cost = YLeaf(YType.uint32, "interface-neighbor-cost")

                                            self.interface_neighbor_id = YLeaf(YType.str, "interface-neighbor-id")

                                            self.neighbor_bdr = YLeaf(YType.boolean, "neighbor-bdr")

                                            self.neighbor_dr = YLeaf(YType.boolean, "neighbor-dr")

                                            self.suppress_hello = YLeaf(YType.boolean, "suppress-hello")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_neighbor_cost",
                                                            "interface_neighbor_id",
                                                            "neighbor_bdr",
                                                            "neighbor_dr",
                                                            "suppress_hello") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_neighbor_cost.is_set or
                                                self.interface_neighbor_id.is_set or
                                                self.neighbor_bdr.is_set or
                                                self.neighbor_dr.is_set or
                                                self.suppress_hello.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_neighbor_cost.yfilter != YFilter.not_set or
                                                self.interface_neighbor_id.yfilter != YFilter.not_set or
                                                self.neighbor_bdr.yfilter != YFilter.not_set or
                                                self.neighbor_dr.yfilter != YFilter.not_set or
                                                self.suppress_hello.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-neighbor" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_neighbor_cost.is_set or self.interface_neighbor_cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_neighbor_cost.get_name_leafdata())
                                            if (self.interface_neighbor_id.is_set or self.interface_neighbor_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_neighbor_id.get_name_leafdata())
                                            if (self.neighbor_bdr.is_set or self.neighbor_bdr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_bdr.get_name_leafdata())
                                            if (self.neighbor_dr.is_set or self.neighbor_dr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_dr.get_name_leafdata())
                                            if (self.suppress_hello.is_set or self.suppress_hello.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.suppress_hello.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-neighbor-cost" or name == "interface-neighbor-id" or name == "neighbor-bdr" or name == "neighbor-dr" or name == "suppress-hello"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-neighbor-cost"):
                                                self.interface_neighbor_cost = value
                                                self.interface_neighbor_cost.value_namespace = name_space
                                                self.interface_neighbor_cost.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-neighbor-id"):
                                                self.interface_neighbor_id = value
                                                self.interface_neighbor_id.value_namespace = name_space
                                                self.interface_neighbor_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-bdr"):
                                                self.neighbor_bdr = value
                                                self.neighbor_bdr.value_namespace = name_space
                                                self.neighbor_bdr.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-dr"):
                                                self.neighbor_dr = value
                                                self.neighbor_dr.value_namespace = name_space
                                                self.neighbor_dr.value_namespace_prefix = name_space_prefix
                                            if(value_path == "suppress-hello"):
                                                self.suppress_hello = value
                                                self.suppress_hello.value_namespace = name_space
                                                self.suppress_hello.value_namespace_prefix = name_space_prefix


                                    class InterfaceMadj(Entity):
                                        """
                                        Information for multi\-area on the interface
                                        
                                        .. attribute:: interface_adj_neighbor_count
                                        
                                        	Total number of Adjacent Neighbors
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: interface_area
                                        
                                        	Area ID string in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: interface_link_cost
                                        
                                        	Interface link cost
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: interface_neighbor_count
                                        
                                        	Number of Neighbors
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: madj_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ospf_interface_state
                                        
                                        	Interface OSPF state
                                        	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceMadj, self).__init__()

                                            self.yang_name = "interface-madj"
                                            self.yang_parent_name = "interface"

                                            self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                            self.interface_area = YLeaf(YType.str, "interface-area")

                                            self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                            self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                            self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                            self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_adj_neighbor_count",
                                                            "interface_area",
                                                            "interface_link_cost",
                                                            "interface_neighbor_count",
                                                            "madj_area_id",
                                                            "ospf_interface_state") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceMadj, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceMadj, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_adj_neighbor_count.is_set or
                                                self.interface_area.is_set or
                                                self.interface_link_cost.is_set or
                                                self.interface_neighbor_count.is_set or
                                                self.madj_area_id.is_set or
                                                self.ospf_interface_state.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_adj_neighbor_count.yfilter != YFilter.not_set or
                                                self.interface_area.yfilter != YFilter.not_set or
                                                self.interface_link_cost.yfilter != YFilter.not_set or
                                                self.interface_neighbor_count.yfilter != YFilter.not_set or
                                                self.madj_area_id.yfilter != YFilter.not_set or
                                                self.ospf_interface_state.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-madj" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_adj_neighbor_count.is_set or self.interface_adj_neighbor_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_adj_neighbor_count.get_name_leafdata())
                                            if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_area.get_name_leafdata())
                                            if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                            if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                            if (self.madj_area_id.is_set or self.madj_area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.madj_area_id.get_name_leafdata())
                                            if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-adj-neighbor-count" or name == "interface-area" or name == "interface-link-cost" or name == "interface-neighbor-count" or name == "madj-area-id" or name == "ospf-interface-state"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-adj-neighbor-count"):
                                                self.interface_adj_neighbor_count = value
                                                self.interface_adj_neighbor_count.value_namespace = name_space
                                                self.interface_adj_neighbor_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-area"):
                                                self.interface_area = value
                                                self.interface_area.value_namespace = name_space
                                                self.interface_area.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-link-cost"):
                                                self.interface_link_cost = value
                                                self.interface_link_cost.value_namespace = name_space
                                                self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-neighbor-count"):
                                                self.interface_neighbor_count = value
                                                self.interface_neighbor_count.value_namespace = name_space
                                                self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "madj-area-id"):
                                                self.madj_area_id = value
                                                self.madj_area_id.value_namespace = name_space
                                                self.madj_area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ospf-interface-state"):
                                                self.ospf_interface_state = value
                                                self.ospf_interface_state.value_namespace = name_space
                                                self.ospf_interface_state.value_namespace_prefix = name_space_prefix


                                    class IpfrrTiebreakers(Entity):
                                        """
                                        IPFRR\-Tiebreakers list
                                        
                                        .. attribute:: tiebreaker_index
                                        
                                        	Tiebreaker Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tiebreaker_type
                                        
                                        	Tiebreaker Type
                                        	**type**\:   :py:class:`IpfrrTbrkr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IpfrrTbrkr>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers, self).__init__()

                                            self.yang_name = "ipfrr-tiebreakers"
                                            self.yang_parent_name = "interface"

                                            self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                            self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tiebreaker_index",
                                                            "tiebreaker_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.tiebreaker_index.is_set or
                                                self.tiebreaker_type.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tiebreaker_index.yfilter != YFilter.not_set or
                                                self.tiebreaker_type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipfrr-tiebreakers" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())
                                            if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tiebreaker-index" or name == "tiebreaker-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tiebreaker-index"):
                                                self.tiebreaker_index = value
                                                self.tiebreaker_index.value_namespace = name_space
                                                self.tiebreaker_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tiebreaker-type"):
                                                self.tiebreaker_type = value
                                                self.tiebreaker_type.value_namespace = name_space
                                                self.tiebreaker_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface_madj:
                                            if (c.has_data()):
                                                return True
                                        for c in self.interface_neighbor:
                                            if (c.has_data()):
                                                return True
                                        for c in self.ipfrr_tiebreakers:
                                            if (c.has_data()):
                                                return True
                                        for c in self.srlg:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_name.is_set or
                                            self.backup_designated_router.is_set or
                                            self.backup_designated_router_address.is_set or
                                            self.backup_designated_router_id.is_set or
                                            self.cfg_cost_fallback.is_set or
                                            self.configured_demand_circuit.is_set or
                                            self.configured_ldp_sync.is_set or
                                            self.configured_ldp_sync_igp_shortcuts.is_set or
                                            self.cost_fallback_active.is_set or
                                            self.dead_interval.is_set or
                                            self.designated_router.is_set or
                                            self.designated_router_address.is_set or
                                            self.designated_router_id.is_set or
                                            self.fast_detect_hold_down_time.is_set or
                                            self.fast_detect_hold_down_time_remaining.is_set or
                                            self.fast_reroute_topology_independent_lfa.is_set or
                                            self.fast_reroute_type.is_set or
                                            self.hello_interval.is_set or
                                            self.hello_interval_ms.is_set or
                                            self.interface_ack_list_count.is_set or
                                            self.interface_ack_list_high_watermark.is_set or
                                            self.interface_address.is_set or
                                            self.interface_area.is_set or
                                            self.interface_bandwidth.is_set or
                                            self.interface_cost_fallback.is_set or
                                            self.interface_dc_bitless_lsa_count.is_set or
                                            self.interface_demand_circuit.is_set or
                                            self.interface_fast_detect_hold_down.is_set or
                                            self.interface_last_nsf.is_set or
                                            self.interface_ldp_sync.is_set or
                                            self.interface_line_state.is_set or
                                            self.interface_link_cost.is_set or
                                            self.interface_lsa_filter.is_set or
                                            self.interface_madj_count.is_set or
                                            self.interface_mask.is_set or
                                            self.interface_name_xr.is_set or
                                            self.interface_nsf.is_set or
                                            self.interface_nsf_enabled.is_set or
                                            self.interface_priority.is_set or
                                            self.interface_retransmission_interrval.is_set or
                                            self.interface_router_id.is_set or
                                            self.interface_sid.is_set or
                                            self.interface_sid_n_flag_clear.is_set or
                                            self.interface_sid_php_off.is_set or
                                            self.interface_state.is_set or
                                            self.interface_strict_spf_sid.is_set or
                                            self.interface_strict_spf_sid_n_flag_clear.is_set or
                                            self.interface_strict_spf_sid_php_off.is_set or
                                            self.interface_tunnel_flags.is_set or
                                            self.interfaceis_madj.is_set or
                                            self.ip_mtu.is_set or
                                            self.is_loopback_stub_network.is_set or
                                            self.maximum_packet_size.is_set or
                                            self.network_lsa_flush_timer.is_set or
                                            self.network_type.is_set or
                                            self.next_hello_time.is_set or
                                            self.next_hello_time_ms.is_set or
                                            self.ospf_interface_state.is_set or
                                            self.passive_interface.is_set or
                                            self.prefix_suppress_primary_addresses.is_set or
                                            self.prefix_suppress_secondary_addresses.is_set or
                                            self.registered_for_link_down_fast_detection.is_set or
                                            self.transmission_delay.is_set or
                                            self.ttl_security_enabled.is_set or
                                            self.ttl_security_hop_count.is_set or
                                            self.wait_interval.is_set or
                                            (self.active_interface is not None and self.active_interface.has_data()) or
                                            (self.interface_bfd_information is not None and self.interface_bfd_information.has_data()))

                                    def has_operation(self):
                                        for c in self.interface_madj:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.interface_neighbor:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.ipfrr_tiebreakers:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.srlg:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.backup_designated_router.yfilter != YFilter.not_set or
                                            self.backup_designated_router_address.yfilter != YFilter.not_set or
                                            self.backup_designated_router_id.yfilter != YFilter.not_set or
                                            self.cfg_cost_fallback.yfilter != YFilter.not_set or
                                            self.configured_demand_circuit.yfilter != YFilter.not_set or
                                            self.configured_ldp_sync.yfilter != YFilter.not_set or
                                            self.configured_ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                                            self.cost_fallback_active.yfilter != YFilter.not_set or
                                            self.dead_interval.yfilter != YFilter.not_set or
                                            self.designated_router.yfilter != YFilter.not_set or
                                            self.designated_router_address.yfilter != YFilter.not_set or
                                            self.designated_router_id.yfilter != YFilter.not_set or
                                            self.fast_detect_hold_down_time.yfilter != YFilter.not_set or
                                            self.fast_detect_hold_down_time_remaining.yfilter != YFilter.not_set or
                                            self.fast_reroute_topology_independent_lfa.yfilter != YFilter.not_set or
                                            self.fast_reroute_type.yfilter != YFilter.not_set or
                                            self.hello_interval.yfilter != YFilter.not_set or
                                            self.hello_interval_ms.yfilter != YFilter.not_set or
                                            self.interface_ack_list_count.yfilter != YFilter.not_set or
                                            self.interface_ack_list_high_watermark.yfilter != YFilter.not_set or
                                            self.interface_address.yfilter != YFilter.not_set or
                                            self.interface_area.yfilter != YFilter.not_set or
                                            self.interface_bandwidth.yfilter != YFilter.not_set or
                                            self.interface_cost_fallback.yfilter != YFilter.not_set or
                                            self.interface_dc_bitless_lsa_count.yfilter != YFilter.not_set or
                                            self.interface_demand_circuit.yfilter != YFilter.not_set or
                                            self.interface_fast_detect_hold_down.yfilter != YFilter.not_set or
                                            self.interface_last_nsf.yfilter != YFilter.not_set or
                                            self.interface_ldp_sync.yfilter != YFilter.not_set or
                                            self.interface_line_state.yfilter != YFilter.not_set or
                                            self.interface_link_cost.yfilter != YFilter.not_set or
                                            self.interface_lsa_filter.yfilter != YFilter.not_set or
                                            self.interface_madj_count.yfilter != YFilter.not_set or
                                            self.interface_mask.yfilter != YFilter.not_set or
                                            self.interface_name_xr.yfilter != YFilter.not_set or
                                            self.interface_nsf.yfilter != YFilter.not_set or
                                            self.interface_nsf_enabled.yfilter != YFilter.not_set or
                                            self.interface_priority.yfilter != YFilter.not_set or
                                            self.interface_retransmission_interrval.yfilter != YFilter.not_set or
                                            self.interface_router_id.yfilter != YFilter.not_set or
                                            self.interface_sid.yfilter != YFilter.not_set or
                                            self.interface_sid_n_flag_clear.yfilter != YFilter.not_set or
                                            self.interface_sid_php_off.yfilter != YFilter.not_set or
                                            self.interface_state.yfilter != YFilter.not_set or
                                            self.interface_strict_spf_sid.yfilter != YFilter.not_set or
                                            self.interface_strict_spf_sid_n_flag_clear.yfilter != YFilter.not_set or
                                            self.interface_strict_spf_sid_php_off.yfilter != YFilter.not_set or
                                            self.interface_tunnel_flags.yfilter != YFilter.not_set or
                                            self.interfaceis_madj.yfilter != YFilter.not_set or
                                            self.ip_mtu.yfilter != YFilter.not_set or
                                            self.is_loopback_stub_network.yfilter != YFilter.not_set or
                                            self.maximum_packet_size.yfilter != YFilter.not_set or
                                            self.network_lsa_flush_timer.yfilter != YFilter.not_set or
                                            self.network_type.yfilter != YFilter.not_set or
                                            self.next_hello_time.yfilter != YFilter.not_set or
                                            self.next_hello_time_ms.yfilter != YFilter.not_set or
                                            self.ospf_interface_state.yfilter != YFilter.not_set or
                                            self.passive_interface.yfilter != YFilter.not_set or
                                            self.prefix_suppress_primary_addresses.yfilter != YFilter.not_set or
                                            self.prefix_suppress_secondary_addresses.yfilter != YFilter.not_set or
                                            self.registered_for_link_down_fast_detection.yfilter != YFilter.not_set or
                                            self.transmission_delay.yfilter != YFilter.not_set or
                                            self.ttl_security_enabled.yfilter != YFilter.not_set or
                                            self.ttl_security_hop_count.yfilter != YFilter.not_set or
                                            self.wait_interval.yfilter != YFilter.not_set or
                                            (self.active_interface is not None and self.active_interface.has_operation()) or
                                            (self.interface_bfd_information is not None and self.interface_bfd_information.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.backup_designated_router.is_set or self.backup_designated_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_designated_router.get_name_leafdata())
                                        if (self.backup_designated_router_address.is_set or self.backup_designated_router_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_designated_router_address.get_name_leafdata())
                                        if (self.backup_designated_router_id.is_set or self.backup_designated_router_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_designated_router_id.get_name_leafdata())
                                        if (self.cfg_cost_fallback.is_set or self.cfg_cost_fallback.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cfg_cost_fallback.get_name_leafdata())
                                        if (self.configured_demand_circuit.is_set or self.configured_demand_circuit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.configured_demand_circuit.get_name_leafdata())
                                        if (self.configured_ldp_sync.is_set or self.configured_ldp_sync.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.configured_ldp_sync.get_name_leafdata())
                                        if (self.configured_ldp_sync_igp_shortcuts.is_set or self.configured_ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.configured_ldp_sync_igp_shortcuts.get_name_leafdata())
                                        if (self.cost_fallback_active.is_set or self.cost_fallback_active.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost_fallback_active.get_name_leafdata())
                                        if (self.dead_interval.is_set or self.dead_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dead_interval.get_name_leafdata())
                                        if (self.designated_router.is_set or self.designated_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.designated_router.get_name_leafdata())
                                        if (self.designated_router_address.is_set or self.designated_router_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.designated_router_address.get_name_leafdata())
                                        if (self.designated_router_id.is_set or self.designated_router_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.designated_router_id.get_name_leafdata())
                                        if (self.fast_detect_hold_down_time.is_set or self.fast_detect_hold_down_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_detect_hold_down_time.get_name_leafdata())
                                        if (self.fast_detect_hold_down_time_remaining.is_set or self.fast_detect_hold_down_time_remaining.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_detect_hold_down_time_remaining.get_name_leafdata())
                                        if (self.fast_reroute_topology_independent_lfa.is_set or self.fast_reroute_topology_independent_lfa.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_reroute_topology_independent_lfa.get_name_leafdata())
                                        if (self.fast_reroute_type.is_set or self.fast_reroute_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_reroute_type.get_name_leafdata())
                                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                        if (self.hello_interval_ms.is_set or self.hello_interval_ms.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hello_interval_ms.get_name_leafdata())
                                        if (self.interface_ack_list_count.is_set or self.interface_ack_list_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_ack_list_count.get_name_leafdata())
                                        if (self.interface_ack_list_high_watermark.is_set or self.interface_ack_list_high_watermark.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_ack_list_high_watermark.get_name_leafdata())
                                        if (self.interface_address.is_set or self.interface_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_address.get_name_leafdata())
                                        if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_area.get_name_leafdata())
                                        if (self.interface_bandwidth.is_set or self.interface_bandwidth.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_bandwidth.get_name_leafdata())
                                        if (self.interface_cost_fallback.is_set or self.interface_cost_fallback.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_cost_fallback.get_name_leafdata())
                                        if (self.interface_dc_bitless_lsa_count.is_set or self.interface_dc_bitless_lsa_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_dc_bitless_lsa_count.get_name_leafdata())
                                        if (self.interface_demand_circuit.is_set or self.interface_demand_circuit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_demand_circuit.get_name_leafdata())
                                        if (self.interface_fast_detect_hold_down.is_set or self.interface_fast_detect_hold_down.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_fast_detect_hold_down.get_name_leafdata())
                                        if (self.interface_last_nsf.is_set or self.interface_last_nsf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_last_nsf.get_name_leafdata())
                                        if (self.interface_ldp_sync.is_set or self.interface_ldp_sync.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_ldp_sync.get_name_leafdata())
                                        if (self.interface_line_state.is_set or self.interface_line_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_line_state.get_name_leafdata())
                                        if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                        if (self.interface_lsa_filter.is_set or self.interface_lsa_filter.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_lsa_filter.get_name_leafdata())
                                        if (self.interface_madj_count.is_set or self.interface_madj_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_madj_count.get_name_leafdata())
                                        if (self.interface_mask.is_set or self.interface_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_mask.get_name_leafdata())
                                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                        if (self.interface_nsf.is_set or self.interface_nsf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_nsf.get_name_leafdata())
                                        if (self.interface_nsf_enabled.is_set or self.interface_nsf_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_nsf_enabled.get_name_leafdata())
                                        if (self.interface_priority.is_set or self.interface_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_priority.get_name_leafdata())
                                        if (self.interface_retransmission_interrval.is_set or self.interface_retransmission_interrval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_retransmission_interrval.get_name_leafdata())
                                        if (self.interface_router_id.is_set or self.interface_router_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_router_id.get_name_leafdata())
                                        if (self.interface_sid.is_set or self.interface_sid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_sid.get_name_leafdata())
                                        if (self.interface_sid_n_flag_clear.is_set or self.interface_sid_n_flag_clear.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_sid_n_flag_clear.get_name_leafdata())
                                        if (self.interface_sid_php_off.is_set or self.interface_sid_php_off.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_sid_php_off.get_name_leafdata())
                                        if (self.interface_state.is_set or self.interface_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_state.get_name_leafdata())
                                        if (self.interface_strict_spf_sid.is_set or self.interface_strict_spf_sid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_strict_spf_sid.get_name_leafdata())
                                        if (self.interface_strict_spf_sid_n_flag_clear.is_set or self.interface_strict_spf_sid_n_flag_clear.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_strict_spf_sid_n_flag_clear.get_name_leafdata())
                                        if (self.interface_strict_spf_sid_php_off.is_set or self.interface_strict_spf_sid_php_off.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_strict_spf_sid_php_off.get_name_leafdata())
                                        if (self.interface_tunnel_flags.is_set or self.interface_tunnel_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_tunnel_flags.get_name_leafdata())
                                        if (self.interfaceis_madj.is_set or self.interfaceis_madj.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interfaceis_madj.get_name_leafdata())
                                        if (self.ip_mtu.is_set or self.ip_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ip_mtu.get_name_leafdata())
                                        if (self.is_loopback_stub_network.is_set or self.is_loopback_stub_network.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_loopback_stub_network.get_name_leafdata())
                                        if (self.maximum_packet_size.is_set or self.maximum_packet_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_packet_size.get_name_leafdata())
                                        if (self.network_lsa_flush_timer.is_set or self.network_lsa_flush_timer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.network_lsa_flush_timer.get_name_leafdata())
                                        if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.network_type.get_name_leafdata())
                                        if (self.next_hello_time.is_set or self.next_hello_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hello_time.get_name_leafdata())
                                        if (self.next_hello_time_ms.is_set or self.next_hello_time_ms.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hello_time_ms.get_name_leafdata())
                                        if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())
                                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                                        if (self.prefix_suppress_primary_addresses.is_set or self.prefix_suppress_primary_addresses.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_suppress_primary_addresses.get_name_leafdata())
                                        if (self.prefix_suppress_secondary_addresses.is_set or self.prefix_suppress_secondary_addresses.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_suppress_secondary_addresses.get_name_leafdata())
                                        if (self.registered_for_link_down_fast_detection.is_set or self.registered_for_link_down_fast_detection.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.registered_for_link_down_fast_detection.get_name_leafdata())
                                        if (self.transmission_delay.is_set or self.transmission_delay.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.transmission_delay.get_name_leafdata())
                                        if (self.ttl_security_enabled.is_set or self.ttl_security_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl_security_enabled.get_name_leafdata())
                                        if (self.ttl_security_hop_count.is_set or self.ttl_security_hop_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl_security_hop_count.get_name_leafdata())
                                        if (self.wait_interval.is_set or self.wait_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.wait_interval.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "active-interface"):
                                            if (self.active_interface is None):
                                                self.active_interface = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface()
                                                self.active_interface.parent = self
                                                self._children_name_map["active_interface"] = "active-interface"
                                            return self.active_interface

                                        if (child_yang_name == "interface-bfd-information"):
                                            if (self.interface_bfd_information is None):
                                                self.interface_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation()
                                                self.interface_bfd_information.parent = self
                                                self._children_name_map["interface_bfd_information"] = "interface-bfd-information"
                                            return self.interface_bfd_information

                                        if (child_yang_name == "interface-madj"):
                                            for c in self.interface_madj:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceMadj()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface_madj.append(c)
                                            return c

                                        if (child_yang_name == "interface-neighbor"):
                                            for c in self.interface_neighbor:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface_neighbor.append(c)
                                            return c

                                        if (child_yang_name == "ipfrr-tiebreakers"):
                                            for c in self.ipfrr_tiebreakers:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.ipfrr_tiebreakers.append(c)
                                            return c

                                        if (child_yang_name == "srlg"):
                                            for c in self.srlg:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.Srlg()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.srlg.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "active-interface" or name == "interface-bfd-information" or name == "interface-madj" or name == "interface-neighbor" or name == "ipfrr-tiebreakers" or name == "srlg" or name == "interface-name" or name == "backup-designated-router" or name == "backup-designated-router-address" or name == "backup-designated-router-id" or name == "cfg-cost-fallback" or name == "configured-demand-circuit" or name == "configured-ldp-sync" or name == "configured-ldp-sync-igp-shortcuts" or name == "cost-fallback-active" or name == "dead-interval" or name == "designated-router" or name == "designated-router-address" or name == "designated-router-id" or name == "fast-detect-hold-down-time" or name == "fast-detect-hold-down-time-remaining" or name == "fast-reroute-topology-independent-lfa" or name == "fast-reroute-type" or name == "hello-interval" or name == "hello-interval-ms" or name == "interface-ack-list-count" or name == "interface-ack-list-high-watermark" or name == "interface-address" or name == "interface-area" or name == "interface-bandwidth" or name == "interface-cost-fallback" or name == "interface-dc-bitless-lsa-count" or name == "interface-demand-circuit" or name == "interface-fast-detect-hold-down" or name == "interface-last-nsf" or name == "interface-ldp-sync" or name == "interface-line-state" or name == "interface-link-cost" or name == "interface-lsa-filter" or name == "interface-madj-count" or name == "interface-mask" or name == "interface-name-xr" or name == "interface-nsf" or name == "interface-nsf-enabled" or name == "interface-priority" or name == "interface-retransmission-interrval" or name == "interface-router-id" or name == "interface-sid" or name == "interface-sid-n-flag-clear" or name == "interface-sid-php-off" or name == "interface-state" or name == "interface-strict-spf-sid" or name == "interface-strict-spf-sid-n-flag-clear" or name == "interface-strict-spf-sid-php-off" or name == "interface-tunnel-flags" or name == "interfaceis-madj" or name == "ip-mtu" or name == "is-loopback-stub-network" or name == "maximum-packet-size" or name == "network-lsa-flush-timer" or name == "network-type" or name == "next-hello-time" or name == "next-hello-time-ms" or name == "ospf-interface-state" or name == "passive-interface" or name == "prefix-suppress-primary-addresses" or name == "prefix-suppress-secondary-addresses" or name == "registered-for-link-down-fast-detection" or name == "transmission-delay" or name == "ttl-security-enabled" or name == "ttl-security-hop-count" or name == "wait-interval"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-designated-router"):
                                            self.backup_designated_router = value
                                            self.backup_designated_router.value_namespace = name_space
                                            self.backup_designated_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-designated-router-address"):
                                            self.backup_designated_router_address = value
                                            self.backup_designated_router_address.value_namespace = name_space
                                            self.backup_designated_router_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-designated-router-id"):
                                            self.backup_designated_router_id = value
                                            self.backup_designated_router_id.value_namespace = name_space
                                            self.backup_designated_router_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cfg-cost-fallback"):
                                            self.cfg_cost_fallback = value
                                            self.cfg_cost_fallback.value_namespace = name_space
                                            self.cfg_cost_fallback.value_namespace_prefix = name_space_prefix
                                        if(value_path == "configured-demand-circuit"):
                                            self.configured_demand_circuit = value
                                            self.configured_demand_circuit.value_namespace = name_space
                                            self.configured_demand_circuit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "configured-ldp-sync"):
                                            self.configured_ldp_sync = value
                                            self.configured_ldp_sync.value_namespace = name_space
                                            self.configured_ldp_sync.value_namespace_prefix = name_space_prefix
                                        if(value_path == "configured-ldp-sync-igp-shortcuts"):
                                            self.configured_ldp_sync_igp_shortcuts = value
                                            self.configured_ldp_sync_igp_shortcuts.value_namespace = name_space
                                            self.configured_ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cost-fallback-active"):
                                            self.cost_fallback_active = value
                                            self.cost_fallback_active.value_namespace = name_space
                                            self.cost_fallback_active.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dead-interval"):
                                            self.dead_interval = value
                                            self.dead_interval.value_namespace = name_space
                                            self.dead_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "designated-router"):
                                            self.designated_router = value
                                            self.designated_router.value_namespace = name_space
                                            self.designated_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "designated-router-address"):
                                            self.designated_router_address = value
                                            self.designated_router_address.value_namespace = name_space
                                            self.designated_router_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "designated-router-id"):
                                            self.designated_router_id = value
                                            self.designated_router_id.value_namespace = name_space
                                            self.designated_router_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fast-detect-hold-down-time"):
                                            self.fast_detect_hold_down_time = value
                                            self.fast_detect_hold_down_time.value_namespace = name_space
                                            self.fast_detect_hold_down_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fast-detect-hold-down-time-remaining"):
                                            self.fast_detect_hold_down_time_remaining = value
                                            self.fast_detect_hold_down_time_remaining.value_namespace = name_space
                                            self.fast_detect_hold_down_time_remaining.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fast-reroute-topology-independent-lfa"):
                                            self.fast_reroute_topology_independent_lfa = value
                                            self.fast_reroute_topology_independent_lfa.value_namespace = name_space
                                            self.fast_reroute_topology_independent_lfa.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fast-reroute-type"):
                                            self.fast_reroute_type = value
                                            self.fast_reroute_type.value_namespace = name_space
                                            self.fast_reroute_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "hello-interval"):
                                            self.hello_interval = value
                                            self.hello_interval.value_namespace = name_space
                                            self.hello_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "hello-interval-ms"):
                                            self.hello_interval_ms = value
                                            self.hello_interval_ms.value_namespace = name_space
                                            self.hello_interval_ms.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-ack-list-count"):
                                            self.interface_ack_list_count = value
                                            self.interface_ack_list_count.value_namespace = name_space
                                            self.interface_ack_list_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-ack-list-high-watermark"):
                                            self.interface_ack_list_high_watermark = value
                                            self.interface_ack_list_high_watermark.value_namespace = name_space
                                            self.interface_ack_list_high_watermark.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-address"):
                                            self.interface_address = value
                                            self.interface_address.value_namespace = name_space
                                            self.interface_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-area"):
                                            self.interface_area = value
                                            self.interface_area.value_namespace = name_space
                                            self.interface_area.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-bandwidth"):
                                            self.interface_bandwidth = value
                                            self.interface_bandwidth.value_namespace = name_space
                                            self.interface_bandwidth.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-cost-fallback"):
                                            self.interface_cost_fallback = value
                                            self.interface_cost_fallback.value_namespace = name_space
                                            self.interface_cost_fallback.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-dc-bitless-lsa-count"):
                                            self.interface_dc_bitless_lsa_count = value
                                            self.interface_dc_bitless_lsa_count.value_namespace = name_space
                                            self.interface_dc_bitless_lsa_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-demand-circuit"):
                                            self.interface_demand_circuit = value
                                            self.interface_demand_circuit.value_namespace = name_space
                                            self.interface_demand_circuit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-fast-detect-hold-down"):
                                            self.interface_fast_detect_hold_down = value
                                            self.interface_fast_detect_hold_down.value_namespace = name_space
                                            self.interface_fast_detect_hold_down.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-last-nsf"):
                                            self.interface_last_nsf = value
                                            self.interface_last_nsf.value_namespace = name_space
                                            self.interface_last_nsf.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-ldp-sync"):
                                            self.interface_ldp_sync = value
                                            self.interface_ldp_sync.value_namespace = name_space
                                            self.interface_ldp_sync.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-line-state"):
                                            self.interface_line_state = value
                                            self.interface_line_state.value_namespace = name_space
                                            self.interface_line_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-link-cost"):
                                            self.interface_link_cost = value
                                            self.interface_link_cost.value_namespace = name_space
                                            self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-lsa-filter"):
                                            self.interface_lsa_filter = value
                                            self.interface_lsa_filter.value_namespace = name_space
                                            self.interface_lsa_filter.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-madj-count"):
                                            self.interface_madj_count = value
                                            self.interface_madj_count.value_namespace = name_space
                                            self.interface_madj_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-mask"):
                                            self.interface_mask = value
                                            self.interface_mask.value_namespace = name_space
                                            self.interface_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-name-xr"):
                                            self.interface_name_xr = value
                                            self.interface_name_xr.value_namespace = name_space
                                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-nsf"):
                                            self.interface_nsf = value
                                            self.interface_nsf.value_namespace = name_space
                                            self.interface_nsf.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-nsf-enabled"):
                                            self.interface_nsf_enabled = value
                                            self.interface_nsf_enabled.value_namespace = name_space
                                            self.interface_nsf_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-priority"):
                                            self.interface_priority = value
                                            self.interface_priority.value_namespace = name_space
                                            self.interface_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-retransmission-interrval"):
                                            self.interface_retransmission_interrval = value
                                            self.interface_retransmission_interrval.value_namespace = name_space
                                            self.interface_retransmission_interrval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-router-id"):
                                            self.interface_router_id = value
                                            self.interface_router_id.value_namespace = name_space
                                            self.interface_router_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-sid"):
                                            self.interface_sid = value
                                            self.interface_sid.value_namespace = name_space
                                            self.interface_sid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-sid-n-flag-clear"):
                                            self.interface_sid_n_flag_clear = value
                                            self.interface_sid_n_flag_clear.value_namespace = name_space
                                            self.interface_sid_n_flag_clear.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-sid-php-off"):
                                            self.interface_sid_php_off = value
                                            self.interface_sid_php_off.value_namespace = name_space
                                            self.interface_sid_php_off.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-state"):
                                            self.interface_state = value
                                            self.interface_state.value_namespace = name_space
                                            self.interface_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-strict-spf-sid"):
                                            self.interface_strict_spf_sid = value
                                            self.interface_strict_spf_sid.value_namespace = name_space
                                            self.interface_strict_spf_sid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-strict-spf-sid-n-flag-clear"):
                                            self.interface_strict_spf_sid_n_flag_clear = value
                                            self.interface_strict_spf_sid_n_flag_clear.value_namespace = name_space
                                            self.interface_strict_spf_sid_n_flag_clear.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-strict-spf-sid-php-off"):
                                            self.interface_strict_spf_sid_php_off = value
                                            self.interface_strict_spf_sid_php_off.value_namespace = name_space
                                            self.interface_strict_spf_sid_php_off.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-tunnel-flags"):
                                            self.interface_tunnel_flags = value
                                            self.interface_tunnel_flags.value_namespace = name_space
                                            self.interface_tunnel_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interfaceis-madj"):
                                            self.interfaceis_madj = value
                                            self.interfaceis_madj.value_namespace = name_space
                                            self.interfaceis_madj.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ip-mtu"):
                                            self.ip_mtu = value
                                            self.ip_mtu.value_namespace = name_space
                                            self.ip_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-loopback-stub-network"):
                                            self.is_loopback_stub_network = value
                                            self.is_loopback_stub_network.value_namespace = name_space
                                            self.is_loopback_stub_network.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-packet-size"):
                                            self.maximum_packet_size = value
                                            self.maximum_packet_size.value_namespace = name_space
                                            self.maximum_packet_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "network-lsa-flush-timer"):
                                            self.network_lsa_flush_timer = value
                                            self.network_lsa_flush_timer.value_namespace = name_space
                                            self.network_lsa_flush_timer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "network-type"):
                                            self.network_type = value
                                            self.network_type.value_namespace = name_space
                                            self.network_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hello-time"):
                                            self.next_hello_time = value
                                            self.next_hello_time.value_namespace = name_space
                                            self.next_hello_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hello-time-ms"):
                                            self.next_hello_time_ms = value
                                            self.next_hello_time_ms.value_namespace = name_space
                                            self.next_hello_time_ms.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-interface-state"):
                                            self.ospf_interface_state = value
                                            self.ospf_interface_state.value_namespace = name_space
                                            self.ospf_interface_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "passive-interface"):
                                            self.passive_interface = value
                                            self.passive_interface.value_namespace = name_space
                                            self.passive_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-suppress-primary-addresses"):
                                            self.prefix_suppress_primary_addresses = value
                                            self.prefix_suppress_primary_addresses.value_namespace = name_space
                                            self.prefix_suppress_primary_addresses.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-suppress-secondary-addresses"):
                                            self.prefix_suppress_secondary_addresses = value
                                            self.prefix_suppress_secondary_addresses.value_namespace = name_space
                                            self.prefix_suppress_secondary_addresses.value_namespace_prefix = name_space_prefix
                                        if(value_path == "registered-for-link-down-fast-detection"):
                                            self.registered_for_link_down_fast_detection = value
                                            self.registered_for_link_down_fast_detection.value_namespace = name_space
                                            self.registered_for_link_down_fast_detection.value_namespace_prefix = name_space_prefix
                                        if(value_path == "transmission-delay"):
                                            self.transmission_delay = value
                                            self.transmission_delay.value_namespace = name_space
                                            self.transmission_delay.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl-security-enabled"):
                                            self.ttl_security_enabled = value
                                            self.ttl_security_enabled.value_namespace = name_space
                                            self.ttl_security_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl-security-hop-count"):
                                            self.ttl_security_hop_count = value
                                            self.ttl_security_hop_count.value_namespace = name_space
                                            self.ttl_security_hop_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "wait-interval"):
                                            self.wait_interval = value
                                            self.wait_interval.value_namespace = name_space
                                            self.wait_interval.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.interface:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.interface:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interfaces" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface"):
                                        for c in self.interface:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.interface.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.area_id.is_set or
                                    (self.area_statistics is not None and self.area_statistics.has_data()) or
                                    (self.flood_list_area_table is not None and self.flood_list_area_table.has_data()) or
                                    (self.interface_briefs is not None and self.interface_briefs.has_data()) or
                                    (self.interfaces is not None and self.interfaces.has_data()) or
                                    (self.neighbor_details is not None and self.neighbor_details.has_data()) or
                                    (self.neighbors is not None and self.neighbors.has_data()) or
                                    (self.requests is not None and self.requests.has_data()) or
                                    (self.retransmissions is not None and self.retransmissions.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.area_id.yfilter != YFilter.not_set or
                                    (self.area_statistics is not None and self.area_statistics.has_operation()) or
                                    (self.flood_list_area_table is not None and self.flood_list_area_table.has_operation()) or
                                    (self.interface_briefs is not None and self.interface_briefs.has_operation()) or
                                    (self.interfaces is not None and self.interfaces.has_operation()) or
                                    (self.neighbor_details is not None and self.neighbor_details.has_operation()) or
                                    (self.neighbors is not None and self.neighbors.has_operation()) or
                                    (self.requests is not None and self.requests.has_operation()) or
                                    (self.retransmissions is not None and self.retransmissions.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "area" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "area-statistics"):
                                    if (self.area_statistics is None):
                                        self.area_statistics = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics()
                                        self.area_statistics.parent = self
                                        self._children_name_map["area_statistics"] = "area-statistics"
                                    return self.area_statistics

                                if (child_yang_name == "flood-list-area-table"):
                                    if (self.flood_list_area_table is None):
                                        self.flood_list_area_table = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable()
                                        self.flood_list_area_table.parent = self
                                        self._children_name_map["flood_list_area_table"] = "flood-list-area-table"
                                    return self.flood_list_area_table

                                if (child_yang_name == "interface-briefs"):
                                    if (self.interface_briefs is None):
                                        self.interface_briefs = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs()
                                        self.interface_briefs.parent = self
                                        self._children_name_map["interface_briefs"] = "interface-briefs"
                                    return self.interface_briefs

                                if (child_yang_name == "interfaces"):
                                    if (self.interfaces is None):
                                        self.interfaces = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces()
                                        self.interfaces.parent = self
                                        self._children_name_map["interfaces"] = "interfaces"
                                    return self.interfaces

                                if (child_yang_name == "neighbor-details"):
                                    if (self.neighbor_details is None):
                                        self.neighbor_details = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails()
                                        self.neighbor_details.parent = self
                                        self._children_name_map["neighbor_details"] = "neighbor-details"
                                    return self.neighbor_details

                                if (child_yang_name == "neighbors"):
                                    if (self.neighbors is None):
                                        self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors()
                                        self.neighbors.parent = self
                                        self._children_name_map["neighbors"] = "neighbors"
                                    return self.neighbors

                                if (child_yang_name == "requests"):
                                    if (self.requests is None):
                                        self.requests = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests()
                                        self.requests.parent = self
                                        self._children_name_map["requests"] = "requests"
                                    return self.requests

                                if (child_yang_name == "retransmissions"):
                                    if (self.retransmissions is None):
                                        self.retransmissions = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions()
                                        self.retransmissions.parent = self
                                        self._children_name_map["retransmissions"] = "retransmissions"
                                    return self.retransmissions

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "area-statistics" or name == "flood-list-area-table" or name == "interface-briefs" or name == "interfaces" or name == "neighbor-details" or name == "neighbors" or name == "requests" or name == "retransmissions" or name == "area-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "area-id"):
                                    self.area_id = value
                                    self.area_id.value_namespace = name_space
                                    self.area_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.area:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.area:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "areas" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "area"):
                                for c in self.area:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.area.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "area"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Database(Entity):
                        """
                        OSPF Link State Database
                        
                        .. attribute:: database_areas
                        
                        	Per\-Area view of Link state database
                        	**type**\:   :py:class:`DatabaseAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas>`
                        
                        .. attribute:: database_summaries
                        
                        	Link State database summary table
                        	**type**\:   :py:class:`DatabaseSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries>`
                        
                        .. attribute:: database_summary_as
                        
                        	Link State Database summary for the AS
                        	**type**\:   :py:class:`DatabaseSummaryAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs>`
                        
                        .. attribute:: lsa_summaries
                        
                        	Link state advertisement summary table
                        	**type**\:   :py:class:`LsaSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries>`
                        
                        .. attribute:: lsas
                        
                        	Link State Database Table
                        	**type**\:   :py:class:`Lsas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Database, self).__init__()

                            self.yang_name = "database"
                            self.yang_parent_name = "vrf"

                            self.database_areas = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas()
                            self.database_areas.parent = self
                            self._children_name_map["database_areas"] = "database-areas"
                            self._children_yang_names.add("database-areas")

                            self.database_summaries = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries()
                            self.database_summaries.parent = self
                            self._children_name_map["database_summaries"] = "database-summaries"
                            self._children_yang_names.add("database-summaries")

                            self.database_summary_as = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs()
                            self.database_summary_as.parent = self
                            self._children_name_map["database_summary_as"] = "database-summary-as"
                            self._children_yang_names.add("database-summary-as")

                            self.lsa_summaries = Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries()
                            self.lsa_summaries.parent = self
                            self._children_name_map["lsa_summaries"] = "lsa-summaries"
                            self._children_yang_names.add("lsa-summaries")

                            self.lsas = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas()
                            self.lsas.parent = self
                            self._children_name_map["lsas"] = "lsas"
                            self._children_yang_names.add("lsas")


                        class DatabaseAreas(Entity):
                            """
                            Per\-Area view of Link state database
                            
                            .. attribute:: database_area
                            
                            	Per\-Area Link State Database data
                            	**type**\: list of    :py:class:`DatabaseArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas, self).__init__()

                                self.yang_name = "database-areas"
                                self.yang_parent_name = "database"

                                self.database_area = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas, self).__setattr__(name, value)


                            class DatabaseArea(Entity):
                                """
                                Per\-Area Link State Database data
                                
                                .. attribute:: area_id  <key>
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_summaries
                                
                                	Link state advertisement summary table
                                	**type**\:   :py:class:`LsaSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries>`
                                
                                .. attribute:: lsas
                                
                                	Link State Database Table
                                	**type**\:   :py:class:`Lsas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea, self).__init__()

                                    self.yang_name = "database-area"
                                    self.yang_parent_name = "database-areas"

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.lsa_summaries = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries()
                                    self.lsa_summaries.parent = self
                                    self._children_name_map["lsa_summaries"] = "lsa-summaries"
                                    self._children_yang_names.add("lsa-summaries")

                                    self.lsas = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas()
                                    self.lsas.parent = self
                                    self._children_name_map["lsas"] = "lsas"
                                    self._children_yang_names.add("lsas")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea, self).__setattr__(name, value)


                                class Lsas(Entity):
                                    """
                                    Link State Database Table
                                    
                                    .. attribute:: lsa
                                    
                                    	Link State Advertisement information
                                    	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas, self).__init__()

                                        self.yang_name = "lsas"
                                        self.yang_parent_name = "database-area"

                                        self.lsa = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas, self).__setattr__(name, value)


                                    class Lsa(Entity):
                                        """
                                        Link State Advertisement information
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Advertising Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: interface_name
                                        
                                        	InterfaceName
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: ls_id
                                        
                                        	Link state ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ls_type
                                        
                                        	Link state type
                                        	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                                        
                                        .. attribute:: lsa_detail_data
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetailData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader>`
                                        
                                        .. attribute:: lsa_internal_data
                                        
                                        	Information pertaining to a specific LSA type
                                        	**type**\:   :py:class:`LsaInternalData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa, self).__init__()

                                            self.yang_name = "lsa"
                                            self.yang_parent_name = "lsas"

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.area_id = YLeaf(YType.int32, "area-id")

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.ls_id = YLeaf(YType.str, "ls-id")

                                            self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                            self.lsa_detail_data = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData()
                                            self.lsa_detail_data.parent = self
                                            self._children_name_map["lsa_detail_data"] = "lsa-detail-data"
                                            self._children_yang_names.add("lsa-detail-data")

                                            self.lsa_header = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")

                                            self.lsa_internal_data = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData()
                                            self.lsa_internal_data.parent = self
                                            self._children_name_map["lsa_internal_data"] = "lsa-internal-data"
                                            self._children_yang_names.add("lsa-internal-data")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("advertising_router",
                                                            "area_id",
                                                            "interface_name",
                                                            "ls_id",
                                                            "ls_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa, self).__setattr__(name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: dn_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_type
                                            
                                            	LSA type
                                            	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsid
                                            
                                            	LS ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: nsf
                                            
                                            	If true,  LSA received from neighbor during NSF
                                            	**type**\:  bool
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "lsa"

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                                self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsid = YLeaf(YType.str, "lsid")

                                                self.nsf = YLeaf(YType.boolean, "nsf")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("advertising_router",
                                                                "checksum",
                                                                "dn_age_lsa",
                                                                "ls_type",
                                                                "lsa_age",
                                                                "lsa_area_id",
                                                                "lsid",
                                                                "nsf",
                                                                "sequence_number") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.advertising_router.is_set or
                                                    self.checksum.is_set or
                                                    self.dn_age_lsa.is_set or
                                                    self.ls_type.is_set or
                                                    self.lsa_age.is_set or
                                                    self.lsa_area_id.is_set or
                                                    self.lsid.is_set or
                                                    self.nsf.is_set or
                                                    self.sequence_number.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.advertising_router.yfilter != YFilter.not_set or
                                                    self.checksum.yfilter != YFilter.not_set or
                                                    self.dn_age_lsa.yfilter != YFilter.not_set or
                                                    self.ls_type.yfilter != YFilter.not_set or
                                                    self.lsa_age.yfilter != YFilter.not_set or
                                                    self.lsa_area_id.yfilter != YFilter.not_set or
                                                    self.lsid.yfilter != YFilter.not_set or
                                                    self.nsf.yfilter != YFilter.not_set or
                                                    self.sequence_number.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "lsa-header" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                                if (self.checksum.is_set or self.checksum.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.checksum.get_name_leafdata())
                                                if (self.dn_age_lsa.is_set or self.dn_age_lsa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dn_age_lsa.get_name_leafdata())
                                                if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ls_type.get_name_leafdata())
                                                if (self.lsa_age.is_set or self.lsa_age.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsa_age.get_name_leafdata())
                                                if (self.lsa_area_id.is_set or self.lsa_area_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsa_area_id.get_name_leafdata())
                                                if (self.lsid.is_set or self.lsid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsid.get_name_leafdata())
                                                if (self.nsf.is_set or self.nsf.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nsf.get_name_leafdata())
                                                if (self.sequence_number.is_set or self.sequence_number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sequence_number.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "advertising-router" or name == "checksum" or name == "dn-age-lsa" or name == "ls-type" or name == "lsa-age" or name == "lsa-area-id" or name == "lsid" or name == "nsf" or name == "sequence-number"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "advertising-router"):
                                                    self.advertising_router = value
                                                    self.advertising_router.value_namespace = name_space
                                                    self.advertising_router.value_namespace_prefix = name_space_prefix
                                                if(value_path == "checksum"):
                                                    self.checksum = value
                                                    self.checksum.value_namespace = name_space
                                                    self.checksum.value_namespace_prefix = name_space_prefix
                                                if(value_path == "dn-age-lsa"):
                                                    self.dn_age_lsa = value
                                                    self.dn_age_lsa.value_namespace = name_space
                                                    self.dn_age_lsa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ls-type"):
                                                    self.ls_type = value
                                                    self.ls_type.value_namespace = name_space
                                                    self.ls_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsa-age"):
                                                    self.lsa_age = value
                                                    self.lsa_age.value_namespace = name_space
                                                    self.lsa_age.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsa-area-id"):
                                                    self.lsa_area_id = value
                                                    self.lsa_area_id.value_namespace = name_space
                                                    self.lsa_area_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsid"):
                                                    self.lsid = value
                                                    self.lsid.value_namespace = name_space
                                                    self.lsid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "nsf"):
                                                    self.nsf = value
                                                    self.nsf.value_namespace = name_space
                                                    self.nsf.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sequence-number"):
                                                    self.sequence_number = value
                                                    self.sequence_number.value_namespace = name_space
                                                    self.sequence_number.value_namespace_prefix = name_space_prefix


                                        class LsaDetailData(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: ase_origin
                                            
                                            	External Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: demand_circuit
                                            
                                            	If true, capable of demand circuit as indicated by LSA's option field
                                            	**type**\:  bool
                                            
                                            .. attribute:: dn_bit
                                            
                                            	if true, DN bit set on the summary LSA indicated by LSA's option field
                                            	**type**\:  bool
                                            
                                            .. attribute:: in_sync
                                            
                                            	Not In Sync With Active
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_last_updated_time
                                            
                                            	Time LSA was last updated
                                            	**type**\:   :py:class:`LsaLastUpdatedTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime>`
                                            
                                            .. attribute:: lsa_prefix_priority
                                            
                                            	Current LSA prefix priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: lsa_rate_limit_due_time
                                            
                                            	Due time for rate\-limit timer (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_throttle_timer
                                            
                                            	LSA throttle timer table information
                                            	**type**\:   :py:class:`LsaThrottleTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer>`
                                            
                                            .. attribute:: lsadb_base_clock
                                            
                                            	Clock stamp since boot
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: lsadb_base_time_stamp
                                            
                                            	Current time stamp
                                            	**type**\:   :py:class:`LsadbBaseTimeStamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp>`
                                            
                                            .. attribute:: new_lsa_prefix_priority
                                            
                                            	New LSA prefix priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: not_delete
                                            
                                            	Reason why LSA is not deleted
                                            	**type**\:   :py:class:`NotDelete <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete>`
                                            
                                            .. attribute:: nssa_translation
                                            
                                            	If true,  capable of type 7 to 5 translation indicated by LSA's option field
                                            	**type**\:  bool
                                            
                                            .. attribute:: routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: sum_origin
                                            
                                            	Summary Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: tos_capable
                                            
                                            	If true, type of service capable indicated by LSA's option field
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData, self).__init__()

                                                self.yang_name = "lsa-detail-data"
                                                self.yang_parent_name = "lsa"

                                                self.advertising_router_reachable = YLeaf(YType.boolean, "advertising-router-reachable")

                                                self.ase_origin = YLeaf(YType.uint16, "ase-origin")

                                                self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                                self.dn_bit = YLeaf(YType.boolean, "dn-bit")

                                                self.in_sync = YLeaf(YType.uint8, "in-sync")

                                                self.length = YLeaf(YType.uint16, "length")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_prefix_priority = YLeaf(YType.uint8, "lsa-prefix-priority")

                                                self.lsa_rate_limit_due_time = YLeaf(YType.uint32, "lsa-rate-limit-due-time")

                                                self.lsadb_base_clock = YLeaf(YType.uint64, "lsadb-base-clock")

                                                self.new_lsa_prefix_priority = YLeaf(YType.uint8, "new-lsa-prefix-priority")

                                                self.nssa_translation = YLeaf(YType.boolean, "nssa-translation")

                                                self.routing_bit = YLeaf(YType.boolean, "routing-bit")

                                                self.sum_origin = YLeaf(YType.uint16, "sum-origin")

                                                self.tos_capable = YLeaf(YType.boolean, "tos-capable")

                                                self.lsa_last_updated_time = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime()
                                                self.lsa_last_updated_time.parent = self
                                                self._children_name_map["lsa_last_updated_time"] = "lsa-last-updated-time"
                                                self._children_yang_names.add("lsa-last-updated-time")

                                                self.lsa_throttle_timer = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer()
                                                self.lsa_throttle_timer.parent = self
                                                self._children_name_map["lsa_throttle_timer"] = "lsa-throttle-timer"
                                                self._children_yang_names.add("lsa-throttle-timer")

                                                self.lsadb_base_time_stamp = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp()
                                                self.lsadb_base_time_stamp.parent = self
                                                self._children_name_map["lsadb_base_time_stamp"] = "lsadb-base-time-stamp"
                                                self._children_yang_names.add("lsadb-base-time-stamp")

                                                self.not_delete = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete()
                                                self.not_delete.parent = self
                                                self._children_name_map["not_delete"] = "not-delete"
                                                self._children_yang_names.add("not-delete")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("advertising_router_reachable",
                                                                "ase_origin",
                                                                "demand_circuit",
                                                                "dn_bit",
                                                                "in_sync",
                                                                "length",
                                                                "lsa_flood_required_post_fail_over",
                                                                "lsa_prefix_priority",
                                                                "lsa_rate_limit_due_time",
                                                                "lsadb_base_clock",
                                                                "new_lsa_prefix_priority",
                                                                "nssa_translation",
                                                                "routing_bit",
                                                                "sum_origin",
                                                                "tos_capable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData, self).__setattr__(name, value)


                                            class LsaThrottleTimer(Entity):
                                                """
                                                LSA throttle timer table information
                                                
                                                .. attribute:: last_inst_minute_table_index
                                                
                                                	Last Minute table index processed
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: last_inst_second_table_index
                                                
                                                	Last Second table index processed
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timer_location
                                                
                                                	Timer table
                                                	**type**\:   :py:class:`TimerTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.TimerTable>`
                                                
                                                .. attribute:: timer_type
                                                
                                                	Timer type
                                                	**type**\:   :py:class:`Timer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Timer>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__init__()

                                                    self.yang_name = "lsa-throttle-timer"
                                                    self.yang_parent_name = "lsa-detail-data"

                                                    self.last_inst_minute_table_index = YLeaf(YType.uint8, "last-inst-minute-table-index")

                                                    self.last_inst_second_table_index = YLeaf(YType.uint8, "last-inst-second-table-index")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")

                                                    self.timer_location = YLeaf(YType.enumeration, "timer-location")

                                                    self.timer_type = YLeaf(YType.enumeration, "timer-type")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("last_inst_minute_table_index",
                                                                    "last_inst_second_table_index",
                                                                    "minute_table_index",
                                                                    "second_table_index",
                                                                    "timer_location",
                                                                    "timer_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.last_inst_minute_table_index.is_set or
                                                        self.last_inst_second_table_index.is_set or
                                                        self.minute_table_index.is_set or
                                                        self.second_table_index.is_set or
                                                        self.timer_location.is_set or
                                                        self.timer_type.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.last_inst_minute_table_index.yfilter != YFilter.not_set or
                                                        self.last_inst_second_table_index.yfilter != YFilter.not_set or
                                                        self.minute_table_index.yfilter != YFilter.not_set or
                                                        self.second_table_index.yfilter != YFilter.not_set or
                                                        self.timer_location.yfilter != YFilter.not_set or
                                                        self.timer_type.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lsa-throttle-timer" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.last_inst_minute_table_index.is_set or self.last_inst_minute_table_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.last_inst_minute_table_index.get_name_leafdata())
                                                    if (self.last_inst_second_table_index.is_set or self.last_inst_second_table_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.last_inst_second_table_index.get_name_leafdata())
                                                    if (self.minute_table_index.is_set or self.minute_table_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minute_table_index.get_name_leafdata())
                                                    if (self.second_table_index.is_set or self.second_table_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second_table_index.get_name_leafdata())
                                                    if (self.timer_location.is_set or self.timer_location.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timer_location.get_name_leafdata())
                                                    if (self.timer_type.is_set or self.timer_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timer_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "last-inst-minute-table-index" or name == "last-inst-second-table-index" or name == "minute-table-index" or name == "second-table-index" or name == "timer-location" or name == "timer-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "last-inst-minute-table-index"):
                                                        self.last_inst_minute_table_index = value
                                                        self.last_inst_minute_table_index.value_namespace = name_space
                                                        self.last_inst_minute_table_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "last-inst-second-table-index"):
                                                        self.last_inst_second_table_index = value
                                                        self.last_inst_second_table_index.value_namespace = name_space
                                                        self.last_inst_second_table_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minute-table-index"):
                                                        self.minute_table_index = value
                                                        self.minute_table_index.value_namespace = name_space
                                                        self.minute_table_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second-table-index"):
                                                        self.second_table_index = value
                                                        self.second_table_index.value_namespace = name_space
                                                        self.second_table_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timer-location"):
                                                        self.timer_location = value
                                                        self.timer_location.value_namespace = name_space
                                                        self.timer_location.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timer-type"):
                                                        self.timer_type = value
                                                        self.timer_type.value_namespace = name_space
                                                        self.timer_type.value_namespace_prefix = name_space_prefix


                                            class LsaLastUpdatedTime(Entity):
                                                """
                                                Time LSA was last updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__init__()

                                                    self.yang_name = "lsa-last-updated-time"
                                                    self.yang_parent_name = "lsa-detail-data"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lsa-last-updated-time" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix


                                            class LsadbBaseTimeStamp(Entity):
                                                """
                                                Current time stamp
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__init__()

                                                    self.yang_name = "lsadb-base-time-stamp"
                                                    self.yang_parent_name = "lsa-detail-data"

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("nanosecond",
                                                                    "second") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.nanosecond.is_set or
                                                        self.second.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.nanosecond.yfilter != YFilter.not_set or
                                                        self.second.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lsadb-base-time-stamp" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.second.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "nanosecond" or name == "second"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "nanosecond"):
                                                        self.nanosecond = value
                                                        self.nanosecond.value_namespace = name_space
                                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "second"):
                                                        self.second = value
                                                        self.second.value_namespace = name_space
                                                        self.second.value_namespace_prefix = name_space_prefix


                                            class NotDelete(Entity):
                                                """
                                                Reason why LSA is not deleted
                                                
                                                .. attribute:: acknowledgement
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty
                                                	**type**\:  bool
                                                
                                                .. attribute:: flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: maximum_age
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table
                                                	**type**\:  bool
                                                
                                                .. attribute:: sum_orig_pending
                                                
                                                	If true, the reason not to delete this LSA is because it is pending summary LSA originating
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete, self).__init__()

                                                    self.yang_name = "not-delete"
                                                    self.yang_parent_name = "lsa-detail-data"

                                                    self.acknowledgement = YLeaf(YType.boolean, "acknowledgement")

                                                    self.flood_pending = YLeaf(YType.boolean, "flood-pending")

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.maximum_age = YLeaf(YType.boolean, "maximum-age")

                                                    self.neighbor_exchange = YLeaf(YType.boolean, "neighbor-exchange")

                                                    self.no_delete = YLeaf(YType.boolean, "no-delete")

                                                    self.nsr_ack_pending = YLeaf(YType.boolean, "nsr-ack-pending")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.partial_spf = YLeaf(YType.boolean, "partial-spf")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.routing_table = YLeaf(YType.boolean, "routing-table")

                                                    self.sum_orig_pending = YLeaf(YType.boolean, "sum-orig-pending")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("acknowledgement",
                                                                    "flood_pending",
                                                                    "free_time",
                                                                    "maximum_age",
                                                                    "neighbor_exchange",
                                                                    "no_delete",
                                                                    "nsr_ack_pending",
                                                                    "nsr_flood_required",
                                                                    "partial_spf",
                                                                    "rate_limit",
                                                                    "routing_table",
                                                                    "sum_orig_pending") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.acknowledgement.is_set or
                                                        self.flood_pending.is_set or
                                                        self.free_time.is_set or
                                                        self.maximum_age.is_set or
                                                        self.neighbor_exchange.is_set or
                                                        self.no_delete.is_set or
                                                        self.nsr_ack_pending.is_set or
                                                        self.nsr_flood_required.is_set or
                                                        self.partial_spf.is_set or
                                                        self.rate_limit.is_set or
                                                        self.routing_table.is_set or
                                                        self.sum_orig_pending.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.acknowledgement.yfilter != YFilter.not_set or
                                                        self.flood_pending.yfilter != YFilter.not_set or
                                                        self.free_time.yfilter != YFilter.not_set or
                                                        self.maximum_age.yfilter != YFilter.not_set or
                                                        self.neighbor_exchange.yfilter != YFilter.not_set or
                                                        self.no_delete.yfilter != YFilter.not_set or
                                                        self.nsr_ack_pending.yfilter != YFilter.not_set or
                                                        self.nsr_flood_required.yfilter != YFilter.not_set or
                                                        self.partial_spf.yfilter != YFilter.not_set or
                                                        self.rate_limit.yfilter != YFilter.not_set or
                                                        self.routing_table.yfilter != YFilter.not_set or
                                                        self.sum_orig_pending.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "not-delete" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.acknowledgement.is_set or self.acknowledgement.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.acknowledgement.get_name_leafdata())
                                                    if (self.flood_pending.is_set or self.flood_pending.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flood_pending.get_name_leafdata())
                                                    if (self.free_time.is_set or self.free_time.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.free_time.get_name_leafdata())
                                                    if (self.maximum_age.is_set or self.maximum_age.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_age.get_name_leafdata())
                                                    if (self.neighbor_exchange.is_set or self.neighbor_exchange.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_exchange.get_name_leafdata())
                                                    if (self.no_delete.is_set or self.no_delete.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.no_delete.get_name_leafdata())
                                                    if (self.nsr_ack_pending.is_set or self.nsr_ack_pending.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nsr_ack_pending.get_name_leafdata())
                                                    if (self.nsr_flood_required.is_set or self.nsr_flood_required.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nsr_flood_required.get_name_leafdata())
                                                    if (self.partial_spf.is_set or self.partial_spf.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.partial_spf.get_name_leafdata())
                                                    if (self.rate_limit.is_set or self.rate_limit.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rate_limit.get_name_leafdata())
                                                    if (self.routing_table.is_set or self.routing_table.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.routing_table.get_name_leafdata())
                                                    if (self.sum_orig_pending.is_set or self.sum_orig_pending.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sum_orig_pending.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "acknowledgement" or name == "flood-pending" or name == "free-time" or name == "maximum-age" or name == "neighbor-exchange" or name == "no-delete" or name == "nsr-ack-pending" or name == "nsr-flood-required" or name == "partial-spf" or name == "rate-limit" or name == "routing-table" or name == "sum-orig-pending"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "acknowledgement"):
                                                        self.acknowledgement = value
                                                        self.acknowledgement.value_namespace = name_space
                                                        self.acknowledgement.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flood-pending"):
                                                        self.flood_pending = value
                                                        self.flood_pending.value_namespace = name_space
                                                        self.flood_pending.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "free-time"):
                                                        self.free_time = value
                                                        self.free_time.value_namespace = name_space
                                                        self.free_time.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-age"):
                                                        self.maximum_age = value
                                                        self.maximum_age.value_namespace = name_space
                                                        self.maximum_age.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-exchange"):
                                                        self.neighbor_exchange = value
                                                        self.neighbor_exchange.value_namespace = name_space
                                                        self.neighbor_exchange.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "no-delete"):
                                                        self.no_delete = value
                                                        self.no_delete.value_namespace = name_space
                                                        self.no_delete.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nsr-ack-pending"):
                                                        self.nsr_ack_pending = value
                                                        self.nsr_ack_pending.value_namespace = name_space
                                                        self.nsr_ack_pending.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nsr-flood-required"):
                                                        self.nsr_flood_required = value
                                                        self.nsr_flood_required.value_namespace = name_space
                                                        self.nsr_flood_required.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "partial-spf"):
                                                        self.partial_spf = value
                                                        self.partial_spf.value_namespace = name_space
                                                        self.partial_spf.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rate-limit"):
                                                        self.rate_limit = value
                                                        self.rate_limit.value_namespace = name_space
                                                        self.rate_limit.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "routing-table"):
                                                        self.routing_table = value
                                                        self.routing_table.value_namespace = name_space
                                                        self.routing_table.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sum-orig-pending"):
                                                        self.sum_orig_pending = value
                                                        self.sum_orig_pending.value_namespace = name_space
                                                        self.sum_orig_pending.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.advertising_router_reachable.is_set or
                                                    self.ase_origin.is_set or
                                                    self.demand_circuit.is_set or
                                                    self.dn_bit.is_set or
                                                    self.in_sync.is_set or
                                                    self.length.is_set or
                                                    self.lsa_flood_required_post_fail_over.is_set or
                                                    self.lsa_prefix_priority.is_set or
                                                    self.lsa_rate_limit_due_time.is_set or
                                                    self.lsadb_base_clock.is_set or
                                                    self.new_lsa_prefix_priority.is_set or
                                                    self.nssa_translation.is_set or
                                                    self.routing_bit.is_set or
                                                    self.sum_origin.is_set or
                                                    self.tos_capable.is_set or
                                                    (self.lsa_last_updated_time is not None and self.lsa_last_updated_time.has_data()) or
                                                    (self.lsa_throttle_timer is not None and self.lsa_throttle_timer.has_data()) or
                                                    (self.lsadb_base_time_stamp is not None and self.lsadb_base_time_stamp.has_data()) or
                                                    (self.not_delete is not None and self.not_delete.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.advertising_router_reachable.yfilter != YFilter.not_set or
                                                    self.ase_origin.yfilter != YFilter.not_set or
                                                    self.demand_circuit.yfilter != YFilter.not_set or
                                                    self.dn_bit.yfilter != YFilter.not_set or
                                                    self.in_sync.yfilter != YFilter.not_set or
                                                    self.length.yfilter != YFilter.not_set or
                                                    self.lsa_flood_required_post_fail_over.yfilter != YFilter.not_set or
                                                    self.lsa_prefix_priority.yfilter != YFilter.not_set or
                                                    self.lsa_rate_limit_due_time.yfilter != YFilter.not_set or
                                                    self.lsadb_base_clock.yfilter != YFilter.not_set or
                                                    self.new_lsa_prefix_priority.yfilter != YFilter.not_set or
                                                    self.nssa_translation.yfilter != YFilter.not_set or
                                                    self.routing_bit.yfilter != YFilter.not_set or
                                                    self.sum_origin.yfilter != YFilter.not_set or
                                                    self.tos_capable.yfilter != YFilter.not_set or
                                                    (self.lsa_last_updated_time is not None and self.lsa_last_updated_time.has_operation()) or
                                                    (self.lsa_throttle_timer is not None and self.lsa_throttle_timer.has_operation()) or
                                                    (self.lsadb_base_time_stamp is not None and self.lsadb_base_time_stamp.has_operation()) or
                                                    (self.not_delete is not None and self.not_delete.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "lsa-detail-data" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.advertising_router_reachable.is_set or self.advertising_router_reachable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.advertising_router_reachable.get_name_leafdata())
                                                if (self.ase_origin.is_set or self.ase_origin.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ase_origin.get_name_leafdata())
                                                if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                                                if (self.dn_bit.is_set or self.dn_bit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dn_bit.get_name_leafdata())
                                                if (self.in_sync.is_set or self.in_sync.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.in_sync.get_name_leafdata())
                                                if (self.length.is_set or self.length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.length.get_name_leafdata())
                                                if (self.lsa_flood_required_post_fail_over.is_set or self.lsa_flood_required_post_fail_over.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsa_flood_required_post_fail_over.get_name_leafdata())
                                                if (self.lsa_prefix_priority.is_set or self.lsa_prefix_priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsa_prefix_priority.get_name_leafdata())
                                                if (self.lsa_rate_limit_due_time.is_set or self.lsa_rate_limit_due_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsa_rate_limit_due_time.get_name_leafdata())
                                                if (self.lsadb_base_clock.is_set or self.lsadb_base_clock.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsadb_base_clock.get_name_leafdata())
                                                if (self.new_lsa_prefix_priority.is_set or self.new_lsa_prefix_priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.new_lsa_prefix_priority.get_name_leafdata())
                                                if (self.nssa_translation.is_set or self.nssa_translation.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nssa_translation.get_name_leafdata())
                                                if (self.routing_bit.is_set or self.routing_bit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.routing_bit.get_name_leafdata())
                                                if (self.sum_origin.is_set or self.sum_origin.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sum_origin.get_name_leafdata())
                                                if (self.tos_capable.is_set or self.tos_capable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tos_capable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "lsa-last-updated-time"):
                                                    if (self.lsa_last_updated_time is None):
                                                        self.lsa_last_updated_time = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime()
                                                        self.lsa_last_updated_time.parent = self
                                                        self._children_name_map["lsa_last_updated_time"] = "lsa-last-updated-time"
                                                    return self.lsa_last_updated_time

                                                if (child_yang_name == "lsa-throttle-timer"):
                                                    if (self.lsa_throttle_timer is None):
                                                        self.lsa_throttle_timer = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer()
                                                        self.lsa_throttle_timer.parent = self
                                                        self._children_name_map["lsa_throttle_timer"] = "lsa-throttle-timer"
                                                    return self.lsa_throttle_timer

                                                if (child_yang_name == "lsadb-base-time-stamp"):
                                                    if (self.lsadb_base_time_stamp is None):
                                                        self.lsadb_base_time_stamp = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp()
                                                        self.lsadb_base_time_stamp.parent = self
                                                        self._children_name_map["lsadb_base_time_stamp"] = "lsadb-base-time-stamp"
                                                    return self.lsadb_base_time_stamp

                                                if (child_yang_name == "not-delete"):
                                                    if (self.not_delete is None):
                                                        self.not_delete = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete()
                                                        self.not_delete.parent = self
                                                        self._children_name_map["not_delete"] = "not-delete"
                                                    return self.not_delete

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lsa-last-updated-time" or name == "lsa-throttle-timer" or name == "lsadb-base-time-stamp" or name == "not-delete" or name == "advertising-router-reachable" or name == "ase-origin" or name == "demand-circuit" or name == "dn-bit" or name == "in-sync" or name == "length" or name == "lsa-flood-required-post-fail-over" or name == "lsa-prefix-priority" or name == "lsa-rate-limit-due-time" or name == "lsadb-base-clock" or name == "new-lsa-prefix-priority" or name == "nssa-translation" or name == "routing-bit" or name == "sum-origin" or name == "tos-capable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "advertising-router-reachable"):
                                                    self.advertising_router_reachable = value
                                                    self.advertising_router_reachable.value_namespace = name_space
                                                    self.advertising_router_reachable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ase-origin"):
                                                    self.ase_origin = value
                                                    self.ase_origin.value_namespace = name_space
                                                    self.ase_origin.value_namespace_prefix = name_space_prefix
                                                if(value_path == "demand-circuit"):
                                                    self.demand_circuit = value
                                                    self.demand_circuit.value_namespace = name_space
                                                    self.demand_circuit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "dn-bit"):
                                                    self.dn_bit = value
                                                    self.dn_bit.value_namespace = name_space
                                                    self.dn_bit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "in-sync"):
                                                    self.in_sync = value
                                                    self.in_sync.value_namespace = name_space
                                                    self.in_sync.value_namespace_prefix = name_space_prefix
                                                if(value_path == "length"):
                                                    self.length = value
                                                    self.length.value_namespace = name_space
                                                    self.length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsa-flood-required-post-fail-over"):
                                                    self.lsa_flood_required_post_fail_over = value
                                                    self.lsa_flood_required_post_fail_over.value_namespace = name_space
                                                    self.lsa_flood_required_post_fail_over.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsa-prefix-priority"):
                                                    self.lsa_prefix_priority = value
                                                    self.lsa_prefix_priority.value_namespace = name_space
                                                    self.lsa_prefix_priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsa-rate-limit-due-time"):
                                                    self.lsa_rate_limit_due_time = value
                                                    self.lsa_rate_limit_due_time.value_namespace = name_space
                                                    self.lsa_rate_limit_due_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsadb-base-clock"):
                                                    self.lsadb_base_clock = value
                                                    self.lsadb_base_clock.value_namespace = name_space
                                                    self.lsadb_base_clock.value_namespace_prefix = name_space_prefix
                                                if(value_path == "new-lsa-prefix-priority"):
                                                    self.new_lsa_prefix_priority = value
                                                    self.new_lsa_prefix_priority.value_namespace = name_space
                                                    self.new_lsa_prefix_priority.value_namespace_prefix = name_space_prefix
                                                if(value_path == "nssa-translation"):
                                                    self.nssa_translation = value
                                                    self.nssa_translation.value_namespace = name_space
                                                    self.nssa_translation.value_namespace_prefix = name_space_prefix
                                                if(value_path == "routing-bit"):
                                                    self.routing_bit = value
                                                    self.routing_bit.value_namespace = name_space
                                                    self.routing_bit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sum-origin"):
                                                    self.sum_origin = value
                                                    self.sum_origin.value_namespace = name_space
                                                    self.sum_origin.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tos-capable"):
                                                    self.tos_capable = value
                                                    self.tos_capable.value_namespace = name_space
                                                    self.tos_capable.value_namespace_prefix = name_space_prefix


                                        class LsaInternalData(Entity):
                                            """
                                            Information pertaining to a specific LSA type
                                            
                                            .. attribute:: external_lsa_type
                                            
                                            	External LSA
                                            	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType>`
                                            
                                            .. attribute:: internal_lsa_type
                                            
                                            	InternalLSAType
                                            	**type**\:   :py:class:`OspfInternalLsaTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInternalLsaTypes>`
                                            
                                            .. attribute:: network_lsa_type
                                            
                                            	Network LSA
                                            	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType>`
                                            
                                            .. attribute:: opaque_el_lsa_type
                                            
                                            	Extended Link LSA type
                                            	**type**\:   :py:class:`OpaqueElLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType>`
                                            
                                            .. attribute:: opaque_ep_lsa_type
                                            
                                            	Extende Prefix LSA type
                                            	**type**\:   :py:class:`OpaqueEpLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType>`
                                            
                                            .. attribute:: opaque_grace_lsa
                                            
                                            	Opaque\-link, opaque type 3 Grace LSA
                                            	**type**\:   :py:class:`OpaqueGraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa>`
                                            
                                            .. attribute:: opaque_link_lsa_type
                                            
                                            	Opaque\-Link LSA
                                            	**type**\:   :py:class:`OpaqueLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType>`
                                            
                                            .. attribute:: opaque_mpls_te_lsa_type
                                            
                                            	Opaque\-Area, opaque type 1 LSA
                                            	**type**\:   :py:class:`OpaqueMplsTeLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType>`
                                            
                                            .. attribute:: opaque_router_info_lsa_type
                                            
                                            	Opaque Router Information LSA
                                            	**type**\:   :py:class:`OpaqueRouterInfoLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType>`
                                            
                                            .. attribute:: router_lsa_type
                                            
                                            	Router LSA
                                            	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType>`
                                            
                                            .. attribute:: summary_lsa_type
                                            
                                            	Summary LSA
                                            	**type**\:   :py:class:`SummaryLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData, self).__init__()

                                                self.yang_name = "lsa-internal-data"
                                                self.yang_parent_name = "lsa"

                                                self.internal_lsa_type = YLeaf(YType.enumeration, "internal-lsa-type")

                                                self.external_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType()
                                                self.external_lsa_type.parent = self
                                                self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                                self._children_yang_names.add("external-lsa-type")

                                                self.network_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType()
                                                self.network_lsa_type.parent = self
                                                self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                                self._children_yang_names.add("network-lsa-type")

                                                self.opaque_el_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType()
                                                self.opaque_el_lsa_type.parent = self
                                                self._children_name_map["opaque_el_lsa_type"] = "opaque-el-lsa-type"
                                                self._children_yang_names.add("opaque-el-lsa-type")

                                                self.opaque_ep_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType()
                                                self.opaque_ep_lsa_type.parent = self
                                                self._children_name_map["opaque_ep_lsa_type"] = "opaque-ep-lsa-type"
                                                self._children_yang_names.add("opaque-ep-lsa-type")

                                                self.opaque_grace_lsa = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa()
                                                self.opaque_grace_lsa.parent = self
                                                self._children_name_map["opaque_grace_lsa"] = "opaque-grace-lsa"
                                                self._children_yang_names.add("opaque-grace-lsa")

                                                self.opaque_link_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType()
                                                self.opaque_link_lsa_type.parent = self
                                                self._children_name_map["opaque_link_lsa_type"] = "opaque-link-lsa-type"
                                                self._children_yang_names.add("opaque-link-lsa-type")

                                                self.opaque_mpls_te_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType()
                                                self.opaque_mpls_te_lsa_type.parent = self
                                                self._children_name_map["opaque_mpls_te_lsa_type"] = "opaque-mpls-te-lsa-type"
                                                self._children_yang_names.add("opaque-mpls-te-lsa-type")

                                                self.opaque_router_info_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType()
                                                self.opaque_router_info_lsa_type.parent = self
                                                self._children_name_map["opaque_router_info_lsa_type"] = "opaque-router-info-lsa-type"
                                                self._children_yang_names.add("opaque-router-info-lsa-type")

                                                self.router_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType()
                                                self.router_lsa_type.parent = self
                                                self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                                self._children_yang_names.add("router-lsa-type")

                                                self.summary_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType()
                                                self.summary_lsa_type.parent = self
                                                self._children_name_map["summary_lsa_type"] = "summary-lsa-type"
                                                self._children_yang_names.add("summary-lsa-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_lsa_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData, self).__setattr__(name, value)


                                            class RouterLsaType(Entity):
                                                """
                                                Router LSA
                                                
                                                .. attribute:: internal_link
                                                
                                                	List of links for internal LSA
                                                	**type**\: list of    :py:class:`InternalLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink>`
                                                
                                                .. attribute:: internal_lsa
                                                
                                                	If true, internal LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: link
                                                
                                                	List of links in this LSA
                                                	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link>`
                                                
                                                .. attribute:: router_abr
                                                
                                                	If True, router is an Area Border Router
                                                	**type**\:  bool
                                                
                                                .. attribute:: router_asbr
                                                
                                                	If True, router is an Autonomous system Border Router
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__init__()

                                                    self.yang_name = "router-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"

                                                    self.internal_lsa = YLeaf(YType.boolean, "internal-lsa")

                                                    self.router_abr = YLeaf(YType.boolean, "router-abr")

                                                    self.router_asbr = YLeaf(YType.boolean, "router-asbr")

                                                    self.internal_link = YList(self)
                                                    self.link = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("internal_lsa",
                                                                    "router_abr",
                                                                    "router_asbr") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__setattr__(name, value)


                                                class Link(Entity):
                                                    """
                                                    List of links in this LSA
                                                    
                                                    .. attribute:: link_data
                                                    
                                                    	Link Data
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	Link ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: link_metric
                                                    
                                                    	Cost for using this link
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: link_tos
                                                    
                                                    	List of type of service metrics
                                                    	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos>`
                                                    
                                                    .. attribute:: link_type
                                                    
                                                    	Type of link
                                                    	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__init__()

                                                        self.yang_name = "link"
                                                        self.yang_parent_name = "router-lsa-type"

                                                        self.link_data = YLeaf(YType.str, "link-data")

                                                        self.link_id = YLeaf(YType.str, "link-id")

                                                        self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                        self.link_type = YLeaf(YType.enumeration, "link-type")

                                                        self.link_tos = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("link_data",
                                                                        "link_id",
                                                                        "link_metric",
                                                                        "link_type") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__setattr__(name, value)


                                                    class LinkTos(Entity):
                                                        """
                                                        List of type of service metrics
                                                        
                                                        .. attribute:: router_tos
                                                        
                                                        	Type of Service
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tos_cost
                                                        
                                                        	Type of service specific metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__init__()

                                                            self.yang_name = "link-tos"
                                                            self.yang_parent_name = "link"

                                                            self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                            self.tos_cost = YLeaf(YType.uint16, "tos-cost")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("router_tos",
                                                                            "tos_cost") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.router_tos.is_set or
                                                                self.tos_cost.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.router_tos.yfilter != YFilter.not_set or
                                                                self.tos_cost.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "link-tos" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.router_tos.is_set or self.router_tos.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.router_tos.get_name_leafdata())
                                                            if (self.tos_cost.is_set or self.tos_cost.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tos_cost.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "router-tos" or name == "tos-cost"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "router-tos"):
                                                                self.router_tos = value
                                                                self.router_tos.value_namespace = name_space
                                                                self.router_tos.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tos-cost"):
                                                                self.tos_cost = value
                                                                self.tos_cost.value_namespace = name_space
                                                                self.tos_cost.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.link_tos:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.link_data.is_set or
                                                            self.link_id.is_set or
                                                            self.link_metric.is_set or
                                                            self.link_type.is_set)

                                                    def has_operation(self):
                                                        for c in self.link_tos:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.link_data.yfilter != YFilter.not_set or
                                                            self.link_id.yfilter != YFilter.not_set or
                                                            self.link_metric.yfilter != YFilter.not_set or
                                                            self.link_type.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "link" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.link_data.is_set or self.link_data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.link_data.get_name_leafdata())
                                                        if (self.link_id.is_set or self.link_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.link_id.get_name_leafdata())
                                                        if (self.link_metric.is_set or self.link_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.link_metric.get_name_leafdata())
                                                        if (self.link_type.is_set or self.link_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.link_type.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "link-tos"):
                                                            for c in self.link_tos:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.link_tos.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "link-tos" or name == "link-data" or name == "link-id" or name == "link-metric" or name == "link-type"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "link-data"):
                                                            self.link_data = value
                                                            self.link_data.value_namespace = name_space
                                                            self.link_data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "link-id"):
                                                            self.link_id = value
                                                            self.link_id.value_namespace = name_space
                                                            self.link_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "link-metric"):
                                                            self.link_metric = value
                                                            self.link_metric.value_namespace = name_space
                                                            self.link_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "link-type"):
                                                            self.link_type = value
                                                            self.link_type.value_namespace = name_space
                                                            self.link_type.value_namespace_prefix = name_space_prefix


                                                class InternalLink(Entity):
                                                    """
                                                    List of links for internal LSA
                                                    
                                                    .. attribute:: link_data
                                                    
                                                    	Link Data
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	Link ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: link_metric
                                                    
                                                    	Cost for using this link
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: link_tos
                                                    
                                                    	List of type of service metrics
                                                    	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos>`
                                                    
                                                    .. attribute:: link_type
                                                    
                                                    	Type of link
                                                    	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__init__()

                                                        self.yang_name = "internal-link"
                                                        self.yang_parent_name = "router-lsa-type"

                                                        self.link_data = YLeaf(YType.str, "link-data")

                                                        self.link_id = YLeaf(YType.str, "link-id")

                                                        self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                        self.link_type = YLeaf(YType.enumeration, "link-type")

                                                        self.link_tos = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("link_data",
                                                                        "link_id",
                                                                        "link_metric",
                                                                        "link_type") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__setattr__(name, value)


                                                    class LinkTos(Entity):
                                                        """
                                                        List of type of service metrics
                                                        
                                                        .. attribute:: router_tos
                                                        
                                                        	Type of Service
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tos_cost
                                                        
                                                        	Type of service specific metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__init__()

                                                            self.yang_name = "link-tos"
                                                            self.yang_parent_name = "internal-link"

                                                            self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                            self.tos_cost = YLeaf(YType.uint16, "tos-cost")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("router_tos",
                                                                            "tos_cost") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.router_tos.is_set or
                                                                self.tos_cost.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.router_tos.yfilter != YFilter.not_set or
                                                                self.tos_cost.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "link-tos" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.router_tos.is_set or self.router_tos.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.router_tos.get_name_leafdata())
                                                            if (self.tos_cost.is_set or self.tos_cost.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.tos_cost.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "router-tos" or name == "tos-cost"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "router-tos"):
                                                                self.router_tos = value
                                                                self.router_tos.value_namespace = name_space
                                                                self.router_tos.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "tos-cost"):
                                                                self.tos_cost = value
                                                                self.tos_cost.value_namespace = name_space
                                                                self.tos_cost.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.link_tos:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.link_data.is_set or
                                                            self.link_id.is_set or
                                                            self.link_metric.is_set or
                                                            self.link_type.is_set)

                                                    def has_operation(self):
                                                        for c in self.link_tos:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.link_data.yfilter != YFilter.not_set or
                                                            self.link_id.yfilter != YFilter.not_set or
                                                            self.link_metric.yfilter != YFilter.not_set or
                                                            self.link_type.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "internal-link" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.link_data.is_set or self.link_data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.link_data.get_name_leafdata())
                                                        if (self.link_id.is_set or self.link_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.link_id.get_name_leafdata())
                                                        if (self.link_metric.is_set or self.link_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.link_metric.get_name_leafdata())
                                                        if (self.link_type.is_set or self.link_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.link_type.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "link-tos"):
                                                            for c in self.link_tos:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.link_tos.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "link-tos" or name == "link-data" or name == "link-id" or name == "link-metric" or name == "link-type"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "link-data"):
                                                            self.link_data = value
                                                            self.link_data.value_namespace = name_space
                                                            self.link_data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "link-id"):
                                                            self.link_id = value
                                                            self.link_id.value_namespace = name_space
                                                            self.link_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "link-metric"):
                                                            self.link_metric = value
                                                            self.link_metric.value_namespace = name_space
                                                            self.link_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "link-type"):
                                                            self.link_type = value
                                                            self.link_type.value_namespace = name_space
                                                            self.link_type.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.internal_link:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.link:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.internal_lsa.is_set or
                                                        self.router_abr.is_set or
                                                        self.router_asbr.is_set)

                                                def has_operation(self):
                                                    for c in self.internal_link:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.link:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.internal_lsa.yfilter != YFilter.not_set or
                                                        self.router_abr.yfilter != YFilter.not_set or
                                                        self.router_asbr.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "router-lsa-type" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.internal_lsa.is_set or self.internal_lsa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.internal_lsa.get_name_leafdata())
                                                    if (self.router_abr.is_set or self.router_abr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.router_abr.get_name_leafdata())
                                                    if (self.router_asbr.is_set or self.router_asbr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.router_asbr.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "internal-link"):
                                                        for c in self.internal_link:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.internal_link.append(c)
                                                        return c

                                                    if (child_yang_name == "link"):
                                                        for c in self.link:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.link.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "internal-link" or name == "link" or name == "internal-lsa" or name == "router-abr" or name == "router-asbr"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "internal-lsa"):
                                                        self.internal_lsa = value
                                                        self.internal_lsa.value_namespace = name_space
                                                        self.internal_lsa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "router-abr"):
                                                        self.router_abr = value
                                                        self.router_abr.value_namespace = name_space
                                                        self.router_abr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "router-asbr"):
                                                        self.router_asbr = value
                                                        self.router_asbr.value_namespace = name_space
                                                        self.router_asbr.value_namespace_prefix = name_space_prefix


                                            class NetworkLsaType(Entity):
                                                """
                                                Network LSA
                                                
                                                .. attribute:: neighbor_router
                                                
                                                	Neighbor router list
                                                	**type**\: list of    :py:class:`NeighborRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter>`
                                                
                                                .. attribute:: network_prefix_length
                                                
                                                	Network prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__init__()

                                                    self.yang_name = "network-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"

                                                    self.network_prefix_length = YLeaf(YType.uint32, "network-prefix-length")

                                                    self.neighbor_router = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("network_prefix_length") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__setattr__(name, value)


                                                class NeighborRouter(Entity):
                                                    """
                                                    Neighbor router list
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__init__()

                                                        self.yang_name = "neighbor-router"
                                                        self.yang_parent_name = "network-lsa-type"

                                                        self.entry = YLeaf(YType.str, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "neighbor-router" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.neighbor_router:
                                                        if (c.has_data()):
                                                            return True
                                                    return self.network_prefix_length.is_set

                                                def has_operation(self):
                                                    for c in self.neighbor_router:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.network_prefix_length.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "network-lsa-type" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.network_prefix_length.is_set or self.network_prefix_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.network_prefix_length.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "neighbor-router"):
                                                        for c in self.neighbor_router:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.neighbor_router.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "neighbor-router" or name == "network-prefix-length"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "network-prefix-length"):
                                                        self.network_prefix_length = value
                                                        self.network_prefix_length.value_namespace = name_space
                                                        self.network_prefix_length.value_namespace_prefix = name_space_prefix


                                            class SummaryLsaType(Entity):
                                                """
                                                Summary LSA
                                                
                                                .. attribute:: internal_sum_lsa
                                                
                                                	If true, internal max\-metric LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: summary_lsa_metric
                                                
                                                	Metric
                                                	**type**\: list of    :py:class:`SummaryLsaMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric>`
                                                
                                                .. attribute:: summary_prefix_length
                                                
                                                	Summary LSA prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__init__()

                                                    self.yang_name = "summary-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"

                                                    self.internal_sum_lsa = YLeaf(YType.boolean, "internal-sum-lsa")

                                                    self.summary_prefix_length = YLeaf(YType.uint32, "summary-prefix-length")

                                                    self.summary_lsa_metric = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("internal_sum_lsa",
                                                                    "summary_prefix_length") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__setattr__(name, value)


                                                class SummaryLsaMetric(Entity):
                                                    """
                                                    Metric
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__init__()

                                                        self.yang_name = "summary-lsa-metric"
                                                        self.yang_parent_name = "summary-lsa-type"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "summary-lsa-metric" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.summary_lsa_metric:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.internal_sum_lsa.is_set or
                                                        self.summary_prefix_length.is_set)

                                                def has_operation(self):
                                                    for c in self.summary_lsa_metric:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.internal_sum_lsa.yfilter != YFilter.not_set or
                                                        self.summary_prefix_length.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "summary-lsa-type" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.internal_sum_lsa.is_set or self.internal_sum_lsa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.internal_sum_lsa.get_name_leafdata())
                                                    if (self.summary_prefix_length.is_set or self.summary_prefix_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.summary_prefix_length.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "summary-lsa-metric"):
                                                        for c in self.summary_lsa_metric:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.summary_lsa_metric.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "summary-lsa-metric" or name == "internal-sum-lsa" or name == "summary-prefix-length"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "internal-sum-lsa"):
                                                        self.internal_sum_lsa = value
                                                        self.internal_sum_lsa.value_namespace = name_space
                                                        self.internal_sum_lsa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "summary-prefix-length"):
                                                        self.summary_prefix_length = value
                                                        self.summary_prefix_length.value_namespace = name_space
                                                        self.summary_prefix_length.value_namespace_prefix = name_space_prefix


                                            class ExternalLsaType(Entity):
                                                """
                                                External LSA
                                                
                                                .. attribute:: external_prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: external_tos_metric
                                                
                                                	Type of service information
                                                	**type**\: list of    :py:class:`ExternalTosMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric>`
                                                
                                                .. attribute:: internal_external_lsa
                                                
                                                	If true, internal max\-metric LSA
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__init__()

                                                    self.yang_name = "external-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"

                                                    self.external_prefix_length = YLeaf(YType.uint32, "external-prefix-length")

                                                    self.internal_external_lsa = YLeaf(YType.boolean, "internal-external-lsa")

                                                    self.external_tos_metric = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("external_prefix_length",
                                                                    "internal_external_lsa") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__setattr__(name, value)


                                                class ExternalTosMetric(Entity):
                                                    """
                                                    Type of service information
                                                    
                                                    .. attribute:: external_metric
                                                    
                                                    	Cost of this route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: external_metric_type
                                                    
                                                    	External LSA metric type
                                                    	**type**\:   :py:class:`ExMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.ExMetric>`
                                                    
                                                    .. attribute:: external_tag
                                                    
                                                    	Route Tag
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: external_tos
                                                    
                                                    	Type of Service
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: forwarding_address
                                                    
                                                    	Forwarding Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__init__()

                                                        self.yang_name = "external-tos-metric"
                                                        self.yang_parent_name = "external-lsa-type"

                                                        self.external_metric = YLeaf(YType.uint32, "external-metric")

                                                        self.external_metric_type = YLeaf(YType.enumeration, "external-metric-type")

                                                        self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                        self.external_tos = YLeaf(YType.uint32, "external-tos")

                                                        self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("external_metric",
                                                                        "external_metric_type",
                                                                        "external_tag",
                                                                        "external_tos",
                                                                        "forwarding_address") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.external_metric.is_set or
                                                            self.external_metric_type.is_set or
                                                            self.external_tag.is_set or
                                                            self.external_tos.is_set or
                                                            self.forwarding_address.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.external_metric.yfilter != YFilter.not_set or
                                                            self.external_metric_type.yfilter != YFilter.not_set or
                                                            self.external_tag.yfilter != YFilter.not_set or
                                                            self.external_tos.yfilter != YFilter.not_set or
                                                            self.forwarding_address.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "external-tos-metric" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.external_metric.is_set or self.external_metric.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.external_metric.get_name_leafdata())
                                                        if (self.external_metric_type.is_set or self.external_metric_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.external_metric_type.get_name_leafdata())
                                                        if (self.external_tag.is_set or self.external_tag.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.external_tag.get_name_leafdata())
                                                        if (self.external_tos.is_set or self.external_tos.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.external_tos.get_name_leafdata())
                                                        if (self.forwarding_address.is_set or self.forwarding_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.forwarding_address.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "external-metric" or name == "external-metric-type" or name == "external-tag" or name == "external-tos" or name == "forwarding-address"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "external-metric"):
                                                            self.external_metric = value
                                                            self.external_metric.value_namespace = name_space
                                                            self.external_metric.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "external-metric-type"):
                                                            self.external_metric_type = value
                                                            self.external_metric_type.value_namespace = name_space
                                                            self.external_metric_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "external-tag"):
                                                            self.external_tag = value
                                                            self.external_tag.value_namespace = name_space
                                                            self.external_tag.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "external-tos"):
                                                            self.external_tos = value
                                                            self.external_tos.value_namespace = name_space
                                                            self.external_tos.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "forwarding-address"):
                                                            self.forwarding_address = value
                                                            self.forwarding_address.value_namespace = name_space
                                                            self.forwarding_address.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.external_tos_metric:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.external_prefix_length.is_set or
                                                        self.internal_external_lsa.is_set)

                                                def has_operation(self):
                                                    for c in self.external_tos_metric:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.external_prefix_length.yfilter != YFilter.not_set or
                                                        self.internal_external_lsa.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "external-lsa-type" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.external_prefix_length.is_set or self.external_prefix_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.external_prefix_length.get_name_leafdata())
                                                    if (self.internal_external_lsa.is_set or self.internal_external_lsa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.internal_external_lsa.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "external-tos-metric"):
                                                        for c in self.external_tos_metric:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.external_tos_metric.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "external-tos-metric" or name == "external-prefix-length" or name == "internal-external-lsa"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "external-prefix-length"):
                                                        self.external_prefix_length = value
                                                        self.external_prefix_length.value_namespace = name_space
                                                        self.external_prefix_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "internal-external-lsa"):
                                                        self.internal_external_lsa = value
                                                        self.internal_external_lsa.value_namespace = name_space
                                                        self.internal_external_lsa.value_namespace_prefix = name_space_prefix


                                            class OpaqueLinkLsaType(Entity):
                                                """
                                                Opaque\-Link LSA
                                                
                                                .. attribute:: opaque_interface_name
                                                
                                                	Interface on which the Opaque link LSA is received
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__init__()

                                                    self.yang_name = "opaque-link-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"

                                                    self.opaque_interface_name = YLeaf(YType.str, "opaque-interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("opaque_interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.opaque_interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.opaque_interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opaque-link-lsa-type" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.opaque_interface_name.is_set or self.opaque_interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.opaque_interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "opaque-interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "opaque-interface-name"):
                                                        self.opaque_interface_name = value
                                                        self.opaque_interface_name.value_namespace = name_space
                                                        self.opaque_interface_name.value_namespace_prefix = name_space_prefix


                                            class OpaqueMplsTeLsaType(Entity):
                                                """
                                                Opaque\-Area, opaque type 1 LSA
                                                
                                                .. attribute:: tlv
                                                
                                                	List of TLVs
                                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__init__()

                                                    self.yang_name = "opaque-mpls-te-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"

                                                    self.tlv = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__setattr__(name, value)


                                                class Tlv(Entity):
                                                    """
                                                    List of TLVs
                                                    
                                                    .. attribute:: mpls_dste_link
                                                    
                                                    	MPLS DS\-TE supported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: mpls_router_id
                                                    
                                                    	MPLS\-TE Router ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: te_link_sub_tlv
                                                    
                                                    	List of Sub\-TLVs
                                                    	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv>`
                                                    
                                                    .. attribute:: tlv_data
                                                    
                                                    	TLV direct data
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tlv_length
                                                    
                                                    	Length of top\-level TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: tlv_type
                                                    
                                                    	Type of top\-level TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__init__()

                                                        self.yang_name = "tlv"
                                                        self.yang_parent_name = "opaque-mpls-te-lsa-type"

                                                        self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                        self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                        self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                        self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                        self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                        self.te_link_sub_tlv = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("mpls_dste_link",
                                                                        "mpls_router_id",
                                                                        "tlv_data",
                                                                        "tlv_length",
                                                                        "tlv_type") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__setattr__(name, value)


                                                    class TeLinkSubTlv(Entity):
                                                        """
                                                        List of Sub\-TLVs
                                                        
                                                        .. attribute:: sub_tlv_length
                                                        
                                                        	Length of sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: sub_tlv_type
                                                        
                                                        	Type of sub TLV
                                                        	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                        
                                                        .. attribute:: sub_tlv_value
                                                        
                                                        	Value of sub TLV
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                            self.yang_name = "te-link-sub-tlv"
                                                            self.yang_parent_name = "tlv"

                                                            self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                            self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                            self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("sub_tlv_length",
                                                                            "sub_tlv_type",
                                                                            "sub_tlv_value") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.sub_tlv_length.is_set or
                                                                self.sub_tlv_type.is_set or
                                                                self.sub_tlv_value.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.sub_tlv_length.yfilter != YFilter.not_set or
                                                                self.sub_tlv_type.yfilter != YFilter.not_set or
                                                                self.sub_tlv_value.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "te-link-sub-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.sub_tlv_length.is_set or self.sub_tlv_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sub_tlv_length.get_name_leafdata())
                                                            if (self.sub_tlv_type.is_set or self.sub_tlv_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sub_tlv_type.get_name_leafdata())
                                                            if (self.sub_tlv_value.is_set or self.sub_tlv_value.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sub_tlv_value.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "sub-tlv-length" or name == "sub-tlv-type" or name == "sub-tlv-value"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "sub-tlv-length"):
                                                                self.sub_tlv_length = value
                                                                self.sub_tlv_length.value_namespace = name_space
                                                                self.sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "sub-tlv-type"):
                                                                self.sub_tlv_type = value
                                                                self.sub_tlv_type.value_namespace = name_space
                                                                self.sub_tlv_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "sub-tlv-value"):
                                                                self.sub_tlv_value = value
                                                                self.sub_tlv_value.value_namespace = name_space
                                                                self.sub_tlv_value.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.te_link_sub_tlv:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.mpls_dste_link.is_set or
                                                            self.mpls_router_id.is_set or
                                                            self.tlv_data.is_set or
                                                            self.tlv_length.is_set or
                                                            self.tlv_type.is_set)

                                                    def has_operation(self):
                                                        for c in self.te_link_sub_tlv:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.mpls_dste_link.yfilter != YFilter.not_set or
                                                            self.mpls_router_id.yfilter != YFilter.not_set or
                                                            self.tlv_data.yfilter != YFilter.not_set or
                                                            self.tlv_length.yfilter != YFilter.not_set or
                                                            self.tlv_type.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "tlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.mpls_dste_link.is_set or self.mpls_dste_link.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_dste_link.get_name_leafdata())
                                                        if (self.mpls_router_id.is_set or self.mpls_router_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_router_id.get_name_leafdata())
                                                        if (self.tlv_data.is_set or self.tlv_data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tlv_data.get_name_leafdata())
                                                        if (self.tlv_length.is_set or self.tlv_length.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tlv_length.get_name_leafdata())
                                                        if (self.tlv_type.is_set or self.tlv_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tlv_type.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "te-link-sub-tlv"):
                                                            for c in self.te_link_sub_tlv:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.te_link_sub_tlv.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "te-link-sub-tlv" or name == "mpls-dste-link" or name == "mpls-router-id" or name == "tlv-data" or name == "tlv-length" or name == "tlv-type"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "mpls-dste-link"):
                                                            self.mpls_dste_link = value
                                                            self.mpls_dste_link.value_namespace = name_space
                                                            self.mpls_dste_link.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mpls-router-id"):
                                                            self.mpls_router_id = value
                                                            self.mpls_router_id.value_namespace = name_space
                                                            self.mpls_router_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tlv-data"):
                                                            self.tlv_data = value
                                                            self.tlv_data.value_namespace = name_space
                                                            self.tlv_data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tlv-length"):
                                                            self.tlv_length = value
                                                            self.tlv_length.value_namespace = name_space
                                                            self.tlv_length.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tlv-type"):
                                                            self.tlv_type = value
                                                            self.tlv_type.value_namespace = name_space
                                                            self.tlv_type.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.tlv:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.tlv:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opaque-mpls-te-lsa-type" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "tlv"):
                                                        for c in self.tlv:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.tlv.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tlv"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class OpaqueGraceLsa(Entity):
                                                """
                                                Opaque\-link, opaque type 3 Grace LSA
                                                
                                                .. attribute:: grace_period
                                                
                                                	The amount of time the router's neighbor should advertise it fully adjacent (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: grace_reason
                                                
                                                	Reason for router restart
                                                	**type**\:   :py:class:`OspfGrReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfGrReason>`
                                                
                                                .. attribute:: ip_address
                                                
                                                	IP interface address on the subnet associated with the grace LSA
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__init__()

                                                    self.yang_name = "opaque-grace-lsa"
                                                    self.yang_parent_name = "lsa-internal-data"

                                                    self.grace_period = YLeaf(YType.uint32, "grace-period")

                                                    self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                                    self.ip_address = YLeaf(YType.str, "ip-address")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("grace_period",
                                                                    "grace_reason",
                                                                    "ip_address") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.grace_period.is_set or
                                                        self.grace_reason.is_set or
                                                        self.ip_address.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.grace_period.yfilter != YFilter.not_set or
                                                        self.grace_reason.yfilter != YFilter.not_set or
                                                        self.ip_address.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opaque-grace-lsa" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.grace_period.is_set or self.grace_period.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.grace_period.get_name_leafdata())
                                                    if (self.grace_reason.is_set or self.grace_reason.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.grace_reason.get_name_leafdata())
                                                    if (self.ip_address.is_set or self.ip_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ip_address.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "grace-period" or name == "grace-reason" or name == "ip-address"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "grace-period"):
                                                        self.grace_period = value
                                                        self.grace_period.value_namespace = name_space
                                                        self.grace_period.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "grace-reason"):
                                                        self.grace_reason = value
                                                        self.grace_reason.value_namespace = name_space
                                                        self.grace_reason.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ip-address"):
                                                        self.ip_address = value
                                                        self.ip_address.value_namespace = name_space
                                                        self.ip_address.value_namespace_prefix = name_space_prefix


                                            class OpaqueRouterInfoLsaType(Entity):
                                                """
                                                Opaque Router Information LSA
                                                
                                                .. attribute:: opaque_ri_interface_name
                                                
                                                	Interface on which this Link\-Local Opaque link LSA is received
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: opaque_rilsa_scope
                                                
                                                	Opaque LSA flooding scope, a.k.a., Opaque LSA Type
                                                	**type**\:   :py:class:`OspfLsaOpqRiScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLsaOpqRiScope>`
                                                
                                                .. attribute:: opaque_ritlv
                                                
                                                	Router Information TLV
                                                	**type**\: list of    :py:class:`OpaqueRitlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__init__()

                                                    self.yang_name = "opaque-router-info-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"

                                                    self.opaque_ri_interface_name = YLeaf(YType.str, "opaque-ri-interface-name")

                                                    self.opaque_rilsa_scope = YLeaf(YType.enumeration, "opaque-rilsa-scope")

                                                    self.opaque_ritlv = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("opaque_ri_interface_name",
                                                                    "opaque_rilsa_scope") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__setattr__(name, value)


                                                class OpaqueRitlv(Entity):
                                                    """
                                                    Router Information TLV
                                                    
                                                    .. attribute:: pcedtlv
                                                    
                                                    	PCE Discovery TLV
                                                    	**type**\:   :py:class:`Pcedtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv>`
                                                    
                                                    .. attribute:: ritlv_internal_type
                                                    
                                                    	RITLVInternalType
                                                    	**type**\:   :py:class:`OspfShOpqRiTlvTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiTlvTypes>`
                                                    
                                                    .. attribute:: rtr_cap_tlv
                                                    
                                                    	Rtr Cap TLV
                                                    	**type**\:   :py:class:`RtrCapTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv>`
                                                    
                                                    .. attribute:: sr_algo_tlv
                                                    
                                                    	SR Algorithm TLV
                                                    	**type**\:   :py:class:`SrAlgoTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv>`
                                                    
                                                    .. attribute:: sr_range_tlv
                                                    
                                                    	SR Range TLV
                                                    	**type**\:   :py:class:`SrRangeTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv>`
                                                    
                                                    .. attribute:: unknown_tlv
                                                    
                                                    	Unknown Rtr Info TLV
                                                    	**type**\:   :py:class:`UnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__init__()

                                                        self.yang_name = "opaque-ritlv"
                                                        self.yang_parent_name = "opaque-router-info-lsa-type"

                                                        self.ritlv_internal_type = YLeaf(YType.enumeration, "ritlv-internal-type")

                                                        self.pcedtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv()
                                                        self.pcedtlv.parent = self
                                                        self._children_name_map["pcedtlv"] = "pcedtlv"
                                                        self._children_yang_names.add("pcedtlv")

                                                        self.rtr_cap_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv()
                                                        self.rtr_cap_tlv.parent = self
                                                        self._children_name_map["rtr_cap_tlv"] = "rtr-cap-tlv"
                                                        self._children_yang_names.add("rtr-cap-tlv")

                                                        self.sr_algo_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv()
                                                        self.sr_algo_tlv.parent = self
                                                        self._children_name_map["sr_algo_tlv"] = "sr-algo-tlv"
                                                        self._children_yang_names.add("sr-algo-tlv")

                                                        self.sr_range_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv()
                                                        self.sr_range_tlv.parent = self
                                                        self._children_name_map["sr_range_tlv"] = "sr-range-tlv"
                                                        self._children_yang_names.add("sr-range-tlv")

                                                        self.unknown_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv()
                                                        self.unknown_tlv.parent = self
                                                        self._children_name_map["unknown_tlv"] = "unknown-tlv"
                                                        self._children_yang_names.add("unknown-tlv")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("ritlv_internal_type") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__setattr__(name, value)


                                                    class UnknownTlv(Entity):
                                                        """
                                                        Unknown Rtr Info TLV
                                                        
                                                        .. attribute:: ri_gen_tlv_length
                                                        
                                                        	Length of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ri_gen_tlv_type
                                                        
                                                        	Type of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ri_genvalue
                                                        
                                                        	Data in TLV
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__init__()

                                                            self.yang_name = "unknown-tlv"
                                                            self.yang_parent_name = "opaque-ritlv"

                                                            self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                            self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                            self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("ri_gen_tlv_length",
                                                                            "ri_gen_tlv_type",
                                                                            "ri_genvalue") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.ri_gen_tlv_length.is_set or
                                                                self.ri_gen_tlv_type.is_set or
                                                                self.ri_genvalue.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.ri_gen_tlv_length.yfilter != YFilter.not_set or
                                                                self.ri_gen_tlv_type.yfilter != YFilter.not_set or
                                                                self.ri_genvalue.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "unknown-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.ri_gen_tlv_length.is_set or self.ri_gen_tlv_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ri_gen_tlv_length.get_name_leafdata())
                                                            if (self.ri_gen_tlv_type.is_set or self.ri_gen_tlv_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ri_gen_tlv_type.get_name_leafdata())
                                                            if (self.ri_genvalue.is_set or self.ri_genvalue.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ri_genvalue.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "ri-gen-tlv-length" or name == "ri-gen-tlv-type" or name == "ri-genvalue"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "ri-gen-tlv-length"):
                                                                self.ri_gen_tlv_length = value
                                                                self.ri_gen_tlv_length.value_namespace = name_space
                                                                self.ri_gen_tlv_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ri-gen-tlv-type"):
                                                                self.ri_gen_tlv_type = value
                                                                self.ri_gen_tlv_type.value_namespace = name_space
                                                                self.ri_gen_tlv_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ri-genvalue"):
                                                                self.ri_genvalue = value
                                                                self.ri_genvalue.value_namespace = name_space
                                                                self.ri_genvalue.value_namespace_prefix = name_space_prefix


                                                    class RtrCapTlv(Entity):
                                                        """
                                                        Rtr Cap TLV
                                                        
                                                        .. attribute:: rtr_cap_additional_info
                                                        
                                                        	Additional Information in TLV
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: rtr_cap_all_bits
                                                        
                                                        	All capability bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rtr_cap_area_te
                                                        
                                                        	Traffic Engineering capability of area
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rtr_cap_graceful_restart
                                                        
                                                        	Graceful Restart Capability
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rtr_cap_graceful_restart_helper
                                                        
                                                        	Graceful Restart Helper Capability
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rtr_cap_p2plan
                                                        
                                                        	P2P LAN Capability
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rtr_cap_stub_rtr
                                                        
                                                        	Stub Router capability
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rtr_cap_te_exp
                                                        
                                                        	TE Experimental bit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rtr_cap_tlv_length
                                                        
                                                        	Length of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__init__()

                                                            self.yang_name = "rtr-cap-tlv"
                                                            self.yang_parent_name = "opaque-ritlv"

                                                            self.rtr_cap_additional_info = YLeaf(YType.str, "rtr-cap-additional-info")

                                                            self.rtr_cap_all_bits = YLeaf(YType.uint32, "rtr-cap-all-bits")

                                                            self.rtr_cap_area_te = YLeaf(YType.boolean, "rtr-cap-area-te")

                                                            self.rtr_cap_graceful_restart = YLeaf(YType.boolean, "rtr-cap-graceful-restart")

                                                            self.rtr_cap_graceful_restart_helper = YLeaf(YType.boolean, "rtr-cap-graceful-restart-helper")

                                                            self.rtr_cap_p2plan = YLeaf(YType.boolean, "rtr-cap-p2plan")

                                                            self.rtr_cap_stub_rtr = YLeaf(YType.boolean, "rtr-cap-stub-rtr")

                                                            self.rtr_cap_te_exp = YLeaf(YType.boolean, "rtr-cap-te-exp")

                                                            self.rtr_cap_tlv_length = YLeaf(YType.uint16, "rtr-cap-tlv-length")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("rtr_cap_additional_info",
                                                                            "rtr_cap_all_bits",
                                                                            "rtr_cap_area_te",
                                                                            "rtr_cap_graceful_restart",
                                                                            "rtr_cap_graceful_restart_helper",
                                                                            "rtr_cap_p2plan",
                                                                            "rtr_cap_stub_rtr",
                                                                            "rtr_cap_te_exp",
                                                                            "rtr_cap_tlv_length") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.rtr_cap_additional_info.is_set or
                                                                self.rtr_cap_all_bits.is_set or
                                                                self.rtr_cap_area_te.is_set or
                                                                self.rtr_cap_graceful_restart.is_set or
                                                                self.rtr_cap_graceful_restart_helper.is_set or
                                                                self.rtr_cap_p2plan.is_set or
                                                                self.rtr_cap_stub_rtr.is_set or
                                                                self.rtr_cap_te_exp.is_set or
                                                                self.rtr_cap_tlv_length.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.rtr_cap_additional_info.yfilter != YFilter.not_set or
                                                                self.rtr_cap_all_bits.yfilter != YFilter.not_set or
                                                                self.rtr_cap_area_te.yfilter != YFilter.not_set or
                                                                self.rtr_cap_graceful_restart.yfilter != YFilter.not_set or
                                                                self.rtr_cap_graceful_restart_helper.yfilter != YFilter.not_set or
                                                                self.rtr_cap_p2plan.yfilter != YFilter.not_set or
                                                                self.rtr_cap_stub_rtr.yfilter != YFilter.not_set or
                                                                self.rtr_cap_te_exp.yfilter != YFilter.not_set or
                                                                self.rtr_cap_tlv_length.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "rtr-cap-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.rtr_cap_additional_info.is_set or self.rtr_cap_additional_info.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.rtr_cap_additional_info.get_name_leafdata())
                                                            if (self.rtr_cap_all_bits.is_set or self.rtr_cap_all_bits.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.rtr_cap_all_bits.get_name_leafdata())
                                                            if (self.rtr_cap_area_te.is_set or self.rtr_cap_area_te.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.rtr_cap_area_te.get_name_leafdata())
                                                            if (self.rtr_cap_graceful_restart.is_set or self.rtr_cap_graceful_restart.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.rtr_cap_graceful_restart.get_name_leafdata())
                                                            if (self.rtr_cap_graceful_restart_helper.is_set or self.rtr_cap_graceful_restart_helper.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.rtr_cap_graceful_restart_helper.get_name_leafdata())
                                                            if (self.rtr_cap_p2plan.is_set or self.rtr_cap_p2plan.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.rtr_cap_p2plan.get_name_leafdata())
                                                            if (self.rtr_cap_stub_rtr.is_set or self.rtr_cap_stub_rtr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.rtr_cap_stub_rtr.get_name_leafdata())
                                                            if (self.rtr_cap_te_exp.is_set or self.rtr_cap_te_exp.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.rtr_cap_te_exp.get_name_leafdata())
                                                            if (self.rtr_cap_tlv_length.is_set or self.rtr_cap_tlv_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.rtr_cap_tlv_length.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "rtr-cap-additional-info" or name == "rtr-cap-all-bits" or name == "rtr-cap-area-te" or name == "rtr-cap-graceful-restart" or name == "rtr-cap-graceful-restart-helper" or name == "rtr-cap-p2plan" or name == "rtr-cap-stub-rtr" or name == "rtr-cap-te-exp" or name == "rtr-cap-tlv-length"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "rtr-cap-additional-info"):
                                                                self.rtr_cap_additional_info = value
                                                                self.rtr_cap_additional_info.value_namespace = name_space
                                                                self.rtr_cap_additional_info.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "rtr-cap-all-bits"):
                                                                self.rtr_cap_all_bits = value
                                                                self.rtr_cap_all_bits.value_namespace = name_space
                                                                self.rtr_cap_all_bits.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "rtr-cap-area-te"):
                                                                self.rtr_cap_area_te = value
                                                                self.rtr_cap_area_te.value_namespace = name_space
                                                                self.rtr_cap_area_te.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "rtr-cap-graceful-restart"):
                                                                self.rtr_cap_graceful_restart = value
                                                                self.rtr_cap_graceful_restart.value_namespace = name_space
                                                                self.rtr_cap_graceful_restart.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "rtr-cap-graceful-restart-helper"):
                                                                self.rtr_cap_graceful_restart_helper = value
                                                                self.rtr_cap_graceful_restart_helper.value_namespace = name_space
                                                                self.rtr_cap_graceful_restart_helper.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "rtr-cap-p2plan"):
                                                                self.rtr_cap_p2plan = value
                                                                self.rtr_cap_p2plan.value_namespace = name_space
                                                                self.rtr_cap_p2plan.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "rtr-cap-stub-rtr"):
                                                                self.rtr_cap_stub_rtr = value
                                                                self.rtr_cap_stub_rtr.value_namespace = name_space
                                                                self.rtr_cap_stub_rtr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "rtr-cap-te-exp"):
                                                                self.rtr_cap_te_exp = value
                                                                self.rtr_cap_te_exp.value_namespace = name_space
                                                                self.rtr_cap_te_exp.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "rtr-cap-tlv-length"):
                                                                self.rtr_cap_tlv_length = value
                                                                self.rtr_cap_tlv_length.value_namespace = name_space
                                                                self.rtr_cap_tlv_length.value_namespace_prefix = name_space_prefix


                                                    class Pcedtlv(Entity):
                                                        """
                                                        PCE Discovery TLV
                                                        
                                                        .. attribute:: pced_addr
                                                        
                                                        	PCE Address
                                                        	**type**\:   :py:class:`PcedAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr>`
                                                        
                                                        .. attribute:: pced_scope
                                                        
                                                        	PCE Scope Information
                                                        	**type**\:   :py:class:`PcedScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope>`
                                                        
                                                        .. attribute:: pcedtlv_length
                                                        
                                                        	Length of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__init__()

                                                            self.yang_name = "pcedtlv"
                                                            self.yang_parent_name = "opaque-ritlv"

                                                            self.pcedtlv_length = YLeaf(YType.uint16, "pcedtlv-length")

                                                            self.pced_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr()
                                                            self.pced_addr.parent = self
                                                            self._children_name_map["pced_addr"] = "pced-addr"
                                                            self._children_yang_names.add("pced-addr")

                                                            self.pced_scope = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope()
                                                            self.pced_scope.parent = self
                                                            self._children_name_map["pced_scope"] = "pced-scope"
                                                            self._children_yang_names.add("pced-scope")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("pcedtlv_length") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__setattr__(name, value)


                                                        class PcedAddr(Entity):
                                                            """
                                                            PCE Address
                                                            
                                                            .. attribute:: ipv4pce_addr
                                                            
                                                            	IPv4 PCE Address
                                                            	**type**\:   :py:class:`Ipv4PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr>`
                                                            
                                                            .. attribute:: ipv6pce_addr
                                                            
                                                            	IPv6 PCE Address
                                                            	**type**\:   :py:class:`Ipv6PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr>`
                                                            
                                                            .. attribute:: pce_addr_type
                                                            
                                                            	PCEAddrType
                                                            	**type**\:   :py:class:`OspfShOpqRiPceAddrTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiPceAddrTypes>`
                                                            
                                                            .. attribute:: pce_addr_unknown_tlv
                                                            
                                                            	Unknown PCE Addr TLV
                                                            	**type**\:   :py:class:`PceAddrUnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__init__()

                                                                self.yang_name = "pced-addr"
                                                                self.yang_parent_name = "pcedtlv"

                                                                self.pce_addr_type = YLeaf(YType.enumeration, "pce-addr-type")

                                                                self.ipv4pce_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr()
                                                                self.ipv4pce_addr.parent = self
                                                                self._children_name_map["ipv4pce_addr"] = "ipv4pce-addr"
                                                                self._children_yang_names.add("ipv4pce-addr")

                                                                self.ipv6pce_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr()
                                                                self.ipv6pce_addr.parent = self
                                                                self._children_name_map["ipv6pce_addr"] = "ipv6pce-addr"
                                                                self._children_yang_names.add("ipv6pce-addr")

                                                                self.pce_addr_unknown_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv()
                                                                self.pce_addr_unknown_tlv.parent = self
                                                                self._children_name_map["pce_addr_unknown_tlv"] = "pce-addr-unknown-tlv"
                                                                self._children_yang_names.add("pce-addr-unknown-tlv")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("pce_addr_type") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__setattr__(name, value)


                                                            class PceAddrUnknownTlv(Entity):
                                                                """
                                                                Unknown PCE Addr TLV
                                                                
                                                                .. attribute:: ri_gen_tlv_length
                                                                
                                                                	Length of TLV
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ri_gen_tlv_type
                                                                
                                                                	Type of TLV
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ri_genvalue
                                                                
                                                                	Data in TLV
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-01-02'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__init__()

                                                                    self.yang_name = "pce-addr-unknown-tlv"
                                                                    self.yang_parent_name = "pced-addr"

                                                                    self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                                    self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                                    self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("ri_gen_tlv_length",
                                                                                    "ri_gen_tlv_type",
                                                                                    "ri_genvalue") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    return (
                                                                        self.ri_gen_tlv_length.is_set or
                                                                        self.ri_gen_tlv_type.is_set or
                                                                        self.ri_genvalue.is_set)

                                                                def has_operation(self):
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.ri_gen_tlv_length.yfilter != YFilter.not_set or
                                                                        self.ri_gen_tlv_type.yfilter != YFilter.not_set or
                                                                        self.ri_genvalue.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "pce-addr-unknown-tlv" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.ri_gen_tlv_length.is_set or self.ri_gen_tlv_length.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ri_gen_tlv_length.get_name_leafdata())
                                                                    if (self.ri_gen_tlv_type.is_set or self.ri_gen_tlv_type.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ri_gen_tlv_type.get_name_leafdata())
                                                                    if (self.ri_genvalue.is_set or self.ri_genvalue.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ri_genvalue.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "ri-gen-tlv-length" or name == "ri-gen-tlv-type" or name == "ri-genvalue"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "ri-gen-tlv-length"):
                                                                        self.ri_gen_tlv_length = value
                                                                        self.ri_gen_tlv_length.value_namespace = name_space
                                                                        self.ri_gen_tlv_length.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ri-gen-tlv-type"):
                                                                        self.ri_gen_tlv_type = value
                                                                        self.ri_gen_tlv_type.value_namespace = name_space
                                                                        self.ri_gen_tlv_type.value_namespace_prefix = name_space_prefix
                                                                    if(value_path == "ri-genvalue"):
                                                                        self.ri_genvalue = value
                                                                        self.ri_genvalue.value_namespace = name_space
                                                                        self.ri_genvalue.value_namespace_prefix = name_space_prefix


                                                            class Ipv4PceAddr(Entity):
                                                                """
                                                                IPv4 PCE Address
                                                                
                                                                .. attribute:: pceipv4_addr
                                                                
                                                                	PCE IPv4 Address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-01-02'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__init__()

                                                                    self.yang_name = "ipv4pce-addr"
                                                                    self.yang_parent_name = "pced-addr"

                                                                    self.pceipv4_addr = YLeaf(YType.str, "pceipv4-addr")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("pceipv4_addr") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    return self.pceipv4_addr.is_set

                                                                def has_operation(self):
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.pceipv4_addr.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv4pce-addr" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.pceipv4_addr.is_set or self.pceipv4_addr.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pceipv4_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "pceipv4-addr"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "pceipv4-addr"):
                                                                        self.pceipv4_addr = value
                                                                        self.pceipv4_addr.value_namespace = name_space
                                                                        self.pceipv4_addr.value_namespace_prefix = name_space_prefix


                                                            class Ipv6PceAddr(Entity):
                                                                """
                                                                IPv6 PCE Address
                                                                
                                                                .. attribute:: pceipv6_addr
                                                                
                                                                	PCE IPv6 Address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-01-02'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__init__()

                                                                    self.yang_name = "ipv6pce-addr"
                                                                    self.yang_parent_name = "pced-addr"

                                                                    self.pceipv6_addr = YLeaf(YType.str, "pceipv6-addr")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("pceipv6_addr") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__setattr__(name, value)

                                                                def has_data(self):
                                                                    return self.pceipv6_addr.is_set

                                                                def has_operation(self):
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.pceipv6_addr.yfilter != YFilter.not_set)

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "ipv6pce-addr" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.pceipv6_addr.is_set or self.pceipv6_addr.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.pceipv6_addr.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "pceipv6-addr"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "pceipv6-addr"):
                                                                        self.pceipv6_addr = value
                                                                        self.pceipv6_addr.value_namespace = name_space
                                                                        self.pceipv6_addr.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                return (
                                                                    self.pce_addr_type.is_set or
                                                                    (self.ipv4pce_addr is not None and self.ipv4pce_addr.has_data()) or
                                                                    (self.ipv6pce_addr is not None and self.ipv6pce_addr.has_data()) or
                                                                    (self.pce_addr_unknown_tlv is not None and self.pce_addr_unknown_tlv.has_data()))

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.pce_addr_type.yfilter != YFilter.not_set or
                                                                    (self.ipv4pce_addr is not None and self.ipv4pce_addr.has_operation()) or
                                                                    (self.ipv6pce_addr is not None and self.ipv6pce_addr.has_operation()) or
                                                                    (self.pce_addr_unknown_tlv is not None and self.pce_addr_unknown_tlv.has_operation()))

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "pced-addr" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.pce_addr_type.is_set or self.pce_addr_type.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.pce_addr_type.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "ipv4pce-addr"):
                                                                    if (self.ipv4pce_addr is None):
                                                                        self.ipv4pce_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr()
                                                                        self.ipv4pce_addr.parent = self
                                                                        self._children_name_map["ipv4pce_addr"] = "ipv4pce-addr"
                                                                    return self.ipv4pce_addr

                                                                if (child_yang_name == "ipv6pce-addr"):
                                                                    if (self.ipv6pce_addr is None):
                                                                        self.ipv6pce_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr()
                                                                        self.ipv6pce_addr.parent = self
                                                                        self._children_name_map["ipv6pce_addr"] = "ipv6pce-addr"
                                                                    return self.ipv6pce_addr

                                                                if (child_yang_name == "pce-addr-unknown-tlv"):
                                                                    if (self.pce_addr_unknown_tlv is None):
                                                                        self.pce_addr_unknown_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv()
                                                                        self.pce_addr_unknown_tlv.parent = self
                                                                        self._children_name_map["pce_addr_unknown_tlv"] = "pce-addr-unknown-tlv"
                                                                    return self.pce_addr_unknown_tlv

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ipv4pce-addr" or name == "ipv6pce-addr" or name == "pce-addr-unknown-tlv" or name == "pce-addr-type"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "pce-addr-type"):
                                                                    self.pce_addr_type = value
                                                                    self.pce_addr_type.value_namespace = name_space
                                                                    self.pce_addr_type.value_namespace_prefix = name_space_prefix


                                                        class PcedScope(Entity):
                                                            """
                                                            PCE Scope Information
                                                            
                                                            .. attribute:: all_scope_info_bits
                                                            
                                                            	PCE Scope Information
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: lbit
                                                            
                                                            	L Bit
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: pref_l
                                                            
                                                            	Pref L
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pref_r
                                                            
                                                            	Pref R
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pref_s
                                                            
                                                            	Pref S
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pref_y
                                                            
                                                            	Pref Y
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: rbit
                                                            
                                                            	R Bit
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: rd_bit
                                                            
                                                            	Rd Bit
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: sbit
                                                            
                                                            	S Bit
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: sd_bit
                                                            
                                                            	Sd Bit
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: ybit
                                                            
                                                            	Y Bit
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__init__()

                                                                self.yang_name = "pced-scope"
                                                                self.yang_parent_name = "pcedtlv"

                                                                self.all_scope_info_bits = YLeaf(YType.uint32, "all-scope-info-bits")

                                                                self.lbit = YLeaf(YType.boolean, "lbit")

                                                                self.pref_l = YLeaf(YType.uint8, "pref-l")

                                                                self.pref_r = YLeaf(YType.uint8, "pref-r")

                                                                self.pref_s = YLeaf(YType.uint8, "pref-s")

                                                                self.pref_y = YLeaf(YType.uint8, "pref-y")

                                                                self.rbit = YLeaf(YType.boolean, "rbit")

                                                                self.rd_bit = YLeaf(YType.boolean, "rd-bit")

                                                                self.sbit = YLeaf(YType.boolean, "sbit")

                                                                self.sd_bit = YLeaf(YType.boolean, "sd-bit")

                                                                self.ybit = YLeaf(YType.boolean, "ybit")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("all_scope_info_bits",
                                                                                "lbit",
                                                                                "pref_l",
                                                                                "pref_r",
                                                                                "pref_s",
                                                                                "pref_y",
                                                                                "rbit",
                                                                                "rd_bit",
                                                                                "sbit",
                                                                                "sd_bit",
                                                                                "ybit") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__setattr__(name, value)

                                                            def has_data(self):
                                                                return (
                                                                    self.all_scope_info_bits.is_set or
                                                                    self.lbit.is_set or
                                                                    self.pref_l.is_set or
                                                                    self.pref_r.is_set or
                                                                    self.pref_s.is_set or
                                                                    self.pref_y.is_set or
                                                                    self.rbit.is_set or
                                                                    self.rd_bit.is_set or
                                                                    self.sbit.is_set or
                                                                    self.sd_bit.is_set or
                                                                    self.ybit.is_set)

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.all_scope_info_bits.yfilter != YFilter.not_set or
                                                                    self.lbit.yfilter != YFilter.not_set or
                                                                    self.pref_l.yfilter != YFilter.not_set or
                                                                    self.pref_r.yfilter != YFilter.not_set or
                                                                    self.pref_s.yfilter != YFilter.not_set or
                                                                    self.pref_y.yfilter != YFilter.not_set or
                                                                    self.rbit.yfilter != YFilter.not_set or
                                                                    self.rd_bit.yfilter != YFilter.not_set or
                                                                    self.sbit.yfilter != YFilter.not_set or
                                                                    self.sd_bit.yfilter != YFilter.not_set or
                                                                    self.ybit.yfilter != YFilter.not_set)

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "pced-scope" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.all_scope_info_bits.is_set or self.all_scope_info_bits.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.all_scope_info_bits.get_name_leafdata())
                                                                if (self.lbit.is_set or self.lbit.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.lbit.get_name_leafdata())
                                                                if (self.pref_l.is_set or self.pref_l.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.pref_l.get_name_leafdata())
                                                                if (self.pref_r.is_set or self.pref_r.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.pref_r.get_name_leafdata())
                                                                if (self.pref_s.is_set or self.pref_s.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.pref_s.get_name_leafdata())
                                                                if (self.pref_y.is_set or self.pref_y.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.pref_y.get_name_leafdata())
                                                                if (self.rbit.is_set or self.rbit.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.rbit.get_name_leafdata())
                                                                if (self.rd_bit.is_set or self.rd_bit.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.rd_bit.get_name_leafdata())
                                                                if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                if (self.sd_bit.is_set or self.sd_bit.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.sd_bit.get_name_leafdata())
                                                                if (self.ybit.is_set or self.ybit.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.ybit.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "all-scope-info-bits" or name == "lbit" or name == "pref-l" or name == "pref-r" or name == "pref-s" or name == "pref-y" or name == "rbit" or name == "rd-bit" or name == "sbit" or name == "sd-bit" or name == "ybit"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "all-scope-info-bits"):
                                                                    self.all_scope_info_bits = value
                                                                    self.all_scope_info_bits.value_namespace = name_space
                                                                    self.all_scope_info_bits.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "lbit"):
                                                                    self.lbit = value
                                                                    self.lbit.value_namespace = name_space
                                                                    self.lbit.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "pref-l"):
                                                                    self.pref_l = value
                                                                    self.pref_l.value_namespace = name_space
                                                                    self.pref_l.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "pref-r"):
                                                                    self.pref_r = value
                                                                    self.pref_r.value_namespace = name_space
                                                                    self.pref_r.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "pref-s"):
                                                                    self.pref_s = value
                                                                    self.pref_s.value_namespace = name_space
                                                                    self.pref_s.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "pref-y"):
                                                                    self.pref_y = value
                                                                    self.pref_y.value_namespace = name_space
                                                                    self.pref_y.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "rbit"):
                                                                    self.rbit = value
                                                                    self.rbit.value_namespace = name_space
                                                                    self.rbit.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "rd-bit"):
                                                                    self.rd_bit = value
                                                                    self.rd_bit.value_namespace = name_space
                                                                    self.rd_bit.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "sbit"):
                                                                    self.sbit = value
                                                                    self.sbit.value_namespace = name_space
                                                                    self.sbit.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "sd-bit"):
                                                                    self.sd_bit = value
                                                                    self.sd_bit.value_namespace = name_space
                                                                    self.sd_bit.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "ybit"):
                                                                    self.ybit = value
                                                                    self.ybit.value_namespace = name_space
                                                                    self.ybit.value_namespace_prefix = name_space_prefix

                                                        def has_data(self):
                                                            return (
                                                                self.pcedtlv_length.is_set or
                                                                (self.pced_addr is not None and self.pced_addr.has_data()) or
                                                                (self.pced_scope is not None and self.pced_scope.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.pcedtlv_length.yfilter != YFilter.not_set or
                                                                (self.pced_addr is not None and self.pced_addr.has_operation()) or
                                                                (self.pced_scope is not None and self.pced_scope.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "pcedtlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.pcedtlv_length.is_set or self.pcedtlv_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pcedtlv_length.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "pced-addr"):
                                                                if (self.pced_addr is None):
                                                                    self.pced_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr()
                                                                    self.pced_addr.parent = self
                                                                    self._children_name_map["pced_addr"] = "pced-addr"
                                                                return self.pced_addr

                                                            if (child_yang_name == "pced-scope"):
                                                                if (self.pced_scope is None):
                                                                    self.pced_scope = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope()
                                                                    self.pced_scope.parent = self
                                                                    self._children_name_map["pced_scope"] = "pced-scope"
                                                                return self.pced_scope

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "pced-addr" or name == "pced-scope" or name == "pcedtlv-length"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "pcedtlv-length"):
                                                                self.pcedtlv_length = value
                                                                self.pcedtlv_length.value_namespace = name_space
                                                                self.pcedtlv_length.value_namespace_prefix = name_space_prefix


                                                    class SrAlgoTlv(Entity):
                                                        """
                                                        SR Algorithm TLV
                                                        
                                                        .. attribute:: sr_algo_length
                                                        
                                                        	Length of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: sr_algo_value
                                                        
                                                        	SR Algorithms
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__init__()

                                                            self.yang_name = "sr-algo-tlv"
                                                            self.yang_parent_name = "opaque-ritlv"

                                                            self.sr_algo_length = YLeaf(YType.uint16, "sr-algo-length")

                                                            self.sr_algo_value = YLeaf(YType.str, "sr-algo-value")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("sr_algo_length",
                                                                            "sr_algo_value") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.sr_algo_length.is_set or
                                                                self.sr_algo_value.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.sr_algo_length.yfilter != YFilter.not_set or
                                                                self.sr_algo_value.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "sr-algo-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.sr_algo_length.is_set or self.sr_algo_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sr_algo_length.get_name_leafdata())
                                                            if (self.sr_algo_value.is_set or self.sr_algo_value.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sr_algo_value.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "sr-algo-length" or name == "sr-algo-value"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "sr-algo-length"):
                                                                self.sr_algo_length = value
                                                                self.sr_algo_length.value_namespace = name_space
                                                                self.sr_algo_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "sr-algo-value"):
                                                                self.sr_algo_value = value
                                                                self.sr_algo_value.value_namespace = name_space
                                                                self.sr_algo_value.value_namespace_prefix = name_space_prefix


                                                    class SrRangeTlv(Entity):
                                                        """
                                                        SR Range TLV
                                                        
                                                        .. attribute:: sidtlv
                                                        
                                                        	SID sub\-TLV
                                                        	**type**\:   :py:class:`Sidtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv>`
                                                        
                                                        .. attribute:: sr_range_length
                                                        
                                                        	Length of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: sr_range_size
                                                        
                                                        	SR Range Size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__init__()

                                                            self.yang_name = "sr-range-tlv"
                                                            self.yang_parent_name = "opaque-ritlv"

                                                            self.sr_range_length = YLeaf(YType.uint16, "sr-range-length")

                                                            self.sr_range_size = YLeaf(YType.uint32, "sr-range-size")

                                                            self.sidtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv()
                                                            self.sidtlv.parent = self
                                                            self._children_name_map["sidtlv"] = "sidtlv"
                                                            self._children_yang_names.add("sidtlv")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("sr_range_length",
                                                                            "sr_range_size") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__setattr__(name, value)


                                                        class Sidtlv(Entity):
                                                            """
                                                            SID sub\-TLV
                                                            
                                                            .. attribute:: sr_sid_length
                                                            
                                                            	Length of sub\-TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: sr_sid_value
                                                            
                                                            	SID Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__init__()

                                                                self.yang_name = "sidtlv"
                                                                self.yang_parent_name = "sr-range-tlv"

                                                                self.sr_sid_length = YLeaf(YType.uint16, "sr-sid-length")

                                                                self.sr_sid_value = YLeaf(YType.uint32, "sr-sid-value")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("sr_sid_length",
                                                                                "sr_sid_value") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__setattr__(name, value)

                                                            def has_data(self):
                                                                return (
                                                                    self.sr_sid_length.is_set or
                                                                    self.sr_sid_value.is_set)

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.sr_sid_length.yfilter != YFilter.not_set or
                                                                    self.sr_sid_value.yfilter != YFilter.not_set)

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "sidtlv" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.sr_sid_length.is_set or self.sr_sid_length.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.sr_sid_length.get_name_leafdata())
                                                                if (self.sr_sid_value.is_set or self.sr_sid_value.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.sr_sid_value.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "sr-sid-length" or name == "sr-sid-value"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "sr-sid-length"):
                                                                    self.sr_sid_length = value
                                                                    self.sr_sid_length.value_namespace = name_space
                                                                    self.sr_sid_length.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "sr-sid-value"):
                                                                    self.sr_sid_value = value
                                                                    self.sr_sid_value.value_namespace = name_space
                                                                    self.sr_sid_value.value_namespace_prefix = name_space_prefix

                                                        def has_data(self):
                                                            return (
                                                                self.sr_range_length.is_set or
                                                                self.sr_range_size.is_set or
                                                                (self.sidtlv is not None and self.sidtlv.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.sr_range_length.yfilter != YFilter.not_set or
                                                                self.sr_range_size.yfilter != YFilter.not_set or
                                                                (self.sidtlv is not None and self.sidtlv.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "sr-range-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.sr_range_length.is_set or self.sr_range_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sr_range_length.get_name_leafdata())
                                                            if (self.sr_range_size.is_set or self.sr_range_size.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sr_range_size.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "sidtlv"):
                                                                if (self.sidtlv is None):
                                                                    self.sidtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv()
                                                                    self.sidtlv.parent = self
                                                                    self._children_name_map["sidtlv"] = "sidtlv"
                                                                return self.sidtlv

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "sidtlv" or name == "sr-range-length" or name == "sr-range-size"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "sr-range-length"):
                                                                self.sr_range_length = value
                                                                self.sr_range_length.value_namespace = name_space
                                                                self.sr_range_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "sr-range-size"):
                                                                self.sr_range_size = value
                                                                self.sr_range_size.value_namespace = name_space
                                                                self.sr_range_size.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        return (
                                                            self.ritlv_internal_type.is_set or
                                                            (self.pcedtlv is not None and self.pcedtlv.has_data()) or
                                                            (self.rtr_cap_tlv is not None and self.rtr_cap_tlv.has_data()) or
                                                            (self.sr_algo_tlv is not None and self.sr_algo_tlv.has_data()) or
                                                            (self.sr_range_tlv is not None and self.sr_range_tlv.has_data()) or
                                                            (self.unknown_tlv is not None and self.unknown_tlv.has_data()))

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.ritlv_internal_type.yfilter != YFilter.not_set or
                                                            (self.pcedtlv is not None and self.pcedtlv.has_operation()) or
                                                            (self.rtr_cap_tlv is not None and self.rtr_cap_tlv.has_operation()) or
                                                            (self.sr_algo_tlv is not None and self.sr_algo_tlv.has_operation()) or
                                                            (self.sr_range_tlv is not None and self.sr_range_tlv.has_operation()) or
                                                            (self.unknown_tlv is not None and self.unknown_tlv.has_operation()))

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "opaque-ritlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.ritlv_internal_type.is_set or self.ritlv_internal_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ritlv_internal_type.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "pcedtlv"):
                                                            if (self.pcedtlv is None):
                                                                self.pcedtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv()
                                                                self.pcedtlv.parent = self
                                                                self._children_name_map["pcedtlv"] = "pcedtlv"
                                                            return self.pcedtlv

                                                        if (child_yang_name == "rtr-cap-tlv"):
                                                            if (self.rtr_cap_tlv is None):
                                                                self.rtr_cap_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv()
                                                                self.rtr_cap_tlv.parent = self
                                                                self._children_name_map["rtr_cap_tlv"] = "rtr-cap-tlv"
                                                            return self.rtr_cap_tlv

                                                        if (child_yang_name == "sr-algo-tlv"):
                                                            if (self.sr_algo_tlv is None):
                                                                self.sr_algo_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv()
                                                                self.sr_algo_tlv.parent = self
                                                                self._children_name_map["sr_algo_tlv"] = "sr-algo-tlv"
                                                            return self.sr_algo_tlv

                                                        if (child_yang_name == "sr-range-tlv"):
                                                            if (self.sr_range_tlv is None):
                                                                self.sr_range_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv()
                                                                self.sr_range_tlv.parent = self
                                                                self._children_name_map["sr_range_tlv"] = "sr-range-tlv"
                                                            return self.sr_range_tlv

                                                        if (child_yang_name == "unknown-tlv"):
                                                            if (self.unknown_tlv is None):
                                                                self.unknown_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv()
                                                                self.unknown_tlv.parent = self
                                                                self._children_name_map["unknown_tlv"] = "unknown-tlv"
                                                            return self.unknown_tlv

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "pcedtlv" or name == "rtr-cap-tlv" or name == "sr-algo-tlv" or name == "sr-range-tlv" or name == "unknown-tlv" or name == "ritlv-internal-type"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "ritlv-internal-type"):
                                                            self.ritlv_internal_type = value
                                                            self.ritlv_internal_type.value_namespace = name_space
                                                            self.ritlv_internal_type.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.opaque_ritlv:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.opaque_ri_interface_name.is_set or
                                                        self.opaque_rilsa_scope.is_set)

                                                def has_operation(self):
                                                    for c in self.opaque_ritlv:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.opaque_ri_interface_name.yfilter != YFilter.not_set or
                                                        self.opaque_rilsa_scope.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opaque-router-info-lsa-type" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.opaque_ri_interface_name.is_set or self.opaque_ri_interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.opaque_ri_interface_name.get_name_leafdata())
                                                    if (self.opaque_rilsa_scope.is_set or self.opaque_rilsa_scope.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.opaque_rilsa_scope.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "opaque-ritlv"):
                                                        for c in self.opaque_ritlv:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.opaque_ritlv.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "opaque-ritlv" or name == "opaque-ri-interface-name" or name == "opaque-rilsa-scope"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "opaque-ri-interface-name"):
                                                        self.opaque_ri_interface_name = value
                                                        self.opaque_ri_interface_name.value_namespace = name_space
                                                        self.opaque_ri_interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "opaque-rilsa-scope"):
                                                        self.opaque_rilsa_scope = value
                                                        self.opaque_rilsa_scope.value_namespace = name_space
                                                        self.opaque_rilsa_scope.value_namespace_prefix = name_space_prefix


                                            class OpaqueEpLsaType(Entity):
                                                """
                                                Extende Prefix LSA type
                                                
                                                .. attribute:: tlv
                                                
                                                	List of TLVs
                                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__init__()

                                                    self.yang_name = "opaque-ep-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"

                                                    self.tlv = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__setattr__(name, value)


                                                class Tlv(Entity):
                                                    """
                                                    List of TLVs
                                                    
                                                    .. attribute:: mpls_dste_link
                                                    
                                                    	MPLS DS\-TE supported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: mpls_router_id
                                                    
                                                    	MPLS\-TE Router ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: te_link_sub_tlv
                                                    
                                                    	List of Sub\-TLVs
                                                    	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv>`
                                                    
                                                    .. attribute:: tlv_data
                                                    
                                                    	TLV direct data
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tlv_length
                                                    
                                                    	Length of top\-level TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: tlv_type
                                                    
                                                    	Type of top\-level TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__init__()

                                                        self.yang_name = "tlv"
                                                        self.yang_parent_name = "opaque-ep-lsa-type"

                                                        self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                        self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                        self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                        self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                        self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                        self.te_link_sub_tlv = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("mpls_dste_link",
                                                                        "mpls_router_id",
                                                                        "tlv_data",
                                                                        "tlv_length",
                                                                        "tlv_type") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__setattr__(name, value)


                                                    class TeLinkSubTlv(Entity):
                                                        """
                                                        List of Sub\-TLVs
                                                        
                                                        .. attribute:: sub_tlv_length
                                                        
                                                        	Length of sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: sub_tlv_type
                                                        
                                                        	Type of sub TLV
                                                        	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                        
                                                        .. attribute:: sub_tlv_value
                                                        
                                                        	Value of sub TLV
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                            self.yang_name = "te-link-sub-tlv"
                                                            self.yang_parent_name = "tlv"

                                                            self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                            self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                            self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("sub_tlv_length",
                                                                            "sub_tlv_type",
                                                                            "sub_tlv_value") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.sub_tlv_length.is_set or
                                                                self.sub_tlv_type.is_set or
                                                                self.sub_tlv_value.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.sub_tlv_length.yfilter != YFilter.not_set or
                                                                self.sub_tlv_type.yfilter != YFilter.not_set or
                                                                self.sub_tlv_value.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "te-link-sub-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.sub_tlv_length.is_set or self.sub_tlv_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sub_tlv_length.get_name_leafdata())
                                                            if (self.sub_tlv_type.is_set or self.sub_tlv_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sub_tlv_type.get_name_leafdata())
                                                            if (self.sub_tlv_value.is_set or self.sub_tlv_value.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sub_tlv_value.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "sub-tlv-length" or name == "sub-tlv-type" or name == "sub-tlv-value"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "sub-tlv-length"):
                                                                self.sub_tlv_length = value
                                                                self.sub_tlv_length.value_namespace = name_space
                                                                self.sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "sub-tlv-type"):
                                                                self.sub_tlv_type = value
                                                                self.sub_tlv_type.value_namespace = name_space
                                                                self.sub_tlv_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "sub-tlv-value"):
                                                                self.sub_tlv_value = value
                                                                self.sub_tlv_value.value_namespace = name_space
                                                                self.sub_tlv_value.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.te_link_sub_tlv:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.mpls_dste_link.is_set or
                                                            self.mpls_router_id.is_set or
                                                            self.tlv_data.is_set or
                                                            self.tlv_length.is_set or
                                                            self.tlv_type.is_set)

                                                    def has_operation(self):
                                                        for c in self.te_link_sub_tlv:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.mpls_dste_link.yfilter != YFilter.not_set or
                                                            self.mpls_router_id.yfilter != YFilter.not_set or
                                                            self.tlv_data.yfilter != YFilter.not_set or
                                                            self.tlv_length.yfilter != YFilter.not_set or
                                                            self.tlv_type.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "tlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.mpls_dste_link.is_set or self.mpls_dste_link.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_dste_link.get_name_leafdata())
                                                        if (self.mpls_router_id.is_set or self.mpls_router_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_router_id.get_name_leafdata())
                                                        if (self.tlv_data.is_set or self.tlv_data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tlv_data.get_name_leafdata())
                                                        if (self.tlv_length.is_set or self.tlv_length.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tlv_length.get_name_leafdata())
                                                        if (self.tlv_type.is_set or self.tlv_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tlv_type.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "te-link-sub-tlv"):
                                                            for c in self.te_link_sub_tlv:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.te_link_sub_tlv.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "te-link-sub-tlv" or name == "mpls-dste-link" or name == "mpls-router-id" or name == "tlv-data" or name == "tlv-length" or name == "tlv-type"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "mpls-dste-link"):
                                                            self.mpls_dste_link = value
                                                            self.mpls_dste_link.value_namespace = name_space
                                                            self.mpls_dste_link.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mpls-router-id"):
                                                            self.mpls_router_id = value
                                                            self.mpls_router_id.value_namespace = name_space
                                                            self.mpls_router_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tlv-data"):
                                                            self.tlv_data = value
                                                            self.tlv_data.value_namespace = name_space
                                                            self.tlv_data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tlv-length"):
                                                            self.tlv_length = value
                                                            self.tlv_length.value_namespace = name_space
                                                            self.tlv_length.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tlv-type"):
                                                            self.tlv_type = value
                                                            self.tlv_type.value_namespace = name_space
                                                            self.tlv_type.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.tlv:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.tlv:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opaque-ep-lsa-type" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "tlv"):
                                                        for c in self.tlv:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.tlv.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tlv"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class OpaqueElLsaType(Entity):
                                                """
                                                Extended Link LSA type
                                                
                                                .. attribute:: tlv
                                                
                                                	List of TLVs
                                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__init__()

                                                    self.yang_name = "opaque-el-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"

                                                    self.tlv = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__setattr__(name, value)


                                                class Tlv(Entity):
                                                    """
                                                    List of TLVs
                                                    
                                                    .. attribute:: mpls_dste_link
                                                    
                                                    	MPLS DS\-TE supported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: mpls_router_id
                                                    
                                                    	MPLS\-TE Router ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: te_link_sub_tlv
                                                    
                                                    	List of Sub\-TLVs
                                                    	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv>`
                                                    
                                                    .. attribute:: tlv_data
                                                    
                                                    	TLV direct data
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tlv_length
                                                    
                                                    	Length of top\-level TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: tlv_type
                                                    
                                                    	Type of top\-level TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__init__()

                                                        self.yang_name = "tlv"
                                                        self.yang_parent_name = "opaque-el-lsa-type"

                                                        self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                        self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                        self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                        self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                        self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                        self.te_link_sub_tlv = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("mpls_dste_link",
                                                                        "mpls_router_id",
                                                                        "tlv_data",
                                                                        "tlv_length",
                                                                        "tlv_type") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__setattr__(name, value)


                                                    class TeLinkSubTlv(Entity):
                                                        """
                                                        List of Sub\-TLVs
                                                        
                                                        .. attribute:: sub_tlv_length
                                                        
                                                        	Length of sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: sub_tlv_type
                                                        
                                                        	Type of sub TLV
                                                        	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                        
                                                        .. attribute:: sub_tlv_value
                                                        
                                                        	Value of sub TLV
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                            self.yang_name = "te-link-sub-tlv"
                                                            self.yang_parent_name = "tlv"

                                                            self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                            self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                            self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("sub_tlv_length",
                                                                            "sub_tlv_type",
                                                                            "sub_tlv_value") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.sub_tlv_length.is_set or
                                                                self.sub_tlv_type.is_set or
                                                                self.sub_tlv_value.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.sub_tlv_length.yfilter != YFilter.not_set or
                                                                self.sub_tlv_type.yfilter != YFilter.not_set or
                                                                self.sub_tlv_value.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "te-link-sub-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.sub_tlv_length.is_set or self.sub_tlv_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sub_tlv_length.get_name_leafdata())
                                                            if (self.sub_tlv_type.is_set or self.sub_tlv_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sub_tlv_type.get_name_leafdata())
                                                            if (self.sub_tlv_value.is_set or self.sub_tlv_value.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sub_tlv_value.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "sub-tlv-length" or name == "sub-tlv-type" or name == "sub-tlv-value"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "sub-tlv-length"):
                                                                self.sub_tlv_length = value
                                                                self.sub_tlv_length.value_namespace = name_space
                                                                self.sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "sub-tlv-type"):
                                                                self.sub_tlv_type = value
                                                                self.sub_tlv_type.value_namespace = name_space
                                                                self.sub_tlv_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "sub-tlv-value"):
                                                                self.sub_tlv_value = value
                                                                self.sub_tlv_value.value_namespace = name_space
                                                                self.sub_tlv_value.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.te_link_sub_tlv:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.mpls_dste_link.is_set or
                                                            self.mpls_router_id.is_set or
                                                            self.tlv_data.is_set or
                                                            self.tlv_length.is_set or
                                                            self.tlv_type.is_set)

                                                    def has_operation(self):
                                                        for c in self.te_link_sub_tlv:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.mpls_dste_link.yfilter != YFilter.not_set or
                                                            self.mpls_router_id.yfilter != YFilter.not_set or
                                                            self.tlv_data.yfilter != YFilter.not_set or
                                                            self.tlv_length.yfilter != YFilter.not_set or
                                                            self.tlv_type.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "tlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.mpls_dste_link.is_set or self.mpls_dste_link.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_dste_link.get_name_leafdata())
                                                        if (self.mpls_router_id.is_set or self.mpls_router_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.mpls_router_id.get_name_leafdata())
                                                        if (self.tlv_data.is_set or self.tlv_data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tlv_data.get_name_leafdata())
                                                        if (self.tlv_length.is_set or self.tlv_length.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tlv_length.get_name_leafdata())
                                                        if (self.tlv_type.is_set or self.tlv_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tlv_type.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "te-link-sub-tlv"):
                                                            for c in self.te_link_sub_tlv:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.te_link_sub_tlv.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "te-link-sub-tlv" or name == "mpls-dste-link" or name == "mpls-router-id" or name == "tlv-data" or name == "tlv-length" or name == "tlv-type"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "mpls-dste-link"):
                                                            self.mpls_dste_link = value
                                                            self.mpls_dste_link.value_namespace = name_space
                                                            self.mpls_dste_link.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "mpls-router-id"):
                                                            self.mpls_router_id = value
                                                            self.mpls_router_id.value_namespace = name_space
                                                            self.mpls_router_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tlv-data"):
                                                            self.tlv_data = value
                                                            self.tlv_data.value_namespace = name_space
                                                            self.tlv_data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tlv-length"):
                                                            self.tlv_length = value
                                                            self.tlv_length.value_namespace = name_space
                                                            self.tlv_length.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tlv-type"):
                                                            self.tlv_type = value
                                                            self.tlv_type.value_namespace = name_space
                                                            self.tlv_type.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.tlv:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.tlv:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opaque-el-lsa-type" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "tlv"):
                                                        for c in self.tlv:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.tlv.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tlv"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.internal_lsa_type.is_set or
                                                    (self.external_lsa_type is not None and self.external_lsa_type.has_data()) or
                                                    (self.network_lsa_type is not None and self.network_lsa_type.has_data()) or
                                                    (self.opaque_el_lsa_type is not None and self.opaque_el_lsa_type.has_data()) or
                                                    (self.opaque_ep_lsa_type is not None and self.opaque_ep_lsa_type.has_data()) or
                                                    (self.opaque_grace_lsa is not None and self.opaque_grace_lsa.has_data()) or
                                                    (self.opaque_link_lsa_type is not None and self.opaque_link_lsa_type.has_data()) or
                                                    (self.opaque_mpls_te_lsa_type is not None and self.opaque_mpls_te_lsa_type.has_data()) or
                                                    (self.opaque_router_info_lsa_type is not None and self.opaque_router_info_lsa_type.has_data()) or
                                                    (self.router_lsa_type is not None and self.router_lsa_type.has_data()) or
                                                    (self.summary_lsa_type is not None and self.summary_lsa_type.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_lsa_type.yfilter != YFilter.not_set or
                                                    (self.external_lsa_type is not None and self.external_lsa_type.has_operation()) or
                                                    (self.network_lsa_type is not None and self.network_lsa_type.has_operation()) or
                                                    (self.opaque_el_lsa_type is not None and self.opaque_el_lsa_type.has_operation()) or
                                                    (self.opaque_ep_lsa_type is not None and self.opaque_ep_lsa_type.has_operation()) or
                                                    (self.opaque_grace_lsa is not None and self.opaque_grace_lsa.has_operation()) or
                                                    (self.opaque_link_lsa_type is not None and self.opaque_link_lsa_type.has_operation()) or
                                                    (self.opaque_mpls_te_lsa_type is not None and self.opaque_mpls_te_lsa_type.has_operation()) or
                                                    (self.opaque_router_info_lsa_type is not None and self.opaque_router_info_lsa_type.has_operation()) or
                                                    (self.router_lsa_type is not None and self.router_lsa_type.has_operation()) or
                                                    (self.summary_lsa_type is not None and self.summary_lsa_type.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "lsa-internal-data" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_lsa_type.is_set or self.internal_lsa_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_lsa_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "external-lsa-type"):
                                                    if (self.external_lsa_type is None):
                                                        self.external_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType()
                                                        self.external_lsa_type.parent = self
                                                        self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                                    return self.external_lsa_type

                                                if (child_yang_name == "network-lsa-type"):
                                                    if (self.network_lsa_type is None):
                                                        self.network_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType()
                                                        self.network_lsa_type.parent = self
                                                        self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                                    return self.network_lsa_type

                                                if (child_yang_name == "opaque-el-lsa-type"):
                                                    if (self.opaque_el_lsa_type is None):
                                                        self.opaque_el_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType()
                                                        self.opaque_el_lsa_type.parent = self
                                                        self._children_name_map["opaque_el_lsa_type"] = "opaque-el-lsa-type"
                                                    return self.opaque_el_lsa_type

                                                if (child_yang_name == "opaque-ep-lsa-type"):
                                                    if (self.opaque_ep_lsa_type is None):
                                                        self.opaque_ep_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType()
                                                        self.opaque_ep_lsa_type.parent = self
                                                        self._children_name_map["opaque_ep_lsa_type"] = "opaque-ep-lsa-type"
                                                    return self.opaque_ep_lsa_type

                                                if (child_yang_name == "opaque-grace-lsa"):
                                                    if (self.opaque_grace_lsa is None):
                                                        self.opaque_grace_lsa = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa()
                                                        self.opaque_grace_lsa.parent = self
                                                        self._children_name_map["opaque_grace_lsa"] = "opaque-grace-lsa"
                                                    return self.opaque_grace_lsa

                                                if (child_yang_name == "opaque-link-lsa-type"):
                                                    if (self.opaque_link_lsa_type is None):
                                                        self.opaque_link_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType()
                                                        self.opaque_link_lsa_type.parent = self
                                                        self._children_name_map["opaque_link_lsa_type"] = "opaque-link-lsa-type"
                                                    return self.opaque_link_lsa_type

                                                if (child_yang_name == "opaque-mpls-te-lsa-type"):
                                                    if (self.opaque_mpls_te_lsa_type is None):
                                                        self.opaque_mpls_te_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType()
                                                        self.opaque_mpls_te_lsa_type.parent = self
                                                        self._children_name_map["opaque_mpls_te_lsa_type"] = "opaque-mpls-te-lsa-type"
                                                    return self.opaque_mpls_te_lsa_type

                                                if (child_yang_name == "opaque-router-info-lsa-type"):
                                                    if (self.opaque_router_info_lsa_type is None):
                                                        self.opaque_router_info_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType()
                                                        self.opaque_router_info_lsa_type.parent = self
                                                        self._children_name_map["opaque_router_info_lsa_type"] = "opaque-router-info-lsa-type"
                                                    return self.opaque_router_info_lsa_type

                                                if (child_yang_name == "router-lsa-type"):
                                                    if (self.router_lsa_type is None):
                                                        self.router_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType()
                                                        self.router_lsa_type.parent = self
                                                        self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                                    return self.router_lsa_type

                                                if (child_yang_name == "summary-lsa-type"):
                                                    if (self.summary_lsa_type is None):
                                                        self.summary_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType()
                                                        self.summary_lsa_type.parent = self
                                                        self._children_name_map["summary_lsa_type"] = "summary-lsa-type"
                                                    return self.summary_lsa_type

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "external-lsa-type" or name == "network-lsa-type" or name == "opaque-el-lsa-type" or name == "opaque-ep-lsa-type" or name == "opaque-grace-lsa" or name == "opaque-link-lsa-type" or name == "opaque-mpls-te-lsa-type" or name == "opaque-router-info-lsa-type" or name == "router-lsa-type" or name == "summary-lsa-type" or name == "internal-lsa-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-lsa-type"):
                                                    self.internal_lsa_type = value
                                                    self.internal_lsa_type.value_namespace = name_space
                                                    self.internal_lsa_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.advertising_router.is_set or
                                                self.area_id.is_set or
                                                self.interface_name.is_set or
                                                self.ls_id.is_set or
                                                self.ls_type.is_set or
                                                (self.lsa_detail_data is not None and self.lsa_detail_data.has_data()) or
                                                (self.lsa_header is not None and self.lsa_header.has_data()) or
                                                (self.lsa_internal_data is not None and self.lsa_internal_data.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.advertising_router.yfilter != YFilter.not_set or
                                                self.area_id.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.ls_id.yfilter != YFilter.not_set or
                                                self.ls_type.yfilter != YFilter.not_set or
                                                (self.lsa_detail_data is not None and self.lsa_detail_data.has_operation()) or
                                                (self.lsa_header is not None and self.lsa_header.has_operation()) or
                                                (self.lsa_internal_data is not None and self.lsa_internal_data.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "lsa" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                            if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_id.get_name_leafdata())
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.ls_id.is_set or self.ls_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ls_id.get_name_leafdata())
                                            if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ls_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "lsa-detail-data"):
                                                if (self.lsa_detail_data is None):
                                                    self.lsa_detail_data = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData()
                                                    self.lsa_detail_data.parent = self
                                                    self._children_name_map["lsa_detail_data"] = "lsa-detail-data"
                                                return self.lsa_detail_data

                                            if (child_yang_name == "lsa-header"):
                                                if (self.lsa_header is None):
                                                    self.lsa_header = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                return self.lsa_header

                                            if (child_yang_name == "lsa-internal-data"):
                                                if (self.lsa_internal_data is None):
                                                    self.lsa_internal_data = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData()
                                                    self.lsa_internal_data.parent = self
                                                    self._children_name_map["lsa_internal_data"] = "lsa-internal-data"
                                                return self.lsa_internal_data

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lsa-detail-data" or name == "lsa-header" or name == "lsa-internal-data" or name == "advertising-router" or name == "area-id" or name == "interface-name" or name == "ls-id" or name == "ls-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "advertising-router"):
                                                self.advertising_router = value
                                                self.advertising_router.value_namespace = name_space
                                                self.advertising_router.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-id"):
                                                self.area_id = value
                                                self.area_id.value_namespace = name_space
                                                self.area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ls-id"):
                                                self.ls_id = value
                                                self.ls_id.value_namespace = name_space
                                                self.ls_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ls-type"):
                                                self.ls_type = value
                                                self.ls_type.value_namespace = name_space
                                                self.ls_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.lsa:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.lsa:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lsas" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "lsa"):
                                            for c in self.lsa:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.lsa.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lsa"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class LsaSummaries(Entity):
                                    """
                                    Link state advertisement summary table
                                    
                                    .. attribute:: lsa_summary
                                    
                                    	LSA summary information
                                    	**type**\: list of    :py:class:`LsaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries, self).__init__()

                                        self.yang_name = "lsa-summaries"
                                        self.yang_parent_name = "database-area"

                                        self.lsa_summary = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries, self).__setattr__(name, value)


                                    class LsaSummary(Entity):
                                        """
                                        LSA summary information
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Advertising Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: link_count
                                        
                                        	Number of links
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ls_id
                                        
                                        	Link state ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ls_type
                                        
                                        	Link state type
                                        	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	LSA header information
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary, self).__init__()

                                            self.yang_name = "lsa-summary"
                                            self.yang_parent_name = "lsa-summaries"

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.area_id = YLeaf(YType.int32, "area-id")

                                            self.external_tag = YLeaf(YType.uint32, "external-tag")

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.link_count = YLeaf(YType.uint16, "link-count")

                                            self.ls_id = YLeaf(YType.str, "ls-id")

                                            self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                            self.lsa_header = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("advertising_router",
                                                            "area_id",
                                                            "external_tag",
                                                            "interface_name",
                                                            "link_count",
                                                            "ls_id",
                                                            "ls_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary, self).__setattr__(name, value)


                                        class LsaHeader(Entity):
                                            """
                                            LSA header information
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: dn_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_type
                                            
                                            	LSA type
                                            	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsid
                                            
                                            	LS ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: nsf
                                            
                                            	If true,  LSA received from neighbor during NSF
                                            	**type**\:  bool
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "lsa-summary"

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                                self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsid = YLeaf(YType.str, "lsid")

                                                self.nsf = YLeaf(YType.boolean, "nsf")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("advertising_router",
                                                                "checksum",
                                                                "dn_age_lsa",
                                                                "ls_type",
                                                                "lsa_age",
                                                                "lsa_area_id",
                                                                "lsid",
                                                                "nsf",
                                                                "sequence_number") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.advertising_router.is_set or
                                                    self.checksum.is_set or
                                                    self.dn_age_lsa.is_set or
                                                    self.ls_type.is_set or
                                                    self.lsa_age.is_set or
                                                    self.lsa_area_id.is_set or
                                                    self.lsid.is_set or
                                                    self.nsf.is_set or
                                                    self.sequence_number.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.advertising_router.yfilter != YFilter.not_set or
                                                    self.checksum.yfilter != YFilter.not_set or
                                                    self.dn_age_lsa.yfilter != YFilter.not_set or
                                                    self.ls_type.yfilter != YFilter.not_set or
                                                    self.lsa_age.yfilter != YFilter.not_set or
                                                    self.lsa_area_id.yfilter != YFilter.not_set or
                                                    self.lsid.yfilter != YFilter.not_set or
                                                    self.nsf.yfilter != YFilter.not_set or
                                                    self.sequence_number.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "lsa-header" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                                if (self.checksum.is_set or self.checksum.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.checksum.get_name_leafdata())
                                                if (self.dn_age_lsa.is_set or self.dn_age_lsa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dn_age_lsa.get_name_leafdata())
                                                if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ls_type.get_name_leafdata())
                                                if (self.lsa_age.is_set or self.lsa_age.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsa_age.get_name_leafdata())
                                                if (self.lsa_area_id.is_set or self.lsa_area_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsa_area_id.get_name_leafdata())
                                                if (self.lsid.is_set or self.lsid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsid.get_name_leafdata())
                                                if (self.nsf.is_set or self.nsf.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nsf.get_name_leafdata())
                                                if (self.sequence_number.is_set or self.sequence_number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sequence_number.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "advertising-router" or name == "checksum" or name == "dn-age-lsa" or name == "ls-type" or name == "lsa-age" or name == "lsa-area-id" or name == "lsid" or name == "nsf" or name == "sequence-number"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "advertising-router"):
                                                    self.advertising_router = value
                                                    self.advertising_router.value_namespace = name_space
                                                    self.advertising_router.value_namespace_prefix = name_space_prefix
                                                if(value_path == "checksum"):
                                                    self.checksum = value
                                                    self.checksum.value_namespace = name_space
                                                    self.checksum.value_namespace_prefix = name_space_prefix
                                                if(value_path == "dn-age-lsa"):
                                                    self.dn_age_lsa = value
                                                    self.dn_age_lsa.value_namespace = name_space
                                                    self.dn_age_lsa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ls-type"):
                                                    self.ls_type = value
                                                    self.ls_type.value_namespace = name_space
                                                    self.ls_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsa-age"):
                                                    self.lsa_age = value
                                                    self.lsa_age.value_namespace = name_space
                                                    self.lsa_age.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsa-area-id"):
                                                    self.lsa_area_id = value
                                                    self.lsa_area_id.value_namespace = name_space
                                                    self.lsa_area_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsid"):
                                                    self.lsid = value
                                                    self.lsid.value_namespace = name_space
                                                    self.lsid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "nsf"):
                                                    self.nsf = value
                                                    self.nsf.value_namespace = name_space
                                                    self.nsf.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sequence-number"):
                                                    self.sequence_number = value
                                                    self.sequence_number.value_namespace = name_space
                                                    self.sequence_number.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.advertising_router.is_set or
                                                self.area_id.is_set or
                                                self.external_tag.is_set or
                                                self.interface_name.is_set or
                                                self.link_count.is_set or
                                                self.ls_id.is_set or
                                                self.ls_type.is_set or
                                                (self.lsa_header is not None and self.lsa_header.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.advertising_router.yfilter != YFilter.not_set or
                                                self.area_id.yfilter != YFilter.not_set or
                                                self.external_tag.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.link_count.yfilter != YFilter.not_set or
                                                self.ls_id.yfilter != YFilter.not_set or
                                                self.ls_type.yfilter != YFilter.not_set or
                                                (self.lsa_header is not None and self.lsa_header.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "lsa-summary" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                            if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_id.get_name_leafdata())
                                            if (self.external_tag.is_set or self.external_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.external_tag.get_name_leafdata())
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.link_count.is_set or self.link_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_count.get_name_leafdata())
                                            if (self.ls_id.is_set or self.ls_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ls_id.get_name_leafdata())
                                            if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ls_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "lsa-header"):
                                                if (self.lsa_header is None):
                                                    self.lsa_header = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                return self.lsa_header

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lsa-header" or name == "advertising-router" or name == "area-id" or name == "external-tag" or name == "interface-name" or name == "link-count" or name == "ls-id" or name == "ls-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "advertising-router"):
                                                self.advertising_router = value
                                                self.advertising_router.value_namespace = name_space
                                                self.advertising_router.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-id"):
                                                self.area_id = value
                                                self.area_id.value_namespace = name_space
                                                self.area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "external-tag"):
                                                self.external_tag = value
                                                self.external_tag.value_namespace = name_space
                                                self.external_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-count"):
                                                self.link_count = value
                                                self.link_count.value_namespace = name_space
                                                self.link_count.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ls-id"):
                                                self.ls_id = value
                                                self.ls_id.value_namespace = name_space
                                                self.ls_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ls-type"):
                                                self.ls_type = value
                                                self.ls_type.value_namespace = name_space
                                                self.ls_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.lsa_summary:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.lsa_summary:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lsa-summaries" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "lsa-summary"):
                                            for c in self.lsa_summary:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.lsa_summary.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lsa-summary"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.area_id.is_set or
                                        (self.lsa_summaries is not None and self.lsa_summaries.has_data()) or
                                        (self.lsas is not None and self.lsas.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        (self.lsa_summaries is not None and self.lsa_summaries.has_operation()) or
                                        (self.lsas is not None and self.lsas.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "database-area" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "lsa-summaries"):
                                        if (self.lsa_summaries is None):
                                            self.lsa_summaries = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries()
                                            self.lsa_summaries.parent = self
                                            self._children_name_map["lsa_summaries"] = "lsa-summaries"
                                        return self.lsa_summaries

                                    if (child_yang_name == "lsas"):
                                        if (self.lsas is None):
                                            self.lsas = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas()
                                            self.lsas.parent = self
                                            self._children_name_map["lsas"] = "lsas"
                                        return self.lsas

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lsa-summaries" or name == "lsas" or name == "area-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.database_area:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.database_area:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "database-areas" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "database-area"):
                                    for c in self.database_area:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.database_area.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "database-area"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DatabaseSummaries(Entity):
                            """
                            Link State database summary table
                            
                            .. attribute:: database_summary
                            
                            	Link State Database summary for a particular area
                            	**type**\: list of    :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries, self).__init__()

                                self.yang_name = "database-summaries"
                                self.yang_parent_name = "database"

                                self.database_summary = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries, self).__setattr__(name, value)


                            class DatabaseSummary(Entity):
                                """
                                Link State Database summary for a particular
                                area
                                
                                .. attribute:: area_id  <key>
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: area_lsa_counter
                                
                                	Summary counters for Area scope LSAs
                                	**type**\: list of    :py:class:`AreaLsaCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter>`
                                
                                .. attribute:: dbase_sum_area_id_string
                                
                                	Area id
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary, self).__init__()

                                    self.yang_name = "database-summary"
                                    self.yang_parent_name = "database-summaries"

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.dbase_sum_area_id_string = YLeaf(YType.str, "dbase-sum-area-id-string")

                                    self.area_lsa_counter = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_id",
                                                    "dbase_sum_area_id_string") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary, self).__setattr__(name, value)


                                class AreaLsaCounter(Entity):
                                    """
                                    Summary counters for Area scope LSAs
                                    
                                    .. attribute:: lsa_count
                                    
                                    	Number of LSAs of this type
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: lsa_delete_count
                                    
                                    	Number of deleted LSAs of this type
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: lsa_maxage_count
                                    
                                    	Number of MaxAged LSAs of this type
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: lsa_self_count
                                    
                                    	Number of self\-generated LSAs
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: lsa_type
                                    
                                    	Type of LSAs
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter, self).__init__()

                                        self.yang_name = "area-lsa-counter"
                                        self.yang_parent_name = "database-summary"

                                        self.lsa_count = YLeaf(YType.int32, "lsa-count")

                                        self.lsa_delete_count = YLeaf(YType.int32, "lsa-delete-count")

                                        self.lsa_maxage_count = YLeaf(YType.int32, "lsa-maxage-count")

                                        self.lsa_self_count = YLeaf(YType.int32, "lsa-self-count")

                                        self.lsa_type = YLeaf(YType.enumeration, "lsa-type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lsa_count",
                                                        "lsa_delete_count",
                                                        "lsa_maxage_count",
                                                        "lsa_self_count",
                                                        "lsa_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lsa_count.is_set or
                                            self.lsa_delete_count.is_set or
                                            self.lsa_maxage_count.is_set or
                                            self.lsa_self_count.is_set or
                                            self.lsa_type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lsa_count.yfilter != YFilter.not_set or
                                            self.lsa_delete_count.yfilter != YFilter.not_set or
                                            self.lsa_maxage_count.yfilter != YFilter.not_set or
                                            self.lsa_self_count.yfilter != YFilter.not_set or
                                            self.lsa_type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "area-lsa-counter" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lsa_count.is_set or self.lsa_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_count.get_name_leafdata())
                                        if (self.lsa_delete_count.is_set or self.lsa_delete_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_delete_count.get_name_leafdata())
                                        if (self.lsa_maxage_count.is_set or self.lsa_maxage_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_maxage_count.get_name_leafdata())
                                        if (self.lsa_self_count.is_set or self.lsa_self_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_self_count.get_name_leafdata())
                                        if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lsa-count" or name == "lsa-delete-count" or name == "lsa-maxage-count" or name == "lsa-self-count" or name == "lsa-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lsa-count"):
                                            self.lsa_count = value
                                            self.lsa_count.value_namespace = name_space
                                            self.lsa_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-delete-count"):
                                            self.lsa_delete_count = value
                                            self.lsa_delete_count.value_namespace = name_space
                                            self.lsa_delete_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-maxage-count"):
                                            self.lsa_maxage_count = value
                                            self.lsa_maxage_count.value_namespace = name_space
                                            self.lsa_maxage_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-self-count"):
                                            self.lsa_self_count = value
                                            self.lsa_self_count.value_namespace = name_space
                                            self.lsa_self_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-type"):
                                            self.lsa_type = value
                                            self.lsa_type.value_namespace = name_space
                                            self.lsa_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.area_lsa_counter:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.area_id.is_set or
                                        self.dbase_sum_area_id_string.is_set)

                                def has_operation(self):
                                    for c in self.area_lsa_counter:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.dbase_sum_area_id_string.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "database-summary" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.dbase_sum_area_id_string.is_set or self.dbase_sum_area_id_string.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dbase_sum_area_id_string.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "area-lsa-counter"):
                                        for c in self.area_lsa_counter:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.area_lsa_counter.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "area-lsa-counter" or name == "area-id" or name == "dbase-sum-area-id-string"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dbase-sum-area-id-string"):
                                        self.dbase_sum_area_id_string = value
                                        self.dbase_sum_area_id_string.value_namespace = name_space
                                        self.dbase_sum_area_id_string.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.database_summary:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.database_summary:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "database-summaries" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "database-summary"):
                                    for c in self.database_summary:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.database_summary.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "database-summary"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DatabaseSummaryAs(Entity):
                            """
                            Link State Database summary for the AS
                            
                            .. attribute:: as_lsa_counter
                            
                            	Summary counter for AS scope LSAs
                            	**type**\: list of    :py:class:`AsLsaCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs.AsLsaCounter>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs, self).__init__()

                                self.yang_name = "database-summary-as"
                                self.yang_parent_name = "database"

                                self.as_lsa_counter = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs, self).__setattr__(name, value)


                            class AsLsaCounter(Entity):
                                """
                                Summary counter for AS scope LSAs
                                
                                .. attribute:: lsa_count
                                
                                	Number of LSAs of this type
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_delete_count
                                
                                	Number of deleted LSAs of this type
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_maxage_count
                                
                                	Number of MaxAged LSAs of this type
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_self_count
                                
                                	Number of self\-generated LSAs
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_type
                                
                                	Type of LSAs
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs.AsLsaCounter, self).__init__()

                                    self.yang_name = "as-lsa-counter"
                                    self.yang_parent_name = "database-summary-as"

                                    self.lsa_count = YLeaf(YType.int32, "lsa-count")

                                    self.lsa_delete_count = YLeaf(YType.int32, "lsa-delete-count")

                                    self.lsa_maxage_count = YLeaf(YType.int32, "lsa-maxage-count")

                                    self.lsa_self_count = YLeaf(YType.int32, "lsa-self-count")

                                    self.lsa_type = YLeaf(YType.enumeration, "lsa-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("lsa_count",
                                                    "lsa_delete_count",
                                                    "lsa_maxage_count",
                                                    "lsa_self_count",
                                                    "lsa_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs.AsLsaCounter, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs.AsLsaCounter, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.lsa_count.is_set or
                                        self.lsa_delete_count.is_set or
                                        self.lsa_maxage_count.is_set or
                                        self.lsa_self_count.is_set or
                                        self.lsa_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.lsa_count.yfilter != YFilter.not_set or
                                        self.lsa_delete_count.yfilter != YFilter.not_set or
                                        self.lsa_maxage_count.yfilter != YFilter.not_set or
                                        self.lsa_self_count.yfilter != YFilter.not_set or
                                        self.lsa_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "as-lsa-counter" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.lsa_count.is_set or self.lsa_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_count.get_name_leafdata())
                                    if (self.lsa_delete_count.is_set or self.lsa_delete_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_delete_count.get_name_leafdata())
                                    if (self.lsa_maxage_count.is_set or self.lsa_maxage_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_maxage_count.get_name_leafdata())
                                    if (self.lsa_self_count.is_set or self.lsa_self_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_self_count.get_name_leafdata())
                                    if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lsa-count" or name == "lsa-delete-count" or name == "lsa-maxage-count" or name == "lsa-self-count" or name == "lsa-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "lsa-count"):
                                        self.lsa_count = value
                                        self.lsa_count.value_namespace = name_space
                                        self.lsa_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-delete-count"):
                                        self.lsa_delete_count = value
                                        self.lsa_delete_count.value_namespace = name_space
                                        self.lsa_delete_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-maxage-count"):
                                        self.lsa_maxage_count = value
                                        self.lsa_maxage_count.value_namespace = name_space
                                        self.lsa_maxage_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-self-count"):
                                        self.lsa_self_count = value
                                        self.lsa_self_count.value_namespace = name_space
                                        self.lsa_self_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-type"):
                                        self.lsa_type = value
                                        self.lsa_type.value_namespace = name_space
                                        self.lsa_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.as_lsa_counter:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.as_lsa_counter:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "database-summary-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "as-lsa-counter"):
                                    for c in self.as_lsa_counter:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs.AsLsaCounter()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.as_lsa_counter.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "as-lsa-counter"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Lsas(Entity):
                            """
                            Link State Database Table
                            
                            .. attribute:: lsa
                            
                            	Link State Advertisement information
                            	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas, self).__init__()

                                self.yang_name = "lsas"
                                self.yang_parent_name = "database"

                                self.lsa = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas, self).__setattr__(name, value)


                            class Lsa(Entity):
                                """
                                Link State Advertisement information
                                
                                .. attribute:: advertising_router
                                
                                	Advertising Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: interface_name
                                
                                	InterfaceName
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: ls_id
                                
                                	Link state ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ls_type
                                
                                	Link state type
                                	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                                
                                .. attribute:: lsa_detail_data
                                
                                	Detailed LSA Information
                                	**type**\:   :py:class:`LsaDetailData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData>`
                                
                                .. attribute:: lsa_header
                                
                                	Header information
                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaHeader>`
                                
                                .. attribute:: lsa_internal_data
                                
                                	Information pertaining to a specific LSA type
                                	**type**\:   :py:class:`LsaInternalData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa, self).__init__()

                                    self.yang_name = "lsa"
                                    self.yang_parent_name = "lsas"

                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.ls_id = YLeaf(YType.str, "ls-id")

                                    self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                    self.lsa_detail_data = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData()
                                    self.lsa_detail_data.parent = self
                                    self._children_name_map["lsa_detail_data"] = "lsa-detail-data"
                                    self._children_yang_names.add("lsa-detail-data")

                                    self.lsa_header = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaHeader()
                                    self.lsa_header.parent = self
                                    self._children_name_map["lsa_header"] = "lsa-header"
                                    self._children_yang_names.add("lsa-header")

                                    self.lsa_internal_data = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData()
                                    self.lsa_internal_data.parent = self
                                    self._children_name_map["lsa_internal_data"] = "lsa-internal-data"
                                    self._children_yang_names.add("lsa-internal-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("advertising_router",
                                                    "area_id",
                                                    "interface_name",
                                                    "ls_id",
                                                    "ls_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa, self).__setattr__(name, value)


                                class LsaHeader(Entity):
                                    """
                                    Header information
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Router ID of Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: checksum
                                    
                                    	Checksum value
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: dn_age_lsa
                                    
                                    	If true, Do Not Age this LSA
                                    	**type**\:  bool
                                    
                                    .. attribute:: ls_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: lsa_age
                                    
                                    	LSA's Age (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsa_area_id
                                    
                                    	Area ID in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: lsid
                                    
                                    	LS ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: nsf
                                    
                                    	If true,  LSA received from neighbor during NSF
                                    	**type**\:  bool
                                    
                                    .. attribute:: sequence_number
                                    
                                    	Current Sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaHeader, self).__init__()

                                        self.yang_name = "lsa-header"
                                        self.yang_parent_name = "lsa"

                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                        self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                        self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                        self.lsid = YLeaf(YType.str, "lsid")

                                        self.nsf = YLeaf(YType.boolean, "nsf")

                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("advertising_router",
                                                        "checksum",
                                                        "dn_age_lsa",
                                                        "ls_type",
                                                        "lsa_age",
                                                        "lsa_area_id",
                                                        "lsid",
                                                        "nsf",
                                                        "sequence_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaHeader, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaHeader, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.advertising_router.is_set or
                                            self.checksum.is_set or
                                            self.dn_age_lsa.is_set or
                                            self.ls_type.is_set or
                                            self.lsa_age.is_set or
                                            self.lsa_area_id.is_set or
                                            self.lsid.is_set or
                                            self.nsf.is_set or
                                            self.sequence_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.advertising_router.yfilter != YFilter.not_set or
                                            self.checksum.yfilter != YFilter.not_set or
                                            self.dn_age_lsa.yfilter != YFilter.not_set or
                                            self.ls_type.yfilter != YFilter.not_set or
                                            self.lsa_age.yfilter != YFilter.not_set or
                                            self.lsa_area_id.yfilter != YFilter.not_set or
                                            self.lsid.yfilter != YFilter.not_set or
                                            self.nsf.yfilter != YFilter.not_set or
                                            self.sequence_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lsa-header" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                        if (self.checksum.is_set or self.checksum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.checksum.get_name_leafdata())
                                        if (self.dn_age_lsa.is_set or self.dn_age_lsa.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dn_age_lsa.get_name_leafdata())
                                        if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ls_type.get_name_leafdata())
                                        if (self.lsa_age.is_set or self.lsa_age.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_age.get_name_leafdata())
                                        if (self.lsa_area_id.is_set or self.lsa_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_area_id.get_name_leafdata())
                                        if (self.lsid.is_set or self.lsid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsid.get_name_leafdata())
                                        if (self.nsf.is_set or self.nsf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsf.get_name_leafdata())
                                        if (self.sequence_number.is_set or self.sequence_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "advertising-router" or name == "checksum" or name == "dn-age-lsa" or name == "ls-type" or name == "lsa-age" or name == "lsa-area-id" or name == "lsid" or name == "nsf" or name == "sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "advertising-router"):
                                            self.advertising_router = value
                                            self.advertising_router.value_namespace = name_space
                                            self.advertising_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "checksum"):
                                            self.checksum = value
                                            self.checksum.value_namespace = name_space
                                            self.checksum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dn-age-lsa"):
                                            self.dn_age_lsa = value
                                            self.dn_age_lsa.value_namespace = name_space
                                            self.dn_age_lsa.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ls-type"):
                                            self.ls_type = value
                                            self.ls_type.value_namespace = name_space
                                            self.ls_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-age"):
                                            self.lsa_age = value
                                            self.lsa_age.value_namespace = name_space
                                            self.lsa_age.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-area-id"):
                                            self.lsa_area_id = value
                                            self.lsa_area_id.value_namespace = name_space
                                            self.lsa_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsid"):
                                            self.lsid = value
                                            self.lsid.value_namespace = name_space
                                            self.lsid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsf"):
                                            self.nsf = value
                                            self.nsf.value_namespace = name_space
                                            self.nsf.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number"):
                                            self.sequence_number = value
                                            self.sequence_number.value_namespace = name_space
                                            self.sequence_number.value_namespace_prefix = name_space_prefix


                                class LsaDetailData(Entity):
                                    """
                                    Detailed LSA Information
                                    
                                    .. attribute:: advertising_router_reachable
                                    
                                    	If true, Advertising Router is reachable
                                    	**type**\:  bool
                                    
                                    .. attribute:: ase_origin
                                    
                                    	External Origin
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: demand_circuit
                                    
                                    	If true, capable of demand circuit as indicated by LSA's option field
                                    	**type**\:  bool
                                    
                                    .. attribute:: dn_bit
                                    
                                    	if true, DN bit set on the summary LSA indicated by LSA's option field
                                    	**type**\:  bool
                                    
                                    .. attribute:: in_sync
                                    
                                    	Not In Sync With Active
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: length
                                    
                                    	Length of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsa_flood_required_post_fail_over
                                    
                                    	LSA flood required after FO
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_last_updated_time
                                    
                                    	Time LSA was last updated
                                    	**type**\:   :py:class:`LsaLastUpdatedTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime>`
                                    
                                    .. attribute:: lsa_prefix_priority
                                    
                                    	Current LSA prefix priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: lsa_rate_limit_due_time
                                    
                                    	Due time for rate\-limit timer (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_throttle_timer
                                    
                                    	LSA throttle timer table information
                                    	**type**\:   :py:class:`LsaThrottleTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer>`
                                    
                                    .. attribute:: lsadb_base_clock
                                    
                                    	Clock stamp since boot
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: lsadb_base_time_stamp
                                    
                                    	Current time stamp
                                    	**type**\:   :py:class:`LsadbBaseTimeStamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp>`
                                    
                                    .. attribute:: new_lsa_prefix_priority
                                    
                                    	New LSA prefix priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: not_delete
                                    
                                    	Reason why LSA is not deleted
                                    	**type**\:   :py:class:`NotDelete <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.NotDelete>`
                                    
                                    .. attribute:: nssa_translation
                                    
                                    	If true,  capable of type 7 to 5 translation indicated by LSA's option field
                                    	**type**\:  bool
                                    
                                    .. attribute:: routing_bit
                                    
                                    	If true, Routing Bit set on the LSA
                                    	**type**\:  bool
                                    
                                    .. attribute:: sum_origin
                                    
                                    	Summary Origin
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: tos_capable
                                    
                                    	If true, type of service capable indicated by LSA's option field
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData, self).__init__()

                                        self.yang_name = "lsa-detail-data"
                                        self.yang_parent_name = "lsa"

                                        self.advertising_router_reachable = YLeaf(YType.boolean, "advertising-router-reachable")

                                        self.ase_origin = YLeaf(YType.uint16, "ase-origin")

                                        self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                        self.dn_bit = YLeaf(YType.boolean, "dn-bit")

                                        self.in_sync = YLeaf(YType.uint8, "in-sync")

                                        self.length = YLeaf(YType.uint16, "length")

                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                        self.lsa_prefix_priority = YLeaf(YType.uint8, "lsa-prefix-priority")

                                        self.lsa_rate_limit_due_time = YLeaf(YType.uint32, "lsa-rate-limit-due-time")

                                        self.lsadb_base_clock = YLeaf(YType.uint64, "lsadb-base-clock")

                                        self.new_lsa_prefix_priority = YLeaf(YType.uint8, "new-lsa-prefix-priority")

                                        self.nssa_translation = YLeaf(YType.boolean, "nssa-translation")

                                        self.routing_bit = YLeaf(YType.boolean, "routing-bit")

                                        self.sum_origin = YLeaf(YType.uint16, "sum-origin")

                                        self.tos_capable = YLeaf(YType.boolean, "tos-capable")

                                        self.lsa_last_updated_time = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime()
                                        self.lsa_last_updated_time.parent = self
                                        self._children_name_map["lsa_last_updated_time"] = "lsa-last-updated-time"
                                        self._children_yang_names.add("lsa-last-updated-time")

                                        self.lsa_throttle_timer = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer()
                                        self.lsa_throttle_timer.parent = self
                                        self._children_name_map["lsa_throttle_timer"] = "lsa-throttle-timer"
                                        self._children_yang_names.add("lsa-throttle-timer")

                                        self.lsadb_base_time_stamp = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp()
                                        self.lsadb_base_time_stamp.parent = self
                                        self._children_name_map["lsadb_base_time_stamp"] = "lsadb-base-time-stamp"
                                        self._children_yang_names.add("lsadb-base-time-stamp")

                                        self.not_delete = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.NotDelete()
                                        self.not_delete.parent = self
                                        self._children_name_map["not_delete"] = "not-delete"
                                        self._children_yang_names.add("not-delete")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("advertising_router_reachable",
                                                        "ase_origin",
                                                        "demand_circuit",
                                                        "dn_bit",
                                                        "in_sync",
                                                        "length",
                                                        "lsa_flood_required_post_fail_over",
                                                        "lsa_prefix_priority",
                                                        "lsa_rate_limit_due_time",
                                                        "lsadb_base_clock",
                                                        "new_lsa_prefix_priority",
                                                        "nssa_translation",
                                                        "routing_bit",
                                                        "sum_origin",
                                                        "tos_capable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData, self).__setattr__(name, value)


                                    class LsaThrottleTimer(Entity):
                                        """
                                        LSA throttle timer table information
                                        
                                        .. attribute:: last_inst_minute_table_index
                                        
                                        	Last Minute table index processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_inst_second_table_index
                                        
                                        	Last Second table index processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timer_location
                                        
                                        	Timer table
                                        	**type**\:   :py:class:`TimerTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.TimerTable>`
                                        
                                        .. attribute:: timer_type
                                        
                                        	Timer type
                                        	**type**\:   :py:class:`Timer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Timer>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__init__()

                                            self.yang_name = "lsa-throttle-timer"
                                            self.yang_parent_name = "lsa-detail-data"

                                            self.last_inst_minute_table_index = YLeaf(YType.uint8, "last-inst-minute-table-index")

                                            self.last_inst_second_table_index = YLeaf(YType.uint8, "last-inst-second-table-index")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")

                                            self.timer_location = YLeaf(YType.enumeration, "timer-location")

                                            self.timer_type = YLeaf(YType.enumeration, "timer-type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("last_inst_minute_table_index",
                                                            "last_inst_second_table_index",
                                                            "minute_table_index",
                                                            "second_table_index",
                                                            "timer_location",
                                                            "timer_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.last_inst_minute_table_index.is_set or
                                                self.last_inst_second_table_index.is_set or
                                                self.minute_table_index.is_set or
                                                self.second_table_index.is_set or
                                                self.timer_location.is_set or
                                                self.timer_type.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.last_inst_minute_table_index.yfilter != YFilter.not_set or
                                                self.last_inst_second_table_index.yfilter != YFilter.not_set or
                                                self.minute_table_index.yfilter != YFilter.not_set or
                                                self.second_table_index.yfilter != YFilter.not_set or
                                                self.timer_location.yfilter != YFilter.not_set or
                                                self.timer_type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "lsa-throttle-timer" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.last_inst_minute_table_index.is_set or self.last_inst_minute_table_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.last_inst_minute_table_index.get_name_leafdata())
                                            if (self.last_inst_second_table_index.is_set or self.last_inst_second_table_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.last_inst_second_table_index.get_name_leafdata())
                                            if (self.minute_table_index.is_set or self.minute_table_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minute_table_index.get_name_leafdata())
                                            if (self.second_table_index.is_set or self.second_table_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second_table_index.get_name_leafdata())
                                            if (self.timer_location.is_set or self.timer_location.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timer_location.get_name_leafdata())
                                            if (self.timer_type.is_set or self.timer_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timer_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "last-inst-minute-table-index" or name == "last-inst-second-table-index" or name == "minute-table-index" or name == "second-table-index" or name == "timer-location" or name == "timer-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "last-inst-minute-table-index"):
                                                self.last_inst_minute_table_index = value
                                                self.last_inst_minute_table_index.value_namespace = name_space
                                                self.last_inst_minute_table_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "last-inst-second-table-index"):
                                                self.last_inst_second_table_index = value
                                                self.last_inst_second_table_index.value_namespace = name_space
                                                self.last_inst_second_table_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minute-table-index"):
                                                self.minute_table_index = value
                                                self.minute_table_index.value_namespace = name_space
                                                self.minute_table_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second-table-index"):
                                                self.second_table_index = value
                                                self.second_table_index.value_namespace = name_space
                                                self.second_table_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timer-location"):
                                                self.timer_location = value
                                                self.timer_location.value_namespace = name_space
                                                self.timer_location.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timer-type"):
                                                self.timer_type = value
                                                self.timer_type.value_namespace = name_space
                                                self.timer_type.value_namespace_prefix = name_space_prefix


                                    class LsaLastUpdatedTime(Entity):
                                        """
                                        Time LSA was last updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__init__()

                                            self.yang_name = "lsa-last-updated-time"
                                            self.yang_parent_name = "lsa-detail-data"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "lsa-last-updated-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix


                                    class LsadbBaseTimeStamp(Entity):
                                        """
                                        Current time stamp
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__init__()

                                            self.yang_name = "lsadb-base-time-stamp"
                                            self.yang_parent_name = "lsa-detail-data"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "lsadb-base-time-stamp" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix


                                    class NotDelete(Entity):
                                        """
                                        Reason why LSA is not deleted
                                        
                                        .. attribute:: acknowledgement
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_age
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table
                                        	**type**\:  bool
                                        
                                        .. attribute:: sum_orig_pending
                                        
                                        	If true, the reason not to delete this LSA is because it is pending summary LSA originating
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.NotDelete, self).__init__()

                                            self.yang_name = "not-delete"
                                            self.yang_parent_name = "lsa-detail-data"

                                            self.acknowledgement = YLeaf(YType.boolean, "acknowledgement")

                                            self.flood_pending = YLeaf(YType.boolean, "flood-pending")

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.maximum_age = YLeaf(YType.boolean, "maximum-age")

                                            self.neighbor_exchange = YLeaf(YType.boolean, "neighbor-exchange")

                                            self.no_delete = YLeaf(YType.boolean, "no-delete")

                                            self.nsr_ack_pending = YLeaf(YType.boolean, "nsr-ack-pending")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.partial_spf = YLeaf(YType.boolean, "partial-spf")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.routing_table = YLeaf(YType.boolean, "routing-table")

                                            self.sum_orig_pending = YLeaf(YType.boolean, "sum-orig-pending")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("acknowledgement",
                                                            "flood_pending",
                                                            "free_time",
                                                            "maximum_age",
                                                            "neighbor_exchange",
                                                            "no_delete",
                                                            "nsr_ack_pending",
                                                            "nsr_flood_required",
                                                            "partial_spf",
                                                            "rate_limit",
                                                            "routing_table",
                                                            "sum_orig_pending") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.NotDelete, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.NotDelete, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.acknowledgement.is_set or
                                                self.flood_pending.is_set or
                                                self.free_time.is_set or
                                                self.maximum_age.is_set or
                                                self.neighbor_exchange.is_set or
                                                self.no_delete.is_set or
                                                self.nsr_ack_pending.is_set or
                                                self.nsr_flood_required.is_set or
                                                self.partial_spf.is_set or
                                                self.rate_limit.is_set or
                                                self.routing_table.is_set or
                                                self.sum_orig_pending.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.acknowledgement.yfilter != YFilter.not_set or
                                                self.flood_pending.yfilter != YFilter.not_set or
                                                self.free_time.yfilter != YFilter.not_set or
                                                self.maximum_age.yfilter != YFilter.not_set or
                                                self.neighbor_exchange.yfilter != YFilter.not_set or
                                                self.no_delete.yfilter != YFilter.not_set or
                                                self.nsr_ack_pending.yfilter != YFilter.not_set or
                                                self.nsr_flood_required.yfilter != YFilter.not_set or
                                                self.partial_spf.yfilter != YFilter.not_set or
                                                self.rate_limit.yfilter != YFilter.not_set or
                                                self.routing_table.yfilter != YFilter.not_set or
                                                self.sum_orig_pending.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "not-delete" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.acknowledgement.is_set or self.acknowledgement.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.acknowledgement.get_name_leafdata())
                                            if (self.flood_pending.is_set or self.flood_pending.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_pending.get_name_leafdata())
                                            if (self.free_time.is_set or self.free_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.free_time.get_name_leafdata())
                                            if (self.maximum_age.is_set or self.maximum_age.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_age.get_name_leafdata())
                                            if (self.neighbor_exchange.is_set or self.neighbor_exchange.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_exchange.get_name_leafdata())
                                            if (self.no_delete.is_set or self.no_delete.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.no_delete.get_name_leafdata())
                                            if (self.nsr_ack_pending.is_set or self.nsr_ack_pending.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nsr_ack_pending.get_name_leafdata())
                                            if (self.nsr_flood_required.is_set or self.nsr_flood_required.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nsr_flood_required.get_name_leafdata())
                                            if (self.partial_spf.is_set or self.partial_spf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.partial_spf.get_name_leafdata())
                                            if (self.rate_limit.is_set or self.rate_limit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rate_limit.get_name_leafdata())
                                            if (self.routing_table.is_set or self.routing_table.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.routing_table.get_name_leafdata())
                                            if (self.sum_orig_pending.is_set or self.sum_orig_pending.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sum_orig_pending.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "acknowledgement" or name == "flood-pending" or name == "free-time" or name == "maximum-age" or name == "neighbor-exchange" or name == "no-delete" or name == "nsr-ack-pending" or name == "nsr-flood-required" or name == "partial-spf" or name == "rate-limit" or name == "routing-table" or name == "sum-orig-pending"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "acknowledgement"):
                                                self.acknowledgement = value
                                                self.acknowledgement.value_namespace = name_space
                                                self.acknowledgement.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-pending"):
                                                self.flood_pending = value
                                                self.flood_pending.value_namespace = name_space
                                                self.flood_pending.value_namespace_prefix = name_space_prefix
                                            if(value_path == "free-time"):
                                                self.free_time = value
                                                self.free_time.value_namespace = name_space
                                                self.free_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-age"):
                                                self.maximum_age = value
                                                self.maximum_age.value_namespace = name_space
                                                self.maximum_age.value_namespace_prefix = name_space_prefix
                                            if(value_path == "neighbor-exchange"):
                                                self.neighbor_exchange = value
                                                self.neighbor_exchange.value_namespace = name_space
                                                self.neighbor_exchange.value_namespace_prefix = name_space_prefix
                                            if(value_path == "no-delete"):
                                                self.no_delete = value
                                                self.no_delete.value_namespace = name_space
                                                self.no_delete.value_namespace_prefix = name_space_prefix
                                            if(value_path == "nsr-ack-pending"):
                                                self.nsr_ack_pending = value
                                                self.nsr_ack_pending.value_namespace = name_space
                                                self.nsr_ack_pending.value_namespace_prefix = name_space_prefix
                                            if(value_path == "nsr-flood-required"):
                                                self.nsr_flood_required = value
                                                self.nsr_flood_required.value_namespace = name_space
                                                self.nsr_flood_required.value_namespace_prefix = name_space_prefix
                                            if(value_path == "partial-spf"):
                                                self.partial_spf = value
                                                self.partial_spf.value_namespace = name_space
                                                self.partial_spf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rate-limit"):
                                                self.rate_limit = value
                                                self.rate_limit.value_namespace = name_space
                                                self.rate_limit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "routing-table"):
                                                self.routing_table = value
                                                self.routing_table.value_namespace = name_space
                                                self.routing_table.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sum-orig-pending"):
                                                self.sum_orig_pending = value
                                                self.sum_orig_pending.value_namespace = name_space
                                                self.sum_orig_pending.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.advertising_router_reachable.is_set or
                                            self.ase_origin.is_set or
                                            self.demand_circuit.is_set or
                                            self.dn_bit.is_set or
                                            self.in_sync.is_set or
                                            self.length.is_set or
                                            self.lsa_flood_required_post_fail_over.is_set or
                                            self.lsa_prefix_priority.is_set or
                                            self.lsa_rate_limit_due_time.is_set or
                                            self.lsadb_base_clock.is_set or
                                            self.new_lsa_prefix_priority.is_set or
                                            self.nssa_translation.is_set or
                                            self.routing_bit.is_set or
                                            self.sum_origin.is_set or
                                            self.tos_capable.is_set or
                                            (self.lsa_last_updated_time is not None and self.lsa_last_updated_time.has_data()) or
                                            (self.lsa_throttle_timer is not None and self.lsa_throttle_timer.has_data()) or
                                            (self.lsadb_base_time_stamp is not None and self.lsadb_base_time_stamp.has_data()) or
                                            (self.not_delete is not None and self.not_delete.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.advertising_router_reachable.yfilter != YFilter.not_set or
                                            self.ase_origin.yfilter != YFilter.not_set or
                                            self.demand_circuit.yfilter != YFilter.not_set or
                                            self.dn_bit.yfilter != YFilter.not_set or
                                            self.in_sync.yfilter != YFilter.not_set or
                                            self.length.yfilter != YFilter.not_set or
                                            self.lsa_flood_required_post_fail_over.yfilter != YFilter.not_set or
                                            self.lsa_prefix_priority.yfilter != YFilter.not_set or
                                            self.lsa_rate_limit_due_time.yfilter != YFilter.not_set or
                                            self.lsadb_base_clock.yfilter != YFilter.not_set or
                                            self.new_lsa_prefix_priority.yfilter != YFilter.not_set or
                                            self.nssa_translation.yfilter != YFilter.not_set or
                                            self.routing_bit.yfilter != YFilter.not_set or
                                            self.sum_origin.yfilter != YFilter.not_set or
                                            self.tos_capable.yfilter != YFilter.not_set or
                                            (self.lsa_last_updated_time is not None and self.lsa_last_updated_time.has_operation()) or
                                            (self.lsa_throttle_timer is not None and self.lsa_throttle_timer.has_operation()) or
                                            (self.lsadb_base_time_stamp is not None and self.lsadb_base_time_stamp.has_operation()) or
                                            (self.not_delete is not None and self.not_delete.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lsa-detail-data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.advertising_router_reachable.is_set or self.advertising_router_reachable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.advertising_router_reachable.get_name_leafdata())
                                        if (self.ase_origin.is_set or self.ase_origin.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ase_origin.get_name_leafdata())
                                        if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                                        if (self.dn_bit.is_set or self.dn_bit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dn_bit.get_name_leafdata())
                                        if (self.in_sync.is_set or self.in_sync.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.in_sync.get_name_leafdata())
                                        if (self.length.is_set or self.length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.length.get_name_leafdata())
                                        if (self.lsa_flood_required_post_fail_over.is_set or self.lsa_flood_required_post_fail_over.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_flood_required_post_fail_over.get_name_leafdata())
                                        if (self.lsa_prefix_priority.is_set or self.lsa_prefix_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_prefix_priority.get_name_leafdata())
                                        if (self.lsa_rate_limit_due_time.is_set or self.lsa_rate_limit_due_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_rate_limit_due_time.get_name_leafdata())
                                        if (self.lsadb_base_clock.is_set or self.lsadb_base_clock.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsadb_base_clock.get_name_leafdata())
                                        if (self.new_lsa_prefix_priority.is_set or self.new_lsa_prefix_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.new_lsa_prefix_priority.get_name_leafdata())
                                        if (self.nssa_translation.is_set or self.nssa_translation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nssa_translation.get_name_leafdata())
                                        if (self.routing_bit.is_set or self.routing_bit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.routing_bit.get_name_leafdata())
                                        if (self.sum_origin.is_set or self.sum_origin.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sum_origin.get_name_leafdata())
                                        if (self.tos_capable.is_set or self.tos_capable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_capable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "lsa-last-updated-time"):
                                            if (self.lsa_last_updated_time is None):
                                                self.lsa_last_updated_time = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime()
                                                self.lsa_last_updated_time.parent = self
                                                self._children_name_map["lsa_last_updated_time"] = "lsa-last-updated-time"
                                            return self.lsa_last_updated_time

                                        if (child_yang_name == "lsa-throttle-timer"):
                                            if (self.lsa_throttle_timer is None):
                                                self.lsa_throttle_timer = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer()
                                                self.lsa_throttle_timer.parent = self
                                                self._children_name_map["lsa_throttle_timer"] = "lsa-throttle-timer"
                                            return self.lsa_throttle_timer

                                        if (child_yang_name == "lsadb-base-time-stamp"):
                                            if (self.lsadb_base_time_stamp is None):
                                                self.lsadb_base_time_stamp = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp()
                                                self.lsadb_base_time_stamp.parent = self
                                                self._children_name_map["lsadb_base_time_stamp"] = "lsadb-base-time-stamp"
                                            return self.lsadb_base_time_stamp

                                        if (child_yang_name == "not-delete"):
                                            if (self.not_delete is None):
                                                self.not_delete = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.NotDelete()
                                                self.not_delete.parent = self
                                                self._children_name_map["not_delete"] = "not-delete"
                                            return self.not_delete

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lsa-last-updated-time" or name == "lsa-throttle-timer" or name == "lsadb-base-time-stamp" or name == "not-delete" or name == "advertising-router-reachable" or name == "ase-origin" or name == "demand-circuit" or name == "dn-bit" or name == "in-sync" or name == "length" or name == "lsa-flood-required-post-fail-over" or name == "lsa-prefix-priority" or name == "lsa-rate-limit-due-time" or name == "lsadb-base-clock" or name == "new-lsa-prefix-priority" or name == "nssa-translation" or name == "routing-bit" or name == "sum-origin" or name == "tos-capable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "advertising-router-reachable"):
                                            self.advertising_router_reachable = value
                                            self.advertising_router_reachable.value_namespace = name_space
                                            self.advertising_router_reachable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ase-origin"):
                                            self.ase_origin = value
                                            self.ase_origin.value_namespace = name_space
                                            self.ase_origin.value_namespace_prefix = name_space_prefix
                                        if(value_path == "demand-circuit"):
                                            self.demand_circuit = value
                                            self.demand_circuit.value_namespace = name_space
                                            self.demand_circuit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dn-bit"):
                                            self.dn_bit = value
                                            self.dn_bit.value_namespace = name_space
                                            self.dn_bit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "in-sync"):
                                            self.in_sync = value
                                            self.in_sync.value_namespace = name_space
                                            self.in_sync.value_namespace_prefix = name_space_prefix
                                        if(value_path == "length"):
                                            self.length = value
                                            self.length.value_namespace = name_space
                                            self.length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-flood-required-post-fail-over"):
                                            self.lsa_flood_required_post_fail_over = value
                                            self.lsa_flood_required_post_fail_over.value_namespace = name_space
                                            self.lsa_flood_required_post_fail_over.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-prefix-priority"):
                                            self.lsa_prefix_priority = value
                                            self.lsa_prefix_priority.value_namespace = name_space
                                            self.lsa_prefix_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-rate-limit-due-time"):
                                            self.lsa_rate_limit_due_time = value
                                            self.lsa_rate_limit_due_time.value_namespace = name_space
                                            self.lsa_rate_limit_due_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsadb-base-clock"):
                                            self.lsadb_base_clock = value
                                            self.lsadb_base_clock.value_namespace = name_space
                                            self.lsadb_base_clock.value_namespace_prefix = name_space_prefix
                                        if(value_path == "new-lsa-prefix-priority"):
                                            self.new_lsa_prefix_priority = value
                                            self.new_lsa_prefix_priority.value_namespace = name_space
                                            self.new_lsa_prefix_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nssa-translation"):
                                            self.nssa_translation = value
                                            self.nssa_translation.value_namespace = name_space
                                            self.nssa_translation.value_namespace_prefix = name_space_prefix
                                        if(value_path == "routing-bit"):
                                            self.routing_bit = value
                                            self.routing_bit.value_namespace = name_space
                                            self.routing_bit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sum-origin"):
                                            self.sum_origin = value
                                            self.sum_origin.value_namespace = name_space
                                            self.sum_origin.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-capable"):
                                            self.tos_capable = value
                                            self.tos_capable.value_namespace = name_space
                                            self.tos_capable.value_namespace_prefix = name_space_prefix


                                class LsaInternalData(Entity):
                                    """
                                    Information pertaining to a specific LSA type
                                    
                                    .. attribute:: external_lsa_type
                                    
                                    	External LSA
                                    	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType>`
                                    
                                    .. attribute:: internal_lsa_type
                                    
                                    	InternalLSAType
                                    	**type**\:   :py:class:`OspfInternalLsaTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInternalLsaTypes>`
                                    
                                    .. attribute:: network_lsa_type
                                    
                                    	Network LSA
                                    	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType>`
                                    
                                    .. attribute:: opaque_el_lsa_type
                                    
                                    	Extended Link LSA type
                                    	**type**\:   :py:class:`OpaqueElLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType>`
                                    
                                    .. attribute:: opaque_ep_lsa_type
                                    
                                    	Extende Prefix LSA type
                                    	**type**\:   :py:class:`OpaqueEpLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType>`
                                    
                                    .. attribute:: opaque_grace_lsa
                                    
                                    	Opaque\-link, opaque type 3 Grace LSA
                                    	**type**\:   :py:class:`OpaqueGraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa>`
                                    
                                    .. attribute:: opaque_link_lsa_type
                                    
                                    	Opaque\-Link LSA
                                    	**type**\:   :py:class:`OpaqueLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType>`
                                    
                                    .. attribute:: opaque_mpls_te_lsa_type
                                    
                                    	Opaque\-Area, opaque type 1 LSA
                                    	**type**\:   :py:class:`OpaqueMplsTeLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType>`
                                    
                                    .. attribute:: opaque_router_info_lsa_type
                                    
                                    	Opaque Router Information LSA
                                    	**type**\:   :py:class:`OpaqueRouterInfoLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType>`
                                    
                                    .. attribute:: router_lsa_type
                                    
                                    	Router LSA
                                    	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType>`
                                    
                                    .. attribute:: summary_lsa_type
                                    
                                    	Summary LSA
                                    	**type**\:   :py:class:`SummaryLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData, self).__init__()

                                        self.yang_name = "lsa-internal-data"
                                        self.yang_parent_name = "lsa"

                                        self.internal_lsa_type = YLeaf(YType.enumeration, "internal-lsa-type")

                                        self.external_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType()
                                        self.external_lsa_type.parent = self
                                        self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                        self._children_yang_names.add("external-lsa-type")

                                        self.network_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType()
                                        self.network_lsa_type.parent = self
                                        self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                        self._children_yang_names.add("network-lsa-type")

                                        self.opaque_el_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType()
                                        self.opaque_el_lsa_type.parent = self
                                        self._children_name_map["opaque_el_lsa_type"] = "opaque-el-lsa-type"
                                        self._children_yang_names.add("opaque-el-lsa-type")

                                        self.opaque_ep_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType()
                                        self.opaque_ep_lsa_type.parent = self
                                        self._children_name_map["opaque_ep_lsa_type"] = "opaque-ep-lsa-type"
                                        self._children_yang_names.add("opaque-ep-lsa-type")

                                        self.opaque_grace_lsa = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa()
                                        self.opaque_grace_lsa.parent = self
                                        self._children_name_map["opaque_grace_lsa"] = "opaque-grace-lsa"
                                        self._children_yang_names.add("opaque-grace-lsa")

                                        self.opaque_link_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType()
                                        self.opaque_link_lsa_type.parent = self
                                        self._children_name_map["opaque_link_lsa_type"] = "opaque-link-lsa-type"
                                        self._children_yang_names.add("opaque-link-lsa-type")

                                        self.opaque_mpls_te_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType()
                                        self.opaque_mpls_te_lsa_type.parent = self
                                        self._children_name_map["opaque_mpls_te_lsa_type"] = "opaque-mpls-te-lsa-type"
                                        self._children_yang_names.add("opaque-mpls-te-lsa-type")

                                        self.opaque_router_info_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType()
                                        self.opaque_router_info_lsa_type.parent = self
                                        self._children_name_map["opaque_router_info_lsa_type"] = "opaque-router-info-lsa-type"
                                        self._children_yang_names.add("opaque-router-info-lsa-type")

                                        self.router_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType()
                                        self.router_lsa_type.parent = self
                                        self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                        self._children_yang_names.add("router-lsa-type")

                                        self.summary_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType()
                                        self.summary_lsa_type.parent = self
                                        self._children_name_map["summary_lsa_type"] = "summary-lsa-type"
                                        self._children_yang_names.add("summary-lsa-type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_lsa_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData, self).__setattr__(name, value)


                                    class RouterLsaType(Entity):
                                        """
                                        Router LSA
                                        
                                        .. attribute:: internal_link
                                        
                                        	List of links for internal LSA
                                        	**type**\: list of    :py:class:`InternalLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink>`
                                        
                                        .. attribute:: internal_lsa
                                        
                                        	If true, internal LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: link
                                        
                                        	List of links in this LSA
                                        	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link>`
                                        
                                        .. attribute:: router_abr
                                        
                                        	If True, router is an Area Border Router
                                        	**type**\:  bool
                                        
                                        .. attribute:: router_asbr
                                        
                                        	If True, router is an Autonomous system Border Router
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__init__()

                                            self.yang_name = "router-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"

                                            self.internal_lsa = YLeaf(YType.boolean, "internal-lsa")

                                            self.router_abr = YLeaf(YType.boolean, "router-abr")

                                            self.router_asbr = YLeaf(YType.boolean, "router-asbr")

                                            self.internal_link = YList(self)
                                            self.link = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_lsa",
                                                            "router_abr",
                                                            "router_asbr") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__setattr__(name, value)


                                        class Link(Entity):
                                            """
                                            List of links in this LSA
                                            
                                            .. attribute:: link_data
                                            
                                            	Link Data
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: link_id
                                            
                                            	Link ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: link_metric
                                            
                                            	Cost for using this link
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: link_tos
                                            
                                            	List of type of service metrics
                                            	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos>`
                                            
                                            .. attribute:: link_type
                                            
                                            	Type of link
                                            	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__init__()

                                                self.yang_name = "link"
                                                self.yang_parent_name = "router-lsa-type"

                                                self.link_data = YLeaf(YType.str, "link-data")

                                                self.link_id = YLeaf(YType.str, "link-id")

                                                self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                self.link_type = YLeaf(YType.enumeration, "link-type")

                                                self.link_tos = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("link_data",
                                                                "link_id",
                                                                "link_metric",
                                                                "link_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__setattr__(name, value)


                                            class LinkTos(Entity):
                                                """
                                                List of type of service metrics
                                                
                                                .. attribute:: router_tos
                                                
                                                	Type of Service
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service specific metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__init__()

                                                    self.yang_name = "link-tos"
                                                    self.yang_parent_name = "link"

                                                    self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                    self.tos_cost = YLeaf(YType.uint16, "tos-cost")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("router_tos",
                                                                    "tos_cost") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.router_tos.is_set or
                                                        self.tos_cost.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.router_tos.yfilter != YFilter.not_set or
                                                        self.tos_cost.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "link-tos" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.router_tos.is_set or self.router_tos.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.router_tos.get_name_leafdata())
                                                    if (self.tos_cost.is_set or self.tos_cost.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tos_cost.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "router-tos" or name == "tos-cost"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "router-tos"):
                                                        self.router_tos = value
                                                        self.router_tos.value_namespace = name_space
                                                        self.router_tos.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tos-cost"):
                                                        self.tos_cost = value
                                                        self.tos_cost.value_namespace = name_space
                                                        self.tos_cost.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.link_tos:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.link_data.is_set or
                                                    self.link_id.is_set or
                                                    self.link_metric.is_set or
                                                    self.link_type.is_set)

                                            def has_operation(self):
                                                for c in self.link_tos:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.link_data.yfilter != YFilter.not_set or
                                                    self.link_id.yfilter != YFilter.not_set or
                                                    self.link_metric.yfilter != YFilter.not_set or
                                                    self.link_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "link" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.link_data.is_set or self.link_data.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_data.get_name_leafdata())
                                                if (self.link_id.is_set or self.link_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_id.get_name_leafdata())
                                                if (self.link_metric.is_set or self.link_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_metric.get_name_leafdata())
                                                if (self.link_type.is_set or self.link_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "link-tos"):
                                                    for c in self.link_tos:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.link_tos.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "link-tos" or name == "link-data" or name == "link-id" or name == "link-metric" or name == "link-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "link-data"):
                                                    self.link_data = value
                                                    self.link_data.value_namespace = name_space
                                                    self.link_data.value_namespace_prefix = name_space_prefix
                                                if(value_path == "link-id"):
                                                    self.link_id = value
                                                    self.link_id.value_namespace = name_space
                                                    self.link_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "link-metric"):
                                                    self.link_metric = value
                                                    self.link_metric.value_namespace = name_space
                                                    self.link_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "link-type"):
                                                    self.link_type = value
                                                    self.link_type.value_namespace = name_space
                                                    self.link_type.value_namespace_prefix = name_space_prefix


                                        class InternalLink(Entity):
                                            """
                                            List of links for internal LSA
                                            
                                            .. attribute:: link_data
                                            
                                            	Link Data
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: link_id
                                            
                                            	Link ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: link_metric
                                            
                                            	Cost for using this link
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: link_tos
                                            
                                            	List of type of service metrics
                                            	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos>`
                                            
                                            .. attribute:: link_type
                                            
                                            	Type of link
                                            	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__init__()

                                                self.yang_name = "internal-link"
                                                self.yang_parent_name = "router-lsa-type"

                                                self.link_data = YLeaf(YType.str, "link-data")

                                                self.link_id = YLeaf(YType.str, "link-id")

                                                self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                self.link_type = YLeaf(YType.enumeration, "link-type")

                                                self.link_tos = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("link_data",
                                                                "link_id",
                                                                "link_metric",
                                                                "link_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__setattr__(name, value)


                                            class LinkTos(Entity):
                                                """
                                                List of type of service metrics
                                                
                                                .. attribute:: router_tos
                                                
                                                	Type of Service
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service specific metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__init__()

                                                    self.yang_name = "link-tos"
                                                    self.yang_parent_name = "internal-link"

                                                    self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                    self.tos_cost = YLeaf(YType.uint16, "tos-cost")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("router_tos",
                                                                    "tos_cost") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.router_tos.is_set or
                                                        self.tos_cost.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.router_tos.yfilter != YFilter.not_set or
                                                        self.tos_cost.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "link-tos" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.router_tos.is_set or self.router_tos.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.router_tos.get_name_leafdata())
                                                    if (self.tos_cost.is_set or self.tos_cost.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tos_cost.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "router-tos" or name == "tos-cost"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "router-tos"):
                                                        self.router_tos = value
                                                        self.router_tos.value_namespace = name_space
                                                        self.router_tos.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tos-cost"):
                                                        self.tos_cost = value
                                                        self.tos_cost.value_namespace = name_space
                                                        self.tos_cost.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.link_tos:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.link_data.is_set or
                                                    self.link_id.is_set or
                                                    self.link_metric.is_set or
                                                    self.link_type.is_set)

                                            def has_operation(self):
                                                for c in self.link_tos:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.link_data.yfilter != YFilter.not_set or
                                                    self.link_id.yfilter != YFilter.not_set or
                                                    self.link_metric.yfilter != YFilter.not_set or
                                                    self.link_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "internal-link" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.link_data.is_set or self.link_data.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_data.get_name_leafdata())
                                                if (self.link_id.is_set or self.link_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_id.get_name_leafdata())
                                                if (self.link_metric.is_set or self.link_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_metric.get_name_leafdata())
                                                if (self.link_type.is_set or self.link_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.link_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "link-tos"):
                                                    for c in self.link_tos:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.link_tos.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "link-tos" or name == "link-data" or name == "link-id" or name == "link-metric" or name == "link-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "link-data"):
                                                    self.link_data = value
                                                    self.link_data.value_namespace = name_space
                                                    self.link_data.value_namespace_prefix = name_space_prefix
                                                if(value_path == "link-id"):
                                                    self.link_id = value
                                                    self.link_id.value_namespace = name_space
                                                    self.link_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "link-metric"):
                                                    self.link_metric = value
                                                    self.link_metric.value_namespace = name_space
                                                    self.link_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "link-type"):
                                                    self.link_type = value
                                                    self.link_type.value_namespace = name_space
                                                    self.link_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.internal_link:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.link:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.internal_lsa.is_set or
                                                self.router_abr.is_set or
                                                self.router_asbr.is_set)

                                        def has_operation(self):
                                            for c in self.internal_link:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.link:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_lsa.yfilter != YFilter.not_set or
                                                self.router_abr.yfilter != YFilter.not_set or
                                                self.router_asbr.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "router-lsa-type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_lsa.is_set or self.internal_lsa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_lsa.get_name_leafdata())
                                            if (self.router_abr.is_set or self.router_abr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.router_abr.get_name_leafdata())
                                            if (self.router_asbr.is_set or self.router_asbr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.router_asbr.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "internal-link"):
                                                for c in self.internal_link:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.internal_link.append(c)
                                                return c

                                            if (child_yang_name == "link"):
                                                for c in self.link:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.link.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "internal-link" or name == "link" or name == "internal-lsa" or name == "router-abr" or name == "router-asbr"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-lsa"):
                                                self.internal_lsa = value
                                                self.internal_lsa.value_namespace = name_space
                                                self.internal_lsa.value_namespace_prefix = name_space_prefix
                                            if(value_path == "router-abr"):
                                                self.router_abr = value
                                                self.router_abr.value_namespace = name_space
                                                self.router_abr.value_namespace_prefix = name_space_prefix
                                            if(value_path == "router-asbr"):
                                                self.router_asbr = value
                                                self.router_asbr.value_namespace = name_space
                                                self.router_asbr.value_namespace_prefix = name_space_prefix


                                    class NetworkLsaType(Entity):
                                        """
                                        Network LSA
                                        
                                        .. attribute:: neighbor_router
                                        
                                        	Neighbor router list
                                        	**type**\: list of    :py:class:`NeighborRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter>`
                                        
                                        .. attribute:: network_prefix_length
                                        
                                        	Network prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__init__()

                                            self.yang_name = "network-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"

                                            self.network_prefix_length = YLeaf(YType.uint32, "network-prefix-length")

                                            self.neighbor_router = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("network_prefix_length") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__setattr__(name, value)


                                        class NeighborRouter(Entity):
                                            """
                                            Neighbor router list
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__init__()

                                                self.yang_name = "neighbor-router"
                                                self.yang_parent_name = "network-lsa-type"

                                                self.entry = YLeaf(YType.str, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "neighbor-router" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.neighbor_router:
                                                if (c.has_data()):
                                                    return True
                                            return self.network_prefix_length.is_set

                                        def has_operation(self):
                                            for c in self.neighbor_router:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.network_prefix_length.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "network-lsa-type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.network_prefix_length.is_set or self.network_prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.network_prefix_length.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "neighbor-router"):
                                                for c in self.neighbor_router:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.neighbor_router.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "neighbor-router" or name == "network-prefix-length"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "network-prefix-length"):
                                                self.network_prefix_length = value
                                                self.network_prefix_length.value_namespace = name_space
                                                self.network_prefix_length.value_namespace_prefix = name_space_prefix


                                    class SummaryLsaType(Entity):
                                        """
                                        Summary LSA
                                        
                                        .. attribute:: internal_sum_lsa
                                        
                                        	If true, internal max\-metric LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: summary_lsa_metric
                                        
                                        	Metric
                                        	**type**\: list of    :py:class:`SummaryLsaMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric>`
                                        
                                        .. attribute:: summary_prefix_length
                                        
                                        	Summary LSA prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__init__()

                                            self.yang_name = "summary-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"

                                            self.internal_sum_lsa = YLeaf(YType.boolean, "internal-sum-lsa")

                                            self.summary_prefix_length = YLeaf(YType.uint32, "summary-prefix-length")

                                            self.summary_lsa_metric = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_sum_lsa",
                                                            "summary_prefix_length") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__setattr__(name, value)


                                        class SummaryLsaMetric(Entity):
                                            """
                                            Metric
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__init__()

                                                self.yang_name = "summary-lsa-metric"
                                                self.yang_parent_name = "summary-lsa-type"

                                                self.entry = YLeaf(YType.uint32, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "summary-lsa-metric" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.summary_lsa_metric:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.internal_sum_lsa.is_set or
                                                self.summary_prefix_length.is_set)

                                        def has_operation(self):
                                            for c in self.summary_lsa_metric:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_sum_lsa.yfilter != YFilter.not_set or
                                                self.summary_prefix_length.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "summary-lsa-type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_sum_lsa.is_set or self.internal_sum_lsa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_sum_lsa.get_name_leafdata())
                                            if (self.summary_prefix_length.is_set or self.summary_prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.summary_prefix_length.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "summary-lsa-metric"):
                                                for c in self.summary_lsa_metric:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.summary_lsa_metric.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "summary-lsa-metric" or name == "internal-sum-lsa" or name == "summary-prefix-length"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-sum-lsa"):
                                                self.internal_sum_lsa = value
                                                self.internal_sum_lsa.value_namespace = name_space
                                                self.internal_sum_lsa.value_namespace_prefix = name_space_prefix
                                            if(value_path == "summary-prefix-length"):
                                                self.summary_prefix_length = value
                                                self.summary_prefix_length.value_namespace = name_space
                                                self.summary_prefix_length.value_namespace_prefix = name_space_prefix


                                    class ExternalLsaType(Entity):
                                        """
                                        External LSA
                                        
                                        .. attribute:: external_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_tos_metric
                                        
                                        	Type of service information
                                        	**type**\: list of    :py:class:`ExternalTosMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric>`
                                        
                                        .. attribute:: internal_external_lsa
                                        
                                        	If true, internal max\-metric LSA
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__init__()

                                            self.yang_name = "external-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"

                                            self.external_prefix_length = YLeaf(YType.uint32, "external-prefix-length")

                                            self.internal_external_lsa = YLeaf(YType.boolean, "internal-external-lsa")

                                            self.external_tos_metric = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("external_prefix_length",
                                                            "internal_external_lsa") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__setattr__(name, value)


                                        class ExternalTosMetric(Entity):
                                            """
                                            Type of service information
                                            
                                            .. attribute:: external_metric
                                            
                                            	Cost of this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: external_metric_type
                                            
                                            	External LSA metric type
                                            	**type**\:   :py:class:`ExMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.ExMetric>`
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: external_tos
                                            
                                            	Type of Service
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__init__()

                                                self.yang_name = "external-tos-metric"
                                                self.yang_parent_name = "external-lsa-type"

                                                self.external_metric = YLeaf(YType.uint32, "external-metric")

                                                self.external_metric_type = YLeaf(YType.enumeration, "external-metric-type")

                                                self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                self.external_tos = YLeaf(YType.uint32, "external-tos")

                                                self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("external_metric",
                                                                "external_metric_type",
                                                                "external_tag",
                                                                "external_tos",
                                                                "forwarding_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.external_metric.is_set or
                                                    self.external_metric_type.is_set or
                                                    self.external_tag.is_set or
                                                    self.external_tos.is_set or
                                                    self.forwarding_address.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.external_metric.yfilter != YFilter.not_set or
                                                    self.external_metric_type.yfilter != YFilter.not_set or
                                                    self.external_tag.yfilter != YFilter.not_set or
                                                    self.external_tos.yfilter != YFilter.not_set or
                                                    self.forwarding_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "external-tos-metric" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.external_metric.is_set or self.external_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.external_metric.get_name_leafdata())
                                                if (self.external_metric_type.is_set or self.external_metric_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.external_metric_type.get_name_leafdata())
                                                if (self.external_tag.is_set or self.external_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.external_tag.get_name_leafdata())
                                                if (self.external_tos.is_set or self.external_tos.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.external_tos.get_name_leafdata())
                                                if (self.forwarding_address.is_set or self.forwarding_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.forwarding_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "external-metric" or name == "external-metric-type" or name == "external-tag" or name == "external-tos" or name == "forwarding-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "external-metric"):
                                                    self.external_metric = value
                                                    self.external_metric.value_namespace = name_space
                                                    self.external_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "external-metric-type"):
                                                    self.external_metric_type = value
                                                    self.external_metric_type.value_namespace = name_space
                                                    self.external_metric_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "external-tag"):
                                                    self.external_tag = value
                                                    self.external_tag.value_namespace = name_space
                                                    self.external_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "external-tos"):
                                                    self.external_tos = value
                                                    self.external_tos.value_namespace = name_space
                                                    self.external_tos.value_namespace_prefix = name_space_prefix
                                                if(value_path == "forwarding-address"):
                                                    self.forwarding_address = value
                                                    self.forwarding_address.value_namespace = name_space
                                                    self.forwarding_address.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.external_tos_metric:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.external_prefix_length.is_set or
                                                self.internal_external_lsa.is_set)

                                        def has_operation(self):
                                            for c in self.external_tos_metric:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.external_prefix_length.yfilter != YFilter.not_set or
                                                self.internal_external_lsa.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "external-lsa-type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.external_prefix_length.is_set or self.external_prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.external_prefix_length.get_name_leafdata())
                                            if (self.internal_external_lsa.is_set or self.internal_external_lsa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_external_lsa.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "external-tos-metric"):
                                                for c in self.external_tos_metric:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.external_tos_metric.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "external-tos-metric" or name == "external-prefix-length" or name == "internal-external-lsa"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "external-prefix-length"):
                                                self.external_prefix_length = value
                                                self.external_prefix_length.value_namespace = name_space
                                                self.external_prefix_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "internal-external-lsa"):
                                                self.internal_external_lsa = value
                                                self.internal_external_lsa.value_namespace = name_space
                                                self.internal_external_lsa.value_namespace_prefix = name_space_prefix


                                    class OpaqueLinkLsaType(Entity):
                                        """
                                        Opaque\-Link LSA
                                        
                                        .. attribute:: opaque_interface_name
                                        
                                        	Interface on which the Opaque link LSA is received
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__init__()

                                            self.yang_name = "opaque-link-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"

                                            self.opaque_interface_name = YLeaf(YType.str, "opaque-interface-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("opaque_interface_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.opaque_interface_name.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.opaque_interface_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "opaque-link-lsa-type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.opaque_interface_name.is_set or self.opaque_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.opaque_interface_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "opaque-interface-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "opaque-interface-name"):
                                                self.opaque_interface_name = value
                                                self.opaque_interface_name.value_namespace = name_space
                                                self.opaque_interface_name.value_namespace_prefix = name_space_prefix


                                    class OpaqueMplsTeLsaType(Entity):
                                        """
                                        Opaque\-Area, opaque type 1 LSA
                                        
                                        .. attribute:: tlv
                                        
                                        	List of TLVs
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__init__()

                                            self.yang_name = "opaque-mpls-te-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"

                                            self.tlv = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__setattr__(name, value)


                                        class Tlv(Entity):
                                            """
                                            List of TLVs
                                            
                                            .. attribute:: mpls_dste_link
                                            
                                            	MPLS DS\-TE supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: mpls_router_id
                                            
                                            	MPLS\-TE Router ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: te_link_sub_tlv
                                            
                                            	List of Sub\-TLVs
                                            	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv>`
                                            
                                            .. attribute:: tlv_data
                                            
                                            	TLV direct data
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tlv_length
                                            
                                            	Length of top\-level TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: tlv_type
                                            
                                            	Type of top\-level TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "opaque-mpls-te-lsa-type"

                                                self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                self.te_link_sub_tlv = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("mpls_dste_link",
                                                                "mpls_router_id",
                                                                "tlv_data",
                                                                "tlv_length",
                                                                "tlv_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__setattr__(name, value)


                                            class TeLinkSubTlv(Entity):
                                                """
                                                List of Sub\-TLVs
                                                
                                                .. attribute:: sub_tlv_length
                                                
                                                	Length of sub TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sub_tlv_type
                                                
                                                	Type of sub TLV
                                                	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                
                                                .. attribute:: sub_tlv_value
                                                
                                                	Value of sub TLV
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                    self.yang_name = "te-link-sub-tlv"
                                                    self.yang_parent_name = "tlv"

                                                    self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                    self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                    self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("sub_tlv_length",
                                                                    "sub_tlv_type",
                                                                    "sub_tlv_value") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.sub_tlv_length.is_set or
                                                        self.sub_tlv_type.is_set or
                                                        self.sub_tlv_value.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.sub_tlv_length.yfilter != YFilter.not_set or
                                                        self.sub_tlv_type.yfilter != YFilter.not_set or
                                                        self.sub_tlv_value.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "te-link-sub-tlv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.sub_tlv_length.is_set or self.sub_tlv_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sub_tlv_length.get_name_leafdata())
                                                    if (self.sub_tlv_type.is_set or self.sub_tlv_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sub_tlv_type.get_name_leafdata())
                                                    if (self.sub_tlv_value.is_set or self.sub_tlv_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sub_tlv_value.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "sub-tlv-length" or name == "sub-tlv-type" or name == "sub-tlv-value"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "sub-tlv-length"):
                                                        self.sub_tlv_length = value
                                                        self.sub_tlv_length.value_namespace = name_space
                                                        self.sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sub-tlv-type"):
                                                        self.sub_tlv_type = value
                                                        self.sub_tlv_type.value_namespace = name_space
                                                        self.sub_tlv_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sub-tlv-value"):
                                                        self.sub_tlv_value = value
                                                        self.sub_tlv_value.value_namespace = name_space
                                                        self.sub_tlv_value.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.te_link_sub_tlv:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.mpls_dste_link.is_set or
                                                    self.mpls_router_id.is_set or
                                                    self.tlv_data.is_set or
                                                    self.tlv_length.is_set or
                                                    self.tlv_type.is_set)

                                            def has_operation(self):
                                                for c in self.te_link_sub_tlv:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.mpls_dste_link.yfilter != YFilter.not_set or
                                                    self.mpls_router_id.yfilter != YFilter.not_set or
                                                    self.tlv_data.yfilter != YFilter.not_set or
                                                    self.tlv_length.yfilter != YFilter.not_set or
                                                    self.tlv_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.mpls_dste_link.is_set or self.mpls_dste_link.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mpls_dste_link.get_name_leafdata())
                                                if (self.mpls_router_id.is_set or self.mpls_router_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mpls_router_id.get_name_leafdata())
                                                if (self.tlv_data.is_set or self.tlv_data.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tlv_data.get_name_leafdata())
                                                if (self.tlv_length.is_set or self.tlv_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tlv_length.get_name_leafdata())
                                                if (self.tlv_type.is_set or self.tlv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tlv_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "te-link-sub-tlv"):
                                                    for c in self.te_link_sub_tlv:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.te_link_sub_tlv.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "te-link-sub-tlv" or name == "mpls-dste-link" or name == "mpls-router-id" or name == "tlv-data" or name == "tlv-length" or name == "tlv-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "mpls-dste-link"):
                                                    self.mpls_dste_link = value
                                                    self.mpls_dste_link.value_namespace = name_space
                                                    self.mpls_dste_link.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mpls-router-id"):
                                                    self.mpls_router_id = value
                                                    self.mpls_router_id.value_namespace = name_space
                                                    self.mpls_router_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tlv-data"):
                                                    self.tlv_data = value
                                                    self.tlv_data.value_namespace = name_space
                                                    self.tlv_data.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tlv-length"):
                                                    self.tlv_length = value
                                                    self.tlv_length.value_namespace = name_space
                                                    self.tlv_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tlv-type"):
                                                    self.tlv_type = value
                                                    self.tlv_type.value_namespace = name_space
                                                    self.tlv_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.tlv:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.tlv:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "opaque-mpls-te-lsa-type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tlv"):
                                                for c in self.tlv:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.tlv.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tlv"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class OpaqueGraceLsa(Entity):
                                        """
                                        Opaque\-link, opaque type 3 Grace LSA
                                        
                                        .. attribute:: grace_period
                                        
                                        	The amount of time the router's neighbor should advertise it fully adjacent (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: grace_reason
                                        
                                        	Reason for router restart
                                        	**type**\:   :py:class:`OspfGrReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfGrReason>`
                                        
                                        .. attribute:: ip_address
                                        
                                        	IP interface address on the subnet associated with the grace LSA
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__init__()

                                            self.yang_name = "opaque-grace-lsa"
                                            self.yang_parent_name = "lsa-internal-data"

                                            self.grace_period = YLeaf(YType.uint32, "grace-period")

                                            self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                            self.ip_address = YLeaf(YType.str, "ip-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("grace_period",
                                                            "grace_reason",
                                                            "ip_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.grace_period.is_set or
                                                self.grace_reason.is_set or
                                                self.ip_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.grace_period.yfilter != YFilter.not_set or
                                                self.grace_reason.yfilter != YFilter.not_set or
                                                self.ip_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "opaque-grace-lsa" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.grace_period.is_set or self.grace_period.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.grace_period.get_name_leafdata())
                                            if (self.grace_reason.is_set or self.grace_reason.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.grace_reason.get_name_leafdata())
                                            if (self.ip_address.is_set or self.ip_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ip_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "grace-period" or name == "grace-reason" or name == "ip-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "grace-period"):
                                                self.grace_period = value
                                                self.grace_period.value_namespace = name_space
                                                self.grace_period.value_namespace_prefix = name_space_prefix
                                            if(value_path == "grace-reason"):
                                                self.grace_reason = value
                                                self.grace_reason.value_namespace = name_space
                                                self.grace_reason.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ip-address"):
                                                self.ip_address = value
                                                self.ip_address.value_namespace = name_space
                                                self.ip_address.value_namespace_prefix = name_space_prefix


                                    class OpaqueRouterInfoLsaType(Entity):
                                        """
                                        Opaque Router Information LSA
                                        
                                        .. attribute:: opaque_ri_interface_name
                                        
                                        	Interface on which this Link\-Local Opaque link LSA is received
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: opaque_rilsa_scope
                                        
                                        	Opaque LSA flooding scope, a.k.a., Opaque LSA Type
                                        	**type**\:   :py:class:`OspfLsaOpqRiScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLsaOpqRiScope>`
                                        
                                        .. attribute:: opaque_ritlv
                                        
                                        	Router Information TLV
                                        	**type**\: list of    :py:class:`OpaqueRitlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__init__()

                                            self.yang_name = "opaque-router-info-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"

                                            self.opaque_ri_interface_name = YLeaf(YType.str, "opaque-ri-interface-name")

                                            self.opaque_rilsa_scope = YLeaf(YType.enumeration, "opaque-rilsa-scope")

                                            self.opaque_ritlv = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("opaque_ri_interface_name",
                                                            "opaque_rilsa_scope") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__setattr__(name, value)


                                        class OpaqueRitlv(Entity):
                                            """
                                            Router Information TLV
                                            
                                            .. attribute:: pcedtlv
                                            
                                            	PCE Discovery TLV
                                            	**type**\:   :py:class:`Pcedtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv>`
                                            
                                            .. attribute:: ritlv_internal_type
                                            
                                            	RITLVInternalType
                                            	**type**\:   :py:class:`OspfShOpqRiTlvTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiTlvTypes>`
                                            
                                            .. attribute:: rtr_cap_tlv
                                            
                                            	Rtr Cap TLV
                                            	**type**\:   :py:class:`RtrCapTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv>`
                                            
                                            .. attribute:: sr_algo_tlv
                                            
                                            	SR Algorithm TLV
                                            	**type**\:   :py:class:`SrAlgoTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv>`
                                            
                                            .. attribute:: sr_range_tlv
                                            
                                            	SR Range TLV
                                            	**type**\:   :py:class:`SrRangeTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv>`
                                            
                                            .. attribute:: unknown_tlv
                                            
                                            	Unknown Rtr Info TLV
                                            	**type**\:   :py:class:`UnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__init__()

                                                self.yang_name = "opaque-ritlv"
                                                self.yang_parent_name = "opaque-router-info-lsa-type"

                                                self.ritlv_internal_type = YLeaf(YType.enumeration, "ritlv-internal-type")

                                                self.pcedtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv()
                                                self.pcedtlv.parent = self
                                                self._children_name_map["pcedtlv"] = "pcedtlv"
                                                self._children_yang_names.add("pcedtlv")

                                                self.rtr_cap_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv()
                                                self.rtr_cap_tlv.parent = self
                                                self._children_name_map["rtr_cap_tlv"] = "rtr-cap-tlv"
                                                self._children_yang_names.add("rtr-cap-tlv")

                                                self.sr_algo_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv()
                                                self.sr_algo_tlv.parent = self
                                                self._children_name_map["sr_algo_tlv"] = "sr-algo-tlv"
                                                self._children_yang_names.add("sr-algo-tlv")

                                                self.sr_range_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv()
                                                self.sr_range_tlv.parent = self
                                                self._children_name_map["sr_range_tlv"] = "sr-range-tlv"
                                                self._children_yang_names.add("sr-range-tlv")

                                                self.unknown_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv()
                                                self.unknown_tlv.parent = self
                                                self._children_name_map["unknown_tlv"] = "unknown-tlv"
                                                self._children_yang_names.add("unknown-tlv")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ritlv_internal_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__setattr__(name, value)


                                            class UnknownTlv(Entity):
                                                """
                                                Unknown Rtr Info TLV
                                                
                                                .. attribute:: ri_gen_tlv_length
                                                
                                                	Length of TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ri_gen_tlv_type
                                                
                                                	Type of TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ri_genvalue
                                                
                                                	Data in TLV
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__init__()

                                                    self.yang_name = "unknown-tlv"
                                                    self.yang_parent_name = "opaque-ritlv"

                                                    self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                    self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                    self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("ri_gen_tlv_length",
                                                                    "ri_gen_tlv_type",
                                                                    "ri_genvalue") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.ri_gen_tlv_length.is_set or
                                                        self.ri_gen_tlv_type.is_set or
                                                        self.ri_genvalue.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.ri_gen_tlv_length.yfilter != YFilter.not_set or
                                                        self.ri_gen_tlv_type.yfilter != YFilter.not_set or
                                                        self.ri_genvalue.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unknown-tlv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.ri_gen_tlv_length.is_set or self.ri_gen_tlv_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ri_gen_tlv_length.get_name_leafdata())
                                                    if (self.ri_gen_tlv_type.is_set or self.ri_gen_tlv_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ri_gen_tlv_type.get_name_leafdata())
                                                    if (self.ri_genvalue.is_set or self.ri_genvalue.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ri_genvalue.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ri-gen-tlv-length" or name == "ri-gen-tlv-type" or name == "ri-genvalue"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "ri-gen-tlv-length"):
                                                        self.ri_gen_tlv_length = value
                                                        self.ri_gen_tlv_length.value_namespace = name_space
                                                        self.ri_gen_tlv_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ri-gen-tlv-type"):
                                                        self.ri_gen_tlv_type = value
                                                        self.ri_gen_tlv_type.value_namespace = name_space
                                                        self.ri_gen_tlv_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ri-genvalue"):
                                                        self.ri_genvalue = value
                                                        self.ri_genvalue.value_namespace = name_space
                                                        self.ri_genvalue.value_namespace_prefix = name_space_prefix


                                            class RtrCapTlv(Entity):
                                                """
                                                Rtr Cap TLV
                                                
                                                .. attribute:: rtr_cap_additional_info
                                                
                                                	Additional Information in TLV
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: rtr_cap_all_bits
                                                
                                                	All capability bits
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rtr_cap_area_te
                                                
                                                	Traffic Engineering capability of area
                                                	**type**\:  bool
                                                
                                                .. attribute:: rtr_cap_graceful_restart
                                                
                                                	Graceful Restart Capability
                                                	**type**\:  bool
                                                
                                                .. attribute:: rtr_cap_graceful_restart_helper
                                                
                                                	Graceful Restart Helper Capability
                                                	**type**\:  bool
                                                
                                                .. attribute:: rtr_cap_p2plan
                                                
                                                	P2P LAN Capability
                                                	**type**\:  bool
                                                
                                                .. attribute:: rtr_cap_stub_rtr
                                                
                                                	Stub Router capability
                                                	**type**\:  bool
                                                
                                                .. attribute:: rtr_cap_te_exp
                                                
                                                	TE Experimental bit
                                                	**type**\:  bool
                                                
                                                .. attribute:: rtr_cap_tlv_length
                                                
                                                	Length of TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__init__()

                                                    self.yang_name = "rtr-cap-tlv"
                                                    self.yang_parent_name = "opaque-ritlv"

                                                    self.rtr_cap_additional_info = YLeaf(YType.str, "rtr-cap-additional-info")

                                                    self.rtr_cap_all_bits = YLeaf(YType.uint32, "rtr-cap-all-bits")

                                                    self.rtr_cap_area_te = YLeaf(YType.boolean, "rtr-cap-area-te")

                                                    self.rtr_cap_graceful_restart = YLeaf(YType.boolean, "rtr-cap-graceful-restart")

                                                    self.rtr_cap_graceful_restart_helper = YLeaf(YType.boolean, "rtr-cap-graceful-restart-helper")

                                                    self.rtr_cap_p2plan = YLeaf(YType.boolean, "rtr-cap-p2plan")

                                                    self.rtr_cap_stub_rtr = YLeaf(YType.boolean, "rtr-cap-stub-rtr")

                                                    self.rtr_cap_te_exp = YLeaf(YType.boolean, "rtr-cap-te-exp")

                                                    self.rtr_cap_tlv_length = YLeaf(YType.uint16, "rtr-cap-tlv-length")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("rtr_cap_additional_info",
                                                                    "rtr_cap_all_bits",
                                                                    "rtr_cap_area_te",
                                                                    "rtr_cap_graceful_restart",
                                                                    "rtr_cap_graceful_restart_helper",
                                                                    "rtr_cap_p2plan",
                                                                    "rtr_cap_stub_rtr",
                                                                    "rtr_cap_te_exp",
                                                                    "rtr_cap_tlv_length") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.rtr_cap_additional_info.is_set or
                                                        self.rtr_cap_all_bits.is_set or
                                                        self.rtr_cap_area_te.is_set or
                                                        self.rtr_cap_graceful_restart.is_set or
                                                        self.rtr_cap_graceful_restart_helper.is_set or
                                                        self.rtr_cap_p2plan.is_set or
                                                        self.rtr_cap_stub_rtr.is_set or
                                                        self.rtr_cap_te_exp.is_set or
                                                        self.rtr_cap_tlv_length.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.rtr_cap_additional_info.yfilter != YFilter.not_set or
                                                        self.rtr_cap_all_bits.yfilter != YFilter.not_set or
                                                        self.rtr_cap_area_te.yfilter != YFilter.not_set or
                                                        self.rtr_cap_graceful_restart.yfilter != YFilter.not_set or
                                                        self.rtr_cap_graceful_restart_helper.yfilter != YFilter.not_set or
                                                        self.rtr_cap_p2plan.yfilter != YFilter.not_set or
                                                        self.rtr_cap_stub_rtr.yfilter != YFilter.not_set or
                                                        self.rtr_cap_te_exp.yfilter != YFilter.not_set or
                                                        self.rtr_cap_tlv_length.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rtr-cap-tlv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.rtr_cap_additional_info.is_set or self.rtr_cap_additional_info.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtr_cap_additional_info.get_name_leafdata())
                                                    if (self.rtr_cap_all_bits.is_set or self.rtr_cap_all_bits.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtr_cap_all_bits.get_name_leafdata())
                                                    if (self.rtr_cap_area_te.is_set or self.rtr_cap_area_te.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtr_cap_area_te.get_name_leafdata())
                                                    if (self.rtr_cap_graceful_restart.is_set or self.rtr_cap_graceful_restart.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtr_cap_graceful_restart.get_name_leafdata())
                                                    if (self.rtr_cap_graceful_restart_helper.is_set or self.rtr_cap_graceful_restart_helper.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtr_cap_graceful_restart_helper.get_name_leafdata())
                                                    if (self.rtr_cap_p2plan.is_set or self.rtr_cap_p2plan.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtr_cap_p2plan.get_name_leafdata())
                                                    if (self.rtr_cap_stub_rtr.is_set or self.rtr_cap_stub_rtr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtr_cap_stub_rtr.get_name_leafdata())
                                                    if (self.rtr_cap_te_exp.is_set or self.rtr_cap_te_exp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtr_cap_te_exp.get_name_leafdata())
                                                    if (self.rtr_cap_tlv_length.is_set or self.rtr_cap_tlv_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtr_cap_tlv_length.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "rtr-cap-additional-info" or name == "rtr-cap-all-bits" or name == "rtr-cap-area-te" or name == "rtr-cap-graceful-restart" or name == "rtr-cap-graceful-restart-helper" or name == "rtr-cap-p2plan" or name == "rtr-cap-stub-rtr" or name == "rtr-cap-te-exp" or name == "rtr-cap-tlv-length"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "rtr-cap-additional-info"):
                                                        self.rtr_cap_additional_info = value
                                                        self.rtr_cap_additional_info.value_namespace = name_space
                                                        self.rtr_cap_additional_info.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtr-cap-all-bits"):
                                                        self.rtr_cap_all_bits = value
                                                        self.rtr_cap_all_bits.value_namespace = name_space
                                                        self.rtr_cap_all_bits.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtr-cap-area-te"):
                                                        self.rtr_cap_area_te = value
                                                        self.rtr_cap_area_te.value_namespace = name_space
                                                        self.rtr_cap_area_te.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtr-cap-graceful-restart"):
                                                        self.rtr_cap_graceful_restart = value
                                                        self.rtr_cap_graceful_restart.value_namespace = name_space
                                                        self.rtr_cap_graceful_restart.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtr-cap-graceful-restart-helper"):
                                                        self.rtr_cap_graceful_restart_helper = value
                                                        self.rtr_cap_graceful_restart_helper.value_namespace = name_space
                                                        self.rtr_cap_graceful_restart_helper.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtr-cap-p2plan"):
                                                        self.rtr_cap_p2plan = value
                                                        self.rtr_cap_p2plan.value_namespace = name_space
                                                        self.rtr_cap_p2plan.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtr-cap-stub-rtr"):
                                                        self.rtr_cap_stub_rtr = value
                                                        self.rtr_cap_stub_rtr.value_namespace = name_space
                                                        self.rtr_cap_stub_rtr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtr-cap-te-exp"):
                                                        self.rtr_cap_te_exp = value
                                                        self.rtr_cap_te_exp.value_namespace = name_space
                                                        self.rtr_cap_te_exp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtr-cap-tlv-length"):
                                                        self.rtr_cap_tlv_length = value
                                                        self.rtr_cap_tlv_length.value_namespace = name_space
                                                        self.rtr_cap_tlv_length.value_namespace_prefix = name_space_prefix


                                            class Pcedtlv(Entity):
                                                """
                                                PCE Discovery TLV
                                                
                                                .. attribute:: pced_addr
                                                
                                                	PCE Address
                                                	**type**\:   :py:class:`PcedAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr>`
                                                
                                                .. attribute:: pced_scope
                                                
                                                	PCE Scope Information
                                                	**type**\:   :py:class:`PcedScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope>`
                                                
                                                .. attribute:: pcedtlv_length
                                                
                                                	Length of TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__init__()

                                                    self.yang_name = "pcedtlv"
                                                    self.yang_parent_name = "opaque-ritlv"

                                                    self.pcedtlv_length = YLeaf(YType.uint16, "pcedtlv-length")

                                                    self.pced_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr()
                                                    self.pced_addr.parent = self
                                                    self._children_name_map["pced_addr"] = "pced-addr"
                                                    self._children_yang_names.add("pced-addr")

                                                    self.pced_scope = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope()
                                                    self.pced_scope.parent = self
                                                    self._children_name_map["pced_scope"] = "pced-scope"
                                                    self._children_yang_names.add("pced-scope")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("pcedtlv_length") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__setattr__(name, value)


                                                class PcedAddr(Entity):
                                                    """
                                                    PCE Address
                                                    
                                                    .. attribute:: ipv4pce_addr
                                                    
                                                    	IPv4 PCE Address
                                                    	**type**\:   :py:class:`Ipv4PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr>`
                                                    
                                                    .. attribute:: ipv6pce_addr
                                                    
                                                    	IPv6 PCE Address
                                                    	**type**\:   :py:class:`Ipv6PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr>`
                                                    
                                                    .. attribute:: pce_addr_type
                                                    
                                                    	PCEAddrType
                                                    	**type**\:   :py:class:`OspfShOpqRiPceAddrTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiPceAddrTypes>`
                                                    
                                                    .. attribute:: pce_addr_unknown_tlv
                                                    
                                                    	Unknown PCE Addr TLV
                                                    	**type**\:   :py:class:`PceAddrUnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__init__()

                                                        self.yang_name = "pced-addr"
                                                        self.yang_parent_name = "pcedtlv"

                                                        self.pce_addr_type = YLeaf(YType.enumeration, "pce-addr-type")

                                                        self.ipv4pce_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr()
                                                        self.ipv4pce_addr.parent = self
                                                        self._children_name_map["ipv4pce_addr"] = "ipv4pce-addr"
                                                        self._children_yang_names.add("ipv4pce-addr")

                                                        self.ipv6pce_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr()
                                                        self.ipv6pce_addr.parent = self
                                                        self._children_name_map["ipv6pce_addr"] = "ipv6pce-addr"
                                                        self._children_yang_names.add("ipv6pce-addr")

                                                        self.pce_addr_unknown_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv()
                                                        self.pce_addr_unknown_tlv.parent = self
                                                        self._children_name_map["pce_addr_unknown_tlv"] = "pce-addr-unknown-tlv"
                                                        self._children_yang_names.add("pce-addr-unknown-tlv")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("pce_addr_type") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__setattr__(name, value)


                                                    class PceAddrUnknownTlv(Entity):
                                                        """
                                                        Unknown PCE Addr TLV
                                                        
                                                        .. attribute:: ri_gen_tlv_length
                                                        
                                                        	Length of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ri_gen_tlv_type
                                                        
                                                        	Type of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ri_genvalue
                                                        
                                                        	Data in TLV
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__init__()

                                                            self.yang_name = "pce-addr-unknown-tlv"
                                                            self.yang_parent_name = "pced-addr"

                                                            self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                            self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                            self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("ri_gen_tlv_length",
                                                                            "ri_gen_tlv_type",
                                                                            "ri_genvalue") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.ri_gen_tlv_length.is_set or
                                                                self.ri_gen_tlv_type.is_set or
                                                                self.ri_genvalue.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.ri_gen_tlv_length.yfilter != YFilter.not_set or
                                                                self.ri_gen_tlv_type.yfilter != YFilter.not_set or
                                                                self.ri_genvalue.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "pce-addr-unknown-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.ri_gen_tlv_length.is_set or self.ri_gen_tlv_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ri_gen_tlv_length.get_name_leafdata())
                                                            if (self.ri_gen_tlv_type.is_set or self.ri_gen_tlv_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ri_gen_tlv_type.get_name_leafdata())
                                                            if (self.ri_genvalue.is_set or self.ri_genvalue.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ri_genvalue.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "ri-gen-tlv-length" or name == "ri-gen-tlv-type" or name == "ri-genvalue"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "ri-gen-tlv-length"):
                                                                self.ri_gen_tlv_length = value
                                                                self.ri_gen_tlv_length.value_namespace = name_space
                                                                self.ri_gen_tlv_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ri-gen-tlv-type"):
                                                                self.ri_gen_tlv_type = value
                                                                self.ri_gen_tlv_type.value_namespace = name_space
                                                                self.ri_gen_tlv_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ri-genvalue"):
                                                                self.ri_genvalue = value
                                                                self.ri_genvalue.value_namespace = name_space
                                                                self.ri_genvalue.value_namespace_prefix = name_space_prefix


                                                    class Ipv4PceAddr(Entity):
                                                        """
                                                        IPv4 PCE Address
                                                        
                                                        .. attribute:: pceipv4_addr
                                                        
                                                        	PCE IPv4 Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__init__()

                                                            self.yang_name = "ipv4pce-addr"
                                                            self.yang_parent_name = "pced-addr"

                                                            self.pceipv4_addr = YLeaf(YType.str, "pceipv4-addr")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("pceipv4_addr") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return self.pceipv4_addr.is_set

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.pceipv4_addr.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ipv4pce-addr" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.pceipv4_addr.is_set or self.pceipv4_addr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pceipv4_addr.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "pceipv4-addr"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "pceipv4-addr"):
                                                                self.pceipv4_addr = value
                                                                self.pceipv4_addr.value_namespace = name_space
                                                                self.pceipv4_addr.value_namespace_prefix = name_space_prefix


                                                    class Ipv6PceAddr(Entity):
                                                        """
                                                        IPv6 PCE Address
                                                        
                                                        .. attribute:: pceipv6_addr
                                                        
                                                        	PCE IPv6 Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__init__()

                                                            self.yang_name = "ipv6pce-addr"
                                                            self.yang_parent_name = "pced-addr"

                                                            self.pceipv6_addr = YLeaf(YType.str, "pceipv6-addr")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("pceipv6_addr") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return self.pceipv6_addr.is_set

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.pceipv6_addr.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ipv6pce-addr" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.pceipv6_addr.is_set or self.pceipv6_addr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pceipv6_addr.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "pceipv6-addr"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "pceipv6-addr"):
                                                                self.pceipv6_addr = value
                                                                self.pceipv6_addr.value_namespace = name_space
                                                                self.pceipv6_addr.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        return (
                                                            self.pce_addr_type.is_set or
                                                            (self.ipv4pce_addr is not None and self.ipv4pce_addr.has_data()) or
                                                            (self.ipv6pce_addr is not None and self.ipv6pce_addr.has_data()) or
                                                            (self.pce_addr_unknown_tlv is not None and self.pce_addr_unknown_tlv.has_data()))

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.pce_addr_type.yfilter != YFilter.not_set or
                                                            (self.ipv4pce_addr is not None and self.ipv4pce_addr.has_operation()) or
                                                            (self.ipv6pce_addr is not None and self.ipv6pce_addr.has_operation()) or
                                                            (self.pce_addr_unknown_tlv is not None and self.pce_addr_unknown_tlv.has_operation()))

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "pced-addr" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.pce_addr_type.is_set or self.pce_addr_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pce_addr_type.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ipv4pce-addr"):
                                                            if (self.ipv4pce_addr is None):
                                                                self.ipv4pce_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr()
                                                                self.ipv4pce_addr.parent = self
                                                                self._children_name_map["ipv4pce_addr"] = "ipv4pce-addr"
                                                            return self.ipv4pce_addr

                                                        if (child_yang_name == "ipv6pce-addr"):
                                                            if (self.ipv6pce_addr is None):
                                                                self.ipv6pce_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr()
                                                                self.ipv6pce_addr.parent = self
                                                                self._children_name_map["ipv6pce_addr"] = "ipv6pce-addr"
                                                            return self.ipv6pce_addr

                                                        if (child_yang_name == "pce-addr-unknown-tlv"):
                                                            if (self.pce_addr_unknown_tlv is None):
                                                                self.pce_addr_unknown_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv()
                                                                self.pce_addr_unknown_tlv.parent = self
                                                                self._children_name_map["pce_addr_unknown_tlv"] = "pce-addr-unknown-tlv"
                                                            return self.pce_addr_unknown_tlv

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv4pce-addr" or name == "ipv6pce-addr" or name == "pce-addr-unknown-tlv" or name == "pce-addr-type"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "pce-addr-type"):
                                                            self.pce_addr_type = value
                                                            self.pce_addr_type.value_namespace = name_space
                                                            self.pce_addr_type.value_namespace_prefix = name_space_prefix


                                                class PcedScope(Entity):
                                                    """
                                                    PCE Scope Information
                                                    
                                                    .. attribute:: all_scope_info_bits
                                                    
                                                    	PCE Scope Information
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lbit
                                                    
                                                    	L Bit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pref_l
                                                    
                                                    	Pref L
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pref_r
                                                    
                                                    	Pref R
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pref_s
                                                    
                                                    	Pref S
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pref_y
                                                    
                                                    	Pref Y
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rbit
                                                    
                                                    	R Bit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rd_bit
                                                    
                                                    	Rd Bit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sbit
                                                    
                                                    	S Bit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sd_bit
                                                    
                                                    	Sd Bit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ybit
                                                    
                                                    	Y Bit
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__init__()

                                                        self.yang_name = "pced-scope"
                                                        self.yang_parent_name = "pcedtlv"

                                                        self.all_scope_info_bits = YLeaf(YType.uint32, "all-scope-info-bits")

                                                        self.lbit = YLeaf(YType.boolean, "lbit")

                                                        self.pref_l = YLeaf(YType.uint8, "pref-l")

                                                        self.pref_r = YLeaf(YType.uint8, "pref-r")

                                                        self.pref_s = YLeaf(YType.uint8, "pref-s")

                                                        self.pref_y = YLeaf(YType.uint8, "pref-y")

                                                        self.rbit = YLeaf(YType.boolean, "rbit")

                                                        self.rd_bit = YLeaf(YType.boolean, "rd-bit")

                                                        self.sbit = YLeaf(YType.boolean, "sbit")

                                                        self.sd_bit = YLeaf(YType.boolean, "sd-bit")

                                                        self.ybit = YLeaf(YType.boolean, "ybit")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("all_scope_info_bits",
                                                                        "lbit",
                                                                        "pref_l",
                                                                        "pref_r",
                                                                        "pref_s",
                                                                        "pref_y",
                                                                        "rbit",
                                                                        "rd_bit",
                                                                        "sbit",
                                                                        "sd_bit",
                                                                        "ybit") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.all_scope_info_bits.is_set or
                                                            self.lbit.is_set or
                                                            self.pref_l.is_set or
                                                            self.pref_r.is_set or
                                                            self.pref_s.is_set or
                                                            self.pref_y.is_set or
                                                            self.rbit.is_set or
                                                            self.rd_bit.is_set or
                                                            self.sbit.is_set or
                                                            self.sd_bit.is_set or
                                                            self.ybit.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.all_scope_info_bits.yfilter != YFilter.not_set or
                                                            self.lbit.yfilter != YFilter.not_set or
                                                            self.pref_l.yfilter != YFilter.not_set or
                                                            self.pref_r.yfilter != YFilter.not_set or
                                                            self.pref_s.yfilter != YFilter.not_set or
                                                            self.pref_y.yfilter != YFilter.not_set or
                                                            self.rbit.yfilter != YFilter.not_set or
                                                            self.rd_bit.yfilter != YFilter.not_set or
                                                            self.sbit.yfilter != YFilter.not_set or
                                                            self.sd_bit.yfilter != YFilter.not_set or
                                                            self.ybit.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "pced-scope" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.all_scope_info_bits.is_set or self.all_scope_info_bits.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.all_scope_info_bits.get_name_leafdata())
                                                        if (self.lbit.is_set or self.lbit.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.lbit.get_name_leafdata())
                                                        if (self.pref_l.is_set or self.pref_l.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pref_l.get_name_leafdata())
                                                        if (self.pref_r.is_set or self.pref_r.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pref_r.get_name_leafdata())
                                                        if (self.pref_s.is_set or self.pref_s.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pref_s.get_name_leafdata())
                                                        if (self.pref_y.is_set or self.pref_y.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pref_y.get_name_leafdata())
                                                        if (self.rbit.is_set or self.rbit.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rbit.get_name_leafdata())
                                                        if (self.rd_bit.is_set or self.rd_bit.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rd_bit.get_name_leafdata())
                                                        if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sbit.get_name_leafdata())
                                                        if (self.sd_bit.is_set or self.sd_bit.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sd_bit.get_name_leafdata())
                                                        if (self.ybit.is_set or self.ybit.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ybit.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "all-scope-info-bits" or name == "lbit" or name == "pref-l" or name == "pref-r" or name == "pref-s" or name == "pref-y" or name == "rbit" or name == "rd-bit" or name == "sbit" or name == "sd-bit" or name == "ybit"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "all-scope-info-bits"):
                                                            self.all_scope_info_bits = value
                                                            self.all_scope_info_bits.value_namespace = name_space
                                                            self.all_scope_info_bits.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "lbit"):
                                                            self.lbit = value
                                                            self.lbit.value_namespace = name_space
                                                            self.lbit.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "pref-l"):
                                                            self.pref_l = value
                                                            self.pref_l.value_namespace = name_space
                                                            self.pref_l.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "pref-r"):
                                                            self.pref_r = value
                                                            self.pref_r.value_namespace = name_space
                                                            self.pref_r.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "pref-s"):
                                                            self.pref_s = value
                                                            self.pref_s.value_namespace = name_space
                                                            self.pref_s.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "pref-y"):
                                                            self.pref_y = value
                                                            self.pref_y.value_namespace = name_space
                                                            self.pref_y.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rbit"):
                                                            self.rbit = value
                                                            self.rbit.value_namespace = name_space
                                                            self.rbit.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rd-bit"):
                                                            self.rd_bit = value
                                                            self.rd_bit.value_namespace = name_space
                                                            self.rd_bit.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "sbit"):
                                                            self.sbit = value
                                                            self.sbit.value_namespace = name_space
                                                            self.sbit.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "sd-bit"):
                                                            self.sd_bit = value
                                                            self.sd_bit.value_namespace = name_space
                                                            self.sd_bit.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ybit"):
                                                            self.ybit = value
                                                            self.ybit.value_namespace = name_space
                                                            self.ybit.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.pcedtlv_length.is_set or
                                                        (self.pced_addr is not None and self.pced_addr.has_data()) or
                                                        (self.pced_scope is not None and self.pced_scope.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.pcedtlv_length.yfilter != YFilter.not_set or
                                                        (self.pced_addr is not None and self.pced_addr.has_operation()) or
                                                        (self.pced_scope is not None and self.pced_scope.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pcedtlv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.pcedtlv_length.is_set or self.pcedtlv_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pcedtlv_length.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "pced-addr"):
                                                        if (self.pced_addr is None):
                                                            self.pced_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr()
                                                            self.pced_addr.parent = self
                                                            self._children_name_map["pced_addr"] = "pced-addr"
                                                        return self.pced_addr

                                                    if (child_yang_name == "pced-scope"):
                                                        if (self.pced_scope is None):
                                                            self.pced_scope = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope()
                                                            self.pced_scope.parent = self
                                                            self._children_name_map["pced_scope"] = "pced-scope"
                                                        return self.pced_scope

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "pced-addr" or name == "pced-scope" or name == "pcedtlv-length"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "pcedtlv-length"):
                                                        self.pcedtlv_length = value
                                                        self.pcedtlv_length.value_namespace = name_space
                                                        self.pcedtlv_length.value_namespace_prefix = name_space_prefix


                                            class SrAlgoTlv(Entity):
                                                """
                                                SR Algorithm TLV
                                                
                                                .. attribute:: sr_algo_length
                                                
                                                	Length of TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sr_algo_value
                                                
                                                	SR Algorithms
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__init__()

                                                    self.yang_name = "sr-algo-tlv"
                                                    self.yang_parent_name = "opaque-ritlv"

                                                    self.sr_algo_length = YLeaf(YType.uint16, "sr-algo-length")

                                                    self.sr_algo_value = YLeaf(YType.str, "sr-algo-value")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("sr_algo_length",
                                                                    "sr_algo_value") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.sr_algo_length.is_set or
                                                        self.sr_algo_value.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.sr_algo_length.yfilter != YFilter.not_set or
                                                        self.sr_algo_value.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sr-algo-tlv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.sr_algo_length.is_set or self.sr_algo_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sr_algo_length.get_name_leafdata())
                                                    if (self.sr_algo_value.is_set or self.sr_algo_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sr_algo_value.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "sr-algo-length" or name == "sr-algo-value"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "sr-algo-length"):
                                                        self.sr_algo_length = value
                                                        self.sr_algo_length.value_namespace = name_space
                                                        self.sr_algo_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sr-algo-value"):
                                                        self.sr_algo_value = value
                                                        self.sr_algo_value.value_namespace = name_space
                                                        self.sr_algo_value.value_namespace_prefix = name_space_prefix


                                            class SrRangeTlv(Entity):
                                                """
                                                SR Range TLV
                                                
                                                .. attribute:: sidtlv
                                                
                                                	SID sub\-TLV
                                                	**type**\:   :py:class:`Sidtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv>`
                                                
                                                .. attribute:: sr_range_length
                                                
                                                	Length of TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sr_range_size
                                                
                                                	SR Range Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__init__()

                                                    self.yang_name = "sr-range-tlv"
                                                    self.yang_parent_name = "opaque-ritlv"

                                                    self.sr_range_length = YLeaf(YType.uint16, "sr-range-length")

                                                    self.sr_range_size = YLeaf(YType.uint32, "sr-range-size")

                                                    self.sidtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv()
                                                    self.sidtlv.parent = self
                                                    self._children_name_map["sidtlv"] = "sidtlv"
                                                    self._children_yang_names.add("sidtlv")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("sr_range_length",
                                                                    "sr_range_size") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__setattr__(name, value)


                                                class Sidtlv(Entity):
                                                    """
                                                    SID sub\-TLV
                                                    
                                                    .. attribute:: sr_sid_length
                                                    
                                                    	Length of sub\-TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sr_sid_value
                                                    
                                                    	SID Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__init__()

                                                        self.yang_name = "sidtlv"
                                                        self.yang_parent_name = "sr-range-tlv"

                                                        self.sr_sid_length = YLeaf(YType.uint16, "sr-sid-length")

                                                        self.sr_sid_value = YLeaf(YType.uint32, "sr-sid-value")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("sr_sid_length",
                                                                        "sr_sid_value") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.sr_sid_length.is_set or
                                                            self.sr_sid_value.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.sr_sid_length.yfilter != YFilter.not_set or
                                                            self.sr_sid_value.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "sidtlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.sr_sid_length.is_set or self.sr_sid_length.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sr_sid_length.get_name_leafdata())
                                                        if (self.sr_sid_value.is_set or self.sr_sid_value.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sr_sid_value.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "sr-sid-length" or name == "sr-sid-value"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "sr-sid-length"):
                                                            self.sr_sid_length = value
                                                            self.sr_sid_length.value_namespace = name_space
                                                            self.sr_sid_length.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "sr-sid-value"):
                                                            self.sr_sid_value = value
                                                            self.sr_sid_value.value_namespace = name_space
                                                            self.sr_sid_value.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.sr_range_length.is_set or
                                                        self.sr_range_size.is_set or
                                                        (self.sidtlv is not None and self.sidtlv.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.sr_range_length.yfilter != YFilter.not_set or
                                                        self.sr_range_size.yfilter != YFilter.not_set or
                                                        (self.sidtlv is not None and self.sidtlv.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sr-range-tlv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.sr_range_length.is_set or self.sr_range_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sr_range_length.get_name_leafdata())
                                                    if (self.sr_range_size.is_set or self.sr_range_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sr_range_size.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "sidtlv"):
                                                        if (self.sidtlv is None):
                                                            self.sidtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv()
                                                            self.sidtlv.parent = self
                                                            self._children_name_map["sidtlv"] = "sidtlv"
                                                        return self.sidtlv

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "sidtlv" or name == "sr-range-length" or name == "sr-range-size"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "sr-range-length"):
                                                        self.sr_range_length = value
                                                        self.sr_range_length.value_namespace = name_space
                                                        self.sr_range_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sr-range-size"):
                                                        self.sr_range_size = value
                                                        self.sr_range_size.value_namespace = name_space
                                                        self.sr_range_size.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.ritlv_internal_type.is_set or
                                                    (self.pcedtlv is not None and self.pcedtlv.has_data()) or
                                                    (self.rtr_cap_tlv is not None and self.rtr_cap_tlv.has_data()) or
                                                    (self.sr_algo_tlv is not None and self.sr_algo_tlv.has_data()) or
                                                    (self.sr_range_tlv is not None and self.sr_range_tlv.has_data()) or
                                                    (self.unknown_tlv is not None and self.unknown_tlv.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ritlv_internal_type.yfilter != YFilter.not_set or
                                                    (self.pcedtlv is not None and self.pcedtlv.has_operation()) or
                                                    (self.rtr_cap_tlv is not None and self.rtr_cap_tlv.has_operation()) or
                                                    (self.sr_algo_tlv is not None and self.sr_algo_tlv.has_operation()) or
                                                    (self.sr_range_tlv is not None and self.sr_range_tlv.has_operation()) or
                                                    (self.unknown_tlv is not None and self.unknown_tlv.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "opaque-ritlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ritlv_internal_type.is_set or self.ritlv_internal_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ritlv_internal_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "pcedtlv"):
                                                    if (self.pcedtlv is None):
                                                        self.pcedtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv()
                                                        self.pcedtlv.parent = self
                                                        self._children_name_map["pcedtlv"] = "pcedtlv"
                                                    return self.pcedtlv

                                                if (child_yang_name == "rtr-cap-tlv"):
                                                    if (self.rtr_cap_tlv is None):
                                                        self.rtr_cap_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv()
                                                        self.rtr_cap_tlv.parent = self
                                                        self._children_name_map["rtr_cap_tlv"] = "rtr-cap-tlv"
                                                    return self.rtr_cap_tlv

                                                if (child_yang_name == "sr-algo-tlv"):
                                                    if (self.sr_algo_tlv is None):
                                                        self.sr_algo_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv()
                                                        self.sr_algo_tlv.parent = self
                                                        self._children_name_map["sr_algo_tlv"] = "sr-algo-tlv"
                                                    return self.sr_algo_tlv

                                                if (child_yang_name == "sr-range-tlv"):
                                                    if (self.sr_range_tlv is None):
                                                        self.sr_range_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv()
                                                        self.sr_range_tlv.parent = self
                                                        self._children_name_map["sr_range_tlv"] = "sr-range-tlv"
                                                    return self.sr_range_tlv

                                                if (child_yang_name == "unknown-tlv"):
                                                    if (self.unknown_tlv is None):
                                                        self.unknown_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv()
                                                        self.unknown_tlv.parent = self
                                                        self._children_name_map["unknown_tlv"] = "unknown-tlv"
                                                    return self.unknown_tlv

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "pcedtlv" or name == "rtr-cap-tlv" or name == "sr-algo-tlv" or name == "sr-range-tlv" or name == "unknown-tlv" or name == "ritlv-internal-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ritlv-internal-type"):
                                                    self.ritlv_internal_type = value
                                                    self.ritlv_internal_type.value_namespace = name_space
                                                    self.ritlv_internal_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.opaque_ritlv:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.opaque_ri_interface_name.is_set or
                                                self.opaque_rilsa_scope.is_set)

                                        def has_operation(self):
                                            for c in self.opaque_ritlv:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.opaque_ri_interface_name.yfilter != YFilter.not_set or
                                                self.opaque_rilsa_scope.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "opaque-router-info-lsa-type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.opaque_ri_interface_name.is_set or self.opaque_ri_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.opaque_ri_interface_name.get_name_leafdata())
                                            if (self.opaque_rilsa_scope.is_set or self.opaque_rilsa_scope.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.opaque_rilsa_scope.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "opaque-ritlv"):
                                                for c in self.opaque_ritlv:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.opaque_ritlv.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "opaque-ritlv" or name == "opaque-ri-interface-name" or name == "opaque-rilsa-scope"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "opaque-ri-interface-name"):
                                                self.opaque_ri_interface_name = value
                                                self.opaque_ri_interface_name.value_namespace = name_space
                                                self.opaque_ri_interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "opaque-rilsa-scope"):
                                                self.opaque_rilsa_scope = value
                                                self.opaque_rilsa_scope.value_namespace = name_space
                                                self.opaque_rilsa_scope.value_namespace_prefix = name_space_prefix


                                    class OpaqueEpLsaType(Entity):
                                        """
                                        Extende Prefix LSA type
                                        
                                        .. attribute:: tlv
                                        
                                        	List of TLVs
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__init__()

                                            self.yang_name = "opaque-ep-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"

                                            self.tlv = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__setattr__(name, value)


                                        class Tlv(Entity):
                                            """
                                            List of TLVs
                                            
                                            .. attribute:: mpls_dste_link
                                            
                                            	MPLS DS\-TE supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: mpls_router_id
                                            
                                            	MPLS\-TE Router ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: te_link_sub_tlv
                                            
                                            	List of Sub\-TLVs
                                            	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv>`
                                            
                                            .. attribute:: tlv_data
                                            
                                            	TLV direct data
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tlv_length
                                            
                                            	Length of top\-level TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: tlv_type
                                            
                                            	Type of top\-level TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "opaque-ep-lsa-type"

                                                self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                self.te_link_sub_tlv = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("mpls_dste_link",
                                                                "mpls_router_id",
                                                                "tlv_data",
                                                                "tlv_length",
                                                                "tlv_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__setattr__(name, value)


                                            class TeLinkSubTlv(Entity):
                                                """
                                                List of Sub\-TLVs
                                                
                                                .. attribute:: sub_tlv_length
                                                
                                                	Length of sub TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sub_tlv_type
                                                
                                                	Type of sub TLV
                                                	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                
                                                .. attribute:: sub_tlv_value
                                                
                                                	Value of sub TLV
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                    self.yang_name = "te-link-sub-tlv"
                                                    self.yang_parent_name = "tlv"

                                                    self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                    self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                    self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("sub_tlv_length",
                                                                    "sub_tlv_type",
                                                                    "sub_tlv_value") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.sub_tlv_length.is_set or
                                                        self.sub_tlv_type.is_set or
                                                        self.sub_tlv_value.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.sub_tlv_length.yfilter != YFilter.not_set or
                                                        self.sub_tlv_type.yfilter != YFilter.not_set or
                                                        self.sub_tlv_value.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "te-link-sub-tlv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.sub_tlv_length.is_set or self.sub_tlv_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sub_tlv_length.get_name_leafdata())
                                                    if (self.sub_tlv_type.is_set or self.sub_tlv_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sub_tlv_type.get_name_leafdata())
                                                    if (self.sub_tlv_value.is_set or self.sub_tlv_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sub_tlv_value.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "sub-tlv-length" or name == "sub-tlv-type" or name == "sub-tlv-value"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "sub-tlv-length"):
                                                        self.sub_tlv_length = value
                                                        self.sub_tlv_length.value_namespace = name_space
                                                        self.sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sub-tlv-type"):
                                                        self.sub_tlv_type = value
                                                        self.sub_tlv_type.value_namespace = name_space
                                                        self.sub_tlv_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sub-tlv-value"):
                                                        self.sub_tlv_value = value
                                                        self.sub_tlv_value.value_namespace = name_space
                                                        self.sub_tlv_value.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.te_link_sub_tlv:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.mpls_dste_link.is_set or
                                                    self.mpls_router_id.is_set or
                                                    self.tlv_data.is_set or
                                                    self.tlv_length.is_set or
                                                    self.tlv_type.is_set)

                                            def has_operation(self):
                                                for c in self.te_link_sub_tlv:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.mpls_dste_link.yfilter != YFilter.not_set or
                                                    self.mpls_router_id.yfilter != YFilter.not_set or
                                                    self.tlv_data.yfilter != YFilter.not_set or
                                                    self.tlv_length.yfilter != YFilter.not_set or
                                                    self.tlv_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.mpls_dste_link.is_set or self.mpls_dste_link.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mpls_dste_link.get_name_leafdata())
                                                if (self.mpls_router_id.is_set or self.mpls_router_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mpls_router_id.get_name_leafdata())
                                                if (self.tlv_data.is_set or self.tlv_data.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tlv_data.get_name_leafdata())
                                                if (self.tlv_length.is_set or self.tlv_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tlv_length.get_name_leafdata())
                                                if (self.tlv_type.is_set or self.tlv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tlv_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "te-link-sub-tlv"):
                                                    for c in self.te_link_sub_tlv:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.te_link_sub_tlv.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "te-link-sub-tlv" or name == "mpls-dste-link" or name == "mpls-router-id" or name == "tlv-data" or name == "tlv-length" or name == "tlv-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "mpls-dste-link"):
                                                    self.mpls_dste_link = value
                                                    self.mpls_dste_link.value_namespace = name_space
                                                    self.mpls_dste_link.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mpls-router-id"):
                                                    self.mpls_router_id = value
                                                    self.mpls_router_id.value_namespace = name_space
                                                    self.mpls_router_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tlv-data"):
                                                    self.tlv_data = value
                                                    self.tlv_data.value_namespace = name_space
                                                    self.tlv_data.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tlv-length"):
                                                    self.tlv_length = value
                                                    self.tlv_length.value_namespace = name_space
                                                    self.tlv_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tlv-type"):
                                                    self.tlv_type = value
                                                    self.tlv_type.value_namespace = name_space
                                                    self.tlv_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.tlv:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.tlv:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "opaque-ep-lsa-type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tlv"):
                                                for c in self.tlv:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.tlv.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tlv"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class OpaqueElLsaType(Entity):
                                        """
                                        Extended Link LSA type
                                        
                                        .. attribute:: tlv
                                        
                                        	List of TLVs
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__init__()

                                            self.yang_name = "opaque-el-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"

                                            self.tlv = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__setattr__(name, value)


                                        class Tlv(Entity):
                                            """
                                            List of TLVs
                                            
                                            .. attribute:: mpls_dste_link
                                            
                                            	MPLS DS\-TE supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: mpls_router_id
                                            
                                            	MPLS\-TE Router ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: te_link_sub_tlv
                                            
                                            	List of Sub\-TLVs
                                            	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv>`
                                            
                                            .. attribute:: tlv_data
                                            
                                            	TLV direct data
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tlv_length
                                            
                                            	Length of top\-level TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: tlv_type
                                            
                                            	Type of top\-level TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "opaque-el-lsa-type"

                                                self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                self.te_link_sub_tlv = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("mpls_dste_link",
                                                                "mpls_router_id",
                                                                "tlv_data",
                                                                "tlv_length",
                                                                "tlv_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__setattr__(name, value)


                                            class TeLinkSubTlv(Entity):
                                                """
                                                List of Sub\-TLVs
                                                
                                                .. attribute:: sub_tlv_length
                                                
                                                	Length of sub TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sub_tlv_type
                                                
                                                	Type of sub TLV
                                                	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                
                                                .. attribute:: sub_tlv_value
                                                
                                                	Value of sub TLV
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                    self.yang_name = "te-link-sub-tlv"
                                                    self.yang_parent_name = "tlv"

                                                    self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                    self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                    self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("sub_tlv_length",
                                                                    "sub_tlv_type",
                                                                    "sub_tlv_value") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.sub_tlv_length.is_set or
                                                        self.sub_tlv_type.is_set or
                                                        self.sub_tlv_value.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.sub_tlv_length.yfilter != YFilter.not_set or
                                                        self.sub_tlv_type.yfilter != YFilter.not_set or
                                                        self.sub_tlv_value.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "te-link-sub-tlv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.sub_tlv_length.is_set or self.sub_tlv_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sub_tlv_length.get_name_leafdata())
                                                    if (self.sub_tlv_type.is_set or self.sub_tlv_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sub_tlv_type.get_name_leafdata())
                                                    if (self.sub_tlv_value.is_set or self.sub_tlv_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sub_tlv_value.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "sub-tlv-length" or name == "sub-tlv-type" or name == "sub-tlv-value"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "sub-tlv-length"):
                                                        self.sub_tlv_length = value
                                                        self.sub_tlv_length.value_namespace = name_space
                                                        self.sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sub-tlv-type"):
                                                        self.sub_tlv_type = value
                                                        self.sub_tlv_type.value_namespace = name_space
                                                        self.sub_tlv_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sub-tlv-value"):
                                                        self.sub_tlv_value = value
                                                        self.sub_tlv_value.value_namespace = name_space
                                                        self.sub_tlv_value.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.te_link_sub_tlv:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.mpls_dste_link.is_set or
                                                    self.mpls_router_id.is_set or
                                                    self.tlv_data.is_set or
                                                    self.tlv_length.is_set or
                                                    self.tlv_type.is_set)

                                            def has_operation(self):
                                                for c in self.te_link_sub_tlv:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.mpls_dste_link.yfilter != YFilter.not_set or
                                                    self.mpls_router_id.yfilter != YFilter.not_set or
                                                    self.tlv_data.yfilter != YFilter.not_set or
                                                    self.tlv_length.yfilter != YFilter.not_set or
                                                    self.tlv_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.mpls_dste_link.is_set or self.mpls_dste_link.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mpls_dste_link.get_name_leafdata())
                                                if (self.mpls_router_id.is_set or self.mpls_router_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mpls_router_id.get_name_leafdata())
                                                if (self.tlv_data.is_set or self.tlv_data.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tlv_data.get_name_leafdata())
                                                if (self.tlv_length.is_set or self.tlv_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tlv_length.get_name_leafdata())
                                                if (self.tlv_type.is_set or self.tlv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tlv_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "te-link-sub-tlv"):
                                                    for c in self.te_link_sub_tlv:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.te_link_sub_tlv.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "te-link-sub-tlv" or name == "mpls-dste-link" or name == "mpls-router-id" or name == "tlv-data" or name == "tlv-length" or name == "tlv-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "mpls-dste-link"):
                                                    self.mpls_dste_link = value
                                                    self.mpls_dste_link.value_namespace = name_space
                                                    self.mpls_dste_link.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mpls-router-id"):
                                                    self.mpls_router_id = value
                                                    self.mpls_router_id.value_namespace = name_space
                                                    self.mpls_router_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tlv-data"):
                                                    self.tlv_data = value
                                                    self.tlv_data.value_namespace = name_space
                                                    self.tlv_data.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tlv-length"):
                                                    self.tlv_length = value
                                                    self.tlv_length.value_namespace = name_space
                                                    self.tlv_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tlv-type"):
                                                    self.tlv_type = value
                                                    self.tlv_type.value_namespace = name_space
                                                    self.tlv_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.tlv:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.tlv:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "opaque-el-lsa-type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tlv"):
                                                for c in self.tlv:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.tlv.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tlv"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.internal_lsa_type.is_set or
                                            (self.external_lsa_type is not None and self.external_lsa_type.has_data()) or
                                            (self.network_lsa_type is not None and self.network_lsa_type.has_data()) or
                                            (self.opaque_el_lsa_type is not None and self.opaque_el_lsa_type.has_data()) or
                                            (self.opaque_ep_lsa_type is not None and self.opaque_ep_lsa_type.has_data()) or
                                            (self.opaque_grace_lsa is not None and self.opaque_grace_lsa.has_data()) or
                                            (self.opaque_link_lsa_type is not None and self.opaque_link_lsa_type.has_data()) or
                                            (self.opaque_mpls_te_lsa_type is not None and self.opaque_mpls_te_lsa_type.has_data()) or
                                            (self.opaque_router_info_lsa_type is not None and self.opaque_router_info_lsa_type.has_data()) or
                                            (self.router_lsa_type is not None and self.router_lsa_type.has_data()) or
                                            (self.summary_lsa_type is not None and self.summary_lsa_type.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_lsa_type.yfilter != YFilter.not_set or
                                            (self.external_lsa_type is not None and self.external_lsa_type.has_operation()) or
                                            (self.network_lsa_type is not None and self.network_lsa_type.has_operation()) or
                                            (self.opaque_el_lsa_type is not None and self.opaque_el_lsa_type.has_operation()) or
                                            (self.opaque_ep_lsa_type is not None and self.opaque_ep_lsa_type.has_operation()) or
                                            (self.opaque_grace_lsa is not None and self.opaque_grace_lsa.has_operation()) or
                                            (self.opaque_link_lsa_type is not None and self.opaque_link_lsa_type.has_operation()) or
                                            (self.opaque_mpls_te_lsa_type is not None and self.opaque_mpls_te_lsa_type.has_operation()) or
                                            (self.opaque_router_info_lsa_type is not None and self.opaque_router_info_lsa_type.has_operation()) or
                                            (self.router_lsa_type is not None and self.router_lsa_type.has_operation()) or
                                            (self.summary_lsa_type is not None and self.summary_lsa_type.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lsa-internal-data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_lsa_type.is_set or self.internal_lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_lsa_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "external-lsa-type"):
                                            if (self.external_lsa_type is None):
                                                self.external_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType()
                                                self.external_lsa_type.parent = self
                                                self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                            return self.external_lsa_type

                                        if (child_yang_name == "network-lsa-type"):
                                            if (self.network_lsa_type is None):
                                                self.network_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType()
                                                self.network_lsa_type.parent = self
                                                self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                            return self.network_lsa_type

                                        if (child_yang_name == "opaque-el-lsa-type"):
                                            if (self.opaque_el_lsa_type is None):
                                                self.opaque_el_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType()
                                                self.opaque_el_lsa_type.parent = self
                                                self._children_name_map["opaque_el_lsa_type"] = "opaque-el-lsa-type"
                                            return self.opaque_el_lsa_type

                                        if (child_yang_name == "opaque-ep-lsa-type"):
                                            if (self.opaque_ep_lsa_type is None):
                                                self.opaque_ep_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType()
                                                self.opaque_ep_lsa_type.parent = self
                                                self._children_name_map["opaque_ep_lsa_type"] = "opaque-ep-lsa-type"
                                            return self.opaque_ep_lsa_type

                                        if (child_yang_name == "opaque-grace-lsa"):
                                            if (self.opaque_grace_lsa is None):
                                                self.opaque_grace_lsa = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa()
                                                self.opaque_grace_lsa.parent = self
                                                self._children_name_map["opaque_grace_lsa"] = "opaque-grace-lsa"
                                            return self.opaque_grace_lsa

                                        if (child_yang_name == "opaque-link-lsa-type"):
                                            if (self.opaque_link_lsa_type is None):
                                                self.opaque_link_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType()
                                                self.opaque_link_lsa_type.parent = self
                                                self._children_name_map["opaque_link_lsa_type"] = "opaque-link-lsa-type"
                                            return self.opaque_link_lsa_type

                                        if (child_yang_name == "opaque-mpls-te-lsa-type"):
                                            if (self.opaque_mpls_te_lsa_type is None):
                                                self.opaque_mpls_te_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType()
                                                self.opaque_mpls_te_lsa_type.parent = self
                                                self._children_name_map["opaque_mpls_te_lsa_type"] = "opaque-mpls-te-lsa-type"
                                            return self.opaque_mpls_te_lsa_type

                                        if (child_yang_name == "opaque-router-info-lsa-type"):
                                            if (self.opaque_router_info_lsa_type is None):
                                                self.opaque_router_info_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType()
                                                self.opaque_router_info_lsa_type.parent = self
                                                self._children_name_map["opaque_router_info_lsa_type"] = "opaque-router-info-lsa-type"
                                            return self.opaque_router_info_lsa_type

                                        if (child_yang_name == "router-lsa-type"):
                                            if (self.router_lsa_type is None):
                                                self.router_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType()
                                                self.router_lsa_type.parent = self
                                                self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                            return self.router_lsa_type

                                        if (child_yang_name == "summary-lsa-type"):
                                            if (self.summary_lsa_type is None):
                                                self.summary_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType()
                                                self.summary_lsa_type.parent = self
                                                self._children_name_map["summary_lsa_type"] = "summary-lsa-type"
                                            return self.summary_lsa_type

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "external-lsa-type" or name == "network-lsa-type" or name == "opaque-el-lsa-type" or name == "opaque-ep-lsa-type" or name == "opaque-grace-lsa" or name == "opaque-link-lsa-type" or name == "opaque-mpls-te-lsa-type" or name == "opaque-router-info-lsa-type" or name == "router-lsa-type" or name == "summary-lsa-type" or name == "internal-lsa-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-lsa-type"):
                                            self.internal_lsa_type = value
                                            self.internal_lsa_type.value_namespace = name_space
                                            self.internal_lsa_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.advertising_router.is_set or
                                        self.area_id.is_set or
                                        self.interface_name.is_set or
                                        self.ls_id.is_set or
                                        self.ls_type.is_set or
                                        (self.lsa_detail_data is not None and self.lsa_detail_data.has_data()) or
                                        (self.lsa_header is not None and self.lsa_header.has_data()) or
                                        (self.lsa_internal_data is not None and self.lsa_internal_data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.advertising_router.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.ls_id.yfilter != YFilter.not_set or
                                        self.ls_type.yfilter != YFilter.not_set or
                                        (self.lsa_detail_data is not None and self.lsa_detail_data.has_operation()) or
                                        (self.lsa_header is not None and self.lsa_header.has_operation()) or
                                        (self.lsa_internal_data is not None and self.lsa_internal_data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "lsa" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.ls_id.is_set or self.ls_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ls_id.get_name_leafdata())
                                    if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ls_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "lsa-detail-data"):
                                        if (self.lsa_detail_data is None):
                                            self.lsa_detail_data = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData()
                                            self.lsa_detail_data.parent = self
                                            self._children_name_map["lsa_detail_data"] = "lsa-detail-data"
                                        return self.lsa_detail_data

                                    if (child_yang_name == "lsa-header"):
                                        if (self.lsa_header is None):
                                            self.lsa_header = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                        return self.lsa_header

                                    if (child_yang_name == "lsa-internal-data"):
                                        if (self.lsa_internal_data is None):
                                            self.lsa_internal_data = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData()
                                            self.lsa_internal_data.parent = self
                                            self._children_name_map["lsa_internal_data"] = "lsa-internal-data"
                                        return self.lsa_internal_data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lsa-detail-data" or name == "lsa-header" or name == "lsa-internal-data" or name == "advertising-router" or name == "area-id" or name == "interface-name" or name == "ls-id" or name == "ls-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "advertising-router"):
                                        self.advertising_router = value
                                        self.advertising_router.value_namespace = name_space
                                        self.advertising_router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ls-id"):
                                        self.ls_id = value
                                        self.ls_id.value_namespace = name_space
                                        self.ls_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ls-type"):
                                        self.ls_type = value
                                        self.ls_type.value_namespace = name_space
                                        self.ls_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.lsa:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.lsa:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "lsas" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "lsa"):
                                    for c in self.lsa:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.lsa.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "lsa"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class LsaSummaries(Entity):
                            """
                            Link state advertisement summary table
                            
                            .. attribute:: lsa_summary
                            
                            	LSA summary information
                            	**type**\: list of    :py:class:`LsaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries, self).__init__()

                                self.yang_name = "lsa-summaries"
                                self.yang_parent_name = "database"

                                self.lsa_summary = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries, self).__setattr__(name, value)


                            class LsaSummary(Entity):
                                """
                                LSA summary information
                                
                                .. attribute:: advertising_router
                                
                                	Advertising Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: external_tag
                                
                                	Route Tag
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: link_count
                                
                                	Number of links
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ls_id
                                
                                	Link state ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ls_type
                                
                                	Link state type
                                	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                                
                                .. attribute:: lsa_header
                                
                                	LSA header information
                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary.LsaHeader>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary, self).__init__()

                                    self.yang_name = "lsa-summary"
                                    self.yang_parent_name = "lsa-summaries"

                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.external_tag = YLeaf(YType.uint32, "external-tag")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.link_count = YLeaf(YType.uint16, "link-count")

                                    self.ls_id = YLeaf(YType.str, "ls-id")

                                    self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                    self.lsa_header = Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary.LsaHeader()
                                    self.lsa_header.parent = self
                                    self._children_name_map["lsa_header"] = "lsa-header"
                                    self._children_yang_names.add("lsa-header")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("advertising_router",
                                                    "area_id",
                                                    "external_tag",
                                                    "interface_name",
                                                    "link_count",
                                                    "ls_id",
                                                    "ls_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary, self).__setattr__(name, value)


                                class LsaHeader(Entity):
                                    """
                                    LSA header information
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Router ID of Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: checksum
                                    
                                    	Checksum value
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: dn_age_lsa
                                    
                                    	If true, Do Not Age this LSA
                                    	**type**\:  bool
                                    
                                    .. attribute:: ls_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: lsa_age
                                    
                                    	LSA's Age (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsa_area_id
                                    
                                    	Area ID in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: lsid
                                    
                                    	LS ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: nsf
                                    
                                    	If true,  LSA received from neighbor during NSF
                                    	**type**\:  bool
                                    
                                    .. attribute:: sequence_number
                                    
                                    	Current Sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary.LsaHeader, self).__init__()

                                        self.yang_name = "lsa-header"
                                        self.yang_parent_name = "lsa-summary"

                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                        self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                        self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                        self.lsid = YLeaf(YType.str, "lsid")

                                        self.nsf = YLeaf(YType.boolean, "nsf")

                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("advertising_router",
                                                        "checksum",
                                                        "dn_age_lsa",
                                                        "ls_type",
                                                        "lsa_age",
                                                        "lsa_area_id",
                                                        "lsid",
                                                        "nsf",
                                                        "sequence_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary.LsaHeader, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary.LsaHeader, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.advertising_router.is_set or
                                            self.checksum.is_set or
                                            self.dn_age_lsa.is_set or
                                            self.ls_type.is_set or
                                            self.lsa_age.is_set or
                                            self.lsa_area_id.is_set or
                                            self.lsid.is_set or
                                            self.nsf.is_set or
                                            self.sequence_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.advertising_router.yfilter != YFilter.not_set or
                                            self.checksum.yfilter != YFilter.not_set or
                                            self.dn_age_lsa.yfilter != YFilter.not_set or
                                            self.ls_type.yfilter != YFilter.not_set or
                                            self.lsa_age.yfilter != YFilter.not_set or
                                            self.lsa_area_id.yfilter != YFilter.not_set or
                                            self.lsid.yfilter != YFilter.not_set or
                                            self.nsf.yfilter != YFilter.not_set or
                                            self.sequence_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lsa-header" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                        if (self.checksum.is_set or self.checksum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.checksum.get_name_leafdata())
                                        if (self.dn_age_lsa.is_set or self.dn_age_lsa.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dn_age_lsa.get_name_leafdata())
                                        if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ls_type.get_name_leafdata())
                                        if (self.lsa_age.is_set or self.lsa_age.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_age.get_name_leafdata())
                                        if (self.lsa_area_id.is_set or self.lsa_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_area_id.get_name_leafdata())
                                        if (self.lsid.is_set or self.lsid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsid.get_name_leafdata())
                                        if (self.nsf.is_set or self.nsf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsf.get_name_leafdata())
                                        if (self.sequence_number.is_set or self.sequence_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "advertising-router" or name == "checksum" or name == "dn-age-lsa" or name == "ls-type" or name == "lsa-age" or name == "lsa-area-id" or name == "lsid" or name == "nsf" or name == "sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "advertising-router"):
                                            self.advertising_router = value
                                            self.advertising_router.value_namespace = name_space
                                            self.advertising_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "checksum"):
                                            self.checksum = value
                                            self.checksum.value_namespace = name_space
                                            self.checksum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dn-age-lsa"):
                                            self.dn_age_lsa = value
                                            self.dn_age_lsa.value_namespace = name_space
                                            self.dn_age_lsa.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ls-type"):
                                            self.ls_type = value
                                            self.ls_type.value_namespace = name_space
                                            self.ls_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-age"):
                                            self.lsa_age = value
                                            self.lsa_age.value_namespace = name_space
                                            self.lsa_age.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-area-id"):
                                            self.lsa_area_id = value
                                            self.lsa_area_id.value_namespace = name_space
                                            self.lsa_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsid"):
                                            self.lsid = value
                                            self.lsid.value_namespace = name_space
                                            self.lsid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsf"):
                                            self.nsf = value
                                            self.nsf.value_namespace = name_space
                                            self.nsf.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number"):
                                            self.sequence_number = value
                                            self.sequence_number.value_namespace = name_space
                                            self.sequence_number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.advertising_router.is_set or
                                        self.area_id.is_set or
                                        self.external_tag.is_set or
                                        self.interface_name.is_set or
                                        self.link_count.is_set or
                                        self.ls_id.is_set or
                                        self.ls_type.is_set or
                                        (self.lsa_header is not None and self.lsa_header.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.advertising_router.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.external_tag.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.link_count.yfilter != YFilter.not_set or
                                        self.ls_id.yfilter != YFilter.not_set or
                                        self.ls_type.yfilter != YFilter.not_set or
                                        (self.lsa_header is not None and self.lsa_header.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "lsa-summary" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.external_tag.is_set or self.external_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.external_tag.get_name_leafdata())
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.link_count.is_set or self.link_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.link_count.get_name_leafdata())
                                    if (self.ls_id.is_set or self.ls_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ls_id.get_name_leafdata())
                                    if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ls_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "lsa-header"):
                                        if (self.lsa_header is None):
                                            self.lsa_header = Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                        return self.lsa_header

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lsa-header" or name == "advertising-router" or name == "area-id" or name == "external-tag" or name == "interface-name" or name == "link-count" or name == "ls-id" or name == "ls-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "advertising-router"):
                                        self.advertising_router = value
                                        self.advertising_router.value_namespace = name_space
                                        self.advertising_router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "external-tag"):
                                        self.external_tag = value
                                        self.external_tag.value_namespace = name_space
                                        self.external_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "link-count"):
                                        self.link_count = value
                                        self.link_count.value_namespace = name_space
                                        self.link_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ls-id"):
                                        self.ls_id = value
                                        self.ls_id.value_namespace = name_space
                                        self.ls_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ls-type"):
                                        self.ls_type = value
                                        self.ls_type.value_namespace = name_space
                                        self.ls_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.lsa_summary:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.lsa_summary:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "lsa-summaries" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "lsa-summary"):
                                    for c in self.lsa_summary:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.lsa_summary.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "lsa-summary"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.database_areas is not None and self.database_areas.has_data()) or
                                (self.database_summaries is not None and self.database_summaries.has_data()) or
                                (self.database_summary_as is not None and self.database_summary_as.has_data()) or
                                (self.lsa_summaries is not None and self.lsa_summaries.has_data()) or
                                (self.lsas is not None and self.lsas.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.database_areas is not None and self.database_areas.has_operation()) or
                                (self.database_summaries is not None and self.database_summaries.has_operation()) or
                                (self.database_summary_as is not None and self.database_summary_as.has_operation()) or
                                (self.lsa_summaries is not None and self.lsa_summaries.has_operation()) or
                                (self.lsas is not None and self.lsas.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "database" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "database-areas"):
                                if (self.database_areas is None):
                                    self.database_areas = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas()
                                    self.database_areas.parent = self
                                    self._children_name_map["database_areas"] = "database-areas"
                                return self.database_areas

                            if (child_yang_name == "database-summaries"):
                                if (self.database_summaries is None):
                                    self.database_summaries = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries()
                                    self.database_summaries.parent = self
                                    self._children_name_map["database_summaries"] = "database-summaries"
                                return self.database_summaries

                            if (child_yang_name == "database-summary-as"):
                                if (self.database_summary_as is None):
                                    self.database_summary_as = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs()
                                    self.database_summary_as.parent = self
                                    self._children_name_map["database_summary_as"] = "database-summary-as"
                                return self.database_summary_as

                            if (child_yang_name == "lsa-summaries"):
                                if (self.lsa_summaries is None):
                                    self.lsa_summaries = Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries()
                                    self.lsa_summaries.parent = self
                                    self._children_name_map["lsa_summaries"] = "lsa-summaries"
                                return self.lsa_summaries

                            if (child_yang_name == "lsas"):
                                if (self.lsas is None):
                                    self.lsas = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas()
                                    self.lsas.parent = self
                                    self._children_name_map["lsas"] = "lsas"
                                return self.lsas

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "database-areas" or name == "database-summaries" or name == "database-summary-as" or name == "lsa-summaries" or name == "lsas"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SummaryPrefixes(Entity):
                        """
                        Summary prefix table
                        
                        .. attribute:: summary_prefix
                        
                        	Summary prefix information
                        	**type**\: list of    :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes, self).__init__()

                            self.yang_name = "summary-prefixes"
                            self.yang_parent_name = "vrf"

                            self.summary_prefix = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes, self).__setattr__(name, value)


                        class SummaryPrefix(Entity):
                            """
                            Summary prefix information
                            
                            .. attribute:: netmask
                            
                            	Summary Mask
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix
                            
                            	Summary Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: summary_mask
                            
                            	Summary Netmask
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: summary_metric
                            
                            	Cost of Summary
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: summary_metric_type
                            
                            	Type of Metric
                            	**type**\:   :py:class:`ExMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.ExMetric>`
                            
                            .. attribute:: summary_prefix
                            
                            	Summary prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: summary_tag
                            
                            	Tag associated with this summary prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix, self).__init__()

                                self.yang_name = "summary-prefix"
                                self.yang_parent_name = "summary-prefixes"

                                self.netmask = YLeaf(YType.str, "netmask")

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.summary_mask = YLeaf(YType.str, "summary-mask")

                                self.summary_metric = YLeaf(YType.uint32, "summary-metric")

                                self.summary_metric_type = YLeaf(YType.enumeration, "summary-metric-type")

                                self.summary_prefix = YLeaf(YType.str, "summary-prefix")

                                self.summary_tag = YLeaf(YType.uint32, "summary-tag")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("netmask",
                                                "prefix",
                                                "summary_mask",
                                                "summary_metric",
                                                "summary_metric_type",
                                                "summary_prefix",
                                                "summary_tag") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.netmask.is_set or
                                    self.prefix.is_set or
                                    self.summary_mask.is_set or
                                    self.summary_metric.is_set or
                                    self.summary_metric_type.is_set or
                                    self.summary_prefix.is_set or
                                    self.summary_tag.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.netmask.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.summary_mask.yfilter != YFilter.not_set or
                                    self.summary_metric.yfilter != YFilter.not_set or
                                    self.summary_metric_type.yfilter != YFilter.not_set or
                                    self.summary_prefix.yfilter != YFilter.not_set or
                                    self.summary_tag.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "summary-prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.netmask.is_set or self.netmask.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.netmask.get_name_leafdata())
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.summary_mask.is_set or self.summary_mask.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_mask.get_name_leafdata())
                                if (self.summary_metric.is_set or self.summary_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_metric.get_name_leafdata())
                                if (self.summary_metric_type.is_set or self.summary_metric_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_metric_type.get_name_leafdata())
                                if (self.summary_prefix.is_set or self.summary_prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_prefix.get_name_leafdata())
                                if (self.summary_tag.is_set or self.summary_tag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_tag.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "netmask" or name == "prefix" or name == "summary-mask" or name == "summary-metric" or name == "summary-metric-type" or name == "summary-prefix" or name == "summary-tag"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "netmask"):
                                    self.netmask = value
                                    self.netmask.value_namespace = name_space
                                    self.netmask.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-mask"):
                                    self.summary_mask = value
                                    self.summary_mask.value_namespace = name_space
                                    self.summary_mask.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-metric"):
                                    self.summary_metric = value
                                    self.summary_metric.value_namespace = name_space
                                    self.summary_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-metric-type"):
                                    self.summary_metric_type = value
                                    self.summary_metric_type.value_namespace = name_space
                                    self.summary_metric_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-prefix"):
                                    self.summary_prefix = value
                                    self.summary_prefix.value_namespace = name_space
                                    self.summary_prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-tag"):
                                    self.summary_tag = value
                                    self.summary_tag.value_namespace = name_space
                                    self.summary_tag.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.summary_prefix:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.summary_prefix:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "summary-prefixes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "summary-prefix"):
                                for c in self.summary_prefix:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.summary_prefix.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "summary-prefix"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class AreaStatistics(Entity):
                        """
                        Container for Statistics
                        
                        .. attribute:: interface_stats_entries
                        
                        	Statistics innformation Interface table
                        	**type**\:   :py:class:`InterfaceStatsEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics, self).__init__()

                            self.yang_name = "area-statistics"
                            self.yang_parent_name = "vrf"

                            self.interface_stats_entries = Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries()
                            self.interface_stats_entries.parent = self
                            self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                            self._children_yang_names.add("interface-stats-entries")


                        class InterfaceStatsEntries(Entity):
                            """
                            Statistics innformation Interface table
                            
                            .. attribute:: interface_stats_entry
                            
                            	Statistics information for a specific interface
                            	**type**\: list of    :py:class:`InterfaceStatsEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries, self).__init__()

                                self.yang_name = "interface-stats-entries"
                                self.yang_parent_name = "area-statistics"

                                self.interface_stats_entry = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries, self).__setattr__(name, value)


                            class InterfaceStatsEntry(Entity):
                                """
                                Statistics information for a specific interface
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: handle
                                
                                	interface handle type
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: if_entry
                                
                                	interface entry
                                	**type**\: list of    :py:class:`IfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry>`
                                
                                .. attribute:: if_name_str
                                
                                	interface name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__init__()

                                    self.yang_name = "interface-stats-entry"
                                    self.yang_parent_name = "interface-stats-entries"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.handle = YLeaf(YType.str, "handle")

                                    self.if_name_str = YLeaf(YType.str, "if-name-str")

                                    self.if_entry = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "handle",
                                                    "if_name_str") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__setattr__(name, value)


                                class IfEntry(Entity):
                                    """
                                    interface entry
                                    
                                    .. attribute:: area_id
                                    
                                    	OSPF area id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_id_str
                                    
                                    	OSPF aread id string
                                    	**type**\:  str
                                    
                                    .. attribute:: if_stat
                                    
                                    	OSPF interface statistics
                                    	**type**\: list of    :py:class:`IfStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat>`
                                    
                                    .. attribute:: madj_intf
                                    
                                    	OSPF madj interface
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__init__()

                                        self.yang_name = "if-entry"
                                        self.yang_parent_name = "interface-stats-entry"

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.area_id_str = YLeaf(YType.str, "area-id-str")

                                        self.madj_intf = YLeaf(YType.boolean, "madj-intf")

                                        self.if_stat = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("area_id",
                                                        "area_id_str",
                                                        "madj_intf") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__setattr__(name, value)


                                    class IfStat(Entity):
                                        """
                                        OSPF interface statistics
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__init__()

                                            self.yang_name = "if-stat"
                                            self.yang_parent_name = "if-entry"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "if-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.if_stat:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.area_id.is_set or
                                            self.area_id_str.is_set or
                                            self.madj_intf.is_set)

                                    def has_operation(self):
                                        for c in self.if_stat:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.area_id.yfilter != YFilter.not_set or
                                            self.area_id_str.yfilter != YFilter.not_set or
                                            self.madj_intf.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "if-entry" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id.get_name_leafdata())
                                        if (self.area_id_str.is_set or self.area_id_str.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id_str.get_name_leafdata())
                                        if (self.madj_intf.is_set or self.madj_intf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.madj_intf.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "if-stat"):
                                            for c in self.if_stat:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.if_stat.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "if-stat" or name == "area-id" or name == "area-id-str" or name == "madj-intf"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "area-id"):
                                            self.area_id = value
                                            self.area_id.value_namespace = name_space
                                            self.area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-id-str"):
                                            self.area_id_str = value
                                            self.area_id_str.value_namespace = name_space
                                            self.area_id_str.value_namespace_prefix = name_space_prefix
                                        if(value_path == "madj-intf"):
                                            self.madj_intf = value
                                            self.madj_intf.value_namespace = name_space
                                            self.madj_intf.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.if_entry:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.interface_name.is_set or
                                        self.handle.is_set or
                                        self.if_name_str.is_set)

                                def has_operation(self):
                                    for c in self.if_entry:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.handle.yfilter != YFilter.not_set or
                                        self.if_name_str.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface-stats-entry" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.handle.is_set or self.handle.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.handle.get_name_leafdata())
                                    if (self.if_name_str.is_set or self.if_name_str.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.if_name_str.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "if-entry"):
                                        for c in self.if_entry:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.if_entry.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "if-entry" or name == "interface-name" or name == "handle" or name == "if-name-str"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "handle"):
                                        self.handle = value
                                        self.handle.value_namespace = name_space
                                        self.handle.value_namespace_prefix = name_space_prefix
                                    if(value_path == "if-name-str"):
                                        self.if_name_str = value
                                        self.if_name_str.value_namespace = name_space
                                        self.if_name_str.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface_stats_entry:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.interface_stats_entry:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-stats-entries" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface-stats-entry"):
                                    for c in self.interface_stats_entry:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface_stats_entry.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-stats-entry"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.interface_stats_entries is not None and self.interface_stats_entries.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.interface_stats_entries is not None and self.interface_stats_entries.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "area-statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface-stats-entries"):
                                if (self.interface_stats_entries is None):
                                    self.interface_stats_entries = Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries()
                                    self.interface_stats_entries.parent = self
                                    self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                                return self.interface_stats_entries

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-stats-entries"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OspfSummary(Entity):
                        """
                        Fast\-reroute topology information
                        
                        .. attribute:: sa_lsa_cnt_type_7ase
                        
                        	sa lsa cnt type 7ase
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_8_ignore
                        
                        	sa lsa cnt type 8 ignore
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_ase
                        
                        	sa lsa cnt type ase
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_mospf
                        
                        	sa lsa cnt type mospf
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_net
                        
                        	sa lsa cnt type net
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_opq_area
                        
                        	sa lsa cnt type opq area
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_opq_as
                        
                        	sa lsa cnt type opq as
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_opq_link
                        
                        	sa lsa cnt type opq link
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_rtr
                        
                        	sa lsa cnt type rtr
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_sum_asb
                        
                        	sa lsa cnt type sum asb
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_sum_net
                        
                        	sa lsa cnt type sum net
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_areas
                        
                        	sa num areas
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_intf
                        
                        	sa num intf
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_intf_up
                        
                        	sa num intf up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_nbrs
                        
                        	sa num nbrs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_nbrs_up
                        
                        	sa num nbrs up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_slintf_up
                        
                        	sa num slintf up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_vintf_up
                        
                        	sa num vintf up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.OspfSummary, self).__init__()

                            self.yang_name = "ospf-summary"
                            self.yang_parent_name = "vrf"

                            self.sa_lsa_cnt_type_7ase = YLeaf(YType.uint32, "sa-lsa-cnt-type-7ase")

                            self.sa_lsa_cnt_type_8_ignore = YLeaf(YType.uint32, "sa-lsa-cnt-type-8-ignore")

                            self.sa_lsa_cnt_type_ase = YLeaf(YType.uint32, "sa-lsa-cnt-type-ase")

                            self.sa_lsa_cnt_type_mospf = YLeaf(YType.uint32, "sa-lsa-cnt-type-mospf")

                            self.sa_lsa_cnt_type_net = YLeaf(YType.uint32, "sa-lsa-cnt-type-net")

                            self.sa_lsa_cnt_type_opq_area = YLeaf(YType.uint32, "sa-lsa-cnt-type-opq-area")

                            self.sa_lsa_cnt_type_opq_as = YLeaf(YType.uint32, "sa-lsa-cnt-type-opq-as")

                            self.sa_lsa_cnt_type_opq_link = YLeaf(YType.uint32, "sa-lsa-cnt-type-opq-link")

                            self.sa_lsa_cnt_type_rtr = YLeaf(YType.uint32, "sa-lsa-cnt-type-rtr")

                            self.sa_lsa_cnt_type_sum_asb = YLeaf(YType.uint32, "sa-lsa-cnt-type-sum-asb")

                            self.sa_lsa_cnt_type_sum_net = YLeaf(YType.uint32, "sa-lsa-cnt-type-sum-net")

                            self.sa_num_areas = YLeaf(YType.uint32, "sa-num-areas")

                            self.sa_num_intf = YLeaf(YType.uint32, "sa-num-intf")

                            self.sa_num_intf_up = YLeaf(YType.uint32, "sa-num-intf-up")

                            self.sa_num_nbrs = YLeaf(YType.uint32, "sa-num-nbrs")

                            self.sa_num_nbrs_up = YLeaf(YType.uint32, "sa-num-nbrs-up")

                            self.sa_num_slintf_up = YLeaf(YType.uint32, "sa-num-slintf-up")

                            self.sa_num_vintf_up = YLeaf(YType.uint32, "sa-num-vintf-up")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("sa_lsa_cnt_type_7ase",
                                            "sa_lsa_cnt_type_8_ignore",
                                            "sa_lsa_cnt_type_ase",
                                            "sa_lsa_cnt_type_mospf",
                                            "sa_lsa_cnt_type_net",
                                            "sa_lsa_cnt_type_opq_area",
                                            "sa_lsa_cnt_type_opq_as",
                                            "sa_lsa_cnt_type_opq_link",
                                            "sa_lsa_cnt_type_rtr",
                                            "sa_lsa_cnt_type_sum_asb",
                                            "sa_lsa_cnt_type_sum_net",
                                            "sa_num_areas",
                                            "sa_num_intf",
                                            "sa_num_intf_up",
                                            "sa_num_nbrs",
                                            "sa_num_nbrs_up",
                                            "sa_num_slintf_up",
                                            "sa_num_vintf_up") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.OspfSummary, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.OspfSummary, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.sa_lsa_cnt_type_7ase.is_set or
                                self.sa_lsa_cnt_type_8_ignore.is_set or
                                self.sa_lsa_cnt_type_ase.is_set or
                                self.sa_lsa_cnt_type_mospf.is_set or
                                self.sa_lsa_cnt_type_net.is_set or
                                self.sa_lsa_cnt_type_opq_area.is_set or
                                self.sa_lsa_cnt_type_opq_as.is_set or
                                self.sa_lsa_cnt_type_opq_link.is_set or
                                self.sa_lsa_cnt_type_rtr.is_set or
                                self.sa_lsa_cnt_type_sum_asb.is_set or
                                self.sa_lsa_cnt_type_sum_net.is_set or
                                self.sa_num_areas.is_set or
                                self.sa_num_intf.is_set or
                                self.sa_num_intf_up.is_set or
                                self.sa_num_nbrs.is_set or
                                self.sa_num_nbrs_up.is_set or
                                self.sa_num_slintf_up.is_set or
                                self.sa_num_vintf_up.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.sa_lsa_cnt_type_7ase.yfilter != YFilter.not_set or
                                self.sa_lsa_cnt_type_8_ignore.yfilter != YFilter.not_set or
                                self.sa_lsa_cnt_type_ase.yfilter != YFilter.not_set or
                                self.sa_lsa_cnt_type_mospf.yfilter != YFilter.not_set or
                                self.sa_lsa_cnt_type_net.yfilter != YFilter.not_set or
                                self.sa_lsa_cnt_type_opq_area.yfilter != YFilter.not_set or
                                self.sa_lsa_cnt_type_opq_as.yfilter != YFilter.not_set or
                                self.sa_lsa_cnt_type_opq_link.yfilter != YFilter.not_set or
                                self.sa_lsa_cnt_type_rtr.yfilter != YFilter.not_set or
                                self.sa_lsa_cnt_type_sum_asb.yfilter != YFilter.not_set or
                                self.sa_lsa_cnt_type_sum_net.yfilter != YFilter.not_set or
                                self.sa_num_areas.yfilter != YFilter.not_set or
                                self.sa_num_intf.yfilter != YFilter.not_set or
                                self.sa_num_intf_up.yfilter != YFilter.not_set or
                                self.sa_num_nbrs.yfilter != YFilter.not_set or
                                self.sa_num_nbrs_up.yfilter != YFilter.not_set or
                                self.sa_num_slintf_up.yfilter != YFilter.not_set or
                                self.sa_num_vintf_up.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ospf-summary" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.sa_lsa_cnt_type_7ase.is_set or self.sa_lsa_cnt_type_7ase.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_lsa_cnt_type_7ase.get_name_leafdata())
                            if (self.sa_lsa_cnt_type_8_ignore.is_set or self.sa_lsa_cnt_type_8_ignore.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_lsa_cnt_type_8_ignore.get_name_leafdata())
                            if (self.sa_lsa_cnt_type_ase.is_set or self.sa_lsa_cnt_type_ase.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_lsa_cnt_type_ase.get_name_leafdata())
                            if (self.sa_lsa_cnt_type_mospf.is_set or self.sa_lsa_cnt_type_mospf.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_lsa_cnt_type_mospf.get_name_leafdata())
                            if (self.sa_lsa_cnt_type_net.is_set or self.sa_lsa_cnt_type_net.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_lsa_cnt_type_net.get_name_leafdata())
                            if (self.sa_lsa_cnt_type_opq_area.is_set or self.sa_lsa_cnt_type_opq_area.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_lsa_cnt_type_opq_area.get_name_leafdata())
                            if (self.sa_lsa_cnt_type_opq_as.is_set or self.sa_lsa_cnt_type_opq_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_lsa_cnt_type_opq_as.get_name_leafdata())
                            if (self.sa_lsa_cnt_type_opq_link.is_set or self.sa_lsa_cnt_type_opq_link.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_lsa_cnt_type_opq_link.get_name_leafdata())
                            if (self.sa_lsa_cnt_type_rtr.is_set or self.sa_lsa_cnt_type_rtr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_lsa_cnt_type_rtr.get_name_leafdata())
                            if (self.sa_lsa_cnt_type_sum_asb.is_set or self.sa_lsa_cnt_type_sum_asb.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_lsa_cnt_type_sum_asb.get_name_leafdata())
                            if (self.sa_lsa_cnt_type_sum_net.is_set or self.sa_lsa_cnt_type_sum_net.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_lsa_cnt_type_sum_net.get_name_leafdata())
                            if (self.sa_num_areas.is_set or self.sa_num_areas.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_num_areas.get_name_leafdata())
                            if (self.sa_num_intf.is_set or self.sa_num_intf.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_num_intf.get_name_leafdata())
                            if (self.sa_num_intf_up.is_set or self.sa_num_intf_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_num_intf_up.get_name_leafdata())
                            if (self.sa_num_nbrs.is_set or self.sa_num_nbrs.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_num_nbrs.get_name_leafdata())
                            if (self.sa_num_nbrs_up.is_set or self.sa_num_nbrs_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_num_nbrs_up.get_name_leafdata())
                            if (self.sa_num_slintf_up.is_set or self.sa_num_slintf_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_num_slintf_up.get_name_leafdata())
                            if (self.sa_num_vintf_up.is_set or self.sa_num_vintf_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_num_vintf_up.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sa-lsa-cnt-type-7ase" or name == "sa-lsa-cnt-type-8-ignore" or name == "sa-lsa-cnt-type-ase" or name == "sa-lsa-cnt-type-mospf" or name == "sa-lsa-cnt-type-net" or name == "sa-lsa-cnt-type-opq-area" or name == "sa-lsa-cnt-type-opq-as" or name == "sa-lsa-cnt-type-opq-link" or name == "sa-lsa-cnt-type-rtr" or name == "sa-lsa-cnt-type-sum-asb" or name == "sa-lsa-cnt-type-sum-net" or name == "sa-num-areas" or name == "sa-num-intf" or name == "sa-num-intf-up" or name == "sa-num-nbrs" or name == "sa-num-nbrs-up" or name == "sa-num-slintf-up" or name == "sa-num-vintf-up"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "sa-lsa-cnt-type-7ase"):
                                self.sa_lsa_cnt_type_7ase = value
                                self.sa_lsa_cnt_type_7ase.value_namespace = name_space
                                self.sa_lsa_cnt_type_7ase.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-lsa-cnt-type-8-ignore"):
                                self.sa_lsa_cnt_type_8_ignore = value
                                self.sa_lsa_cnt_type_8_ignore.value_namespace = name_space
                                self.sa_lsa_cnt_type_8_ignore.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-lsa-cnt-type-ase"):
                                self.sa_lsa_cnt_type_ase = value
                                self.sa_lsa_cnt_type_ase.value_namespace = name_space
                                self.sa_lsa_cnt_type_ase.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-lsa-cnt-type-mospf"):
                                self.sa_lsa_cnt_type_mospf = value
                                self.sa_lsa_cnt_type_mospf.value_namespace = name_space
                                self.sa_lsa_cnt_type_mospf.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-lsa-cnt-type-net"):
                                self.sa_lsa_cnt_type_net = value
                                self.sa_lsa_cnt_type_net.value_namespace = name_space
                                self.sa_lsa_cnt_type_net.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-lsa-cnt-type-opq-area"):
                                self.sa_lsa_cnt_type_opq_area = value
                                self.sa_lsa_cnt_type_opq_area.value_namespace = name_space
                                self.sa_lsa_cnt_type_opq_area.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-lsa-cnt-type-opq-as"):
                                self.sa_lsa_cnt_type_opq_as = value
                                self.sa_lsa_cnt_type_opq_as.value_namespace = name_space
                                self.sa_lsa_cnt_type_opq_as.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-lsa-cnt-type-opq-link"):
                                self.sa_lsa_cnt_type_opq_link = value
                                self.sa_lsa_cnt_type_opq_link.value_namespace = name_space
                                self.sa_lsa_cnt_type_opq_link.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-lsa-cnt-type-rtr"):
                                self.sa_lsa_cnt_type_rtr = value
                                self.sa_lsa_cnt_type_rtr.value_namespace = name_space
                                self.sa_lsa_cnt_type_rtr.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-lsa-cnt-type-sum-asb"):
                                self.sa_lsa_cnt_type_sum_asb = value
                                self.sa_lsa_cnt_type_sum_asb.value_namespace = name_space
                                self.sa_lsa_cnt_type_sum_asb.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-lsa-cnt-type-sum-net"):
                                self.sa_lsa_cnt_type_sum_net = value
                                self.sa_lsa_cnt_type_sum_net.value_namespace = name_space
                                self.sa_lsa_cnt_type_sum_net.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-num-areas"):
                                self.sa_num_areas = value
                                self.sa_num_areas.value_namespace = name_space
                                self.sa_num_areas.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-num-intf"):
                                self.sa_num_intf = value
                                self.sa_num_intf.value_namespace = name_space
                                self.sa_num_intf.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-num-intf-up"):
                                self.sa_num_intf_up = value
                                self.sa_num_intf_up.value_namespace = name_space
                                self.sa_num_intf_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-num-nbrs"):
                                self.sa_num_nbrs = value
                                self.sa_num_nbrs.value_namespace = name_space
                                self.sa_num_nbrs.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-num-nbrs-up"):
                                self.sa_num_nbrs_up = value
                                self.sa_num_nbrs_up.value_namespace = name_space
                                self.sa_num_nbrs_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-num-slintf-up"):
                                self.sa_num_slintf_up = value
                                self.sa_num_slintf_up.value_namespace = name_space
                                self.sa_num_slintf_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-num-vintf-up"):
                                self.sa_num_vintf_up = value
                                self.sa_num_vintf_up.value_namespace = name_space
                                self.sa_num_vintf_up.value_namespace_prefix = name_space_prefix


                    class FastReroute(Entity):
                        """
                        Container for FastReroute
                        
                        .. attribute:: topologies
                        
                        	Fast\-reroute topology information table
                        	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "vrf"

                            self.topologies = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                            self._children_yang_names.add("topologies")


                        class Topologies(Entity):
                            """
                            Fast\-reroute topology information table
                            
                            .. attribute:: topology
                            
                            	Fast\-reroute topology information
                            	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "fast-reroute"

                                self.topology = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies, self).__setattr__(name, value)


                            class Topology(Entity):
                                """
                                Fast\-reroute topology information
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ipfrr_area_revision
                                
                                	IPFRR Topology Revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipfrr_router_id
                                
                                	OSPF Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipfrr_topo
                                
                                	IPFRR Topology entries
                                	**type**\: list of    :py:class:`IpfrrTopo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology.IpfrrTopo>`
                                
                                .. attribute:: ipfrr_topo_area_id
                                
                                	Area ID string in decimal or dotted decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: router_id
                                
                                	Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.ipfrr_area_revision = YLeaf(YType.uint32, "ipfrr-area-revision")

                                    self.ipfrr_router_id = YLeaf(YType.str, "ipfrr-router-id")

                                    self.ipfrr_topo_area_id = YLeaf(YType.str, "ipfrr-topo-area-id")

                                    self.router_id = YLeaf(YType.str, "router-id")

                                    self.ipfrr_topo = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_id",
                                                    "ipfrr_area_revision",
                                                    "ipfrr_router_id",
                                                    "ipfrr_topo_area_id",
                                                    "router_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology, self).__setattr__(name, value)


                                class IpfrrTopo(Entity):
                                    """
                                    IPFRR Topology entries
                                    
                                    .. attribute:: distance
                                    
                                    	IPFRR Topology Distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: distance_reverse
                                    
                                    	IPFRR Topology Reverse Distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dr
                                    
                                    	IPFRR Topology DR entry
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_sourced
                                    
                                    	IPFRR Topology Neighbor Sourced
                                    	**type**\:  bool
                                    
                                    .. attribute:: node_id
                                    
                                    	IPFRR Topology Node ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: poison
                                    
                                    	IPFRR Topology rSPT poison
                                    	**type**\:  bool
                                    
                                    .. attribute:: revision
                                    
                                    	IPFRR Topology Revision
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: type4
                                    
                                    	IPFRR Topoogy Type\-4 entry
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology.IpfrrTopo, self).__init__()

                                        self.yang_name = "ipfrr-topo"
                                        self.yang_parent_name = "topology"

                                        self.distance = YLeaf(YType.uint32, "distance")

                                        self.distance_reverse = YLeaf(YType.uint32, "distance-reverse")

                                        self.dr = YLeaf(YType.boolean, "dr")

                                        self.neighbor_sourced = YLeaf(YType.boolean, "neighbor-sourced")

                                        self.node_id = YLeaf(YType.str, "node-id")

                                        self.poison = YLeaf(YType.boolean, "poison")

                                        self.revision = YLeaf(YType.uint32, "revision")

                                        self.type4 = YLeaf(YType.boolean, "type4")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("distance",
                                                        "distance_reverse",
                                                        "dr",
                                                        "neighbor_sourced",
                                                        "node_id",
                                                        "poison",
                                                        "revision",
                                                        "type4") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology.IpfrrTopo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology.IpfrrTopo, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.distance.is_set or
                                            self.distance_reverse.is_set or
                                            self.dr.is_set or
                                            self.neighbor_sourced.is_set or
                                            self.node_id.is_set or
                                            self.poison.is_set or
                                            self.revision.is_set or
                                            self.type4.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.distance.yfilter != YFilter.not_set or
                                            self.distance_reverse.yfilter != YFilter.not_set or
                                            self.dr.yfilter != YFilter.not_set or
                                            self.neighbor_sourced.yfilter != YFilter.not_set or
                                            self.node_id.yfilter != YFilter.not_set or
                                            self.poison.yfilter != YFilter.not_set or
                                            self.revision.yfilter != YFilter.not_set or
                                            self.type4.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipfrr-topo" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.distance.get_name_leafdata())
                                        if (self.distance_reverse.is_set or self.distance_reverse.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.distance_reverse.get_name_leafdata())
                                        if (self.dr.is_set or self.dr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dr.get_name_leafdata())
                                        if (self.neighbor_sourced.is_set or self.neighbor_sourced.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_sourced.get_name_leafdata())
                                        if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.node_id.get_name_leafdata())
                                        if (self.poison.is_set or self.poison.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.poison.get_name_leafdata())
                                        if (self.revision.is_set or self.revision.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.revision.get_name_leafdata())
                                        if (self.type4.is_set or self.type4.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type4.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "distance" or name == "distance-reverse" or name == "dr" or name == "neighbor-sourced" or name == "node-id" or name == "poison" or name == "revision" or name == "type4"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "distance"):
                                            self.distance = value
                                            self.distance.value_namespace = name_space
                                            self.distance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "distance-reverse"):
                                            self.distance_reverse = value
                                            self.distance_reverse.value_namespace = name_space
                                            self.distance_reverse.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dr"):
                                            self.dr = value
                                            self.dr.value_namespace = name_space
                                            self.dr.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-sourced"):
                                            self.neighbor_sourced = value
                                            self.neighbor_sourced.value_namespace = name_space
                                            self.neighbor_sourced.value_namespace_prefix = name_space_prefix
                                        if(value_path == "node-id"):
                                            self.node_id = value
                                            self.node_id.value_namespace = name_space
                                            self.node_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "poison"):
                                            self.poison = value
                                            self.poison.value_namespace = name_space
                                            self.poison.value_namespace_prefix = name_space_prefix
                                        if(value_path == "revision"):
                                            self.revision = value
                                            self.revision.value_namespace = name_space
                                            self.revision.value_namespace_prefix = name_space_prefix
                                        if(value_path == "type4"):
                                            self.type4 = value
                                            self.type4.value_namespace = name_space
                                            self.type4.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.ipfrr_topo:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.area_id.is_set or
                                        self.ipfrr_area_revision.is_set or
                                        self.ipfrr_router_id.is_set or
                                        self.ipfrr_topo_area_id.is_set or
                                        self.router_id.is_set)

                                def has_operation(self):
                                    for c in self.ipfrr_topo:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.ipfrr_area_revision.yfilter != YFilter.not_set or
                                        self.ipfrr_router_id.yfilter != YFilter.not_set or
                                        self.ipfrr_topo_area_id.yfilter != YFilter.not_set or
                                        self.router_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "topology" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.ipfrr_area_revision.is_set or self.ipfrr_area_revision.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipfrr_area_revision.get_name_leafdata())
                                    if (self.ipfrr_router_id.is_set or self.ipfrr_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipfrr_router_id.get_name_leafdata())
                                    if (self.ipfrr_topo_area_id.is_set or self.ipfrr_topo_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipfrr_topo_area_id.get_name_leafdata())
                                    if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.router_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ipfrr-topo"):
                                        for c in self.ipfrr_topo:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology.IpfrrTopo()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.ipfrr_topo.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipfrr-topo" or name == "area-id" or name == "ipfrr-area-revision" or name == "ipfrr-router-id" or name == "ipfrr-topo-area-id" or name == "router-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipfrr-area-revision"):
                                        self.ipfrr_area_revision = value
                                        self.ipfrr_area_revision.value_namespace = name_space
                                        self.ipfrr_area_revision.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipfrr-router-id"):
                                        self.ipfrr_router_id = value
                                        self.ipfrr_router_id.value_namespace = name_space
                                        self.ipfrr_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipfrr-topo-area-id"):
                                        self.ipfrr_topo_area_id = value
                                        self.ipfrr_topo_area_id.value_namespace = name_space
                                        self.ipfrr_topo_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "router-id"):
                                        self.router_id = value
                                        self.router_id.value_namespace = name_space
                                        self.router_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.topology:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.topology:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "topologies" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "topology"):
                                    for c in self.topology:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.topology.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "topology"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.topologies is not None and self.topologies.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.topologies is not None and self.topologies.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "fast-reroute" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "topologies"):
                                if (self.topologies is None):
                                    self.topologies = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies()
                                    self.topologies.parent = self
                                    self._children_name_map["topologies"] = "topologies"
                                return self.topologies

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "topologies"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.vrf_name.is_set or
                            (self.adjacency_information is not None and self.adjacency_information.has_data()) or
                            (self.area_statistics is not None and self.area_statistics.has_data()) or
                            (self.areas is not None and self.areas.has_data()) or
                            (self.border_routers is not None and self.border_routers.has_data()) or
                            (self.database is not None and self.database.has_data()) or
                            (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                            (self.flood_list_table is not None and self.flood_list_table.has_data()) or
                            (self.interface_information is not None and self.interface_information.has_data()) or
                            (self.interface_vrf_information is not None and self.interface_vrf_information.has_data()) or
                            (self.mpls_te is not None and self.mpls_te.has_data()) or
                            (self.ospf_summary is not None and self.ospf_summary.has_data()) or
                            (self.process_information is not None and self.process_information.has_data()) or
                            (self.route_information is not None and self.route_information.has_data()) or
                            (self.statistics is not None and self.statistics.has_data()) or
                            (self.summary_prefixes is not None and self.summary_prefixes.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.adjacency_information is not None and self.adjacency_information.has_operation()) or
                            (self.area_statistics is not None and self.area_statistics.has_operation()) or
                            (self.areas is not None and self.areas.has_operation()) or
                            (self.border_routers is not None and self.border_routers.has_operation()) or
                            (self.database is not None and self.database.has_operation()) or
                            (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                            (self.flood_list_table is not None and self.flood_list_table.has_operation()) or
                            (self.interface_information is not None and self.interface_information.has_operation()) or
                            (self.interface_vrf_information is not None and self.interface_vrf_information.has_operation()) or
                            (self.mpls_te is not None and self.mpls_te.has_operation()) or
                            (self.ospf_summary is not None and self.ospf_summary.has_operation()) or
                            (self.process_information is not None and self.process_information.has_operation()) or
                            (self.route_information is not None and self.route_information.has_operation()) or
                            (self.statistics is not None and self.statistics.has_operation()) or
                            (self.summary_prefixes is not None and self.summary_prefixes.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "adjacency-information"):
                            if (self.adjacency_information is None):
                                self.adjacency_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation()
                                self.adjacency_information.parent = self
                                self._children_name_map["adjacency_information"] = "adjacency-information"
                            return self.adjacency_information

                        if (child_yang_name == "area-statistics"):
                            if (self.area_statistics is None):
                                self.area_statistics = Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics()
                                self.area_statistics.parent = self
                                self._children_name_map["area_statistics"] = "area-statistics"
                            return self.area_statistics

                        if (child_yang_name == "areas"):
                            if (self.areas is None):
                                self.areas = Ospf.Processes.Process.Vrfs.Vrf.Areas()
                                self.areas.parent = self
                                self._children_name_map["areas"] = "areas"
                            return self.areas

                        if (child_yang_name == "border-routers"):
                            if (self.border_routers is None):
                                self.border_routers = Ospf.Processes.Process.Vrfs.Vrf.BorderRouters()
                                self.border_routers.parent = self
                                self._children_name_map["border_routers"] = "border-routers"
                            return self.border_routers

                        if (child_yang_name == "database"):
                            if (self.database is None):
                                self.database = Ospf.Processes.Process.Vrfs.Vrf.Database()
                                self.database.parent = self
                                self._children_name_map["database"] = "database"
                            return self.database

                        if (child_yang_name == "fast-reroute"):
                            if (self.fast_reroute is None):
                                self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.FastReroute()
                                self.fast_reroute.parent = self
                                self._children_name_map["fast_reroute"] = "fast-reroute"
                            return self.fast_reroute

                        if (child_yang_name == "flood-list-table"):
                            if (self.flood_list_table is None):
                                self.flood_list_table = Ospf.Processes.Process.Vrfs.Vrf.FloodListTable()
                                self.flood_list_table.parent = self
                                self._children_name_map["flood_list_table"] = "flood-list-table"
                            return self.flood_list_table

                        if (child_yang_name == "interface-information"):
                            if (self.interface_information is None):
                                self.interface_information = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation()
                                self.interface_information.parent = self
                                self._children_name_map["interface_information"] = "interface-information"
                            return self.interface_information

                        if (child_yang_name == "interface-vrf-information"):
                            if (self.interface_vrf_information is None):
                                self.interface_vrf_information = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation()
                                self.interface_vrf_information.parent = self
                                self._children_name_map["interface_vrf_information"] = "interface-vrf-information"
                            return self.interface_vrf_information

                        if (child_yang_name == "mpls-te"):
                            if (self.mpls_te is None):
                                self.mpls_te = Ospf.Processes.Process.Vrfs.Vrf.MplsTe()
                                self.mpls_te.parent = self
                                self._children_name_map["mpls_te"] = "mpls-te"
                            return self.mpls_te

                        if (child_yang_name == "ospf-summary"):
                            if (self.ospf_summary is None):
                                self.ospf_summary = Ospf.Processes.Process.Vrfs.Vrf.OspfSummary()
                                self.ospf_summary.parent = self
                                self._children_name_map["ospf_summary"] = "ospf-summary"
                            return self.ospf_summary

                        if (child_yang_name == "process-information"):
                            if (self.process_information is None):
                                self.process_information = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation()
                                self.process_information.parent = self
                                self._children_name_map["process_information"] = "process-information"
                            return self.process_information

                        if (child_yang_name == "route-information"):
                            if (self.route_information is None):
                                self.route_information = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation()
                                self.route_information.parent = self
                                self._children_name_map["route_information"] = "route-information"
                            return self.route_information

                        if (child_yang_name == "statistics"):
                            if (self.statistics is None):
                                self.statistics = Ospf.Processes.Process.Vrfs.Vrf.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                            return self.statistics

                        if (child_yang_name == "summary-prefixes"):
                            if (self.summary_prefixes is None):
                                self.summary_prefixes = Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes()
                                self.summary_prefixes.parent = self
                                self._children_name_map["summary_prefixes"] = "summary-prefixes"
                            return self.summary_prefixes

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "adjacency-information" or name == "area-statistics" or name == "areas" or name == "border-routers" or name == "database" or name == "fast-reroute" or name == "flood-list-table" or name == "interface-information" or name == "interface-vrf-information" or name == "mpls-te" or name == "ospf-summary" or name == "process-information" or name == "route-information" or name == "statistics" or name == "summary-prefixes" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.vrf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.vrf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vrfs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "vrf"):
                        for c in self.vrf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ospf.Processes.Process.Vrfs.Vrf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.vrf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "vrf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Srms(Entity):
                """
                Segment Routing Mapping Server operational
                data
                
                .. attribute:: policy
                
                	Policy operational data
                	**type**\:   :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy>`
                
                

                """

                _prefix = 'ipv4-ospf-oper'
                _revision = '2017-01-02'

                def __init__(self):
                    super(Ospf.Processes.Process.Srms, self).__init__()

                    self.yang_name = "srms"
                    self.yang_parent_name = "process"

                    self.policy = Ospf.Processes.Process.Srms.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"
                    self._children_yang_names.add("policy")


                class Policy(Entity):
                    """
                    Policy operational data
                    
                    .. attribute:: policy_ipv4
                    
                    	IPv4 policy operational data
                    	**type**\:   :py:class:`PolicyIpv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.Srms.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "srms"

                        self.policy_ipv4 = Ospf.Processes.Process.Srms.Policy.PolicyIpv4()
                        self.policy_ipv4.parent = self
                        self._children_name_map["policy_ipv4"] = "policy-ipv4"
                        self._children_yang_names.add("policy-ipv4")


                    class PolicyIpv4(Entity):
                        """
                        IPv4 policy operational data
                        
                        .. attribute:: policy_ipv4_active
                        
                        	IPv4 active policy operational data
                        	**type**\:   :py:class:`PolicyIpv4Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active>`
                        
                        .. attribute:: policy_ipv4_backup
                        
                        	IPv4 backup policy operational data
                        	**type**\:   :py:class:`PolicyIpv4Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4, self).__init__()

                            self.yang_name = "policy-ipv4"
                            self.yang_parent_name = "policy"

                            self.policy_ipv4_active = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active()
                            self.policy_ipv4_active.parent = self
                            self._children_name_map["policy_ipv4_active"] = "policy-ipv4-active"
                            self._children_yang_names.add("policy-ipv4-active")

                            self.policy_ipv4_backup = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup()
                            self.policy_ipv4_backup.parent = self
                            self._children_name_map["policy_ipv4_backup"] = "policy-ipv4-backup"
                            self._children_yang_names.add("policy-ipv4-backup")


                        class PolicyIpv4Backup(Entity):
                            """
                            IPv4 backup policy operational data
                            
                            .. attribute:: policy_mi
                            
                            	Mapping Item
                            	**type**\: list of    :py:class:`PolicyMi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup, self).__init__()

                                self.yang_name = "policy-ipv4-backup"
                                self.yang_parent_name = "policy-ipv4"

                                self.policy_mi = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup, self).__setattr__(name, value)


                            class PolicyMi(Entity):
                                """
                                Mapping Item
                                
                                .. attribute:: mi_id  <key>
                                
                                	Mapping Item ID (0, 1, 2, ...)
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: addr
                                
                                	addr
                                	**type**\:   :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr>`
                                
                                .. attribute:: area
                                
                                	Area (OSPF) or Level (ISIS)
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: flag_attached
                                
                                	Attached flag
                                	**type**\:   :py:class:`SrmsMiFlagEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrmsMiFlagEB>`
                                
                                .. attribute:: last_prefix
                                
                                	Last IP Prefix
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_sid_index
                                
                                	Last SID Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: router
                                
                                	Router ID
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: sid_count
                                
                                	SID range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sid_start
                                
                                	Starting SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: src
                                
                                	src
                                	**type**\:   :py:class:`SrmsMiSrcEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrmsMiSrcEB>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi, self).__init__()

                                    self.yang_name = "policy-mi"
                                    self.yang_parent_name = "policy-ipv4-backup"

                                    self.mi_id = YLeaf(YType.str, "mi-id")

                                    self.area = YLeaf(YType.str, "area")

                                    self.flag_attached = YLeaf(YType.enumeration, "flag-attached")

                                    self.last_prefix = YLeaf(YType.str, "last-prefix")

                                    self.last_sid_index = YLeaf(YType.uint32, "last-sid-index")

                                    self.prefix = YLeaf(YType.uint8, "prefix")

                                    self.router = YLeaf(YType.str, "router")

                                    self.sid_count = YLeaf(YType.uint32, "sid-count")

                                    self.sid_start = YLeaf(YType.uint32, "sid-start")

                                    self.src = YLeaf(YType.enumeration, "src")

                                    self.addr = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                    self._children_yang_names.add("addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mi_id",
                                                    "area",
                                                    "flag_attached",
                                                    "last_prefix",
                                                    "last_sid_index",
                                                    "prefix",
                                                    "router",
                                                    "sid_count",
                                                    "sid_start",
                                                    "src") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi, self).__setattr__(name, value)


                                class Addr(Entity):
                                    """
                                    addr
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:   :py:class:`SrmsMiAfEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrmsMiAfEB>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr, self).__init__()

                                        self.yang_name = "addr"
                                        self.yang_parent_name = "policy-mi"

                                        self.af = YLeaf(YType.enumeration, "af")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af",
                                                        "ipv4",
                                                        "ipv6") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af.is_set or
                                            self.ipv4.is_set or
                                            self.ipv6.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af.yfilter != YFilter.not_set or
                                            self.ipv4.yfilter != YFilter.not_set or
                                            self.ipv6.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af.get_name_leafdata())
                                        if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4.get_name_leafdata())
                                        if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af" or name == "ipv4" or name == "ipv6"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af"):
                                            self.af = value
                                            self.af.value_namespace = name_space
                                            self.af.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4"):
                                            self.ipv4 = value
                                            self.ipv4.value_namespace = name_space
                                            self.ipv4.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6"):
                                            self.ipv6 = value
                                            self.ipv6.value_namespace = name_space
                                            self.ipv6.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mi_id.is_set or
                                        self.area.is_set or
                                        self.flag_attached.is_set or
                                        self.last_prefix.is_set or
                                        self.last_sid_index.is_set or
                                        self.prefix.is_set or
                                        self.router.is_set or
                                        self.sid_count.is_set or
                                        self.sid_start.is_set or
                                        self.src.is_set or
                                        (self.addr is not None and self.addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mi_id.yfilter != YFilter.not_set or
                                        self.area.yfilter != YFilter.not_set or
                                        self.flag_attached.yfilter != YFilter.not_set or
                                        self.last_prefix.yfilter != YFilter.not_set or
                                        self.last_sid_index.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.router.yfilter != YFilter.not_set or
                                        self.sid_count.yfilter != YFilter.not_set or
                                        self.sid_start.yfilter != YFilter.not_set or
                                        self.src.yfilter != YFilter.not_set or
                                        (self.addr is not None and self.addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "policy-mi" + "[mi-id='" + self.mi_id.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mi_id.is_set or self.mi_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mi_id.get_name_leafdata())
                                    if (self.area.is_set or self.area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area.get_name_leafdata())
                                    if (self.flag_attached.is_set or self.flag_attached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flag_attached.get_name_leafdata())
                                    if (self.last_prefix.is_set or self.last_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_prefix.get_name_leafdata())
                                    if (self.last_sid_index.is_set or self.last_sid_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_sid_index.get_name_leafdata())
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.router.is_set or self.router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.router.get_name_leafdata())
                                    if (self.sid_count.is_set or self.sid_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sid_count.get_name_leafdata())
                                    if (self.sid_start.is_set or self.sid_start.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sid_start.get_name_leafdata())
                                    if (self.src.is_set or self.src.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.src.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "addr"):
                                        if (self.addr is None):
                                            self.addr = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr()
                                            self.addr.parent = self
                                            self._children_name_map["addr"] = "addr"
                                        return self.addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "addr" or name == "mi-id" or name == "area" or name == "flag-attached" or name == "last-prefix" or name == "last-sid-index" or name == "prefix" or name == "router" or name == "sid-count" or name == "sid-start" or name == "src"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mi-id"):
                                        self.mi_id = value
                                        self.mi_id.value_namespace = name_space
                                        self.mi_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area"):
                                        self.area = value
                                        self.area.value_namespace = name_space
                                        self.area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flag-attached"):
                                        self.flag_attached = value
                                        self.flag_attached.value_namespace = name_space
                                        self.flag_attached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-prefix"):
                                        self.last_prefix = value
                                        self.last_prefix.value_namespace = name_space
                                        self.last_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-sid-index"):
                                        self.last_sid_index = value
                                        self.last_sid_index.value_namespace = name_space
                                        self.last_sid_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "router"):
                                        self.router = value
                                        self.router.value_namespace = name_space
                                        self.router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sid-count"):
                                        self.sid_count = value
                                        self.sid_count.value_namespace = name_space
                                        self.sid_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sid-start"):
                                        self.sid_start = value
                                        self.sid_start.value_namespace = name_space
                                        self.sid_start.value_namespace_prefix = name_space_prefix
                                    if(value_path == "src"):
                                        self.src = value
                                        self.src.value_namespace = name_space
                                        self.src.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.policy_mi:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.policy_mi:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "policy-ipv4-backup" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "policy-mi"):
                                    for c in self.policy_mi:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.policy_mi.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "policy-mi"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class PolicyIpv4Active(Entity):
                            """
                            IPv4 active policy operational data
                            
                            .. attribute:: policy_mi
                            
                            	Mapping Item
                            	**type**\: list of    :py:class:`PolicyMi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active, self).__init__()

                                self.yang_name = "policy-ipv4-active"
                                self.yang_parent_name = "policy-ipv4"

                                self.policy_mi = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active, self).__setattr__(name, value)


                            class PolicyMi(Entity):
                                """
                                Mapping Item
                                
                                .. attribute:: mi_id  <key>
                                
                                	Mapping Item ID (0, 1, 2, ...)
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: addr
                                
                                	addr
                                	**type**\:   :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr>`
                                
                                .. attribute:: area
                                
                                	Area (OSPF) or Level (ISIS)
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: flag_attached
                                
                                	Attached flag
                                	**type**\:   :py:class:`SrmsMiFlagEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrmsMiFlagEB>`
                                
                                .. attribute:: last_prefix
                                
                                	Last IP Prefix
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_sid_index
                                
                                	Last SID Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: router
                                
                                	Router ID
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: sid_count
                                
                                	SID range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sid_start
                                
                                	Starting SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: src
                                
                                	src
                                	**type**\:   :py:class:`SrmsMiSrcEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrmsMiSrcEB>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi, self).__init__()

                                    self.yang_name = "policy-mi"
                                    self.yang_parent_name = "policy-ipv4-active"

                                    self.mi_id = YLeaf(YType.str, "mi-id")

                                    self.area = YLeaf(YType.str, "area")

                                    self.flag_attached = YLeaf(YType.enumeration, "flag-attached")

                                    self.last_prefix = YLeaf(YType.str, "last-prefix")

                                    self.last_sid_index = YLeaf(YType.uint32, "last-sid-index")

                                    self.prefix = YLeaf(YType.uint8, "prefix")

                                    self.router = YLeaf(YType.str, "router")

                                    self.sid_count = YLeaf(YType.uint32, "sid-count")

                                    self.sid_start = YLeaf(YType.uint32, "sid-start")

                                    self.src = YLeaf(YType.enumeration, "src")

                                    self.addr = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                    self._children_yang_names.add("addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mi_id",
                                                    "area",
                                                    "flag_attached",
                                                    "last_prefix",
                                                    "last_sid_index",
                                                    "prefix",
                                                    "router",
                                                    "sid_count",
                                                    "sid_start",
                                                    "src") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi, self).__setattr__(name, value)


                                class Addr(Entity):
                                    """
                                    addr
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:   :py:class:`SrmsMiAfEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrmsMiAfEB>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr, self).__init__()

                                        self.yang_name = "addr"
                                        self.yang_parent_name = "policy-mi"

                                        self.af = YLeaf(YType.enumeration, "af")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af",
                                                        "ipv4",
                                                        "ipv6") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af.is_set or
                                            self.ipv4.is_set or
                                            self.ipv6.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af.yfilter != YFilter.not_set or
                                            self.ipv4.yfilter != YFilter.not_set or
                                            self.ipv6.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af.get_name_leafdata())
                                        if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4.get_name_leafdata())
                                        if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af" or name == "ipv4" or name == "ipv6"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af"):
                                            self.af = value
                                            self.af.value_namespace = name_space
                                            self.af.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4"):
                                            self.ipv4 = value
                                            self.ipv4.value_namespace = name_space
                                            self.ipv4.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6"):
                                            self.ipv6 = value
                                            self.ipv6.value_namespace = name_space
                                            self.ipv6.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mi_id.is_set or
                                        self.area.is_set or
                                        self.flag_attached.is_set or
                                        self.last_prefix.is_set or
                                        self.last_sid_index.is_set or
                                        self.prefix.is_set or
                                        self.router.is_set or
                                        self.sid_count.is_set or
                                        self.sid_start.is_set or
                                        self.src.is_set or
                                        (self.addr is not None and self.addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mi_id.yfilter != YFilter.not_set or
                                        self.area.yfilter != YFilter.not_set or
                                        self.flag_attached.yfilter != YFilter.not_set or
                                        self.last_prefix.yfilter != YFilter.not_set or
                                        self.last_sid_index.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.router.yfilter != YFilter.not_set or
                                        self.sid_count.yfilter != YFilter.not_set or
                                        self.sid_start.yfilter != YFilter.not_set or
                                        self.src.yfilter != YFilter.not_set or
                                        (self.addr is not None and self.addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "policy-mi" + "[mi-id='" + self.mi_id.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mi_id.is_set or self.mi_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mi_id.get_name_leafdata())
                                    if (self.area.is_set or self.area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area.get_name_leafdata())
                                    if (self.flag_attached.is_set or self.flag_attached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flag_attached.get_name_leafdata())
                                    if (self.last_prefix.is_set or self.last_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_prefix.get_name_leafdata())
                                    if (self.last_sid_index.is_set or self.last_sid_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_sid_index.get_name_leafdata())
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.router.is_set or self.router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.router.get_name_leafdata())
                                    if (self.sid_count.is_set or self.sid_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sid_count.get_name_leafdata())
                                    if (self.sid_start.is_set or self.sid_start.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sid_start.get_name_leafdata())
                                    if (self.src.is_set or self.src.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.src.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "addr"):
                                        if (self.addr is None):
                                            self.addr = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr()
                                            self.addr.parent = self
                                            self._children_name_map["addr"] = "addr"
                                        return self.addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "addr" or name == "mi-id" or name == "area" or name == "flag-attached" or name == "last-prefix" or name == "last-sid-index" or name == "prefix" or name == "router" or name == "sid-count" or name == "sid-start" or name == "src"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mi-id"):
                                        self.mi_id = value
                                        self.mi_id.value_namespace = name_space
                                        self.mi_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area"):
                                        self.area = value
                                        self.area.value_namespace = name_space
                                        self.area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flag-attached"):
                                        self.flag_attached = value
                                        self.flag_attached.value_namespace = name_space
                                        self.flag_attached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-prefix"):
                                        self.last_prefix = value
                                        self.last_prefix.value_namespace = name_space
                                        self.last_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-sid-index"):
                                        self.last_sid_index = value
                                        self.last_sid_index.value_namespace = name_space
                                        self.last_sid_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "router"):
                                        self.router = value
                                        self.router.value_namespace = name_space
                                        self.router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sid-count"):
                                        self.sid_count = value
                                        self.sid_count.value_namespace = name_space
                                        self.sid_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sid-start"):
                                        self.sid_start = value
                                        self.sid_start.value_namespace = name_space
                                        self.sid_start.value_namespace_prefix = name_space_prefix
                                    if(value_path == "src"):
                                        self.src = value
                                        self.src.value_namespace = name_space
                                        self.src.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.policy_mi:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.policy_mi:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "policy-ipv4-active" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "policy-mi"):
                                    for c in self.policy_mi:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.policy_mi.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "policy-mi"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.policy_ipv4_active is not None and self.policy_ipv4_active.has_data()) or
                                (self.policy_ipv4_backup is not None and self.policy_ipv4_backup.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.policy_ipv4_active is not None and self.policy_ipv4_active.has_operation()) or
                                (self.policy_ipv4_backup is not None and self.policy_ipv4_backup.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "policy-ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "policy-ipv4-active"):
                                if (self.policy_ipv4_active is None):
                                    self.policy_ipv4_active = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active()
                                    self.policy_ipv4_active.parent = self
                                    self._children_name_map["policy_ipv4_active"] = "policy-ipv4-active"
                                return self.policy_ipv4_active

                            if (child_yang_name == "policy-ipv4-backup"):
                                if (self.policy_ipv4_backup is None):
                                    self.policy_ipv4_backup = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup()
                                    self.policy_ipv4_backup.parent = self
                                    self._children_name_map["policy_ipv4_backup"] = "policy-ipv4-backup"
                                return self.policy_ipv4_backup

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "policy-ipv4-active" or name == "policy-ipv4-backup"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (self.policy_ipv4 is not None and self.policy_ipv4.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.policy_ipv4 is not None and self.policy_ipv4.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "policy" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "policy-ipv4"):
                            if (self.policy_ipv4 is None):
                                self.policy_ipv4 = Ospf.Processes.Process.Srms.Policy.PolicyIpv4()
                                self.policy_ipv4.parent = self
                                self._children_name_map["policy_ipv4"] = "policy-ipv4"
                            return self.policy_ipv4

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "policy-ipv4"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.policy is not None and self.policy.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.policy is not None and self.policy.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "srms" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "policy"):
                        if (self.policy is None):
                            self.policy = Ospf.Processes.Process.Srms.Policy()
                            self.policy.parent = self
                            self._children_name_map["policy"] = "policy"
                        return self.policy

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "policy"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class DefaultVrf(Entity):
                """
                Operational data for the default VRF
                (instance) in the OSPF process
                
                .. attribute:: adjacency_information
                
                	Container for OSPF Interfaces
                	**type**\:   :py:class:`AdjacencyInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation>`
                
                .. attribute:: area_statistics
                
                	Container for Statistics
                	**type**\:   :py:class:`AreaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AreaStatistics>`
                
                .. attribute:: areas
                
                	Area table
                	**type**\:   :py:class:`Areas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas>`
                
                .. attribute:: border_routers
                
                	Border router table
                	**type**\:   :py:class:`BorderRouters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.BorderRouters>`
                
                .. attribute:: database
                
                	OSPF Link State Database
                	**type**\:   :py:class:`Database <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database>`
                
                .. attribute:: fast_reroute
                
                	Container for FastReroute
                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FastReroute>`
                
                .. attribute:: flood_list_table
                
                	Flood list table
                	**type**\:   :py:class:`FloodListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FloodListTable>`
                
                .. attribute:: interface_information
                
                	Container for OSPF Interfaces/links
                	**type**\:   :py:class:`InterfaceInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation>`
                
                .. attribute:: mpls_te
                
                	Container for MPLS TE
                	**type**\:   :py:class:`MplsTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe>`
                
                .. attribute:: ospf_summary
                
                	Fast\-reroute topology information
                	**type**\:   :py:class:`OspfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.OspfSummary>`
                
                .. attribute:: process_information
                
                	Container for OSPF Process information
                	**type**\:   :py:class:`ProcessInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation>`
                
                .. attribute:: route_information
                
                	Container for OSPF routing tables
                	**type**\:   :py:class:`RouteInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation>`
                
                .. attribute:: statistics
                
                	Container for Statistics
                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics>`
                
                .. attribute:: summary_prefixes
                
                	Summary prefix table
                	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes>`
                
                

                """

                _prefix = 'ipv4-ospf-oper'
                _revision = '2017-01-02'

                def __init__(self):
                    super(Ospf.Processes.Process.DefaultVrf, self).__init__()

                    self.yang_name = "default-vrf"
                    self.yang_parent_name = "process"

                    self.adjacency_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation()
                    self.adjacency_information.parent = self
                    self._children_name_map["adjacency_information"] = "adjacency-information"
                    self._children_yang_names.add("adjacency-information")

                    self.area_statistics = Ospf.Processes.Process.DefaultVrf.AreaStatistics()
                    self.area_statistics.parent = self
                    self._children_name_map["area_statistics"] = "area-statistics"
                    self._children_yang_names.add("area-statistics")

                    self.areas = Ospf.Processes.Process.DefaultVrf.Areas()
                    self.areas.parent = self
                    self._children_name_map["areas"] = "areas"
                    self._children_yang_names.add("areas")

                    self.border_routers = Ospf.Processes.Process.DefaultVrf.BorderRouters()
                    self.border_routers.parent = self
                    self._children_name_map["border_routers"] = "border-routers"
                    self._children_yang_names.add("border-routers")

                    self.database = Ospf.Processes.Process.DefaultVrf.Database()
                    self.database.parent = self
                    self._children_name_map["database"] = "database"
                    self._children_yang_names.add("database")

                    self.fast_reroute = Ospf.Processes.Process.DefaultVrf.FastReroute()
                    self.fast_reroute.parent = self
                    self._children_name_map["fast_reroute"] = "fast-reroute"
                    self._children_yang_names.add("fast-reroute")

                    self.flood_list_table = Ospf.Processes.Process.DefaultVrf.FloodListTable()
                    self.flood_list_table.parent = self
                    self._children_name_map["flood_list_table"] = "flood-list-table"
                    self._children_yang_names.add("flood-list-table")

                    self.interface_information = Ospf.Processes.Process.DefaultVrf.InterfaceInformation()
                    self.interface_information.parent = self
                    self._children_name_map["interface_information"] = "interface-information"
                    self._children_yang_names.add("interface-information")

                    self.mpls_te = Ospf.Processes.Process.DefaultVrf.MplsTe()
                    self.mpls_te.parent = self
                    self._children_name_map["mpls_te"] = "mpls-te"
                    self._children_yang_names.add("mpls-te")

                    self.ospf_summary = Ospf.Processes.Process.DefaultVrf.OspfSummary()
                    self.ospf_summary.parent = self
                    self._children_name_map["ospf_summary"] = "ospf-summary"
                    self._children_yang_names.add("ospf-summary")

                    self.process_information = Ospf.Processes.Process.DefaultVrf.ProcessInformation()
                    self.process_information.parent = self
                    self._children_name_map["process_information"] = "process-information"
                    self._children_yang_names.add("process-information")

                    self.route_information = Ospf.Processes.Process.DefaultVrf.RouteInformation()
                    self.route_information.parent = self
                    self._children_name_map["route_information"] = "route-information"
                    self._children_yang_names.add("route-information")

                    self.statistics = Ospf.Processes.Process.DefaultVrf.Statistics()
                    self.statistics.parent = self
                    self._children_name_map["statistics"] = "statistics"
                    self._children_yang_names.add("statistics")

                    self.summary_prefixes = Ospf.Processes.Process.DefaultVrf.SummaryPrefixes()
                    self.summary_prefixes.parent = self
                    self._children_name_map["summary_prefixes"] = "summary-prefixes"
                    self._children_yang_names.add("summary-prefixes")


                class FloodListTable(Entity):
                    """
                    Flood list table
                    
                    .. attribute:: flood
                    
                    	Flooding information for a specific interface
                    	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.FloodListTable, self).__init__()

                        self.yang_name = "flood-list-table"
                        self.yang_parent_name = "default-vrf"

                        self.flood = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.FloodListTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.FloodListTable, self).__setattr__(name, value)


                    class Flood(Entity):
                        """
                        Flooding information for a specific interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: area_flood
                        
                        	Area scope floodlist
                        	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AreaFlood>`
                        
                        .. attribute:: as_flood
                        
                        	AS scope floodlist
                        	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AsFlood>`
                        
                        .. attribute:: flood_interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: flood_lsa_count
                        
                        	Number of LSAs currently being flooded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flood_pacing_timer
                        
                        	Time until next LS update due (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood, self).__init__()

                            self.yang_name = "flood"
                            self.yang_parent_name = "flood-list-table"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.flood_interface_name = YLeaf(YType.str, "flood-interface-name")

                            self.flood_lsa_count = YLeaf(YType.uint32, "flood-lsa-count")

                            self.flood_pacing_timer = YLeaf(YType.uint32, "flood-pacing-timer")

                            self.area_flood = YList(self)
                            self.as_flood = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "flood_interface_name",
                                            "flood_lsa_count",
                                            "flood_pacing_timer") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood, self).__setattr__(name, value)


                        class AreaFlood(Entity):
                            """
                            Area scope floodlist
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the Advertising Router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_ls_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (s)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: header_lsa_checksum
                            
                            	Checksum of the LSA
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA Type
                            	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AreaFlood, self).__init__()

                                self.yang_name = "area-flood"
                                self.yang_parent_name = "flood"

                                self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("header_advertising_router",
                                                "header_ls_id",
                                                "header_lsa_age",
                                                "header_lsa_checksum",
                                                "header_lsa_type",
                                                "header_sequence_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AreaFlood, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AreaFlood, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.header_advertising_router.is_set or
                                    self.header_ls_id.is_set or
                                    self.header_lsa_age.is_set or
                                    self.header_lsa_checksum.is_set or
                                    self.header_lsa_type.is_set or
                                    self.header_sequence_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.header_advertising_router.yfilter != YFilter.not_set or
                                    self.header_ls_id.yfilter != YFilter.not_set or
                                    self.header_lsa_age.yfilter != YFilter.not_set or
                                    self.header_lsa_checksum.yfilter != YFilter.not_set or
                                    self.header_lsa_type.yfilter != YFilter.not_set or
                                    self.header_sequence_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "area-flood" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "header-advertising-router"):
                                    self.header_advertising_router = value
                                    self.header_advertising_router.value_namespace = name_space
                                    self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                if(value_path == "header-ls-id"):
                                    self.header_ls_id = value
                                    self.header_ls_id.value_namespace = name_space
                                    self.header_ls_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "header-lsa-age"):
                                    self.header_lsa_age = value
                                    self.header_lsa_age.value_namespace = name_space
                                    self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                if(value_path == "header-lsa-checksum"):
                                    self.header_lsa_checksum = value
                                    self.header_lsa_checksum.value_namespace = name_space
                                    self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                if(value_path == "header-lsa-type"):
                                    self.header_lsa_type = value
                                    self.header_lsa_type.value_namespace = name_space
                                    self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "header-sequence-number"):
                                    self.header_sequence_number = value
                                    self.header_sequence_number.value_namespace = name_space
                                    self.header_sequence_number.value_namespace_prefix = name_space_prefix


                        class AsFlood(Entity):
                            """
                            AS scope floodlist
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the Advertising Router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_ls_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (s)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: header_lsa_checksum
                            
                            	Checksum of the LSA
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA Type
                            	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AsFlood, self).__init__()

                                self.yang_name = "as-flood"
                                self.yang_parent_name = "flood"

                                self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("header_advertising_router",
                                                "header_ls_id",
                                                "header_lsa_age",
                                                "header_lsa_checksum",
                                                "header_lsa_type",
                                                "header_sequence_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AsFlood, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AsFlood, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.header_advertising_router.is_set or
                                    self.header_ls_id.is_set or
                                    self.header_lsa_age.is_set or
                                    self.header_lsa_checksum.is_set or
                                    self.header_lsa_type.is_set or
                                    self.header_sequence_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.header_advertising_router.yfilter != YFilter.not_set or
                                    self.header_ls_id.yfilter != YFilter.not_set or
                                    self.header_lsa_age.yfilter != YFilter.not_set or
                                    self.header_lsa_checksum.yfilter != YFilter.not_set or
                                    self.header_lsa_type.yfilter != YFilter.not_set or
                                    self.header_sequence_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "as-flood" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "header-advertising-router"):
                                    self.header_advertising_router = value
                                    self.header_advertising_router.value_namespace = name_space
                                    self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                if(value_path == "header-ls-id"):
                                    self.header_ls_id = value
                                    self.header_ls_id.value_namespace = name_space
                                    self.header_ls_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "header-lsa-age"):
                                    self.header_lsa_age = value
                                    self.header_lsa_age.value_namespace = name_space
                                    self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                if(value_path == "header-lsa-checksum"):
                                    self.header_lsa_checksum = value
                                    self.header_lsa_checksum.value_namespace = name_space
                                    self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                if(value_path == "header-lsa-type"):
                                    self.header_lsa_type = value
                                    self.header_lsa_type.value_namespace = name_space
                                    self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "header-sequence-number"):
                                    self.header_sequence_number = value
                                    self.header_sequence_number.value_namespace = name_space
                                    self.header_sequence_number.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.area_flood:
                                if (c.has_data()):
                                    return True
                            for c in self.as_flood:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.flood_interface_name.is_set or
                                self.flood_lsa_count.is_set or
                                self.flood_pacing_timer.is_set)

                        def has_operation(self):
                            for c in self.area_flood:
                                if (c.has_operation()):
                                    return True
                            for c in self.as_flood:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.flood_interface_name.yfilter != YFilter.not_set or
                                self.flood_lsa_count.yfilter != YFilter.not_set or
                                self.flood_pacing_timer.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "flood" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.flood_interface_name.is_set or self.flood_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flood_interface_name.get_name_leafdata())
                            if (self.flood_lsa_count.is_set or self.flood_lsa_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flood_lsa_count.get_name_leafdata())
                            if (self.flood_pacing_timer.is_set or self.flood_pacing_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flood_pacing_timer.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "area-flood"):
                                for c in self.area_flood:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AreaFlood()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.area_flood.append(c)
                                return c

                            if (child_yang_name == "as-flood"):
                                for c in self.as_flood:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AsFlood()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.as_flood.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "area-flood" or name == "as-flood" or name == "interface-name" or name == "flood-interface-name" or name == "flood-lsa-count" or name == "flood-pacing-timer"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "flood-interface-name"):
                                self.flood_interface_name = value
                                self.flood_interface_name.value_namespace = name_space
                                self.flood_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "flood-lsa-count"):
                                self.flood_lsa_count = value
                                self.flood_lsa_count.value_namespace = name_space
                                self.flood_lsa_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "flood-pacing-timer"):
                                self.flood_pacing_timer = value
                                self.flood_pacing_timer.value_namespace = name_space
                                self.flood_pacing_timer.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.flood:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.flood:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "flood-list-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "flood"):
                            for c in self.flood:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.flood.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flood"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class MplsTe(Entity):
                    """
                    Container for MPLS TE
                    
                    .. attribute:: mpls_te_fragments
                    
                    	MPLS TE Fragment information table
                    	**type**\:   :py:class:`MplsTeFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments>`
                    
                    .. attribute:: mpls_te_links
                    
                    	MPLS TE link information table
                    	**type**\:   :py:class:`MplsTeLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.MplsTe, self).__init__()

                        self.yang_name = "mpls-te"
                        self.yang_parent_name = "default-vrf"

                        self.mpls_te_fragments = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments()
                        self.mpls_te_fragments.parent = self
                        self._children_name_map["mpls_te_fragments"] = "mpls-te-fragments"
                        self._children_yang_names.add("mpls-te-fragments")

                        self.mpls_te_links = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks()
                        self.mpls_te_links.parent = self
                        self._children_name_map["mpls_te_links"] = "mpls-te-links"
                        self._children_yang_names.add("mpls-te-links")


                    class MplsTeLinks(Entity):
                        """
                        MPLS TE link information table
                        
                        .. attribute:: mpls_te_link
                        
                        	MPLS TE link information
                        	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks, self).__init__()

                            self.yang_name = "mpls-te-links"
                            self.yang_parent_name = "mpls-te"

                            self.mpls_te_link = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks, self).__setattr__(name, value)


                        class MplsTeLink(Entity):
                            """
                            MPLS TE link information
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mpls_te_area_id
                            
                            	Area ID string in decimal or dotted decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: mpls_te_area_instance
                            
                            	Area information instance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mpls_te_enabled
                            
                            	If true, MPLS\-TE enabled in area
                            	**type**\:  bool
                            
                            .. attribute:: mpls_te_fragment
                            
                            	MPLS TE fragments in the area
                            	**type**\: list of    :py:class:`MplsTeFragment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment>`
                            
                            .. attribute:: mpls_te_initialized
                            
                            	If true, MPLS\-TE initialized in the area
                            	**type**\:  bool
                            
                            .. attribute:: mpls_te_link
                            
                            	MPLS\-TE links in the area
                            	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink>`
                            
                            .. attribute:: mpls_te_next_fragment_id
                            
                            	Next MPLS\-TE fragment ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mpls_te_router_address
                            
                            	MPLS\-TE router address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mpls_te_router_id
                            
                            	OSPF MPLS\-TE router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: spacious_fragment
                            
                            	If true, fragment has space for next link
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink, self).__init__()

                                self.yang_name = "mpls-te-link"
                                self.yang_parent_name = "mpls-te-links"

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.mpls_te_area_id = YLeaf(YType.str, "mpls-te-area-id")

                                self.mpls_te_area_instance = YLeaf(YType.uint32, "mpls-te-area-instance")

                                self.mpls_te_enabled = YLeaf(YType.boolean, "mpls-te-enabled")

                                self.mpls_te_initialized = YLeaf(YType.boolean, "mpls-te-initialized")

                                self.mpls_te_next_fragment_id = YLeaf(YType.uint32, "mpls-te-next-fragment-id")

                                self.mpls_te_router_address = YLeaf(YType.str, "mpls-te-router-address")

                                self.mpls_te_router_id = YLeaf(YType.str, "mpls-te-router-id")

                                self.spacious_fragment = YLeaf(YType.boolean, "spacious-fragment")

                                self.mpls_te_fragment = YList(self)
                                self.mpls_te_link = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("area_id",
                                                "mpls_te_area_id",
                                                "mpls_te_area_instance",
                                                "mpls_te_enabled",
                                                "mpls_te_initialized",
                                                "mpls_te_next_fragment_id",
                                                "mpls_te_router_address",
                                                "mpls_te_router_id",
                                                "spacious_fragment") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink, self).__setattr__(name, value)


                            class MplsTeLink(Entity):
                                """
                                MPLS\-TE links in the area
                                
                                .. attribute:: affinity
                                
                                	Affinity
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dste_allocation_model_id
                                
                                	DS\-TE Allocation Model ID
                                	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                
                                .. attribute:: dste_in_use
                                
                                	A DS\-TE Allocation Model in use
                                	**type**\:  bool
                                
                                .. attribute:: extended_admin_group_list
                                
                                	Extended Admin Group
                                	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList>`
                                
                                .. attribute:: fragment_id
                                
                                	Fragment ID for this link
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: global_unreserve_bw_per_priority
                                
                                	Global pool unreserved bandwidth for each priority (bytes/s)
                                	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                
                                .. attribute:: igp_metric
                                
                                	Link IGP metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: input_interface_id
                                
                                	Input interface ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_address
                                
                                	The local interface address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: link_protocol_priority_capability
                                
                                	Link protocol and protocol priority capability
                                	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability>`
                                
                                .. attribute:: link_sw_capability
                                
                                	Link switching capability
                                	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability>`
                                
                                .. attribute:: maximum_link_bw
                                
                                	Maximum link bandwidth (bytes/s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte/s
                                
                                .. attribute:: maximum_link_reservable_bw
                                
                                	Maximum link global pool reservable bandwidth (bytes/s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte/s
                                
                                .. attribute:: maximum_link_sub_reservable_bw
                                
                                	Maximum link subpool reservable bandwidth (bytes/s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte/s
                                
                                .. attribute:: mpls_link_instance
                                
                                	Link instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_link_type
                                
                                	Type of link
                                	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                
                                .. attribute:: mplste_link_opt_tlv
                                
                                	List of Optional TLVs
                                	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv>`
                                
                                .. attribute:: neighbor_ip_address
                                
                                	Neighbor IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_system_id
                                
                                	Neighbor system ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: new_link
                                
                                	If true, Link is new
                                	**type**\:  bool
                                
                                .. attribute:: number_of_optional_tl_vs
                                
                                	Number of Optional TLVs
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: output_interface_id
                                
                                	Output interface ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: priority_count
                                
                                	Number of priorities
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: sub_pool_unreserve_bw_per_priority
                                
                                	Sub pool unreserved bandwidth for each priority (bytes/s)
                                	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                
                                .. attribute:: te_metric
                                
                                	Link TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink, self).__init__()

                                    self.yang_name = "mpls-te-link"
                                    self.yang_parent_name = "mpls-te-link"

                                    self.affinity = YLeaf(YType.uint32, "affinity")

                                    self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                    self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                    self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                    self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                    self.link_address = YLeaf(YType.str, "link-address")

                                    self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                    self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                    self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                    self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                    self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                    self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                    self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                    self.new_link = YLeaf(YType.boolean, "new-link")

                                    self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                    self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                    self.priority_count = YLeaf(YType.int32, "priority-count")

                                    self.te_metric = YLeaf(YType.uint32, "te-metric")

                                    self.extended_admin_group_list = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList()
                                    self.extended_admin_group_list.parent = self
                                    self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                    self._children_yang_names.add("extended-admin-group-list")

                                    self.global_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority()
                                    self.global_unreserve_bw_per_priority.parent = self
                                    self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                    self._children_yang_names.add("global-unreserve-bw-per-priority")

                                    self.link_protocol_priority_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability()
                                    self.link_protocol_priority_capability.parent = self
                                    self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                    self._children_yang_names.add("link-protocol-priority-capability")

                                    self.link_sw_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability()
                                    self.link_sw_capability.parent = self
                                    self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                    self._children_yang_names.add("link-sw-capability")

                                    self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                    self.sub_pool_unreserve_bw_per_priority.parent = self
                                    self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                    self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                    self.mplste_link_opt_tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("affinity",
                                                    "dste_allocation_model_id",
                                                    "dste_in_use",
                                                    "fragment_id",
                                                    "igp_metric",
                                                    "input_interface_id",
                                                    "link_address",
                                                    "maximum_link_bw",
                                                    "maximum_link_reservable_bw",
                                                    "maximum_link_sub_reservable_bw",
                                                    "mpls_link_instance",
                                                    "mpls_link_type",
                                                    "neighbor_ip_address",
                                                    "neighbor_system_id",
                                                    "new_link",
                                                    "number_of_optional_tl_vs",
                                                    "output_interface_id",
                                                    "priority_count",
                                                    "te_metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink, self).__setattr__(name, value)


                                class GlobalUnreserveBwPerPriority(Entity):
                                    """
                                    Global pool unreserved bandwidth for each
                                    priority (bytes/s)
                                    
                                    .. attribute:: bw_per_priority
                                    
                                    	Unreserved bandwidth for each priority (bytes/s)
                                    	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                        self.yang_name = "global-unreserve-bw-per-priority"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.bw_per_priority = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)


                                    class BwPerPriority(Entity):
                                        """
                                        Unreserved bandwidth for each priority (bytes/s)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                            self.yang_name = "bw-per-priority"
                                            self.yang_parent_name = "global-unreserve-bw-per-priority"

                                            self.entry = YLeaf(YType.uint64, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.bw_per_priority:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.bw_per_priority:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "global-unreserve-bw-per-priority" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "bw-per-priority"):
                                            for c in self.bw_per_priority:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.bw_per_priority.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bw-per-priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SubPoolUnreserveBwPerPriority(Entity):
                                    """
                                    Sub pool unreserved bandwidth for each priority
                                    (bytes/s)
                                    
                                    .. attribute:: bw_per_priority
                                    
                                    	Unreserved bandwidth for each priority (bytes/s)
                                    	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                        self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.bw_per_priority = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)


                                    class BwPerPriority(Entity):
                                        """
                                        Unreserved bandwidth for each priority (bytes/s)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                            self.yang_name = "bw-per-priority"
                                            self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"

                                            self.entry = YLeaf(YType.uint64, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.bw_per_priority:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.bw_per_priority:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sub-pool-unreserve-bw-per-priority" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "bw-per-priority"):
                                            for c in self.bw_per_priority:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.bw_per_priority.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bw-per-priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class LinkProtocolPriorityCapability(Entity):
                                    """
                                    Link protocol and protocol priority capability
                                    
                                    .. attribute:: link_protocol_capability
                                    
                                    	Link protocol capability
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: link_protocol_priority
                                    
                                    	Link protocol priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                        self.yang_name = "link-protocol-priority-capability"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                        self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("link_protocol_capability",
                                                        "link_protocol_priority") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.link_protocol_capability.is_set or
                                            self.link_protocol_priority.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.link_protocol_capability.yfilter != YFilter.not_set or
                                            self.link_protocol_priority.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "link-protocol-priority-capability" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.link_protocol_capability.is_set or self.link_protocol_capability.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_protocol_capability.get_name_leafdata())
                                        if (self.link_protocol_priority.is_set or self.link_protocol_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_protocol_priority.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "link-protocol-capability" or name == "link-protocol-priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "link-protocol-capability"):
                                            self.link_protocol_capability = value
                                            self.link_protocol_capability.value_namespace = name_space
                                            self.link_protocol_capability.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-protocol-priority"):
                                            self.link_protocol_priority = value
                                            self.link_protocol_priority.value_namespace = name_space
                                            self.link_protocol_priority.value_namespace_prefix = name_space_prefix


                                class LinkSwCapability(Entity):
                                    """
                                    Link switching capability
                                    
                                    .. attribute:: link_encoding
                                    
                                    	Link Encoding
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: link_mtu
                                    
                                    	Link MTU size (bytes)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: link_switching_capability
                                    
                                    	Link Switching Capability
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: maximum_lsp_bw_per_priority
                                    
                                    	Maximum LSP bandwidth for each priority  (bytes/s)
                                    	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                    
                                    .. attribute:: minimum_lsp_bw
                                    
                                    	Minimum LSP bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte/s
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability, self).__init__()

                                        self.yang_name = "link-sw-capability"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                        self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                        self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                        self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                        self.maximum_lsp_bw_per_priority = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("link_encoding",
                                                        "link_mtu",
                                                        "link_switching_capability",
                                                        "minimum_lsp_bw") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)


                                    class MaximumLspBwPerPriority(Entity):
                                        """
                                        Maximum LSP bandwidth for each priority
                                        
                                        (bytes/s)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                            self.yang_name = "maximum-lsp-bw-per-priority"
                                            self.yang_parent_name = "link-sw-capability"

                                            self.entry = YLeaf(YType.uint64, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "maximum-lsp-bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.maximum_lsp_bw_per_priority:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.link_encoding.is_set or
                                            self.link_mtu.is_set or
                                            self.link_switching_capability.is_set or
                                            self.minimum_lsp_bw.is_set)

                                    def has_operation(self):
                                        for c in self.maximum_lsp_bw_per_priority:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.link_encoding.yfilter != YFilter.not_set or
                                            self.link_mtu.yfilter != YFilter.not_set or
                                            self.link_switching_capability.yfilter != YFilter.not_set or
                                            self.minimum_lsp_bw.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "link-sw-capability" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.link_encoding.is_set or self.link_encoding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_encoding.get_name_leafdata())
                                        if (self.link_mtu.is_set or self.link_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_mtu.get_name_leafdata())
                                        if (self.link_switching_capability.is_set or self.link_switching_capability.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_switching_capability.get_name_leafdata())
                                        if (self.minimum_lsp_bw.is_set or self.minimum_lsp_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_lsp_bw.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "maximum-lsp-bw-per-priority"):
                                            for c in self.maximum_lsp_bw_per_priority:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.maximum_lsp_bw_per_priority.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "maximum-lsp-bw-per-priority" or name == "link-encoding" or name == "link-mtu" or name == "link-switching-capability" or name == "minimum-lsp-bw"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "link-encoding"):
                                            self.link_encoding = value
                                            self.link_encoding.value_namespace = name_space
                                            self.link_encoding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-mtu"):
                                            self.link_mtu = value
                                            self.link_mtu.value_namespace = name_space
                                            self.link_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-switching-capability"):
                                            self.link_switching_capability = value
                                            self.link_switching_capability.value_namespace = name_space
                                            self.link_switching_capability.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-lsp-bw"):
                                            self.minimum_lsp_bw = value
                                            self.minimum_lsp_bw.value_namespace = name_space
                                            self.minimum_lsp_bw.value_namespace_prefix = name_space_prefix


                                class ExtendedAdminGroupList(Entity):
                                    """
                                    Extended Admin Group
                                    
                                    .. attribute:: ext_admin_data
                                    
                                    	Value of Extended Admin Group
                                    	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                    
                                    .. attribute:: extended_admin_size
                                    
                                    	Size of the extended admin group
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                        self.yang_name = "extended-admin-group-list"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                        self.ext_admin_data = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("extended_admin_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)


                                    class ExtAdminData(Entity):
                                        """
                                        Value of Extended Admin Group
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                            self.yang_name = "ext-admin-data"
                                            self.yang_parent_name = "extended-admin-group-list"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ext-admin-data" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.ext_admin_data:
                                            if (c.has_data()):
                                                return True
                                        return self.extended_admin_size.is_set

                                    def has_operation(self):
                                        for c in self.ext_admin_data:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.extended_admin_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "extended-admin-group-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.extended_admin_size.is_set or self.extended_admin_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.extended_admin_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "ext-admin-data"):
                                            for c in self.ext_admin_data:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.ext_admin_data.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ext-admin-data" or name == "extended-admin-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "extended-admin-size"):
                                            self.extended_admin_size = value
                                            self.extended_admin_size.value_namespace = name_space
                                            self.extended_admin_size.value_namespace_prefix = name_space_prefix


                                class MplsteLinkOptTlv(Entity):
                                    """
                                    List of Optional TLVs
                                    
                                    .. attribute:: mplste_link_opt_tlv_len
                                    
                                    	Length of Opt TLV
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: mplste_link_opt_tlv_type
                                    
                                    	Type of Opt TLV
                                    	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                    
                                    .. attribute:: mplste_link_opt_tlv_value
                                    
                                    	Value of Opt TLV
                                    	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                        self.yang_name = "mplste-link-opt-tlv"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                        self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                        self.mplste_link_opt_tlv_value = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mplste_link_opt_tlv_len",
                                                        "mplste_link_opt_tlv_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)


                                    class MplsteLinkOptTlvValue(Entity):
                                        """
                                        Value of Opt TLV
                                        
                                        .. attribute:: bctlv_value
                                        
                                        	Value of Bandwidth Constraints TLV
                                        	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                        
                                        .. attribute:: ixcdtlv_value
                                        
                                        	Value of IXCD TLV
                                        	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                        
                                        .. attribute:: opaque_tlv_type
                                        
                                        	OpaqueTLVType
                                        	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                        
                                        .. attribute:: srlgtlv_value
                                        
                                        	Value of SRLG TLV
                                        	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                        
                                        .. attribute:: unidtlv_value
                                        
                                        	Value of Uni Delay TLV
                                        	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                            self.yang_name = "mplste-link-opt-tlv-value"
                                            self.yang_parent_name = "mplste-link-opt-tlv"

                                            self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                            self.bctlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                            self.bctlv_value.parent = self
                                            self._children_name_map["bctlv_value"] = "bctlv-value"
                                            self._children_yang_names.add("bctlv-value")

                                            self.ixcdtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                            self.ixcdtlv_value.parent = self
                                            self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                            self._children_yang_names.add("ixcdtlv-value")

                                            self.srlgtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                            self.srlgtlv_value.parent = self
                                            self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                            self._children_yang_names.add("srlgtlv-value")

                                            self.unidtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                            self.unidtlv_value.parent = self
                                            self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                            self._children_yang_names.add("unidtlv-value")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("opaque_tlv_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)


                                        class BctlvValue(Entity):
                                            """
                                            Value of Bandwidth Constraints TLV
                                            
                                            .. attribute:: model_id
                                            
                                            	Allocation Model ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mplste_link_bc_bandwidth
                                            
                                            	Value of BC TLV
                                            	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                            
                                            .. attribute:: num_b_cs
                                            
                                            	Number of BC TLVs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                self.yang_name = "bctlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                self.model_id = YLeaf(YType.uint8, "model-id")

                                                self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                self.mplste_link_bc_bandwidth = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("model_id",
                                                                "num_b_cs") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)


                                            class MplsteLinkBcBandwidth(Entity):
                                                """
                                                Value of BC TLV
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                    self.yang_name = "mplste-link-bc-bandwidth"
                                                    self.yang_parent_name = "bctlv-value"

                                                    self.entry = YLeaf(YType.uint64, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "mplste-link-bc-bandwidth" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.mplste_link_bc_bandwidth:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.model_id.is_set or
                                                    self.num_b_cs.is_set)

                                            def has_operation(self):
                                                for c in self.mplste_link_bc_bandwidth:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.model_id.yfilter != YFilter.not_set or
                                                    self.num_b_cs.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "bctlv-value" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.model_id.is_set or self.model_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.model_id.get_name_leafdata())
                                                if (self.num_b_cs.is_set or self.num_b_cs.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.num_b_cs.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "mplste-link-bc-bandwidth"):
                                                    for c in self.mplste_link_bc_bandwidth:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.mplste_link_bc_bandwidth.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "mplste-link-bc-bandwidth" or name == "model-id" or name == "num-b-cs"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "model-id"):
                                                    self.model_id = value
                                                    self.model_id.value_namespace = name_space
                                                    self.model_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "num-b-cs"):
                                                    self.num_b_cs = value
                                                    self.num_b_cs.value_namespace = name_space
                                                    self.num_b_cs.value_namespace_prefix = name_space_prefix


                                        class SrlgtlvValue(Entity):
                                            """
                                            Value of SRLG TLV
                                            
                                            .. attribute:: mplste_link_srlg_data
                                            
                                            	Value of SRLG TLV
                                            	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                            
                                            .. attribute:: num_srl_gs
                                            
                                            	Number of SRLG TLVs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: srlg_len
                                            
                                            	Length of SRLG TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                self.yang_name = "srlgtlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                self.mplste_link_srlg_data = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("num_srl_gs",
                                                                "srlg_len") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)


                                            class MplsteLinkSrlgData(Entity):
                                                """
                                                Value of SRLG TLV
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                    self.yang_name = "mplste-link-srlg-data"
                                                    self.yang_parent_name = "srlgtlv-value"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "mplste-link-srlg-data" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.mplste_link_srlg_data:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.num_srl_gs.is_set or
                                                    self.srlg_len.is_set)

                                            def has_operation(self):
                                                for c in self.mplste_link_srlg_data:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.num_srl_gs.yfilter != YFilter.not_set or
                                                    self.srlg_len.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "srlgtlv-value" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.num_srl_gs.is_set or self.num_srl_gs.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.num_srl_gs.get_name_leafdata())
                                                if (self.srlg_len.is_set or self.srlg_len.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.srlg_len.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "mplste-link-srlg-data"):
                                                    for c in self.mplste_link_srlg_data:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.mplste_link_srlg_data.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "mplste-link-srlg-data" or name == "num-srl-gs" or name == "srlg-len"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "num-srl-gs"):
                                                    self.num_srl_gs = value
                                                    self.num_srl_gs.value_namespace = name_space
                                                    self.num_srl_gs.value_namespace_prefix = name_space_prefix
                                                if(value_path == "srlg-len"):
                                                    self.srlg_len = value
                                                    self.srlg_len.value_namespace = name_space
                                                    self.srlg_len.value_namespace_prefix = name_space_prefix


                                        class IxcdtlvValue(Entity):
                                            """
                                            Value of IXCD TLV
                                            
                                            .. attribute:: fixed_scsi_count
                                            
                                            	Fixed SCSI count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flex_scsi_count
                                            
                                            	Flexible SCSI count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ixcd_switching_cap_type
                                            
                                            	Switching Cap type
                                            	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                            
                                            .. attribute:: max_lspbw
                                            
                                            	Max LSP bandwidth array
                                            	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                            
                                            .. attribute:: rile_len_code
                                            
                                            	Rile LenCode
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: switching_cap
                                            
                                            	SCap
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                self.yang_name = "ixcdtlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                self.ixcd_switching_cap_type = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                self.ixcd_switching_cap_type.parent = self
                                                self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                self._children_yang_names.add("ixcd-switching-cap-type")

                                                self.max_lspbw = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("fixed_scsi_count",
                                                                "flex_scsi_count",
                                                                "rile_len_code",
                                                                "switching_cap") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)


                                            class IxcdSwitchingCapType(Entity):
                                                """
                                                Switching Cap type
                                                
                                                .. attribute:: ixcdbw_sub_tlv
                                                
                                                	Sub TLVs
                                                	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                
                                                .. attribute:: ixcdpsc_info
                                                
                                                	IXCD PSC information
                                                	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                
                                                .. attribute:: switching_cap_type
                                                
                                                	SwitchingCapType
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                    self.yang_name = "ixcd-switching-cap-type"
                                                    self.yang_parent_name = "ixcdtlv-value"

                                                    self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                    self.ixcdbw_sub_tlv = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                    self.ixcdbw_sub_tlv.parent = self
                                                    self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                    self._children_yang_names.add("ixcdbw-sub-tlv")

                                                    self.ixcdpsc_info = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                    self.ixcdpsc_info.parent = self
                                                    self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                    self._children_yang_names.add("ixcdpsc-info")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("switching_cap_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)


                                                class IxcdpscInfo(Entity):
                                                    """
                                                    IXCD PSC information
                                                    
                                                    .. attribute:: min_lsp_bandwidth
                                                    
                                                    	Min LSP bandwidth
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: psc_interface_mtu
                                                    
                                                    	 Interface MTU
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                        self.yang_name = "ixcdpsc-info"
                                                        self.yang_parent_name = "ixcd-switching-cap-type"

                                                        self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                        self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("min_lsp_bandwidth",
                                                                        "psc_interface_mtu") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.min_lsp_bandwidth.is_set or
                                                            self.psc_interface_mtu.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.min_lsp_bandwidth.yfilter != YFilter.not_set or
                                                            self.psc_interface_mtu.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ixcdpsc-info" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.min_lsp_bandwidth.is_set or self.min_lsp_bandwidth.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.min_lsp_bandwidth.get_name_leafdata())
                                                        if (self.psc_interface_mtu.is_set or self.psc_interface_mtu.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.psc_interface_mtu.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "min-lsp-bandwidth" or name == "psc-interface-mtu"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "min-lsp-bandwidth"):
                                                            self.min_lsp_bandwidth = value
                                                            self.min_lsp_bandwidth.value_namespace = name_space
                                                            self.min_lsp_bandwidth.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "psc-interface-mtu"):
                                                            self.psc_interface_mtu = value
                                                            self.psc_interface_mtu.value_namespace = name_space
                                                            self.psc_interface_mtu.value_namespace_prefix = name_space_prefix


                                                class IxcdbwSubTlv(Entity):
                                                    """
                                                    Sub TLVs
                                                    
                                                    .. attribute:: arr_bw_sub_tlv
                                                    
                                                    	Array of sub tlvs
                                                    	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                        self.yang_name = "ixcdbw-sub-tlv"
                                                        self.yang_parent_name = "ixcd-switching-cap-type"

                                                        self.arr_bw_sub_tlv = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)


                                                    class ArrBwSubTlv(Entity):
                                                        """
                                                        Array of sub tlvs
                                                        
                                                        .. attribute:: bw_sub_tlv_length
                                                        
                                                        	Length of BW Sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: bw_sub_tlv_type
                                                        
                                                        	Type of Sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: bw_sub_tlv_value
                                                        
                                                        	Value of BW Sub TLV
                                                        	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                            self.yang_name = "arr-bw-sub-tlv"
                                                            self.yang_parent_name = "ixcdbw-sub-tlv"

                                                            self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                            self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                            self.bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                            self.bw_sub_tlv_value.parent = self
                                                            self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                            self._children_yang_names.add("bw-sub-tlv-value")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("bw_sub_tlv_length",
                                                                            "bw_sub_tlv_type") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)


                                                        class BwSubTlvValue(Entity):
                                                            """
                                                            Value of BW Sub TLV
                                                            
                                                            .. attribute:: fixed_bw_sub_tlv_value
                                                            
                                                            	Value of Fixed Sub TLV
                                                            	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                            
                                                            .. attribute:: flex_bw_sub_tlv_value
                                                            
                                                            	Value of Flex Sub TLV
                                                            	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                            
                                                            .. attribute:: ixcdbw_sub_tlv_type
                                                            
                                                            	IXCDBWSubTLVType
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                self.yang_name = "bw-sub-tlv-value"
                                                                self.yang_parent_name = "arr-bw-sub-tlv"

                                                                self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                self.fixed_bw_sub_tlv_value.parent = self
                                                                self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                self.flex_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                self.flex_bw_sub_tlv_value.parent = self
                                                                self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                self._children_yang_names.add("flex-bw-sub-tlv-value")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("ixcdbw_sub_tlv_type") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)


                                                            class FixedBwSubTlvValue(Entity):
                                                                """
                                                                Value of Fixed Sub TLV
                                                                
                                                                .. attribute:: fixed_sub_tlv_value
                                                                
                                                                	Value of Fixed Sub TLV
                                                                	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                
                                                                .. attribute:: unres_oduj_prio
                                                                
                                                                	Array of Unres Oduj Prio
                                                                	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-01-02'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                    self.yang_name = "fixed-bw-sub-tlv-value"
                                                                    self.yang_parent_name = "bw-sub-tlv-value"

                                                                    self.fixed_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                    self.fixed_sub_tlv_value.parent = self
                                                                    self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                    self._children_yang_names.add("fixed-sub-tlv-value")

                                                                    self.unres_oduj_prio = YList(self)

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in () and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)


                                                                class FixedSubTlvValue(Entity):
                                                                    """
                                                                    Value of Fixed Sub TLV
                                                                    
                                                                    .. attribute:: num_stages
                                                                    
                                                                    	Number of stages
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit0
                                                                    
                                                                    	Priority 0
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit1
                                                                    
                                                                    	Priority 1
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit2
                                                                    
                                                                    	Priority 2
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit3
                                                                    
                                                                    	Priority 3
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit4
                                                                    
                                                                    	Priority 4
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit5
                                                                    
                                                                    	Priority 5
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit6
                                                                    
                                                                    	Priority 6
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit7
                                                                    
                                                                    	Priority 7
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: res
                                                                    
                                                                    	Res
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: sbit
                                                                    
                                                                    	S Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: signal_type
                                                                    
                                                                    	Signal Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: stage
                                                                    
                                                                    	Array of Stages
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    .. attribute:: tbit
                                                                    
                                                                    	T Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: tsg
                                                                    
                                                                    	TSG
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                        self.yang_name = "fixed-sub-tlv-value"
                                                                        self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                        self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                        self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                        self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                        self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                        self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                        self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                        self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                        self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                        self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                        self.res = YLeaf(YType.uint8, "res")

                                                                        self.sbit = YLeaf(YType.uint8, "sbit")

                                                                        self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                        self.stage = YLeaf(YType.str, "stage")

                                                                        self.tbit = YLeaf(YType.uint8, "tbit")

                                                                        self.tsg = YLeaf(YType.uint8, "tsg")

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in ("num_stages",
                                                                                        "priority_bit0",
                                                                                        "priority_bit1",
                                                                                        "priority_bit2",
                                                                                        "priority_bit3",
                                                                                        "priority_bit4",
                                                                                        "priority_bit5",
                                                                                        "priority_bit6",
                                                                                        "priority_bit7",
                                                                                        "res",
                                                                                        "sbit",
                                                                                        "signal_type",
                                                                                        "stage",
                                                                                        "tbit",
                                                                                        "tsg") and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)

                                                                    def has_data(self):
                                                                        return (
                                                                            self.num_stages.is_set or
                                                                            self.priority_bit0.is_set or
                                                                            self.priority_bit1.is_set or
                                                                            self.priority_bit2.is_set or
                                                                            self.priority_bit3.is_set or
                                                                            self.priority_bit4.is_set or
                                                                            self.priority_bit5.is_set or
                                                                            self.priority_bit6.is_set or
                                                                            self.priority_bit7.is_set or
                                                                            self.res.is_set or
                                                                            self.sbit.is_set or
                                                                            self.signal_type.is_set or
                                                                            self.stage.is_set or
                                                                            self.tbit.is_set or
                                                                            self.tsg.is_set)

                                                                    def has_operation(self):
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            self.num_stages.yfilter != YFilter.not_set or
                                                                            self.priority_bit0.yfilter != YFilter.not_set or
                                                                            self.priority_bit1.yfilter != YFilter.not_set or
                                                                            self.priority_bit2.yfilter != YFilter.not_set or
                                                                            self.priority_bit3.yfilter != YFilter.not_set or
                                                                            self.priority_bit4.yfilter != YFilter.not_set or
                                                                            self.priority_bit5.yfilter != YFilter.not_set or
                                                                            self.priority_bit6.yfilter != YFilter.not_set or
                                                                            self.priority_bit7.yfilter != YFilter.not_set or
                                                                            self.res.yfilter != YFilter.not_set or
                                                                            self.sbit.yfilter != YFilter.not_set or
                                                                            self.signal_type.yfilter != YFilter.not_set or
                                                                            self.stage.yfilter != YFilter.not_set or
                                                                            self.tbit.yfilter != YFilter.not_set or
                                                                            self.tsg.yfilter != YFilter.not_set)

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "fixed-sub-tlv-value" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()
                                                                        if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                        if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                        if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                        if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                        if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                        if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                        if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                        if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                        if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                        if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.res.get_name_leafdata())
                                                                        if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                        if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                        if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.stage.get_name_leafdata())
                                                                        if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                        if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        if(value_path == "num-stages"):
                                                                            self.num_stages = value
                                                                            self.num_stages.value_namespace = name_space
                                                                            self.num_stages.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit0"):
                                                                            self.priority_bit0 = value
                                                                            self.priority_bit0.value_namespace = name_space
                                                                            self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit1"):
                                                                            self.priority_bit1 = value
                                                                            self.priority_bit1.value_namespace = name_space
                                                                            self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit2"):
                                                                            self.priority_bit2 = value
                                                                            self.priority_bit2.value_namespace = name_space
                                                                            self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit3"):
                                                                            self.priority_bit3 = value
                                                                            self.priority_bit3.value_namespace = name_space
                                                                            self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit4"):
                                                                            self.priority_bit4 = value
                                                                            self.priority_bit4.value_namespace = name_space
                                                                            self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit5"):
                                                                            self.priority_bit5 = value
                                                                            self.priority_bit5.value_namespace = name_space
                                                                            self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit6"):
                                                                            self.priority_bit6 = value
                                                                            self.priority_bit6.value_namespace = name_space
                                                                            self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit7"):
                                                                            self.priority_bit7 = value
                                                                            self.priority_bit7.value_namespace = name_space
                                                                            self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "res"):
                                                                            self.res = value
                                                                            self.res.value_namespace = name_space
                                                                            self.res.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "sbit"):
                                                                            self.sbit = value
                                                                            self.sbit.value_namespace = name_space
                                                                            self.sbit.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "signal-type"):
                                                                            self.signal_type = value
                                                                            self.signal_type.value_namespace = name_space
                                                                            self.signal_type.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "stage"):
                                                                            self.stage = value
                                                                            self.stage.value_namespace = name_space
                                                                            self.stage.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "tbit"):
                                                                            self.tbit = value
                                                                            self.tbit.value_namespace = name_space
                                                                            self.tbit.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "tsg"):
                                                                            self.tsg = value
                                                                            self.tsg.value_namespace = name_space
                                                                            self.tsg.value_namespace_prefix = name_space_prefix


                                                                class UnresOdujPrio(Entity):
                                                                    """
                                                                    Array of Unres Oduj Prio
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                        self.yang_name = "unres-oduj-prio"
                                                                        self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in ("entry") and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)

                                                                    def has_data(self):
                                                                        return self.entry.is_set

                                                                    def has_operation(self):
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            self.entry.yfilter != YFilter.not_set)

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "unres-oduj-prio" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()
                                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "entry"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        if(value_path == "entry"):
                                                                            self.entry = value
                                                                            self.entry.value_namespace = name_space
                                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                                def has_data(self):
                                                                    for c in self.unres_oduj_prio:
                                                                        if (c.has_data()):
                                                                            return True
                                                                    return (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_data())

                                                                def has_operation(self):
                                                                    for c in self.unres_oduj_prio:
                                                                        if (c.has_operation()):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_operation()))

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "fixed-bw-sub-tlv-value" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    if (child_yang_name == "fixed-sub-tlv-value"):
                                                                        if (self.fixed_sub_tlv_value is None):
                                                                            self.fixed_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                            self.fixed_sub_tlv_value.parent = self
                                                                            self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                        return self.fixed_sub_tlv_value

                                                                    if (child_yang_name == "unres-oduj-prio"):
                                                                        for c in self.unres_oduj_prio:
                                                                            segment = c.get_segment_path()
                                                                            if (segment_path == segment):
                                                                                return c
                                                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio()
                                                                        c.parent = self
                                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                                        self._local_refs[local_reference_key] = c
                                                                        self.unres_oduj_prio.append(c)
                                                                        return c

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "fixed-sub-tlv-value" or name == "unres-oduj-prio"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    pass


                                                            class FlexBwSubTlvValue(Entity):
                                                                """
                                                                Value of Flex Sub TLV
                                                                
                                                                .. attribute:: flex_sub_tlv_value_common
                                                                
                                                                	Flex Sub TLV Value
                                                                	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                
                                                                .. attribute:: max_lspbw
                                                                
                                                                	Max LSP BW Array
                                                                	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                
                                                                .. attribute:: unres_lspbw
                                                                
                                                                	Array of Unres LSP BW
                                                                	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-01-02'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                    self.yang_name = "flex-bw-sub-tlv-value"
                                                                    self.yang_parent_name = "bw-sub-tlv-value"

                                                                    self.flex_sub_tlv_value_common = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                    self.flex_sub_tlv_value_common.parent = self
                                                                    self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                    self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                    self.max_lspbw = YList(self)
                                                                    self.unres_lspbw = YList(self)

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in () and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)


                                                                class FlexSubTlvValueCommon(Entity):
                                                                    """
                                                                    Flex Sub TLV Value
                                                                    
                                                                    .. attribute:: num_stages
                                                                    
                                                                    	Number of stages
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit0
                                                                    
                                                                    	Priority 0
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit1
                                                                    
                                                                    	Priority 1
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit2
                                                                    
                                                                    	Priority 2
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit3
                                                                    
                                                                    	Priority 3
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit4
                                                                    
                                                                    	Priority 4
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit5
                                                                    
                                                                    	Priority 5
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit6
                                                                    
                                                                    	Priority 6
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit7
                                                                    
                                                                    	Priority 7
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: res
                                                                    
                                                                    	Res
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: sbit
                                                                    
                                                                    	S Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: signal_type
                                                                    
                                                                    	Signal Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: stage
                                                                    
                                                                    	Array of Stages
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    .. attribute:: tbit
                                                                    
                                                                    	T Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: tsg
                                                                    
                                                                    	TSG
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                        self.yang_name = "flex-sub-tlv-value-common"
                                                                        self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                        self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                        self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                        self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                        self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                        self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                        self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                        self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                        self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                        self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                        self.res = YLeaf(YType.uint8, "res")

                                                                        self.sbit = YLeaf(YType.uint8, "sbit")

                                                                        self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                        self.stage = YLeaf(YType.str, "stage")

                                                                        self.tbit = YLeaf(YType.uint8, "tbit")

                                                                        self.tsg = YLeaf(YType.uint8, "tsg")

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in ("num_stages",
                                                                                        "priority_bit0",
                                                                                        "priority_bit1",
                                                                                        "priority_bit2",
                                                                                        "priority_bit3",
                                                                                        "priority_bit4",
                                                                                        "priority_bit5",
                                                                                        "priority_bit6",
                                                                                        "priority_bit7",
                                                                                        "res",
                                                                                        "sbit",
                                                                                        "signal_type",
                                                                                        "stage",
                                                                                        "tbit",
                                                                                        "tsg") and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)

                                                                    def has_data(self):
                                                                        return (
                                                                            self.num_stages.is_set or
                                                                            self.priority_bit0.is_set or
                                                                            self.priority_bit1.is_set or
                                                                            self.priority_bit2.is_set or
                                                                            self.priority_bit3.is_set or
                                                                            self.priority_bit4.is_set or
                                                                            self.priority_bit5.is_set or
                                                                            self.priority_bit6.is_set or
                                                                            self.priority_bit7.is_set or
                                                                            self.res.is_set or
                                                                            self.sbit.is_set or
                                                                            self.signal_type.is_set or
                                                                            self.stage.is_set or
                                                                            self.tbit.is_set or
                                                                            self.tsg.is_set)

                                                                    def has_operation(self):
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            self.num_stages.yfilter != YFilter.not_set or
                                                                            self.priority_bit0.yfilter != YFilter.not_set or
                                                                            self.priority_bit1.yfilter != YFilter.not_set or
                                                                            self.priority_bit2.yfilter != YFilter.not_set or
                                                                            self.priority_bit3.yfilter != YFilter.not_set or
                                                                            self.priority_bit4.yfilter != YFilter.not_set or
                                                                            self.priority_bit5.yfilter != YFilter.not_set or
                                                                            self.priority_bit6.yfilter != YFilter.not_set or
                                                                            self.priority_bit7.yfilter != YFilter.not_set or
                                                                            self.res.yfilter != YFilter.not_set or
                                                                            self.sbit.yfilter != YFilter.not_set or
                                                                            self.signal_type.yfilter != YFilter.not_set or
                                                                            self.stage.yfilter != YFilter.not_set or
                                                                            self.tbit.yfilter != YFilter.not_set or
                                                                            self.tsg.yfilter != YFilter.not_set)

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "flex-sub-tlv-value-common" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()
                                                                        if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                        if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                        if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                        if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                        if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                        if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                        if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                        if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                        if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                        if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.res.get_name_leafdata())
                                                                        if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                        if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                        if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.stage.get_name_leafdata())
                                                                        if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                        if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        if(value_path == "num-stages"):
                                                                            self.num_stages = value
                                                                            self.num_stages.value_namespace = name_space
                                                                            self.num_stages.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit0"):
                                                                            self.priority_bit0 = value
                                                                            self.priority_bit0.value_namespace = name_space
                                                                            self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit1"):
                                                                            self.priority_bit1 = value
                                                                            self.priority_bit1.value_namespace = name_space
                                                                            self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit2"):
                                                                            self.priority_bit2 = value
                                                                            self.priority_bit2.value_namespace = name_space
                                                                            self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit3"):
                                                                            self.priority_bit3 = value
                                                                            self.priority_bit3.value_namespace = name_space
                                                                            self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit4"):
                                                                            self.priority_bit4 = value
                                                                            self.priority_bit4.value_namespace = name_space
                                                                            self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit5"):
                                                                            self.priority_bit5 = value
                                                                            self.priority_bit5.value_namespace = name_space
                                                                            self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit6"):
                                                                            self.priority_bit6 = value
                                                                            self.priority_bit6.value_namespace = name_space
                                                                            self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit7"):
                                                                            self.priority_bit7 = value
                                                                            self.priority_bit7.value_namespace = name_space
                                                                            self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "res"):
                                                                            self.res = value
                                                                            self.res.value_namespace = name_space
                                                                            self.res.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "sbit"):
                                                                            self.sbit = value
                                                                            self.sbit.value_namespace = name_space
                                                                            self.sbit.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "signal-type"):
                                                                            self.signal_type = value
                                                                            self.signal_type.value_namespace = name_space
                                                                            self.signal_type.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "stage"):
                                                                            self.stage = value
                                                                            self.stage.value_namespace = name_space
                                                                            self.stage.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "tbit"):
                                                                            self.tbit = value
                                                                            self.tbit.value_namespace = name_space
                                                                            self.tbit.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "tsg"):
                                                                            self.tsg = value
                                                                            self.tsg.value_namespace = name_space
                                                                            self.tsg.value_namespace_prefix = name_space_prefix


                                                                class UnresLspbw(Entity):
                                                                    """
                                                                    Array of Unres LSP BW
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..18446744073709551615
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                        self.yang_name = "unres-lspbw"
                                                                        self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                        self.entry = YLeaf(YType.uint64, "entry")

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in ("entry") and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)

                                                                    def has_data(self):
                                                                        return self.entry.is_set

                                                                    def has_operation(self):
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            self.entry.yfilter != YFilter.not_set)

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "unres-lspbw" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()
                                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "entry"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        if(value_path == "entry"):
                                                                            self.entry = value
                                                                            self.entry.value_namespace = name_space
                                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                                class MaxLspbw(Entity):
                                                                    """
                                                                    Max LSP BW Array
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..18446744073709551615
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                        self.yang_name = "max-lspbw"
                                                                        self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                        self.entry = YLeaf(YType.uint64, "entry")

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in ("entry") and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)

                                                                    def has_data(self):
                                                                        return self.entry.is_set

                                                                    def has_operation(self):
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            self.entry.yfilter != YFilter.not_set)

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "max-lspbw" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()
                                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "entry"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        if(value_path == "entry"):
                                                                            self.entry = value
                                                                            self.entry.value_namespace = name_space
                                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                                def has_data(self):
                                                                    for c in self.max_lspbw:
                                                                        if (c.has_data()):
                                                                            return True
                                                                    for c in self.unres_lspbw:
                                                                        if (c.has_data()):
                                                                            return True
                                                                    return (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_data())

                                                                def has_operation(self):
                                                                    for c in self.max_lspbw:
                                                                        if (c.has_operation()):
                                                                            return True
                                                                    for c in self.unres_lspbw:
                                                                        if (c.has_operation()):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_operation()))

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "flex-bw-sub-tlv-value" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    if (child_yang_name == "flex-sub-tlv-value-common"):
                                                                        if (self.flex_sub_tlv_value_common is None):
                                                                            self.flex_sub_tlv_value_common = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                            self.flex_sub_tlv_value_common.parent = self
                                                                            self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                        return self.flex_sub_tlv_value_common

                                                                    if (child_yang_name == "max-lspbw"):
                                                                        for c in self.max_lspbw:
                                                                            segment = c.get_segment_path()
                                                                            if (segment_path == segment):
                                                                                return c
                                                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw()
                                                                        c.parent = self
                                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                                        self._local_refs[local_reference_key] = c
                                                                        self.max_lspbw.append(c)
                                                                        return c

                                                                    if (child_yang_name == "unres-lspbw"):
                                                                        for c in self.unres_lspbw:
                                                                            segment = c.get_segment_path()
                                                                            if (segment_path == segment):
                                                                                return c
                                                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw()
                                                                        c.parent = self
                                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                                        self._local_refs[local_reference_key] = c
                                                                        self.unres_lspbw.append(c)
                                                                        return c

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "flex-sub-tlv-value-common" or name == "max-lspbw" or name == "unres-lspbw"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    pass

                                                            def has_data(self):
                                                                return (
                                                                    self.ixcdbw_sub_tlv_type.is_set or
                                                                    (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_data()) or
                                                                    (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_data()))

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                    (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_operation()) or
                                                                    (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_operation()))

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "bw-sub-tlv-value" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.ixcdbw_sub_tlv_type.is_set or self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.ixcdbw_sub_tlv_type.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "fixed-bw-sub-tlv-value"):
                                                                    if (self.fixed_bw_sub_tlv_value is None):
                                                                        self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                        self.fixed_bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                    return self.fixed_bw_sub_tlv_value

                                                                if (child_yang_name == "flex-bw-sub-tlv-value"):
                                                                    if (self.flex_bw_sub_tlv_value is None):
                                                                        self.flex_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                        self.flex_bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                    return self.flex_bw_sub_tlv_value

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "fixed-bw-sub-tlv-value" or name == "flex-bw-sub-tlv-value" or name == "ixcdbw-sub-tlv-type"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "ixcdbw-sub-tlv-type"):
                                                                    self.ixcdbw_sub_tlv_type = value
                                                                    self.ixcdbw_sub_tlv_type.value_namespace = name_space
                                                                    self.ixcdbw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                        def has_data(self):
                                                            return (
                                                                self.bw_sub_tlv_length.is_set or
                                                                self.bw_sub_tlv_type.is_set or
                                                                (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.bw_sub_tlv_length.yfilter != YFilter.not_set or
                                                                self.bw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "arr-bw-sub-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.bw_sub_tlv_length.is_set or self.bw_sub_tlv_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bw_sub_tlv_length.get_name_leafdata())
                                                            if (self.bw_sub_tlv_type.is_set or self.bw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bw_sub_tlv_type.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "bw-sub-tlv-value"):
                                                                if (self.bw_sub_tlv_value is None):
                                                                    self.bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                    self.bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                return self.bw_sub_tlv_value

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "bw-sub-tlv-value" or name == "bw-sub-tlv-length" or name == "bw-sub-tlv-type"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "bw-sub-tlv-length"):
                                                                self.bw_sub_tlv_length = value
                                                                self.bw_sub_tlv_length.value_namespace = name_space
                                                                self.bw_sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bw-sub-tlv-type"):
                                                                self.bw_sub_tlv_type = value
                                                                self.bw_sub_tlv_type.value_namespace = name_space
                                                                self.bw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.arr_bw_sub_tlv:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.arr_bw_sub_tlv:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ixcdbw-sub-tlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "arr-bw-sub-tlv"):
                                                            for c in self.arr_bw_sub_tlv:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.arr_bw_sub_tlv.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "arr-bw-sub-tlv"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.switching_cap_type.is_set or
                                                        (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_data()) or
                                                        (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.switching_cap_type.yfilter != YFilter.not_set or
                                                        (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_operation()) or
                                                        (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ixcd-switching-cap-type" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.switching_cap_type.is_set or self.switching_cap_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.switching_cap_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ixcdbw-sub-tlv"):
                                                        if (self.ixcdbw_sub_tlv is None):
                                                            self.ixcdbw_sub_tlv = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                            self.ixcdbw_sub_tlv.parent = self
                                                            self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                        return self.ixcdbw_sub_tlv

                                                    if (child_yang_name == "ixcdpsc-info"):
                                                        if (self.ixcdpsc_info is None):
                                                            self.ixcdpsc_info = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                            self.ixcdpsc_info.parent = self
                                                            self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                        return self.ixcdpsc_info

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ixcdbw-sub-tlv" or name == "ixcdpsc-info" or name == "switching-cap-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "switching-cap-type"):
                                                        self.switching_cap_type = value
                                                        self.switching_cap_type.value_namespace = name_space
                                                        self.switching_cap_type.value_namespace_prefix = name_space_prefix


                                            class MaxLspbw(Entity):
                                                """
                                                Max LSP bandwidth array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** \-9223372036854775808..9223372036854775807
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                    self.yang_name = "max-lspbw"
                                                    self.yang_parent_name = "ixcdtlv-value"

                                                    self.entry = YLeaf(YType.int64, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "max-lspbw" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.max_lspbw:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.fixed_scsi_count.is_set or
                                                    self.flex_scsi_count.is_set or
                                                    self.rile_len_code.is_set or
                                                    self.switching_cap.is_set or
                                                    (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_data()))

                                            def has_operation(self):
                                                for c in self.max_lspbw:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.fixed_scsi_count.yfilter != YFilter.not_set or
                                                    self.flex_scsi_count.yfilter != YFilter.not_set or
                                                    self.rile_len_code.yfilter != YFilter.not_set or
                                                    self.switching_cap.yfilter != YFilter.not_set or
                                                    (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ixcdtlv-value" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.fixed_scsi_count.is_set or self.fixed_scsi_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fixed_scsi_count.get_name_leafdata())
                                                if (self.flex_scsi_count.is_set or self.flex_scsi_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flex_scsi_count.get_name_leafdata())
                                                if (self.rile_len_code.is_set or self.rile_len_code.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rile_len_code.get_name_leafdata())
                                                if (self.switching_cap.is_set or self.switching_cap.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.switching_cap.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ixcd-switching-cap-type"):
                                                    if (self.ixcd_switching_cap_type is None):
                                                        self.ixcd_switching_cap_type = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                        self.ixcd_switching_cap_type.parent = self
                                                        self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                    return self.ixcd_switching_cap_type

                                                if (child_yang_name == "max-lspbw"):
                                                    for c in self.max_lspbw:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.max_lspbw.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ixcd-switching-cap-type" or name == "max-lspbw" or name == "fixed-scsi-count" or name == "flex-scsi-count" or name == "rile-len-code" or name == "switching-cap"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "fixed-scsi-count"):
                                                    self.fixed_scsi_count = value
                                                    self.fixed_scsi_count.value_namespace = name_space
                                                    self.fixed_scsi_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flex-scsi-count"):
                                                    self.flex_scsi_count = value
                                                    self.flex_scsi_count.value_namespace = name_space
                                                    self.flex_scsi_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rile-len-code"):
                                                    self.rile_len_code = value
                                                    self.rile_len_code.value_namespace = name_space
                                                    self.rile_len_code.value_namespace_prefix = name_space_prefix
                                                if(value_path == "switching-cap"):
                                                    self.switching_cap = value
                                                    self.switching_cap.value_namespace = name_space
                                                    self.switching_cap.value_namespace_prefix = name_space_prefix


                                        class UnidtlvValue(Entity):
                                            """
                                            Value of Uni Delay TLV
                                            
                                            .. attribute:: uni_dir_delay
                                            
                                            	Uni Dir Delay
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                self.yang_name = "unidtlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("uni_dir_delay") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.uni_dir_delay.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.uni_dir_delay.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unidtlv-value" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.uni_dir_delay.is_set or self.uni_dir_delay.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.uni_dir_delay.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "uni-dir-delay"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "uni-dir-delay"):
                                                    self.uni_dir_delay = value
                                                    self.uni_dir_delay.value_namespace = name_space
                                                    self.uni_dir_delay.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.opaque_tlv_type.is_set or
                                                (self.bctlv_value is not None and self.bctlv_value.has_data()) or
                                                (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_data()) or
                                                (self.srlgtlv_value is not None and self.srlgtlv_value.has_data()) or
                                                (self.unidtlv_value is not None and self.unidtlv_value.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.opaque_tlv_type.yfilter != YFilter.not_set or
                                                (self.bctlv_value is not None and self.bctlv_value.has_operation()) or
                                                (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_operation()) or
                                                (self.srlgtlv_value is not None and self.srlgtlv_value.has_operation()) or
                                                (self.unidtlv_value is not None and self.unidtlv_value.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mplste-link-opt-tlv-value" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.opaque_tlv_type.is_set or self.opaque_tlv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.opaque_tlv_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "bctlv-value"):
                                                if (self.bctlv_value is None):
                                                    self.bctlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                    self.bctlv_value.parent = self
                                                    self._children_name_map["bctlv_value"] = "bctlv-value"
                                                return self.bctlv_value

                                            if (child_yang_name == "ixcdtlv-value"):
                                                if (self.ixcdtlv_value is None):
                                                    self.ixcdtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                    self.ixcdtlv_value.parent = self
                                                    self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                return self.ixcdtlv_value

                                            if (child_yang_name == "srlgtlv-value"):
                                                if (self.srlgtlv_value is None):
                                                    self.srlgtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                    self.srlgtlv_value.parent = self
                                                    self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                return self.srlgtlv_value

                                            if (child_yang_name == "unidtlv-value"):
                                                if (self.unidtlv_value is None):
                                                    self.unidtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                    self.unidtlv_value.parent = self
                                                    self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                return self.unidtlv_value

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bctlv-value" or name == "ixcdtlv-value" or name == "srlgtlv-value" or name == "unidtlv-value" or name == "opaque-tlv-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "opaque-tlv-type"):
                                                self.opaque_tlv_type = value
                                                self.opaque_tlv_type.value_namespace = name_space
                                                self.opaque_tlv_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.mplste_link_opt_tlv_value:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.mplste_link_opt_tlv_len.is_set or
                                            self.mplste_link_opt_tlv_type.is_set)

                                    def has_operation(self):
                                        for c in self.mplste_link_opt_tlv_value:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set or
                                            self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mplste-link-opt-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mplste_link_opt_tlv_len.is_set or self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mplste_link_opt_tlv_len.get_name_leafdata())
                                        if (self.mplste_link_opt_tlv_type.is_set or self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mplste_link_opt_tlv_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "mplste-link-opt-tlv-value"):
                                            for c in self.mplste_link_opt_tlv_value:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.mplste_link_opt_tlv_value.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mplste-link-opt-tlv-value" or name == "mplste-link-opt-tlv-len" or name == "mplste-link-opt-tlv-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mplste-link-opt-tlv-len"):
                                            self.mplste_link_opt_tlv_len = value
                                            self.mplste_link_opt_tlv_len.value_namespace = name_space
                                            self.mplste_link_opt_tlv_len.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mplste-link-opt-tlv-type"):
                                            self.mplste_link_opt_tlv_type = value
                                            self.mplste_link_opt_tlv_type.value_namespace = name_space
                                            self.mplste_link_opt_tlv_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.mplste_link_opt_tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.affinity.is_set or
                                        self.dste_allocation_model_id.is_set or
                                        self.dste_in_use.is_set or
                                        self.fragment_id.is_set or
                                        self.igp_metric.is_set or
                                        self.input_interface_id.is_set or
                                        self.link_address.is_set or
                                        self.maximum_link_bw.is_set or
                                        self.maximum_link_reservable_bw.is_set or
                                        self.maximum_link_sub_reservable_bw.is_set or
                                        self.mpls_link_instance.is_set or
                                        self.mpls_link_type.is_set or
                                        self.neighbor_ip_address.is_set or
                                        self.neighbor_system_id.is_set or
                                        self.new_link.is_set or
                                        self.number_of_optional_tl_vs.is_set or
                                        self.output_interface_id.is_set or
                                        self.priority_count.is_set or
                                        self.te_metric.is_set or
                                        (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_data()) or
                                        (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_data()) or
                                        (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_data()) or
                                        (self.link_sw_capability is not None and self.link_sw_capability.has_data()) or
                                        (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_data()))

                                def has_operation(self):
                                    for c in self.mplste_link_opt_tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.affinity.yfilter != YFilter.not_set or
                                        self.dste_allocation_model_id.yfilter != YFilter.not_set or
                                        self.dste_in_use.yfilter != YFilter.not_set or
                                        self.fragment_id.yfilter != YFilter.not_set or
                                        self.igp_metric.yfilter != YFilter.not_set or
                                        self.input_interface_id.yfilter != YFilter.not_set or
                                        self.link_address.yfilter != YFilter.not_set or
                                        self.maximum_link_bw.yfilter != YFilter.not_set or
                                        self.maximum_link_reservable_bw.yfilter != YFilter.not_set or
                                        self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set or
                                        self.mpls_link_instance.yfilter != YFilter.not_set or
                                        self.mpls_link_type.yfilter != YFilter.not_set or
                                        self.neighbor_ip_address.yfilter != YFilter.not_set or
                                        self.neighbor_system_id.yfilter != YFilter.not_set or
                                        self.new_link.yfilter != YFilter.not_set or
                                        self.number_of_optional_tl_vs.yfilter != YFilter.not_set or
                                        self.output_interface_id.yfilter != YFilter.not_set or
                                        self.priority_count.yfilter != YFilter.not_set or
                                        self.te_metric.yfilter != YFilter.not_set or
                                        (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_operation()) or
                                        (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_operation()) or
                                        (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_operation()) or
                                        (self.link_sw_capability is not None and self.link_sw_capability.has_operation()) or
                                        (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mpls-te-link" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.affinity.is_set or self.affinity.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.affinity.get_name_leafdata())
                                    if (self.dste_allocation_model_id.is_set or self.dste_allocation_model_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dste_allocation_model_id.get_name_leafdata())
                                    if (self.dste_in_use.is_set or self.dste_in_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dste_in_use.get_name_leafdata())
                                    if (self.fragment_id.is_set or self.fragment_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fragment_id.get_name_leafdata())
                                    if (self.igp_metric.is_set or self.igp_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igp_metric.get_name_leafdata())
                                    if (self.input_interface_id.is_set or self.input_interface_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.input_interface_id.get_name_leafdata())
                                    if (self.link_address.is_set or self.link_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.link_address.get_name_leafdata())
                                    if (self.maximum_link_bw.is_set or self.maximum_link_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_link_bw.get_name_leafdata())
                                    if (self.maximum_link_reservable_bw.is_set or self.maximum_link_reservable_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_link_reservable_bw.get_name_leafdata())
                                    if (self.maximum_link_sub_reservable_bw.is_set or self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_link_sub_reservable_bw.get_name_leafdata())
                                    if (self.mpls_link_instance.is_set or self.mpls_link_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_link_instance.get_name_leafdata())
                                    if (self.mpls_link_type.is_set or self.mpls_link_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_link_type.get_name_leafdata())
                                    if (self.neighbor_ip_address.is_set or self.neighbor_ip_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_ip_address.get_name_leafdata())
                                    if (self.neighbor_system_id.is_set or self.neighbor_system_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_system_id.get_name_leafdata())
                                    if (self.new_link.is_set or self.new_link.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.new_link.get_name_leafdata())
                                    if (self.number_of_optional_tl_vs.is_set or self.number_of_optional_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number_of_optional_tl_vs.get_name_leafdata())
                                    if (self.output_interface_id.is_set or self.output_interface_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.output_interface_id.get_name_leafdata())
                                    if (self.priority_count.is_set or self.priority_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.priority_count.get_name_leafdata())
                                    if (self.te_metric.is_set or self.te_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "extended-admin-group-list"):
                                        if (self.extended_admin_group_list is None):
                                            self.extended_admin_group_list = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList()
                                            self.extended_admin_group_list.parent = self
                                            self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                        return self.extended_admin_group_list

                                    if (child_yang_name == "global-unreserve-bw-per-priority"):
                                        if (self.global_unreserve_bw_per_priority is None):
                                            self.global_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority()
                                            self.global_unreserve_bw_per_priority.parent = self
                                            self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                        return self.global_unreserve_bw_per_priority

                                    if (child_yang_name == "link-protocol-priority-capability"):
                                        if (self.link_protocol_priority_capability is None):
                                            self.link_protocol_priority_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability()
                                            self.link_protocol_priority_capability.parent = self
                                            self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                        return self.link_protocol_priority_capability

                                    if (child_yang_name == "link-sw-capability"):
                                        if (self.link_sw_capability is None):
                                            self.link_sw_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability()
                                            self.link_sw_capability.parent = self
                                            self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                        return self.link_sw_capability

                                    if (child_yang_name == "mplste-link-opt-tlv"):
                                        for c in self.mplste_link_opt_tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.mplste_link_opt_tlv.append(c)
                                        return c

                                    if (child_yang_name == "sub-pool-unreserve-bw-per-priority"):
                                        if (self.sub_pool_unreserve_bw_per_priority is None):
                                            self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                            self.sub_pool_unreserve_bw_per_priority.parent = self
                                            self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                        return self.sub_pool_unreserve_bw_per_priority

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "extended-admin-group-list" or name == "global-unreserve-bw-per-priority" or name == "link-protocol-priority-capability" or name == "link-sw-capability" or name == "mplste-link-opt-tlv" or name == "sub-pool-unreserve-bw-per-priority" or name == "affinity" or name == "dste-allocation-model-id" or name == "dste-in-use" or name == "fragment-id" or name == "igp-metric" or name == "input-interface-id" or name == "link-address" or name == "maximum-link-bw" or name == "maximum-link-reservable-bw" or name == "maximum-link-sub-reservable-bw" or name == "mpls-link-instance" or name == "mpls-link-type" or name == "neighbor-ip-address" or name == "neighbor-system-id" or name == "new-link" or name == "number-of-optional-tl-vs" or name == "output-interface-id" or name == "priority-count" or name == "te-metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "affinity"):
                                        self.affinity = value
                                        self.affinity.value_namespace = name_space
                                        self.affinity.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dste-allocation-model-id"):
                                        self.dste_allocation_model_id = value
                                        self.dste_allocation_model_id.value_namespace = name_space
                                        self.dste_allocation_model_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dste-in-use"):
                                        self.dste_in_use = value
                                        self.dste_in_use.value_namespace = name_space
                                        self.dste_in_use.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fragment-id"):
                                        self.fragment_id = value
                                        self.fragment_id.value_namespace = name_space
                                        self.fragment_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igp-metric"):
                                        self.igp_metric = value
                                        self.igp_metric.value_namespace = name_space
                                        self.igp_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "input-interface-id"):
                                        self.input_interface_id = value
                                        self.input_interface_id.value_namespace = name_space
                                        self.input_interface_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "link-address"):
                                        self.link_address = value
                                        self.link_address.value_namespace = name_space
                                        self.link_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-link-bw"):
                                        self.maximum_link_bw = value
                                        self.maximum_link_bw.value_namespace = name_space
                                        self.maximum_link_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-link-reservable-bw"):
                                        self.maximum_link_reservable_bw = value
                                        self.maximum_link_reservable_bw.value_namespace = name_space
                                        self.maximum_link_reservable_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-link-sub-reservable-bw"):
                                        self.maximum_link_sub_reservable_bw = value
                                        self.maximum_link_sub_reservable_bw.value_namespace = name_space
                                        self.maximum_link_sub_reservable_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-link-instance"):
                                        self.mpls_link_instance = value
                                        self.mpls_link_instance.value_namespace = name_space
                                        self.mpls_link_instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-link-type"):
                                        self.mpls_link_type = value
                                        self.mpls_link_type.value_namespace = name_space
                                        self.mpls_link_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-ip-address"):
                                        self.neighbor_ip_address = value
                                        self.neighbor_ip_address.value_namespace = name_space
                                        self.neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-system-id"):
                                        self.neighbor_system_id = value
                                        self.neighbor_system_id.value_namespace = name_space
                                        self.neighbor_system_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "new-link"):
                                        self.new_link = value
                                        self.new_link.value_namespace = name_space
                                        self.new_link.value_namespace_prefix = name_space_prefix
                                    if(value_path == "number-of-optional-tl-vs"):
                                        self.number_of_optional_tl_vs = value
                                        self.number_of_optional_tl_vs.value_namespace = name_space
                                        self.number_of_optional_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "output-interface-id"):
                                        self.output_interface_id = value
                                        self.output_interface_id.value_namespace = name_space
                                        self.output_interface_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "priority-count"):
                                        self.priority_count = value
                                        self.priority_count.value_namespace = name_space
                                        self.priority_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-metric"):
                                        self.te_metric = value
                                        self.te_metric.value_namespace = name_space
                                        self.te_metric.value_namespace_prefix = name_space_prefix


                            class MplsTeFragment(Entity):
                                """
                                MPLS TE fragments in the area
                                
                                .. attribute:: dste_model_id
                                
                                	DS\-TE Allocation Model ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: fragment_id
                                
                                	Fragment ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fragment_instance
                                
                                	Fragment instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_te_link
                                
                                	List of fragment links
                                	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink>`
                                
                                .. attribute:: same_fragment_count
                                
                                	Number of fragment links which haven't changed since the last update
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment, self).__init__()

                                    self.yang_name = "mpls-te-fragment"
                                    self.yang_parent_name = "mpls-te-link"

                                    self.dste_model_id = YLeaf(YType.uint8, "dste-model-id")

                                    self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                    self.fragment_instance = YLeaf(YType.uint32, "fragment-instance")

                                    self.same_fragment_count = YLeaf(YType.uint8, "same-fragment-count")

                                    self.mpls_te_link = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dste_model_id",
                                                    "fragment_id",
                                                    "fragment_instance",
                                                    "same_fragment_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment, self).__setattr__(name, value)


                                class MplsTeLink(Entity):
                                    """
                                    List of fragment links
                                    
                                    .. attribute:: affinity
                                    
                                    	Affinity
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dste_allocation_model_id
                                    
                                    	DS\-TE Allocation Model ID
                                    	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                    
                                    .. attribute:: dste_in_use
                                    
                                    	A DS\-TE Allocation Model in use
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_admin_group_list
                                    
                                    	Extended Admin Group
                                    	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList>`
                                    
                                    .. attribute:: fragment_id
                                    
                                    	Fragment ID for this link
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: global_unreserve_bw_per_priority
                                    
                                    	Global pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                    
                                    .. attribute:: igp_metric
                                    
                                    	Link IGP metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: input_interface_id
                                    
                                    	Input interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_address
                                    
                                    	The local interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: link_protocol_priority_capability
                                    
                                    	Link protocol and protocol priority capability
                                    	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability>`
                                    
                                    .. attribute:: link_sw_capability
                                    
                                    	Link switching capability
                                    	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability>`
                                    
                                    .. attribute:: maximum_link_bw
                                    
                                    	Maximum link bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_reservable_bw
                                    
                                    	Maximum link global pool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_sub_reservable_bw
                                    
                                    	Maximum link subpool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: mpls_link_instance
                                    
                                    	Link instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mpls_link_type
                                    
                                    	Type of link
                                    	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                    
                                    .. attribute:: mplste_link_opt_tlv
                                    
                                    	List of Optional TLVs
                                    	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv>`
                                    
                                    .. attribute:: neighbor_ip_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_system_id
                                    
                                    	Neighbor system ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: new_link
                                    
                                    	If true, Link is new
                                    	**type**\:  bool
                                    
                                    .. attribute:: number_of_optional_tl_vs
                                    
                                    	Number of Optional TLVs
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: output_interface_id
                                    
                                    	Output interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: priority_count
                                    
                                    	Number of priorities
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_pool_unreserve_bw_per_priority
                                    
                                    	Sub pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                    
                                    .. attribute:: te_metric
                                    
                                    	Link TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink, self).__init__()

                                        self.yang_name = "mpls-te-link"
                                        self.yang_parent_name = "mpls-te-fragment"

                                        self.affinity = YLeaf(YType.uint32, "affinity")

                                        self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                        self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                        self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                        self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                        self.link_address = YLeaf(YType.str, "link-address")

                                        self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                        self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                        self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                        self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                        self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                        self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                        self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                        self.new_link = YLeaf(YType.boolean, "new-link")

                                        self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                        self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                        self.priority_count = YLeaf(YType.int32, "priority-count")

                                        self.te_metric = YLeaf(YType.uint32, "te-metric")

                                        self.extended_admin_group_list = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                        self.extended_admin_group_list.parent = self
                                        self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                        self._children_yang_names.add("extended-admin-group-list")

                                        self.global_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                        self.global_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                        self._children_yang_names.add("global-unreserve-bw-per-priority")

                                        self.link_protocol_priority_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                        self.link_protocol_priority_capability.parent = self
                                        self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                        self._children_yang_names.add("link-protocol-priority-capability")

                                        self.link_sw_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                        self.link_sw_capability.parent = self
                                        self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                        self._children_yang_names.add("link-sw-capability")

                                        self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                        self.sub_pool_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                        self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                        self.mplste_link_opt_tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("affinity",
                                                        "dste_allocation_model_id",
                                                        "dste_in_use",
                                                        "fragment_id",
                                                        "igp_metric",
                                                        "input_interface_id",
                                                        "link_address",
                                                        "maximum_link_bw",
                                                        "maximum_link_reservable_bw",
                                                        "maximum_link_sub_reservable_bw",
                                                        "mpls_link_instance",
                                                        "mpls_link_type",
                                                        "neighbor_ip_address",
                                                        "neighbor_system_id",
                                                        "new_link",
                                                        "number_of_optional_tl_vs",
                                                        "output_interface_id",
                                                        "priority_count",
                                                        "te_metric") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink, self).__setattr__(name, value)


                                    class GlobalUnreserveBwPerPriority(Entity):
                                        """
                                        Global pool unreserved bandwidth for each
                                        priority (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "global-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.bw_per_priority = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "global-unreserve-bw-per-priority"

                                                self.entry = YLeaf(YType.uint64, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "global-unreserve-bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "bw-per-priority"):
                                                for c in self.bw_per_priority:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.bw_per_priority.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bw-per-priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SubPoolUnreserveBwPerPriority(Entity):
                                        """
                                        Sub pool unreserved bandwidth for each priority
                                        (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.bw_per_priority = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"

                                                self.entry = YLeaf(YType.uint64, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sub-pool-unreserve-bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "bw-per-priority"):
                                                for c in self.bw_per_priority:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.bw_per_priority.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bw-per-priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class LinkProtocolPriorityCapability(Entity):
                                        """
                                        Link protocol and protocol priority capability
                                        
                                        .. attribute:: link_protocol_capability
                                        
                                        	Link protocol capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_protocol_priority
                                        
                                        	Link protocol priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                            self.yang_name = "link-protocol-priority-capability"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                            self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("link_protocol_capability",
                                                            "link_protocol_priority") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.link_protocol_capability.is_set or
                                                self.link_protocol_priority.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.link_protocol_capability.yfilter != YFilter.not_set or
                                                self.link_protocol_priority.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "link-protocol-priority-capability" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.link_protocol_capability.is_set or self.link_protocol_capability.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_protocol_capability.get_name_leafdata())
                                            if (self.link_protocol_priority.is_set or self.link_protocol_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_protocol_priority.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "link-protocol-capability" or name == "link-protocol-priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "link-protocol-capability"):
                                                self.link_protocol_capability = value
                                                self.link_protocol_capability.value_namespace = name_space
                                                self.link_protocol_capability.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-protocol-priority"):
                                                self.link_protocol_priority = value
                                                self.link_protocol_priority.value_namespace = name_space
                                                self.link_protocol_priority.value_namespace_prefix = name_space_prefix


                                    class LinkSwCapability(Entity):
                                        """
                                        Link switching capability
                                        
                                        .. attribute:: link_encoding
                                        
                                        	Link Encoding
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_mtu
                                        
                                        	Link MTU size (bytes)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: link_switching_capability
                                        
                                        	Link Switching Capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: maximum_lsp_bw_per_priority
                                        
                                        	Maximum LSP bandwidth for each priority  (bytes/s)
                                        	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                        
                                        .. attribute:: minimum_lsp_bw
                                        
                                        	Minimum LSP bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__init__()

                                            self.yang_name = "link-sw-capability"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                            self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                            self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                            self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                            self.maximum_lsp_bw_per_priority = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("link_encoding",
                                                            "link_mtu",
                                                            "link_switching_capability",
                                                            "minimum_lsp_bw") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)


                                        class MaximumLspBwPerPriority(Entity):
                                            """
                                            Maximum LSP bandwidth for each priority
                                            
                                            (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                                self.yang_name = "maximum-lsp-bw-per-priority"
                                                self.yang_parent_name = "link-sw-capability"

                                                self.entry = YLeaf(YType.uint64, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "maximum-lsp-bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.maximum_lsp_bw_per_priority:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.link_encoding.is_set or
                                                self.link_mtu.is_set or
                                                self.link_switching_capability.is_set or
                                                self.minimum_lsp_bw.is_set)

                                        def has_operation(self):
                                            for c in self.maximum_lsp_bw_per_priority:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.link_encoding.yfilter != YFilter.not_set or
                                                self.link_mtu.yfilter != YFilter.not_set or
                                                self.link_switching_capability.yfilter != YFilter.not_set or
                                                self.minimum_lsp_bw.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "link-sw-capability" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.link_encoding.is_set or self.link_encoding.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_encoding.get_name_leafdata())
                                            if (self.link_mtu.is_set or self.link_mtu.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_mtu.get_name_leafdata())
                                            if (self.link_switching_capability.is_set or self.link_switching_capability.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_switching_capability.get_name_leafdata())
                                            if (self.minimum_lsp_bw.is_set or self.minimum_lsp_bw.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_lsp_bw.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "maximum-lsp-bw-per-priority"):
                                                for c in self.maximum_lsp_bw_per_priority:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.maximum_lsp_bw_per_priority.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "maximum-lsp-bw-per-priority" or name == "link-encoding" or name == "link-mtu" or name == "link-switching-capability" or name == "minimum-lsp-bw"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "link-encoding"):
                                                self.link_encoding = value
                                                self.link_encoding.value_namespace = name_space
                                                self.link_encoding.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-mtu"):
                                                self.link_mtu = value
                                                self.link_mtu.value_namespace = name_space
                                                self.link_mtu.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-switching-capability"):
                                                self.link_switching_capability = value
                                                self.link_switching_capability.value_namespace = name_space
                                                self.link_switching_capability.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-lsp-bw"):
                                                self.minimum_lsp_bw = value
                                                self.minimum_lsp_bw.value_namespace = name_space
                                                self.minimum_lsp_bw.value_namespace_prefix = name_space_prefix


                                    class ExtendedAdminGroupList(Entity):
                                        """
                                        Extended Admin Group
                                        
                                        .. attribute:: ext_admin_data
                                        
                                        	Value of Extended Admin Group
                                        	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                        
                                        .. attribute:: extended_admin_size
                                        
                                        	Size of the extended admin group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                            self.yang_name = "extended-admin-group-list"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                            self.ext_admin_data = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("extended_admin_size") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)


                                        class ExtAdminData(Entity):
                                            """
                                            Value of Extended Admin Group
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                                self.yang_name = "ext-admin-data"
                                                self.yang_parent_name = "extended-admin-group-list"

                                                self.entry = YLeaf(YType.uint32, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ext-admin-data" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.ext_admin_data:
                                                if (c.has_data()):
                                                    return True
                                            return self.extended_admin_size.is_set

                                        def has_operation(self):
                                            for c in self.ext_admin_data:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.extended_admin_size.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "extended-admin-group-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.extended_admin_size.is_set or self.extended_admin_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.extended_admin_size.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "ext-admin-data"):
                                                for c in self.ext_admin_data:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ext_admin_data.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ext-admin-data" or name == "extended-admin-size"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "extended-admin-size"):
                                                self.extended_admin_size = value
                                                self.extended_admin_size.value_namespace = name_space
                                                self.extended_admin_size.value_namespace_prefix = name_space_prefix


                                    class MplsteLinkOptTlv(Entity):
                                        """
                                        List of Optional TLVs
                                        
                                        .. attribute:: mplste_link_opt_tlv_len
                                        
                                        	Length of Opt TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mplste_link_opt_tlv_type
                                        
                                        	Type of Opt TLV
                                        	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                        
                                        .. attribute:: mplste_link_opt_tlv_value
                                        
                                        	Value of Opt TLV
                                        	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                            self.yang_name = "mplste-link-opt-tlv"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                            self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                            self.mplste_link_opt_tlv_value = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("mplste_link_opt_tlv_len",
                                                            "mplste_link_opt_tlv_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)


                                        class MplsteLinkOptTlvValue(Entity):
                                            """
                                            Value of Opt TLV
                                            
                                            .. attribute:: bctlv_value
                                            
                                            	Value of Bandwidth Constraints TLV
                                            	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                            
                                            .. attribute:: ixcdtlv_value
                                            
                                            	Value of IXCD TLV
                                            	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                            
                                            .. attribute:: opaque_tlv_type
                                            
                                            	OpaqueTLVType
                                            	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                            
                                            .. attribute:: srlgtlv_value
                                            
                                            	Value of SRLG TLV
                                            	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                            
                                            .. attribute:: unidtlv_value
                                            
                                            	Value of Uni Delay TLV
                                            	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                                self.yang_name = "mplste-link-opt-tlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv"

                                                self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                                self.bctlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                self.bctlv_value.parent = self
                                                self._children_name_map["bctlv_value"] = "bctlv-value"
                                                self._children_yang_names.add("bctlv-value")

                                                self.ixcdtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                self.ixcdtlv_value.parent = self
                                                self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                self._children_yang_names.add("ixcdtlv-value")

                                                self.srlgtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                self.srlgtlv_value.parent = self
                                                self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                self._children_yang_names.add("srlgtlv-value")

                                                self.unidtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                self.unidtlv_value.parent = self
                                                self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                self._children_yang_names.add("unidtlv-value")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("opaque_tlv_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)


                                            class BctlvValue(Entity):
                                                """
                                                Value of Bandwidth Constraints TLV
                                                
                                                .. attribute:: model_id
                                                
                                                	Allocation Model ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mplste_link_bc_bandwidth
                                                
                                                	Value of BC TLV
                                                	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                                
                                                .. attribute:: num_b_cs
                                                
                                                	Number of BC TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                    self.yang_name = "bctlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.model_id = YLeaf(YType.uint8, "model-id")

                                                    self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                    self.mplste_link_bc_bandwidth = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("model_id",
                                                                    "num_b_cs") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)


                                                class MplsteLinkBcBandwidth(Entity):
                                                    """
                                                    Value of BC TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                        self.yang_name = "mplste-link-bc-bandwidth"
                                                        self.yang_parent_name = "bctlv-value"

                                                        self.entry = YLeaf(YType.uint64, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "mplste-link-bc-bandwidth" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.mplste_link_bc_bandwidth:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.model_id.is_set or
                                                        self.num_b_cs.is_set)

                                                def has_operation(self):
                                                    for c in self.mplste_link_bc_bandwidth:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.model_id.yfilter != YFilter.not_set or
                                                        self.num_b_cs.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bctlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.model_id.is_set or self.model_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.model_id.get_name_leafdata())
                                                    if (self.num_b_cs.is_set or self.num_b_cs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_b_cs.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "mplste-link-bc-bandwidth"):
                                                        for c in self.mplste_link_bc_bandwidth:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.mplste_link_bc_bandwidth.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "mplste-link-bc-bandwidth" or name == "model-id" or name == "num-b-cs"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "model-id"):
                                                        self.model_id = value
                                                        self.model_id.value_namespace = name_space
                                                        self.model_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-b-cs"):
                                                        self.num_b_cs = value
                                                        self.num_b_cs.value_namespace = name_space
                                                        self.num_b_cs.value_namespace_prefix = name_space_prefix


                                            class SrlgtlvValue(Entity):
                                                """
                                                Value of SRLG TLV
                                                
                                                .. attribute:: mplste_link_srlg_data
                                                
                                                	Value of SRLG TLV
                                                	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                                
                                                .. attribute:: num_srl_gs
                                                
                                                	Number of SRLG TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: srlg_len
                                                
                                                	Length of SRLG TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                    self.yang_name = "srlgtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                    self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                    self.mplste_link_srlg_data = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("num_srl_gs",
                                                                    "srlg_len") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)


                                                class MplsteLinkSrlgData(Entity):
                                                    """
                                                    Value of SRLG TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                        self.yang_name = "mplste-link-srlg-data"
                                                        self.yang_parent_name = "srlgtlv-value"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "mplste-link-srlg-data" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.mplste_link_srlg_data:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.num_srl_gs.is_set or
                                                        self.srlg_len.is_set)

                                                def has_operation(self):
                                                    for c in self.mplste_link_srlg_data:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.num_srl_gs.yfilter != YFilter.not_set or
                                                        self.srlg_len.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "srlgtlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.num_srl_gs.is_set or self.num_srl_gs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_srl_gs.get_name_leafdata())
                                                    if (self.srlg_len.is_set or self.srlg_len.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.srlg_len.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "mplste-link-srlg-data"):
                                                        for c in self.mplste_link_srlg_data:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.mplste_link_srlg_data.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "mplste-link-srlg-data" or name == "num-srl-gs" or name == "srlg-len"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "num-srl-gs"):
                                                        self.num_srl_gs = value
                                                        self.num_srl_gs.value_namespace = name_space
                                                        self.num_srl_gs.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "srlg-len"):
                                                        self.srlg_len = value
                                                        self.srlg_len.value_namespace = name_space
                                                        self.srlg_len.value_namespace_prefix = name_space_prefix


                                            class IxcdtlvValue(Entity):
                                                """
                                                Value of IXCD TLV
                                                
                                                .. attribute:: fixed_scsi_count
                                                
                                                	Fixed SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flex_scsi_count
                                                
                                                	Flexible SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ixcd_switching_cap_type
                                                
                                                	Switching Cap type
                                                	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                                
                                                .. attribute:: max_lspbw
                                                
                                                	Max LSP bandwidth array
                                                	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                                
                                                .. attribute:: rile_len_code
                                                
                                                	Rile LenCode
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: switching_cap
                                                
                                                	SCap
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                    self.yang_name = "ixcdtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                    self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                    self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                    self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                    self.ixcd_switching_cap_type = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                    self.ixcd_switching_cap_type.parent = self
                                                    self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                    self._children_yang_names.add("ixcd-switching-cap-type")

                                                    self.max_lspbw = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("fixed_scsi_count",
                                                                    "flex_scsi_count",
                                                                    "rile_len_code",
                                                                    "switching_cap") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)


                                                class IxcdSwitchingCapType(Entity):
                                                    """
                                                    Switching Cap type
                                                    
                                                    .. attribute:: ixcdbw_sub_tlv
                                                    
                                                    	Sub TLVs
                                                    	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                    
                                                    .. attribute:: ixcdpsc_info
                                                    
                                                    	IXCD PSC information
                                                    	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                    
                                                    .. attribute:: switching_cap_type
                                                    
                                                    	SwitchingCapType
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                        self.yang_name = "ixcd-switching-cap-type"
                                                        self.yang_parent_name = "ixcdtlv-value"

                                                        self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                        self.ixcdbw_sub_tlv = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                        self.ixcdbw_sub_tlv.parent = self
                                                        self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                        self._children_yang_names.add("ixcdbw-sub-tlv")

                                                        self.ixcdpsc_info = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                        self.ixcdpsc_info.parent = self
                                                        self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                        self._children_yang_names.add("ixcdpsc-info")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("switching_cap_type") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)


                                                    class IxcdpscInfo(Entity):
                                                        """
                                                        IXCD PSC information
                                                        
                                                        .. attribute:: min_lsp_bandwidth
                                                        
                                                        	Min LSP bandwidth
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: psc_interface_mtu
                                                        
                                                        	 Interface MTU
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                            self.yang_name = "ixcdpsc-info"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"

                                                            self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                            self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("min_lsp_bandwidth",
                                                                            "psc_interface_mtu") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.min_lsp_bandwidth.is_set or
                                                                self.psc_interface_mtu.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.min_lsp_bandwidth.yfilter != YFilter.not_set or
                                                                self.psc_interface_mtu.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ixcdpsc-info" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.min_lsp_bandwidth.is_set or self.min_lsp_bandwidth.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.min_lsp_bandwidth.get_name_leafdata())
                                                            if (self.psc_interface_mtu.is_set or self.psc_interface_mtu.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.psc_interface_mtu.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "min-lsp-bandwidth" or name == "psc-interface-mtu"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "min-lsp-bandwidth"):
                                                                self.min_lsp_bandwidth = value
                                                                self.min_lsp_bandwidth.value_namespace = name_space
                                                                self.min_lsp_bandwidth.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "psc-interface-mtu"):
                                                                self.psc_interface_mtu = value
                                                                self.psc_interface_mtu.value_namespace = name_space
                                                                self.psc_interface_mtu.value_namespace_prefix = name_space_prefix


                                                    class IxcdbwSubTlv(Entity):
                                                        """
                                                        Sub TLVs
                                                        
                                                        .. attribute:: arr_bw_sub_tlv
                                                        
                                                        	Array of sub tlvs
                                                        	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                            self.yang_name = "ixcdbw-sub-tlv"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"

                                                            self.arr_bw_sub_tlv = YList(self)

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in () and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)


                                                        class ArrBwSubTlv(Entity):
                                                            """
                                                            Array of sub tlvs
                                                            
                                                            .. attribute:: bw_sub_tlv_length
                                                            
                                                            	Length of BW Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_type
                                                            
                                                            	Type of Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_value
                                                            
                                                            	Value of BW Sub TLV
                                                            	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                                self.yang_name = "arr-bw-sub-tlv"
                                                                self.yang_parent_name = "ixcdbw-sub-tlv"

                                                                self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                                self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                                self.bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                self.bw_sub_tlv_value.parent = self
                                                                self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                self._children_yang_names.add("bw-sub-tlv-value")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("bw_sub_tlv_length",
                                                                                "bw_sub_tlv_type") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)


                                                            class BwSubTlvValue(Entity):
                                                                """
                                                                Value of BW Sub TLV
                                                                
                                                                .. attribute:: fixed_bw_sub_tlv_value
                                                                
                                                                	Value of Fixed Sub TLV
                                                                	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                                
                                                                .. attribute:: flex_bw_sub_tlv_value
                                                                
                                                                	Value of Flex Sub TLV
                                                                	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                                
                                                                .. attribute:: ixcdbw_sub_tlv_type
                                                                
                                                                	IXCDBWSubTLVType
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-01-02'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                    self.yang_name = "bw-sub-tlv-value"
                                                                    self.yang_parent_name = "arr-bw-sub-tlv"

                                                                    self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                    self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                    self.fixed_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                    self.flex_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                    self.flex_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("flex-bw-sub-tlv-value")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("ixcdbw_sub_tlv_type") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)


                                                                class FixedBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Fixed Sub TLV
                                                                    
                                                                    .. attribute:: fixed_sub_tlv_value
                                                                    
                                                                    	Value of Fixed Sub TLV
                                                                    	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                    
                                                                    .. attribute:: unres_oduj_prio
                                                                    
                                                                    	Array of Unres Oduj Prio
                                                                    	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "fixed-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"

                                                                        self.fixed_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                        self.fixed_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                        self._children_yang_names.add("fixed-sub-tlv-value")

                                                                        self.unres_oduj_prio = YList(self)

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in () and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)


                                                                    class FixedSubTlvValue(Entity):
                                                                        """
                                                                        Value of Fixed Sub TLV
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                            self.yang_name = "fixed-sub-tlv-value"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("num_stages",
                                                                                            "priority_bit0",
                                                                                            "priority_bit1",
                                                                                            "priority_bit2",
                                                                                            "priority_bit3",
                                                                                            "priority_bit4",
                                                                                            "priority_bit5",
                                                                                            "priority_bit6",
                                                                                            "priority_bit7",
                                                                                            "res",
                                                                                            "sbit",
                                                                                            "signal_type",
                                                                                            "stage",
                                                                                            "tbit",
                                                                                            "tsg") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return (
                                                                                self.num_stages.is_set or
                                                                                self.priority_bit0.is_set or
                                                                                self.priority_bit1.is_set or
                                                                                self.priority_bit2.is_set or
                                                                                self.priority_bit3.is_set or
                                                                                self.priority_bit4.is_set or
                                                                                self.priority_bit5.is_set or
                                                                                self.priority_bit6.is_set or
                                                                                self.priority_bit7.is_set or
                                                                                self.res.is_set or
                                                                                self.sbit.is_set or
                                                                                self.signal_type.is_set or
                                                                                self.stage.is_set or
                                                                                self.tbit.is_set or
                                                                                self.tsg.is_set)

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.num_stages.yfilter != YFilter.not_set or
                                                                                self.priority_bit0.yfilter != YFilter.not_set or
                                                                                self.priority_bit1.yfilter != YFilter.not_set or
                                                                                self.priority_bit2.yfilter != YFilter.not_set or
                                                                                self.priority_bit3.yfilter != YFilter.not_set or
                                                                                self.priority_bit4.yfilter != YFilter.not_set or
                                                                                self.priority_bit5.yfilter != YFilter.not_set or
                                                                                self.priority_bit6.yfilter != YFilter.not_set or
                                                                                self.priority_bit7.yfilter != YFilter.not_set or
                                                                                self.res.yfilter != YFilter.not_set or
                                                                                self.sbit.yfilter != YFilter.not_set or
                                                                                self.signal_type.yfilter != YFilter.not_set or
                                                                                self.stage.yfilter != YFilter.not_set or
                                                                                self.tbit.yfilter != YFilter.not_set or
                                                                                self.tsg.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "fixed-sub-tlv-value" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                            if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                            if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                            if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                            if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                            if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                            if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                            if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                            if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                            if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.res.get_name_leafdata())
                                                                            if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                            if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                            if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.stage.get_name_leafdata())
                                                                            if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                            if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "num-stages"):
                                                                                self.num_stages = value
                                                                                self.num_stages.value_namespace = name_space
                                                                                self.num_stages.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit0"):
                                                                                self.priority_bit0 = value
                                                                                self.priority_bit0.value_namespace = name_space
                                                                                self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit1"):
                                                                                self.priority_bit1 = value
                                                                                self.priority_bit1.value_namespace = name_space
                                                                                self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit2"):
                                                                                self.priority_bit2 = value
                                                                                self.priority_bit2.value_namespace = name_space
                                                                                self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit3"):
                                                                                self.priority_bit3 = value
                                                                                self.priority_bit3.value_namespace = name_space
                                                                                self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit4"):
                                                                                self.priority_bit4 = value
                                                                                self.priority_bit4.value_namespace = name_space
                                                                                self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit5"):
                                                                                self.priority_bit5 = value
                                                                                self.priority_bit5.value_namespace = name_space
                                                                                self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit6"):
                                                                                self.priority_bit6 = value
                                                                                self.priority_bit6.value_namespace = name_space
                                                                                self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit7"):
                                                                                self.priority_bit7 = value
                                                                                self.priority_bit7.value_namespace = name_space
                                                                                self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "res"):
                                                                                self.res = value
                                                                                self.res.value_namespace = name_space
                                                                                self.res.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "sbit"):
                                                                                self.sbit = value
                                                                                self.sbit.value_namespace = name_space
                                                                                self.sbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "signal-type"):
                                                                                self.signal_type = value
                                                                                self.signal_type.value_namespace = name_space
                                                                                self.signal_type.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "stage"):
                                                                                self.stage = value
                                                                                self.stage.value_namespace = name_space
                                                                                self.stage.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tbit"):
                                                                                self.tbit = value
                                                                                self.tbit.value_namespace = name_space
                                                                                self.tbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tsg"):
                                                                                self.tsg = value
                                                                                self.tsg.value_namespace = name_space
                                                                                self.tsg.value_namespace_prefix = name_space_prefix


                                                                    class UnresOdujPrio(Entity):
                                                                        """
                                                                        Array of Unres Oduj Prio
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                            self.yang_name = "unres-oduj-prio"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                            self.entry = YLeaf(YType.uint32, "entry")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("entry") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return self.entry.is_set

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.entry.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "unres-oduj-prio" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "entry"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "entry"):
                                                                                self.entry = value
                                                                                self.entry.value_namespace = name_space
                                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                                    def has_data(self):
                                                                        for c in self.unres_oduj_prio:
                                                                            if (c.has_data()):
                                                                                return True
                                                                        return (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_data())

                                                                    def has_operation(self):
                                                                        for c in self.unres_oduj_prio:
                                                                            if (c.has_operation()):
                                                                                return True
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_operation()))

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "fixed-bw-sub-tlv-value" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        if (child_yang_name == "fixed-sub-tlv-value"):
                                                                            if (self.fixed_sub_tlv_value is None):
                                                                                self.fixed_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                                self.fixed_sub_tlv_value.parent = self
                                                                                self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                            return self.fixed_sub_tlv_value

                                                                        if (child_yang_name == "unres-oduj-prio"):
                                                                            for c in self.unres_oduj_prio:
                                                                                segment = c.get_segment_path()
                                                                                if (segment_path == segment):
                                                                                    return c
                                                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio()
                                                                            c.parent = self
                                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                                            self._local_refs[local_reference_key] = c
                                                                            self.unres_oduj_prio.append(c)
                                                                            return c

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "fixed-sub-tlv-value" or name == "unres-oduj-prio"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        pass


                                                                class FlexBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Flex Sub TLV
                                                                    
                                                                    .. attribute:: flex_sub_tlv_value_common
                                                                    
                                                                    	Flex Sub TLV Value
                                                                    	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                    
                                                                    .. attribute:: max_lspbw
                                                                    
                                                                    	Max LSP BW Array
                                                                    	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                    
                                                                    .. attribute:: unres_lspbw
                                                                    
                                                                    	Array of Unres LSP BW
                                                                    	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "flex-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"

                                                                        self.flex_sub_tlv_value_common = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                        self.flex_sub_tlv_value_common.parent = self
                                                                        self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                        self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                        self.max_lspbw = YList(self)
                                                                        self.unres_lspbw = YList(self)

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in () and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)


                                                                    class FlexSubTlvValueCommon(Entity):
                                                                        """
                                                                        Flex Sub TLV Value
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                            self.yang_name = "flex-sub-tlv-value-common"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("num_stages",
                                                                                            "priority_bit0",
                                                                                            "priority_bit1",
                                                                                            "priority_bit2",
                                                                                            "priority_bit3",
                                                                                            "priority_bit4",
                                                                                            "priority_bit5",
                                                                                            "priority_bit6",
                                                                                            "priority_bit7",
                                                                                            "res",
                                                                                            "sbit",
                                                                                            "signal_type",
                                                                                            "stage",
                                                                                            "tbit",
                                                                                            "tsg") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return (
                                                                                self.num_stages.is_set or
                                                                                self.priority_bit0.is_set or
                                                                                self.priority_bit1.is_set or
                                                                                self.priority_bit2.is_set or
                                                                                self.priority_bit3.is_set or
                                                                                self.priority_bit4.is_set or
                                                                                self.priority_bit5.is_set or
                                                                                self.priority_bit6.is_set or
                                                                                self.priority_bit7.is_set or
                                                                                self.res.is_set or
                                                                                self.sbit.is_set or
                                                                                self.signal_type.is_set or
                                                                                self.stage.is_set or
                                                                                self.tbit.is_set or
                                                                                self.tsg.is_set)

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.num_stages.yfilter != YFilter.not_set or
                                                                                self.priority_bit0.yfilter != YFilter.not_set or
                                                                                self.priority_bit1.yfilter != YFilter.not_set or
                                                                                self.priority_bit2.yfilter != YFilter.not_set or
                                                                                self.priority_bit3.yfilter != YFilter.not_set or
                                                                                self.priority_bit4.yfilter != YFilter.not_set or
                                                                                self.priority_bit5.yfilter != YFilter.not_set or
                                                                                self.priority_bit6.yfilter != YFilter.not_set or
                                                                                self.priority_bit7.yfilter != YFilter.not_set or
                                                                                self.res.yfilter != YFilter.not_set or
                                                                                self.sbit.yfilter != YFilter.not_set or
                                                                                self.signal_type.yfilter != YFilter.not_set or
                                                                                self.stage.yfilter != YFilter.not_set or
                                                                                self.tbit.yfilter != YFilter.not_set or
                                                                                self.tsg.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "flex-sub-tlv-value-common" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                            if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                            if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                            if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                            if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                            if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                            if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                            if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                            if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                            if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.res.get_name_leafdata())
                                                                            if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                            if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                            if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.stage.get_name_leafdata())
                                                                            if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                            if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "num-stages"):
                                                                                self.num_stages = value
                                                                                self.num_stages.value_namespace = name_space
                                                                                self.num_stages.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit0"):
                                                                                self.priority_bit0 = value
                                                                                self.priority_bit0.value_namespace = name_space
                                                                                self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit1"):
                                                                                self.priority_bit1 = value
                                                                                self.priority_bit1.value_namespace = name_space
                                                                                self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit2"):
                                                                                self.priority_bit2 = value
                                                                                self.priority_bit2.value_namespace = name_space
                                                                                self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit3"):
                                                                                self.priority_bit3 = value
                                                                                self.priority_bit3.value_namespace = name_space
                                                                                self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit4"):
                                                                                self.priority_bit4 = value
                                                                                self.priority_bit4.value_namespace = name_space
                                                                                self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit5"):
                                                                                self.priority_bit5 = value
                                                                                self.priority_bit5.value_namespace = name_space
                                                                                self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit6"):
                                                                                self.priority_bit6 = value
                                                                                self.priority_bit6.value_namespace = name_space
                                                                                self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit7"):
                                                                                self.priority_bit7 = value
                                                                                self.priority_bit7.value_namespace = name_space
                                                                                self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "res"):
                                                                                self.res = value
                                                                                self.res.value_namespace = name_space
                                                                                self.res.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "sbit"):
                                                                                self.sbit = value
                                                                                self.sbit.value_namespace = name_space
                                                                                self.sbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "signal-type"):
                                                                                self.signal_type = value
                                                                                self.signal_type.value_namespace = name_space
                                                                                self.signal_type.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "stage"):
                                                                                self.stage = value
                                                                                self.stage.value_namespace = name_space
                                                                                self.stage.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tbit"):
                                                                                self.tbit = value
                                                                                self.tbit.value_namespace = name_space
                                                                                self.tbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tsg"):
                                                                                self.tsg = value
                                                                                self.tsg.value_namespace = name_space
                                                                                self.tsg.value_namespace_prefix = name_space_prefix


                                                                    class UnresLspbw(Entity):
                                                                        """
                                                                        Array of Unres LSP BW
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                            self.yang_name = "unres-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                            self.entry = YLeaf(YType.uint64, "entry")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("entry") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return self.entry.is_set

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.entry.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "unres-lspbw" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "entry"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "entry"):
                                                                                self.entry = value
                                                                                self.entry.value_namespace = name_space
                                                                                self.entry.value_namespace_prefix = name_space_prefix


                                                                    class MaxLspbw(Entity):
                                                                        """
                                                                        Max LSP BW Array
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                            self.yang_name = "max-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                            self.entry = YLeaf(YType.uint64, "entry")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("entry") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return self.entry.is_set

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.entry.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "max-lspbw" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "entry"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "entry"):
                                                                                self.entry = value
                                                                                self.entry.value_namespace = name_space
                                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                                    def has_data(self):
                                                                        for c in self.max_lspbw:
                                                                            if (c.has_data()):
                                                                                return True
                                                                        for c in self.unres_lspbw:
                                                                            if (c.has_data()):
                                                                                return True
                                                                        return (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_data())

                                                                    def has_operation(self):
                                                                        for c in self.max_lspbw:
                                                                            if (c.has_operation()):
                                                                                return True
                                                                        for c in self.unres_lspbw:
                                                                            if (c.has_operation()):
                                                                                return True
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_operation()))

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "flex-bw-sub-tlv-value" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        if (child_yang_name == "flex-sub-tlv-value-common"):
                                                                            if (self.flex_sub_tlv_value_common is None):
                                                                                self.flex_sub_tlv_value_common = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                                self.flex_sub_tlv_value_common.parent = self
                                                                                self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                            return self.flex_sub_tlv_value_common

                                                                        if (child_yang_name == "max-lspbw"):
                                                                            for c in self.max_lspbw:
                                                                                segment = c.get_segment_path()
                                                                                if (segment_path == segment):
                                                                                    return c
                                                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw()
                                                                            c.parent = self
                                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                                            self._local_refs[local_reference_key] = c
                                                                            self.max_lspbw.append(c)
                                                                            return c

                                                                        if (child_yang_name == "unres-lspbw"):
                                                                            for c in self.unres_lspbw:
                                                                                segment = c.get_segment_path()
                                                                                if (segment_path == segment):
                                                                                    return c
                                                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw()
                                                                            c.parent = self
                                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                                            self._local_refs[local_reference_key] = c
                                                                            self.unres_lspbw.append(c)
                                                                            return c

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "flex-sub-tlv-value-common" or name == "max-lspbw" or name == "unres-lspbw"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        pass

                                                                def has_data(self):
                                                                    return (
                                                                        self.ixcdbw_sub_tlv_type.is_set or
                                                                        (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_data()) or
                                                                        (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_data()))

                                                                def has_operation(self):
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                        (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_operation()) or
                                                                        (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_operation()))

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "bw-sub-tlv-value" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.ixcdbw_sub_tlv_type.is_set or self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ixcdbw_sub_tlv_type.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    if (child_yang_name == "fixed-bw-sub-tlv-value"):
                                                                        if (self.fixed_bw_sub_tlv_value is None):
                                                                            self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                            self.fixed_bw_sub_tlv_value.parent = self
                                                                            self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                        return self.fixed_bw_sub_tlv_value

                                                                    if (child_yang_name == "flex-bw-sub-tlv-value"):
                                                                        if (self.flex_bw_sub_tlv_value is None):
                                                                            self.flex_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                            self.flex_bw_sub_tlv_value.parent = self
                                                                            self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                        return self.flex_bw_sub_tlv_value

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "fixed-bw-sub-tlv-value" or name == "flex-bw-sub-tlv-value" or name == "ixcdbw-sub-tlv-type"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "ixcdbw-sub-tlv-type"):
                                                                        self.ixcdbw_sub_tlv_type = value
                                                                        self.ixcdbw_sub_tlv_type.value_namespace = name_space
                                                                        self.ixcdbw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                return (
                                                                    self.bw_sub_tlv_length.is_set or
                                                                    self.bw_sub_tlv_type.is_set or
                                                                    (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_data()))

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.bw_sub_tlv_length.yfilter != YFilter.not_set or
                                                                    self.bw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                    (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_operation()))

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "arr-bw-sub-tlv" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.bw_sub_tlv_length.is_set or self.bw_sub_tlv_length.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.bw_sub_tlv_length.get_name_leafdata())
                                                                if (self.bw_sub_tlv_type.is_set or self.bw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.bw_sub_tlv_type.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "bw-sub-tlv-value"):
                                                                    if (self.bw_sub_tlv_value is None):
                                                                        self.bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                        self.bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                    return self.bw_sub_tlv_value

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "bw-sub-tlv-value" or name == "bw-sub-tlv-length" or name == "bw-sub-tlv-type"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "bw-sub-tlv-length"):
                                                                    self.bw_sub_tlv_length = value
                                                                    self.bw_sub_tlv_length.value_namespace = name_space
                                                                    self.bw_sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "bw-sub-tlv-type"):
                                                                    self.bw_sub_tlv_type = value
                                                                    self.bw_sub_tlv_type.value_namespace = name_space
                                                                    self.bw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                        def has_data(self):
                                                            for c in self.arr_bw_sub_tlv:
                                                                if (c.has_data()):
                                                                    return True
                                                            return False

                                                        def has_operation(self):
                                                            for c in self.arr_bw_sub_tlv:
                                                                if (c.has_operation()):
                                                                    return True
                                                            return self.yfilter != YFilter.not_set

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ixcdbw-sub-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "arr-bw-sub-tlv"):
                                                                for c in self.arr_bw_sub_tlv:
                                                                    segment = c.get_segment_path()
                                                                    if (segment_path == segment):
                                                                        return c
                                                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv()
                                                                c.parent = self
                                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                                self._local_refs[local_reference_key] = c
                                                                self.arr_bw_sub_tlv.append(c)
                                                                return c

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "arr-bw-sub-tlv"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            pass

                                                    def has_data(self):
                                                        return (
                                                            self.switching_cap_type.is_set or
                                                            (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_data()) or
                                                            (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_data()))

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.switching_cap_type.yfilter != YFilter.not_set or
                                                            (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_operation()) or
                                                            (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_operation()))

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ixcd-switching-cap-type" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.switching_cap_type.is_set or self.switching_cap_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.switching_cap_type.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ixcdbw-sub-tlv"):
                                                            if (self.ixcdbw_sub_tlv is None):
                                                                self.ixcdbw_sub_tlv = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                                self.ixcdbw_sub_tlv.parent = self
                                                                self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                            return self.ixcdbw_sub_tlv

                                                        if (child_yang_name == "ixcdpsc-info"):
                                                            if (self.ixcdpsc_info is None):
                                                                self.ixcdpsc_info = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                                self.ixcdpsc_info.parent = self
                                                                self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                            return self.ixcdpsc_info

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ixcdbw-sub-tlv" or name == "ixcdpsc-info" or name == "switching-cap-type"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "switching-cap-type"):
                                                            self.switching_cap_type = value
                                                            self.switching_cap_type.value_namespace = name_space
                                                            self.switching_cap_type.value_namespace_prefix = name_space_prefix


                                                class MaxLspbw(Entity):
                                                    """
                                                    Max LSP bandwidth array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-9223372036854775808..9223372036854775807
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                        self.yang_name = "max-lspbw"
                                                        self.yang_parent_name = "ixcdtlv-value"

                                                        self.entry = YLeaf(YType.int64, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "max-lspbw" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.max_lspbw:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.fixed_scsi_count.is_set or
                                                        self.flex_scsi_count.is_set or
                                                        self.rile_len_code.is_set or
                                                        self.switching_cap.is_set or
                                                        (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_data()))

                                                def has_operation(self):
                                                    for c in self.max_lspbw:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.fixed_scsi_count.yfilter != YFilter.not_set or
                                                        self.flex_scsi_count.yfilter != YFilter.not_set or
                                                        self.rile_len_code.yfilter != YFilter.not_set or
                                                        self.switching_cap.yfilter != YFilter.not_set or
                                                        (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ixcdtlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.fixed_scsi_count.is_set or self.fixed_scsi_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fixed_scsi_count.get_name_leafdata())
                                                    if (self.flex_scsi_count.is_set or self.flex_scsi_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flex_scsi_count.get_name_leafdata())
                                                    if (self.rile_len_code.is_set or self.rile_len_code.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rile_len_code.get_name_leafdata())
                                                    if (self.switching_cap.is_set or self.switching_cap.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.switching_cap.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ixcd-switching-cap-type"):
                                                        if (self.ixcd_switching_cap_type is None):
                                                            self.ixcd_switching_cap_type = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                            self.ixcd_switching_cap_type.parent = self
                                                            self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                        return self.ixcd_switching_cap_type

                                                    if (child_yang_name == "max-lspbw"):
                                                        for c in self.max_lspbw:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.max_lspbw.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ixcd-switching-cap-type" or name == "max-lspbw" or name == "fixed-scsi-count" or name == "flex-scsi-count" or name == "rile-len-code" or name == "switching-cap"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "fixed-scsi-count"):
                                                        self.fixed_scsi_count = value
                                                        self.fixed_scsi_count.value_namespace = name_space
                                                        self.fixed_scsi_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flex-scsi-count"):
                                                        self.flex_scsi_count = value
                                                        self.flex_scsi_count.value_namespace = name_space
                                                        self.flex_scsi_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rile-len-code"):
                                                        self.rile_len_code = value
                                                        self.rile_len_code.value_namespace = name_space
                                                        self.rile_len_code.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "switching-cap"):
                                                        self.switching_cap = value
                                                        self.switching_cap.value_namespace = name_space
                                                        self.switching_cap.value_namespace_prefix = name_space_prefix


                                            class UnidtlvValue(Entity):
                                                """
                                                Value of Uni Delay TLV
                                                
                                                .. attribute:: uni_dir_delay
                                                
                                                	Uni Dir Delay
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                    self.yang_name = "unidtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("uni_dir_delay") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.uni_dir_delay.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.uni_dir_delay.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unidtlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.uni_dir_delay.is_set or self.uni_dir_delay.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.uni_dir_delay.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "uni-dir-delay"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "uni-dir-delay"):
                                                        self.uni_dir_delay = value
                                                        self.uni_dir_delay.value_namespace = name_space
                                                        self.uni_dir_delay.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.opaque_tlv_type.is_set or
                                                    (self.bctlv_value is not None and self.bctlv_value.has_data()) or
                                                    (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_data()) or
                                                    (self.srlgtlv_value is not None and self.srlgtlv_value.has_data()) or
                                                    (self.unidtlv_value is not None and self.unidtlv_value.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.opaque_tlv_type.yfilter != YFilter.not_set or
                                                    (self.bctlv_value is not None and self.bctlv_value.has_operation()) or
                                                    (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_operation()) or
                                                    (self.srlgtlv_value is not None and self.srlgtlv_value.has_operation()) or
                                                    (self.unidtlv_value is not None and self.unidtlv_value.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mplste-link-opt-tlv-value" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.opaque_tlv_type.is_set or self.opaque_tlv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.opaque_tlv_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bctlv-value"):
                                                    if (self.bctlv_value is None):
                                                        self.bctlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                        self.bctlv_value.parent = self
                                                        self._children_name_map["bctlv_value"] = "bctlv-value"
                                                    return self.bctlv_value

                                                if (child_yang_name == "ixcdtlv-value"):
                                                    if (self.ixcdtlv_value is None):
                                                        self.ixcdtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                        self.ixcdtlv_value.parent = self
                                                        self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                    return self.ixcdtlv_value

                                                if (child_yang_name == "srlgtlv-value"):
                                                    if (self.srlgtlv_value is None):
                                                        self.srlgtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                        self.srlgtlv_value.parent = self
                                                        self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                    return self.srlgtlv_value

                                                if (child_yang_name == "unidtlv-value"):
                                                    if (self.unidtlv_value is None):
                                                        self.unidtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                        self.unidtlv_value.parent = self
                                                        self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                    return self.unidtlv_value

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bctlv-value" or name == "ixcdtlv-value" or name == "srlgtlv-value" or name == "unidtlv-value" or name == "opaque-tlv-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "opaque-tlv-type"):
                                                    self.opaque_tlv_type = value
                                                    self.opaque_tlv_type.value_namespace = name_space
                                                    self.opaque_tlv_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.mplste_link_opt_tlv_value:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.mplste_link_opt_tlv_len.is_set or
                                                self.mplste_link_opt_tlv_type.is_set)

                                        def has_operation(self):
                                            for c in self.mplste_link_opt_tlv_value:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set or
                                                self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mplste-link-opt-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.mplste_link_opt_tlv_len.is_set or self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mplste_link_opt_tlv_len.get_name_leafdata())
                                            if (self.mplste_link_opt_tlv_type.is_set or self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mplste_link_opt_tlv_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "mplste-link-opt-tlv-value"):
                                                for c in self.mplste_link_opt_tlv_value:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.mplste_link_opt_tlv_value.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "mplste-link-opt-tlv-value" or name == "mplste-link-opt-tlv-len" or name == "mplste-link-opt-tlv-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "mplste-link-opt-tlv-len"):
                                                self.mplste_link_opt_tlv_len = value
                                                self.mplste_link_opt_tlv_len.value_namespace = name_space
                                                self.mplste_link_opt_tlv_len.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mplste-link-opt-tlv-type"):
                                                self.mplste_link_opt_tlv_type = value
                                                self.mplste_link_opt_tlv_type.value_namespace = name_space
                                                self.mplste_link_opt_tlv_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.mplste_link_opt_tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.affinity.is_set or
                                            self.dste_allocation_model_id.is_set or
                                            self.dste_in_use.is_set or
                                            self.fragment_id.is_set or
                                            self.igp_metric.is_set or
                                            self.input_interface_id.is_set or
                                            self.link_address.is_set or
                                            self.maximum_link_bw.is_set or
                                            self.maximum_link_reservable_bw.is_set or
                                            self.maximum_link_sub_reservable_bw.is_set or
                                            self.mpls_link_instance.is_set or
                                            self.mpls_link_type.is_set or
                                            self.neighbor_ip_address.is_set or
                                            self.neighbor_system_id.is_set or
                                            self.new_link.is_set or
                                            self.number_of_optional_tl_vs.is_set or
                                            self.output_interface_id.is_set or
                                            self.priority_count.is_set or
                                            self.te_metric.is_set or
                                            (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_data()) or
                                            (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_data()) or
                                            (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_data()) or
                                            (self.link_sw_capability is not None and self.link_sw_capability.has_data()) or
                                            (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_data()))

                                    def has_operation(self):
                                        for c in self.mplste_link_opt_tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.affinity.yfilter != YFilter.not_set or
                                            self.dste_allocation_model_id.yfilter != YFilter.not_set or
                                            self.dste_in_use.yfilter != YFilter.not_set or
                                            self.fragment_id.yfilter != YFilter.not_set or
                                            self.igp_metric.yfilter != YFilter.not_set or
                                            self.input_interface_id.yfilter != YFilter.not_set or
                                            self.link_address.yfilter != YFilter.not_set or
                                            self.maximum_link_bw.yfilter != YFilter.not_set or
                                            self.maximum_link_reservable_bw.yfilter != YFilter.not_set or
                                            self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set or
                                            self.mpls_link_instance.yfilter != YFilter.not_set or
                                            self.mpls_link_type.yfilter != YFilter.not_set or
                                            self.neighbor_ip_address.yfilter != YFilter.not_set or
                                            self.neighbor_system_id.yfilter != YFilter.not_set or
                                            self.new_link.yfilter != YFilter.not_set or
                                            self.number_of_optional_tl_vs.yfilter != YFilter.not_set or
                                            self.output_interface_id.yfilter != YFilter.not_set or
                                            self.priority_count.yfilter != YFilter.not_set or
                                            self.te_metric.yfilter != YFilter.not_set or
                                            (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_operation()) or
                                            (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_operation()) or
                                            (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_operation()) or
                                            (self.link_sw_capability is not None and self.link_sw_capability.has_operation()) or
                                            (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls-te-link" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.affinity.is_set or self.affinity.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.affinity.get_name_leafdata())
                                        if (self.dste_allocation_model_id.is_set or self.dste_allocation_model_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dste_allocation_model_id.get_name_leafdata())
                                        if (self.dste_in_use.is_set or self.dste_in_use.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dste_in_use.get_name_leafdata())
                                        if (self.fragment_id.is_set or self.fragment_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fragment_id.get_name_leafdata())
                                        if (self.igp_metric.is_set or self.igp_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igp_metric.get_name_leafdata())
                                        if (self.input_interface_id.is_set or self.input_interface_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.input_interface_id.get_name_leafdata())
                                        if (self.link_address.is_set or self.link_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_address.get_name_leafdata())
                                        if (self.maximum_link_bw.is_set or self.maximum_link_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_link_bw.get_name_leafdata())
                                        if (self.maximum_link_reservable_bw.is_set or self.maximum_link_reservable_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_link_reservable_bw.get_name_leafdata())
                                        if (self.maximum_link_sub_reservable_bw.is_set or self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_link_sub_reservable_bw.get_name_leafdata())
                                        if (self.mpls_link_instance.is_set or self.mpls_link_instance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_link_instance.get_name_leafdata())
                                        if (self.mpls_link_type.is_set or self.mpls_link_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_link_type.get_name_leafdata())
                                        if (self.neighbor_ip_address.is_set or self.neighbor_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_ip_address.get_name_leafdata())
                                        if (self.neighbor_system_id.is_set or self.neighbor_system_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_system_id.get_name_leafdata())
                                        if (self.new_link.is_set or self.new_link.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.new_link.get_name_leafdata())
                                        if (self.number_of_optional_tl_vs.is_set or self.number_of_optional_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number_of_optional_tl_vs.get_name_leafdata())
                                        if (self.output_interface_id.is_set or self.output_interface_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.output_interface_id.get_name_leafdata())
                                        if (self.priority_count.is_set or self.priority_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.priority_count.get_name_leafdata())
                                        if (self.te_metric.is_set or self.te_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_metric.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "extended-admin-group-list"):
                                            if (self.extended_admin_group_list is None):
                                                self.extended_admin_group_list = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                                self.extended_admin_group_list.parent = self
                                                self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                            return self.extended_admin_group_list

                                        if (child_yang_name == "global-unreserve-bw-per-priority"):
                                            if (self.global_unreserve_bw_per_priority is None):
                                                self.global_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                                self.global_unreserve_bw_per_priority.parent = self
                                                self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                            return self.global_unreserve_bw_per_priority

                                        if (child_yang_name == "link-protocol-priority-capability"):
                                            if (self.link_protocol_priority_capability is None):
                                                self.link_protocol_priority_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                                self.link_protocol_priority_capability.parent = self
                                                self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                            return self.link_protocol_priority_capability

                                        if (child_yang_name == "link-sw-capability"):
                                            if (self.link_sw_capability is None):
                                                self.link_sw_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                                self.link_sw_capability.parent = self
                                                self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                            return self.link_sw_capability

                                        if (child_yang_name == "mplste-link-opt-tlv"):
                                            for c in self.mplste_link_opt_tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.mplste_link_opt_tlv.append(c)
                                            return c

                                        if (child_yang_name == "sub-pool-unreserve-bw-per-priority"):
                                            if (self.sub_pool_unreserve_bw_per_priority is None):
                                                self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                                self.sub_pool_unreserve_bw_per_priority.parent = self
                                                self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                            return self.sub_pool_unreserve_bw_per_priority

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "extended-admin-group-list" or name == "global-unreserve-bw-per-priority" or name == "link-protocol-priority-capability" or name == "link-sw-capability" or name == "mplste-link-opt-tlv" or name == "sub-pool-unreserve-bw-per-priority" or name == "affinity" or name == "dste-allocation-model-id" or name == "dste-in-use" or name == "fragment-id" or name == "igp-metric" or name == "input-interface-id" or name == "link-address" or name == "maximum-link-bw" or name == "maximum-link-reservable-bw" or name == "maximum-link-sub-reservable-bw" or name == "mpls-link-instance" or name == "mpls-link-type" or name == "neighbor-ip-address" or name == "neighbor-system-id" or name == "new-link" or name == "number-of-optional-tl-vs" or name == "output-interface-id" or name == "priority-count" or name == "te-metric"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "affinity"):
                                            self.affinity = value
                                            self.affinity.value_namespace = name_space
                                            self.affinity.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dste-allocation-model-id"):
                                            self.dste_allocation_model_id = value
                                            self.dste_allocation_model_id.value_namespace = name_space
                                            self.dste_allocation_model_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dste-in-use"):
                                            self.dste_in_use = value
                                            self.dste_in_use.value_namespace = name_space
                                            self.dste_in_use.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fragment-id"):
                                            self.fragment_id = value
                                            self.fragment_id.value_namespace = name_space
                                            self.fragment_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igp-metric"):
                                            self.igp_metric = value
                                            self.igp_metric.value_namespace = name_space
                                            self.igp_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "input-interface-id"):
                                            self.input_interface_id = value
                                            self.input_interface_id.value_namespace = name_space
                                            self.input_interface_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-address"):
                                            self.link_address = value
                                            self.link_address.value_namespace = name_space
                                            self.link_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-link-bw"):
                                            self.maximum_link_bw = value
                                            self.maximum_link_bw.value_namespace = name_space
                                            self.maximum_link_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-link-reservable-bw"):
                                            self.maximum_link_reservable_bw = value
                                            self.maximum_link_reservable_bw.value_namespace = name_space
                                            self.maximum_link_reservable_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-link-sub-reservable-bw"):
                                            self.maximum_link_sub_reservable_bw = value
                                            self.maximum_link_sub_reservable_bw.value_namespace = name_space
                                            self.maximum_link_sub_reservable_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-link-instance"):
                                            self.mpls_link_instance = value
                                            self.mpls_link_instance.value_namespace = name_space
                                            self.mpls_link_instance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-link-type"):
                                            self.mpls_link_type = value
                                            self.mpls_link_type.value_namespace = name_space
                                            self.mpls_link_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-ip-address"):
                                            self.neighbor_ip_address = value
                                            self.neighbor_ip_address.value_namespace = name_space
                                            self.neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-system-id"):
                                            self.neighbor_system_id = value
                                            self.neighbor_system_id.value_namespace = name_space
                                            self.neighbor_system_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "new-link"):
                                            self.new_link = value
                                            self.new_link.value_namespace = name_space
                                            self.new_link.value_namespace_prefix = name_space_prefix
                                        if(value_path == "number-of-optional-tl-vs"):
                                            self.number_of_optional_tl_vs = value
                                            self.number_of_optional_tl_vs.value_namespace = name_space
                                            self.number_of_optional_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "output-interface-id"):
                                            self.output_interface_id = value
                                            self.output_interface_id.value_namespace = name_space
                                            self.output_interface_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "priority-count"):
                                            self.priority_count = value
                                            self.priority_count.value_namespace = name_space
                                            self.priority_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-metric"):
                                            self.te_metric = value
                                            self.te_metric.value_namespace = name_space
                                            self.te_metric.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.mpls_te_link:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.dste_model_id.is_set or
                                        self.fragment_id.is_set or
                                        self.fragment_instance.is_set or
                                        self.same_fragment_count.is_set)

                                def has_operation(self):
                                    for c in self.mpls_te_link:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dste_model_id.yfilter != YFilter.not_set or
                                        self.fragment_id.yfilter != YFilter.not_set or
                                        self.fragment_instance.yfilter != YFilter.not_set or
                                        self.same_fragment_count.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mpls-te-fragment" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dste_model_id.is_set or self.dste_model_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dste_model_id.get_name_leafdata())
                                    if (self.fragment_id.is_set or self.fragment_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fragment_id.get_name_leafdata())
                                    if (self.fragment_instance.is_set or self.fragment_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fragment_instance.get_name_leafdata())
                                    if (self.same_fragment_count.is_set or self.same_fragment_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.same_fragment_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "mpls-te-link"):
                                        for c in self.mpls_te_link:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.mpls_te_link.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mpls-te-link" or name == "dste-model-id" or name == "fragment-id" or name == "fragment-instance" or name == "same-fragment-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dste-model-id"):
                                        self.dste_model_id = value
                                        self.dste_model_id.value_namespace = name_space
                                        self.dste_model_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fragment-id"):
                                        self.fragment_id = value
                                        self.fragment_id.value_namespace = name_space
                                        self.fragment_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fragment-instance"):
                                        self.fragment_instance = value
                                        self.fragment_instance.value_namespace = name_space
                                        self.fragment_instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "same-fragment-count"):
                                        self.same_fragment_count = value
                                        self.same_fragment_count.value_namespace = name_space
                                        self.same_fragment_count.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.mpls_te_fragment:
                                    if (c.has_data()):
                                        return True
                                for c in self.mpls_te_link:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.area_id.is_set or
                                    self.mpls_te_area_id.is_set or
                                    self.mpls_te_area_instance.is_set or
                                    self.mpls_te_enabled.is_set or
                                    self.mpls_te_initialized.is_set or
                                    self.mpls_te_next_fragment_id.is_set or
                                    self.mpls_te_router_address.is_set or
                                    self.mpls_te_router_id.is_set or
                                    self.spacious_fragment.is_set)

                            def has_operation(self):
                                for c in self.mpls_te_fragment:
                                    if (c.has_operation()):
                                        return True
                                for c in self.mpls_te_link:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.area_id.yfilter != YFilter.not_set or
                                    self.mpls_te_area_id.yfilter != YFilter.not_set or
                                    self.mpls_te_area_instance.yfilter != YFilter.not_set or
                                    self.mpls_te_enabled.yfilter != YFilter.not_set or
                                    self.mpls_te_initialized.yfilter != YFilter.not_set or
                                    self.mpls_te_next_fragment_id.yfilter != YFilter.not_set or
                                    self.mpls_te_router_address.yfilter != YFilter.not_set or
                                    self.mpls_te_router_id.yfilter != YFilter.not_set or
                                    self.spacious_fragment.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mpls-te-link" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                if (self.mpls_te_area_id.is_set or self.mpls_te_area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_area_id.get_name_leafdata())
                                if (self.mpls_te_area_instance.is_set or self.mpls_te_area_instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_area_instance.get_name_leafdata())
                                if (self.mpls_te_enabled.is_set or self.mpls_te_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_enabled.get_name_leafdata())
                                if (self.mpls_te_initialized.is_set or self.mpls_te_initialized.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_initialized.get_name_leafdata())
                                if (self.mpls_te_next_fragment_id.is_set or self.mpls_te_next_fragment_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_next_fragment_id.get_name_leafdata())
                                if (self.mpls_te_router_address.is_set or self.mpls_te_router_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_router_address.get_name_leafdata())
                                if (self.mpls_te_router_id.is_set or self.mpls_te_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_router_id.get_name_leafdata())
                                if (self.spacious_fragment.is_set or self.spacious_fragment.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spacious_fragment.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mpls-te-fragment"):
                                    for c in self.mpls_te_fragment:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.mpls_te_fragment.append(c)
                                    return c

                                if (child_yang_name == "mpls-te-link"):
                                    for c in self.mpls_te_link:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.mpls_te_link.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mpls-te-fragment" or name == "mpls-te-link" or name == "area-id" or name == "mpls-te-area-id" or name == "mpls-te-area-instance" or name == "mpls-te-enabled" or name == "mpls-te-initialized" or name == "mpls-te-next-fragment-id" or name == "mpls-te-router-address" or name == "mpls-te-router-id" or name == "spacious-fragment"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "area-id"):
                                    self.area_id = value
                                    self.area_id.value_namespace = name_space
                                    self.area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-area-id"):
                                    self.mpls_te_area_id = value
                                    self.mpls_te_area_id.value_namespace = name_space
                                    self.mpls_te_area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-area-instance"):
                                    self.mpls_te_area_instance = value
                                    self.mpls_te_area_instance.value_namespace = name_space
                                    self.mpls_te_area_instance.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-enabled"):
                                    self.mpls_te_enabled = value
                                    self.mpls_te_enabled.value_namespace = name_space
                                    self.mpls_te_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-initialized"):
                                    self.mpls_te_initialized = value
                                    self.mpls_te_initialized.value_namespace = name_space
                                    self.mpls_te_initialized.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-next-fragment-id"):
                                    self.mpls_te_next_fragment_id = value
                                    self.mpls_te_next_fragment_id.value_namespace = name_space
                                    self.mpls_te_next_fragment_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-router-address"):
                                    self.mpls_te_router_address = value
                                    self.mpls_te_router_address.value_namespace = name_space
                                    self.mpls_te_router_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-router-id"):
                                    self.mpls_te_router_id = value
                                    self.mpls_te_router_id.value_namespace = name_space
                                    self.mpls_te_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "spacious-fragment"):
                                    self.spacious_fragment = value
                                    self.spacious_fragment.value_namespace = name_space
                                    self.spacious_fragment.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.mpls_te_link:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.mpls_te_link:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mpls-te-links" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mpls-te-link"):
                                for c in self.mpls_te_link:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.mpls_te_link.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mpls-te-link"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class MplsTeFragments(Entity):
                        """
                        MPLS TE Fragment information table
                        
                        .. attribute:: mpls_te_fragment
                        
                        	MPLS TE Fragment
                        	**type**\: list of    :py:class:`MplsTeFragment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments, self).__init__()

                            self.yang_name = "mpls-te-fragments"
                            self.yang_parent_name = "mpls-te"

                            self.mpls_te_fragment = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments, self).__setattr__(name, value)


                        class MplsTeFragment(Entity):
                            """
                            MPLS TE Fragment
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mpls_te_area_id
                            
                            	Area ID string in decimal or dotted decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: mpls_te_area_instance
                            
                            	Area information instance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mpls_te_enabled
                            
                            	If true, MPLS\-TE enabled in area
                            	**type**\:  bool
                            
                            .. attribute:: mpls_te_fragment
                            
                            	MPLS TE fragments in the area
                            	**type**\: list of    :py:class:`MplsTeFragment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment>`
                            
                            .. attribute:: mpls_te_initialized
                            
                            	If true, MPLS\-TE initialized in the area
                            	**type**\:  bool
                            
                            .. attribute:: mpls_te_link
                            
                            	MPLS\-TE links in the area
                            	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink>`
                            
                            .. attribute:: mpls_te_next_fragment_id
                            
                            	Next MPLS\-TE fragment ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mpls_te_router_address
                            
                            	MPLS\-TE router address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mpls_te_router_id
                            
                            	OSPF MPLS\-TE router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: spacious_fragment
                            
                            	If true, fragment has space for next link
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment, self).__init__()

                                self.yang_name = "mpls-te-fragment"
                                self.yang_parent_name = "mpls-te-fragments"

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.mpls_te_area_id = YLeaf(YType.str, "mpls-te-area-id")

                                self.mpls_te_area_instance = YLeaf(YType.uint32, "mpls-te-area-instance")

                                self.mpls_te_enabled = YLeaf(YType.boolean, "mpls-te-enabled")

                                self.mpls_te_initialized = YLeaf(YType.boolean, "mpls-te-initialized")

                                self.mpls_te_next_fragment_id = YLeaf(YType.uint32, "mpls-te-next-fragment-id")

                                self.mpls_te_router_address = YLeaf(YType.str, "mpls-te-router-address")

                                self.mpls_te_router_id = YLeaf(YType.str, "mpls-te-router-id")

                                self.spacious_fragment = YLeaf(YType.boolean, "spacious-fragment")

                                self.mpls_te_fragment = YList(self)
                                self.mpls_te_link = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("area_id",
                                                "mpls_te_area_id",
                                                "mpls_te_area_instance",
                                                "mpls_te_enabled",
                                                "mpls_te_initialized",
                                                "mpls_te_next_fragment_id",
                                                "mpls_te_router_address",
                                                "mpls_te_router_id",
                                                "spacious_fragment") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment, self).__setattr__(name, value)


                            class MplsTeLink(Entity):
                                """
                                MPLS\-TE links in the area
                                
                                .. attribute:: affinity
                                
                                	Affinity
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dste_allocation_model_id
                                
                                	DS\-TE Allocation Model ID
                                	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                
                                .. attribute:: dste_in_use
                                
                                	A DS\-TE Allocation Model in use
                                	**type**\:  bool
                                
                                .. attribute:: extended_admin_group_list
                                
                                	Extended Admin Group
                                	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList>`
                                
                                .. attribute:: fragment_id
                                
                                	Fragment ID for this link
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: global_unreserve_bw_per_priority
                                
                                	Global pool unreserved bandwidth for each priority (bytes/s)
                                	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                
                                .. attribute:: igp_metric
                                
                                	Link IGP metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: input_interface_id
                                
                                	Input interface ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_address
                                
                                	The local interface address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: link_protocol_priority_capability
                                
                                	Link protocol and protocol priority capability
                                	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability>`
                                
                                .. attribute:: link_sw_capability
                                
                                	Link switching capability
                                	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability>`
                                
                                .. attribute:: maximum_link_bw
                                
                                	Maximum link bandwidth (bytes/s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte/s
                                
                                .. attribute:: maximum_link_reservable_bw
                                
                                	Maximum link global pool reservable bandwidth (bytes/s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte/s
                                
                                .. attribute:: maximum_link_sub_reservable_bw
                                
                                	Maximum link subpool reservable bandwidth (bytes/s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte/s
                                
                                .. attribute:: mpls_link_instance
                                
                                	Link instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_link_type
                                
                                	Type of link
                                	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                
                                .. attribute:: mplste_link_opt_tlv
                                
                                	List of Optional TLVs
                                	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv>`
                                
                                .. attribute:: neighbor_ip_address
                                
                                	Neighbor IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_system_id
                                
                                	Neighbor system ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: new_link
                                
                                	If true, Link is new
                                	**type**\:  bool
                                
                                .. attribute:: number_of_optional_tl_vs
                                
                                	Number of Optional TLVs
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: output_interface_id
                                
                                	Output interface ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: priority_count
                                
                                	Number of priorities
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: sub_pool_unreserve_bw_per_priority
                                
                                	Sub pool unreserved bandwidth for each priority (bytes/s)
                                	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                
                                .. attribute:: te_metric
                                
                                	Link TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink, self).__init__()

                                    self.yang_name = "mpls-te-link"
                                    self.yang_parent_name = "mpls-te-fragment"

                                    self.affinity = YLeaf(YType.uint32, "affinity")

                                    self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                    self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                    self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                    self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                    self.link_address = YLeaf(YType.str, "link-address")

                                    self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                    self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                    self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                    self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                    self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                    self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                    self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                    self.new_link = YLeaf(YType.boolean, "new-link")

                                    self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                    self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                    self.priority_count = YLeaf(YType.int32, "priority-count")

                                    self.te_metric = YLeaf(YType.uint32, "te-metric")

                                    self.extended_admin_group_list = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                    self.extended_admin_group_list.parent = self
                                    self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                    self._children_yang_names.add("extended-admin-group-list")

                                    self.global_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                    self.global_unreserve_bw_per_priority.parent = self
                                    self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                    self._children_yang_names.add("global-unreserve-bw-per-priority")

                                    self.link_protocol_priority_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                    self.link_protocol_priority_capability.parent = self
                                    self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                    self._children_yang_names.add("link-protocol-priority-capability")

                                    self.link_sw_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                    self.link_sw_capability.parent = self
                                    self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                    self._children_yang_names.add("link-sw-capability")

                                    self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                    self.sub_pool_unreserve_bw_per_priority.parent = self
                                    self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                    self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                    self.mplste_link_opt_tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("affinity",
                                                    "dste_allocation_model_id",
                                                    "dste_in_use",
                                                    "fragment_id",
                                                    "igp_metric",
                                                    "input_interface_id",
                                                    "link_address",
                                                    "maximum_link_bw",
                                                    "maximum_link_reservable_bw",
                                                    "maximum_link_sub_reservable_bw",
                                                    "mpls_link_instance",
                                                    "mpls_link_type",
                                                    "neighbor_ip_address",
                                                    "neighbor_system_id",
                                                    "new_link",
                                                    "number_of_optional_tl_vs",
                                                    "output_interface_id",
                                                    "priority_count",
                                                    "te_metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink, self).__setattr__(name, value)


                                class GlobalUnreserveBwPerPriority(Entity):
                                    """
                                    Global pool unreserved bandwidth for each
                                    priority (bytes/s)
                                    
                                    .. attribute:: bw_per_priority
                                    
                                    	Unreserved bandwidth for each priority (bytes/s)
                                    	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                        self.yang_name = "global-unreserve-bw-per-priority"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.bw_per_priority = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)


                                    class BwPerPriority(Entity):
                                        """
                                        Unreserved bandwidth for each priority (bytes/s)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                            self.yang_name = "bw-per-priority"
                                            self.yang_parent_name = "global-unreserve-bw-per-priority"

                                            self.entry = YLeaf(YType.uint64, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.bw_per_priority:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.bw_per_priority:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "global-unreserve-bw-per-priority" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "bw-per-priority"):
                                            for c in self.bw_per_priority:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.bw_per_priority.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bw-per-priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SubPoolUnreserveBwPerPriority(Entity):
                                    """
                                    Sub pool unreserved bandwidth for each priority
                                    (bytes/s)
                                    
                                    .. attribute:: bw_per_priority
                                    
                                    	Unreserved bandwidth for each priority (bytes/s)
                                    	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                        self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.bw_per_priority = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)


                                    class BwPerPriority(Entity):
                                        """
                                        Unreserved bandwidth for each priority (bytes/s)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                            self.yang_name = "bw-per-priority"
                                            self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"

                                            self.entry = YLeaf(YType.uint64, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.bw_per_priority:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.bw_per_priority:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sub-pool-unreserve-bw-per-priority" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "bw-per-priority"):
                                            for c in self.bw_per_priority:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.bw_per_priority.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bw-per-priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class LinkProtocolPriorityCapability(Entity):
                                    """
                                    Link protocol and protocol priority capability
                                    
                                    .. attribute:: link_protocol_capability
                                    
                                    	Link protocol capability
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: link_protocol_priority
                                    
                                    	Link protocol priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                        self.yang_name = "link-protocol-priority-capability"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                        self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("link_protocol_capability",
                                                        "link_protocol_priority") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.link_protocol_capability.is_set or
                                            self.link_protocol_priority.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.link_protocol_capability.yfilter != YFilter.not_set or
                                            self.link_protocol_priority.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "link-protocol-priority-capability" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.link_protocol_capability.is_set or self.link_protocol_capability.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_protocol_capability.get_name_leafdata())
                                        if (self.link_protocol_priority.is_set or self.link_protocol_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_protocol_priority.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "link-protocol-capability" or name == "link-protocol-priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "link-protocol-capability"):
                                            self.link_protocol_capability = value
                                            self.link_protocol_capability.value_namespace = name_space
                                            self.link_protocol_capability.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-protocol-priority"):
                                            self.link_protocol_priority = value
                                            self.link_protocol_priority.value_namespace = name_space
                                            self.link_protocol_priority.value_namespace_prefix = name_space_prefix


                                class LinkSwCapability(Entity):
                                    """
                                    Link switching capability
                                    
                                    .. attribute:: link_encoding
                                    
                                    	Link Encoding
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: link_mtu
                                    
                                    	Link MTU size (bytes)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: link_switching_capability
                                    
                                    	Link Switching Capability
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: maximum_lsp_bw_per_priority
                                    
                                    	Maximum LSP bandwidth for each priority  (bytes/s)
                                    	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                    
                                    .. attribute:: minimum_lsp_bw
                                    
                                    	Minimum LSP bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte/s
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__init__()

                                        self.yang_name = "link-sw-capability"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                        self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                        self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                        self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                        self.maximum_lsp_bw_per_priority = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("link_encoding",
                                                        "link_mtu",
                                                        "link_switching_capability",
                                                        "minimum_lsp_bw") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)


                                    class MaximumLspBwPerPriority(Entity):
                                        """
                                        Maximum LSP bandwidth for each priority
                                        
                                        (bytes/s)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                            self.yang_name = "maximum-lsp-bw-per-priority"
                                            self.yang_parent_name = "link-sw-capability"

                                            self.entry = YLeaf(YType.uint64, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "maximum-lsp-bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.maximum_lsp_bw_per_priority:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.link_encoding.is_set or
                                            self.link_mtu.is_set or
                                            self.link_switching_capability.is_set or
                                            self.minimum_lsp_bw.is_set)

                                    def has_operation(self):
                                        for c in self.maximum_lsp_bw_per_priority:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.link_encoding.yfilter != YFilter.not_set or
                                            self.link_mtu.yfilter != YFilter.not_set or
                                            self.link_switching_capability.yfilter != YFilter.not_set or
                                            self.minimum_lsp_bw.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "link-sw-capability" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.link_encoding.is_set or self.link_encoding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_encoding.get_name_leafdata())
                                        if (self.link_mtu.is_set or self.link_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_mtu.get_name_leafdata())
                                        if (self.link_switching_capability.is_set or self.link_switching_capability.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_switching_capability.get_name_leafdata())
                                        if (self.minimum_lsp_bw.is_set or self.minimum_lsp_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_lsp_bw.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "maximum-lsp-bw-per-priority"):
                                            for c in self.maximum_lsp_bw_per_priority:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.maximum_lsp_bw_per_priority.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "maximum-lsp-bw-per-priority" or name == "link-encoding" or name == "link-mtu" or name == "link-switching-capability" or name == "minimum-lsp-bw"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "link-encoding"):
                                            self.link_encoding = value
                                            self.link_encoding.value_namespace = name_space
                                            self.link_encoding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-mtu"):
                                            self.link_mtu = value
                                            self.link_mtu.value_namespace = name_space
                                            self.link_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-switching-capability"):
                                            self.link_switching_capability = value
                                            self.link_switching_capability.value_namespace = name_space
                                            self.link_switching_capability.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-lsp-bw"):
                                            self.minimum_lsp_bw = value
                                            self.minimum_lsp_bw.value_namespace = name_space
                                            self.minimum_lsp_bw.value_namespace_prefix = name_space_prefix


                                class ExtendedAdminGroupList(Entity):
                                    """
                                    Extended Admin Group
                                    
                                    .. attribute:: ext_admin_data
                                    
                                    	Value of Extended Admin Group
                                    	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                    
                                    .. attribute:: extended_admin_size
                                    
                                    	Size of the extended admin group
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                        self.yang_name = "extended-admin-group-list"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                        self.ext_admin_data = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("extended_admin_size") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)


                                    class ExtAdminData(Entity):
                                        """
                                        Value of Extended Admin Group
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                            self.yang_name = "ext-admin-data"
                                            self.yang_parent_name = "extended-admin-group-list"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ext-admin-data" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.ext_admin_data:
                                            if (c.has_data()):
                                                return True
                                        return self.extended_admin_size.is_set

                                    def has_operation(self):
                                        for c in self.ext_admin_data:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.extended_admin_size.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "extended-admin-group-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.extended_admin_size.is_set or self.extended_admin_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.extended_admin_size.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "ext-admin-data"):
                                            for c in self.ext_admin_data:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.ext_admin_data.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ext-admin-data" or name == "extended-admin-size"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "extended-admin-size"):
                                            self.extended_admin_size = value
                                            self.extended_admin_size.value_namespace = name_space
                                            self.extended_admin_size.value_namespace_prefix = name_space_prefix


                                class MplsteLinkOptTlv(Entity):
                                    """
                                    List of Optional TLVs
                                    
                                    .. attribute:: mplste_link_opt_tlv_len
                                    
                                    	Length of Opt TLV
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: mplste_link_opt_tlv_type
                                    
                                    	Type of Opt TLV
                                    	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                    
                                    .. attribute:: mplste_link_opt_tlv_value
                                    
                                    	Value of Opt TLV
                                    	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                        self.yang_name = "mplste-link-opt-tlv"
                                        self.yang_parent_name = "mpls-te-link"

                                        self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                        self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                        self.mplste_link_opt_tlv_value = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mplste_link_opt_tlv_len",
                                                        "mplste_link_opt_tlv_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)


                                    class MplsteLinkOptTlvValue(Entity):
                                        """
                                        Value of Opt TLV
                                        
                                        .. attribute:: bctlv_value
                                        
                                        	Value of Bandwidth Constraints TLV
                                        	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                        
                                        .. attribute:: ixcdtlv_value
                                        
                                        	Value of IXCD TLV
                                        	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                        
                                        .. attribute:: opaque_tlv_type
                                        
                                        	OpaqueTLVType
                                        	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                        
                                        .. attribute:: srlgtlv_value
                                        
                                        	Value of SRLG TLV
                                        	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                        
                                        .. attribute:: unidtlv_value
                                        
                                        	Value of Uni Delay TLV
                                        	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                            self.yang_name = "mplste-link-opt-tlv-value"
                                            self.yang_parent_name = "mplste-link-opt-tlv"

                                            self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                            self.bctlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                            self.bctlv_value.parent = self
                                            self._children_name_map["bctlv_value"] = "bctlv-value"
                                            self._children_yang_names.add("bctlv-value")

                                            self.ixcdtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                            self.ixcdtlv_value.parent = self
                                            self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                            self._children_yang_names.add("ixcdtlv-value")

                                            self.srlgtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                            self.srlgtlv_value.parent = self
                                            self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                            self._children_yang_names.add("srlgtlv-value")

                                            self.unidtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                            self.unidtlv_value.parent = self
                                            self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                            self._children_yang_names.add("unidtlv-value")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("opaque_tlv_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)


                                        class BctlvValue(Entity):
                                            """
                                            Value of Bandwidth Constraints TLV
                                            
                                            .. attribute:: model_id
                                            
                                            	Allocation Model ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mplste_link_bc_bandwidth
                                            
                                            	Value of BC TLV
                                            	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                            
                                            .. attribute:: num_b_cs
                                            
                                            	Number of BC TLVs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                self.yang_name = "bctlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                self.model_id = YLeaf(YType.uint8, "model-id")

                                                self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                self.mplste_link_bc_bandwidth = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("model_id",
                                                                "num_b_cs") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)


                                            class MplsteLinkBcBandwidth(Entity):
                                                """
                                                Value of BC TLV
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                    self.yang_name = "mplste-link-bc-bandwidth"
                                                    self.yang_parent_name = "bctlv-value"

                                                    self.entry = YLeaf(YType.uint64, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "mplste-link-bc-bandwidth" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.mplste_link_bc_bandwidth:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.model_id.is_set or
                                                    self.num_b_cs.is_set)

                                            def has_operation(self):
                                                for c in self.mplste_link_bc_bandwidth:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.model_id.yfilter != YFilter.not_set or
                                                    self.num_b_cs.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "bctlv-value" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.model_id.is_set or self.model_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.model_id.get_name_leafdata())
                                                if (self.num_b_cs.is_set or self.num_b_cs.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.num_b_cs.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "mplste-link-bc-bandwidth"):
                                                    for c in self.mplste_link_bc_bandwidth:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.mplste_link_bc_bandwidth.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "mplste-link-bc-bandwidth" or name == "model-id" or name == "num-b-cs"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "model-id"):
                                                    self.model_id = value
                                                    self.model_id.value_namespace = name_space
                                                    self.model_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "num-b-cs"):
                                                    self.num_b_cs = value
                                                    self.num_b_cs.value_namespace = name_space
                                                    self.num_b_cs.value_namespace_prefix = name_space_prefix


                                        class SrlgtlvValue(Entity):
                                            """
                                            Value of SRLG TLV
                                            
                                            .. attribute:: mplste_link_srlg_data
                                            
                                            	Value of SRLG TLV
                                            	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                            
                                            .. attribute:: num_srl_gs
                                            
                                            	Number of SRLG TLVs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: srlg_len
                                            
                                            	Length of SRLG TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                self.yang_name = "srlgtlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                self.mplste_link_srlg_data = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("num_srl_gs",
                                                                "srlg_len") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)


                                            class MplsteLinkSrlgData(Entity):
                                                """
                                                Value of SRLG TLV
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                    self.yang_name = "mplste-link-srlg-data"
                                                    self.yang_parent_name = "srlgtlv-value"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "mplste-link-srlg-data" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.mplste_link_srlg_data:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.num_srl_gs.is_set or
                                                    self.srlg_len.is_set)

                                            def has_operation(self):
                                                for c in self.mplste_link_srlg_data:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.num_srl_gs.yfilter != YFilter.not_set or
                                                    self.srlg_len.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "srlgtlv-value" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.num_srl_gs.is_set or self.num_srl_gs.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.num_srl_gs.get_name_leafdata())
                                                if (self.srlg_len.is_set or self.srlg_len.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.srlg_len.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "mplste-link-srlg-data"):
                                                    for c in self.mplste_link_srlg_data:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.mplste_link_srlg_data.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "mplste-link-srlg-data" or name == "num-srl-gs" or name == "srlg-len"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "num-srl-gs"):
                                                    self.num_srl_gs = value
                                                    self.num_srl_gs.value_namespace = name_space
                                                    self.num_srl_gs.value_namespace_prefix = name_space_prefix
                                                if(value_path == "srlg-len"):
                                                    self.srlg_len = value
                                                    self.srlg_len.value_namespace = name_space
                                                    self.srlg_len.value_namespace_prefix = name_space_prefix


                                        class IxcdtlvValue(Entity):
                                            """
                                            Value of IXCD TLV
                                            
                                            .. attribute:: fixed_scsi_count
                                            
                                            	Fixed SCSI count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flex_scsi_count
                                            
                                            	Flexible SCSI count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ixcd_switching_cap_type
                                            
                                            	Switching Cap type
                                            	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                            
                                            .. attribute:: max_lspbw
                                            
                                            	Max LSP bandwidth array
                                            	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                            
                                            .. attribute:: rile_len_code
                                            
                                            	Rile LenCode
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: switching_cap
                                            
                                            	SCap
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                self.yang_name = "ixcdtlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                self.ixcd_switching_cap_type = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                self.ixcd_switching_cap_type.parent = self
                                                self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                self._children_yang_names.add("ixcd-switching-cap-type")

                                                self.max_lspbw = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("fixed_scsi_count",
                                                                "flex_scsi_count",
                                                                "rile_len_code",
                                                                "switching_cap") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)


                                            class IxcdSwitchingCapType(Entity):
                                                """
                                                Switching Cap type
                                                
                                                .. attribute:: ixcdbw_sub_tlv
                                                
                                                	Sub TLVs
                                                	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                
                                                .. attribute:: ixcdpsc_info
                                                
                                                	IXCD PSC information
                                                	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                
                                                .. attribute:: switching_cap_type
                                                
                                                	SwitchingCapType
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                    self.yang_name = "ixcd-switching-cap-type"
                                                    self.yang_parent_name = "ixcdtlv-value"

                                                    self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                    self.ixcdbw_sub_tlv = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                    self.ixcdbw_sub_tlv.parent = self
                                                    self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                    self._children_yang_names.add("ixcdbw-sub-tlv")

                                                    self.ixcdpsc_info = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                    self.ixcdpsc_info.parent = self
                                                    self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                    self._children_yang_names.add("ixcdpsc-info")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("switching_cap_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)


                                                class IxcdpscInfo(Entity):
                                                    """
                                                    IXCD PSC information
                                                    
                                                    .. attribute:: min_lsp_bandwidth
                                                    
                                                    	Min LSP bandwidth
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: psc_interface_mtu
                                                    
                                                    	 Interface MTU
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                        self.yang_name = "ixcdpsc-info"
                                                        self.yang_parent_name = "ixcd-switching-cap-type"

                                                        self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                        self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("min_lsp_bandwidth",
                                                                        "psc_interface_mtu") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.min_lsp_bandwidth.is_set or
                                                            self.psc_interface_mtu.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.min_lsp_bandwidth.yfilter != YFilter.not_set or
                                                            self.psc_interface_mtu.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ixcdpsc-info" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.min_lsp_bandwidth.is_set or self.min_lsp_bandwidth.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.min_lsp_bandwidth.get_name_leafdata())
                                                        if (self.psc_interface_mtu.is_set or self.psc_interface_mtu.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.psc_interface_mtu.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "min-lsp-bandwidth" or name == "psc-interface-mtu"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "min-lsp-bandwidth"):
                                                            self.min_lsp_bandwidth = value
                                                            self.min_lsp_bandwidth.value_namespace = name_space
                                                            self.min_lsp_bandwidth.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "psc-interface-mtu"):
                                                            self.psc_interface_mtu = value
                                                            self.psc_interface_mtu.value_namespace = name_space
                                                            self.psc_interface_mtu.value_namespace_prefix = name_space_prefix


                                                class IxcdbwSubTlv(Entity):
                                                    """
                                                    Sub TLVs
                                                    
                                                    .. attribute:: arr_bw_sub_tlv
                                                    
                                                    	Array of sub tlvs
                                                    	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                        self.yang_name = "ixcdbw-sub-tlv"
                                                        self.yang_parent_name = "ixcd-switching-cap-type"

                                                        self.arr_bw_sub_tlv = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in () and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)


                                                    class ArrBwSubTlv(Entity):
                                                        """
                                                        Array of sub tlvs
                                                        
                                                        .. attribute:: bw_sub_tlv_length
                                                        
                                                        	Length of BW Sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: bw_sub_tlv_type
                                                        
                                                        	Type of Sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: bw_sub_tlv_value
                                                        
                                                        	Value of BW Sub TLV
                                                        	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                            self.yang_name = "arr-bw-sub-tlv"
                                                            self.yang_parent_name = "ixcdbw-sub-tlv"

                                                            self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                            self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                            self.bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                            self.bw_sub_tlv_value.parent = self
                                                            self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                            self._children_yang_names.add("bw-sub-tlv-value")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("bw_sub_tlv_length",
                                                                            "bw_sub_tlv_type") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)


                                                        class BwSubTlvValue(Entity):
                                                            """
                                                            Value of BW Sub TLV
                                                            
                                                            .. attribute:: fixed_bw_sub_tlv_value
                                                            
                                                            	Value of Fixed Sub TLV
                                                            	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                            
                                                            .. attribute:: flex_bw_sub_tlv_value
                                                            
                                                            	Value of Flex Sub TLV
                                                            	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                            
                                                            .. attribute:: ixcdbw_sub_tlv_type
                                                            
                                                            	IXCDBWSubTLVType
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                self.yang_name = "bw-sub-tlv-value"
                                                                self.yang_parent_name = "arr-bw-sub-tlv"

                                                                self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                self.fixed_bw_sub_tlv_value.parent = self
                                                                self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                self.flex_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                self.flex_bw_sub_tlv_value.parent = self
                                                                self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                self._children_yang_names.add("flex-bw-sub-tlv-value")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("ixcdbw_sub_tlv_type") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)


                                                            class FixedBwSubTlvValue(Entity):
                                                                """
                                                                Value of Fixed Sub TLV
                                                                
                                                                .. attribute:: fixed_sub_tlv_value
                                                                
                                                                	Value of Fixed Sub TLV
                                                                	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                
                                                                .. attribute:: unres_oduj_prio
                                                                
                                                                	Array of Unres Oduj Prio
                                                                	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-01-02'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                    self.yang_name = "fixed-bw-sub-tlv-value"
                                                                    self.yang_parent_name = "bw-sub-tlv-value"

                                                                    self.fixed_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                    self.fixed_sub_tlv_value.parent = self
                                                                    self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                    self._children_yang_names.add("fixed-sub-tlv-value")

                                                                    self.unres_oduj_prio = YList(self)

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in () and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)


                                                                class FixedSubTlvValue(Entity):
                                                                    """
                                                                    Value of Fixed Sub TLV
                                                                    
                                                                    .. attribute:: num_stages
                                                                    
                                                                    	Number of stages
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit0
                                                                    
                                                                    	Priority 0
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit1
                                                                    
                                                                    	Priority 1
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit2
                                                                    
                                                                    	Priority 2
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit3
                                                                    
                                                                    	Priority 3
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit4
                                                                    
                                                                    	Priority 4
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit5
                                                                    
                                                                    	Priority 5
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit6
                                                                    
                                                                    	Priority 6
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit7
                                                                    
                                                                    	Priority 7
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: res
                                                                    
                                                                    	Res
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: sbit
                                                                    
                                                                    	S Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: signal_type
                                                                    
                                                                    	Signal Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: stage
                                                                    
                                                                    	Array of Stages
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    .. attribute:: tbit
                                                                    
                                                                    	T Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: tsg
                                                                    
                                                                    	TSG
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                        self.yang_name = "fixed-sub-tlv-value"
                                                                        self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                        self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                        self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                        self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                        self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                        self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                        self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                        self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                        self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                        self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                        self.res = YLeaf(YType.uint8, "res")

                                                                        self.sbit = YLeaf(YType.uint8, "sbit")

                                                                        self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                        self.stage = YLeaf(YType.str, "stage")

                                                                        self.tbit = YLeaf(YType.uint8, "tbit")

                                                                        self.tsg = YLeaf(YType.uint8, "tsg")

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in ("num_stages",
                                                                                        "priority_bit0",
                                                                                        "priority_bit1",
                                                                                        "priority_bit2",
                                                                                        "priority_bit3",
                                                                                        "priority_bit4",
                                                                                        "priority_bit5",
                                                                                        "priority_bit6",
                                                                                        "priority_bit7",
                                                                                        "res",
                                                                                        "sbit",
                                                                                        "signal_type",
                                                                                        "stage",
                                                                                        "tbit",
                                                                                        "tsg") and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)

                                                                    def has_data(self):
                                                                        return (
                                                                            self.num_stages.is_set or
                                                                            self.priority_bit0.is_set or
                                                                            self.priority_bit1.is_set or
                                                                            self.priority_bit2.is_set or
                                                                            self.priority_bit3.is_set or
                                                                            self.priority_bit4.is_set or
                                                                            self.priority_bit5.is_set or
                                                                            self.priority_bit6.is_set or
                                                                            self.priority_bit7.is_set or
                                                                            self.res.is_set or
                                                                            self.sbit.is_set or
                                                                            self.signal_type.is_set or
                                                                            self.stage.is_set or
                                                                            self.tbit.is_set or
                                                                            self.tsg.is_set)

                                                                    def has_operation(self):
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            self.num_stages.yfilter != YFilter.not_set or
                                                                            self.priority_bit0.yfilter != YFilter.not_set or
                                                                            self.priority_bit1.yfilter != YFilter.not_set or
                                                                            self.priority_bit2.yfilter != YFilter.not_set or
                                                                            self.priority_bit3.yfilter != YFilter.not_set or
                                                                            self.priority_bit4.yfilter != YFilter.not_set or
                                                                            self.priority_bit5.yfilter != YFilter.not_set or
                                                                            self.priority_bit6.yfilter != YFilter.not_set or
                                                                            self.priority_bit7.yfilter != YFilter.not_set or
                                                                            self.res.yfilter != YFilter.not_set or
                                                                            self.sbit.yfilter != YFilter.not_set or
                                                                            self.signal_type.yfilter != YFilter.not_set or
                                                                            self.stage.yfilter != YFilter.not_set or
                                                                            self.tbit.yfilter != YFilter.not_set or
                                                                            self.tsg.yfilter != YFilter.not_set)

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "fixed-sub-tlv-value" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()
                                                                        if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                        if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                        if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                        if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                        if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                        if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                        if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                        if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                        if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                        if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.res.get_name_leafdata())
                                                                        if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                        if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                        if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.stage.get_name_leafdata())
                                                                        if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                        if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        if(value_path == "num-stages"):
                                                                            self.num_stages = value
                                                                            self.num_stages.value_namespace = name_space
                                                                            self.num_stages.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit0"):
                                                                            self.priority_bit0 = value
                                                                            self.priority_bit0.value_namespace = name_space
                                                                            self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit1"):
                                                                            self.priority_bit1 = value
                                                                            self.priority_bit1.value_namespace = name_space
                                                                            self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit2"):
                                                                            self.priority_bit2 = value
                                                                            self.priority_bit2.value_namespace = name_space
                                                                            self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit3"):
                                                                            self.priority_bit3 = value
                                                                            self.priority_bit3.value_namespace = name_space
                                                                            self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit4"):
                                                                            self.priority_bit4 = value
                                                                            self.priority_bit4.value_namespace = name_space
                                                                            self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit5"):
                                                                            self.priority_bit5 = value
                                                                            self.priority_bit5.value_namespace = name_space
                                                                            self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit6"):
                                                                            self.priority_bit6 = value
                                                                            self.priority_bit6.value_namespace = name_space
                                                                            self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit7"):
                                                                            self.priority_bit7 = value
                                                                            self.priority_bit7.value_namespace = name_space
                                                                            self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "res"):
                                                                            self.res = value
                                                                            self.res.value_namespace = name_space
                                                                            self.res.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "sbit"):
                                                                            self.sbit = value
                                                                            self.sbit.value_namespace = name_space
                                                                            self.sbit.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "signal-type"):
                                                                            self.signal_type = value
                                                                            self.signal_type.value_namespace = name_space
                                                                            self.signal_type.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "stage"):
                                                                            self.stage = value
                                                                            self.stage.value_namespace = name_space
                                                                            self.stage.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "tbit"):
                                                                            self.tbit = value
                                                                            self.tbit.value_namespace = name_space
                                                                            self.tbit.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "tsg"):
                                                                            self.tsg = value
                                                                            self.tsg.value_namespace = name_space
                                                                            self.tsg.value_namespace_prefix = name_space_prefix


                                                                class UnresOdujPrio(Entity):
                                                                    """
                                                                    Array of Unres Oduj Prio
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                        self.yang_name = "unres-oduj-prio"
                                                                        self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in ("entry") and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)

                                                                    def has_data(self):
                                                                        return self.entry.is_set

                                                                    def has_operation(self):
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            self.entry.yfilter != YFilter.not_set)

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "unres-oduj-prio" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()
                                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "entry"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        if(value_path == "entry"):
                                                                            self.entry = value
                                                                            self.entry.value_namespace = name_space
                                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                                def has_data(self):
                                                                    for c in self.unres_oduj_prio:
                                                                        if (c.has_data()):
                                                                            return True
                                                                    return (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_data())

                                                                def has_operation(self):
                                                                    for c in self.unres_oduj_prio:
                                                                        if (c.has_operation()):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_operation()))

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "fixed-bw-sub-tlv-value" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    if (child_yang_name == "fixed-sub-tlv-value"):
                                                                        if (self.fixed_sub_tlv_value is None):
                                                                            self.fixed_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                            self.fixed_sub_tlv_value.parent = self
                                                                            self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                        return self.fixed_sub_tlv_value

                                                                    if (child_yang_name == "unres-oduj-prio"):
                                                                        for c in self.unres_oduj_prio:
                                                                            segment = c.get_segment_path()
                                                                            if (segment_path == segment):
                                                                                return c
                                                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio()
                                                                        c.parent = self
                                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                                        self._local_refs[local_reference_key] = c
                                                                        self.unres_oduj_prio.append(c)
                                                                        return c

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "fixed-sub-tlv-value" or name == "unres-oduj-prio"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    pass


                                                            class FlexBwSubTlvValue(Entity):
                                                                """
                                                                Value of Flex Sub TLV
                                                                
                                                                .. attribute:: flex_sub_tlv_value_common
                                                                
                                                                	Flex Sub TLV Value
                                                                	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                
                                                                .. attribute:: max_lspbw
                                                                
                                                                	Max LSP BW Array
                                                                	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                
                                                                .. attribute:: unres_lspbw
                                                                
                                                                	Array of Unres LSP BW
                                                                	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-01-02'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                    self.yang_name = "flex-bw-sub-tlv-value"
                                                                    self.yang_parent_name = "bw-sub-tlv-value"

                                                                    self.flex_sub_tlv_value_common = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                    self.flex_sub_tlv_value_common.parent = self
                                                                    self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                    self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                    self.max_lspbw = YList(self)
                                                                    self.unres_lspbw = YList(self)

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in () and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)


                                                                class FlexSubTlvValueCommon(Entity):
                                                                    """
                                                                    Flex Sub TLV Value
                                                                    
                                                                    .. attribute:: num_stages
                                                                    
                                                                    	Number of stages
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit0
                                                                    
                                                                    	Priority 0
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit1
                                                                    
                                                                    	Priority 1
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit2
                                                                    
                                                                    	Priority 2
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit3
                                                                    
                                                                    	Priority 3
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit4
                                                                    
                                                                    	Priority 4
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit5
                                                                    
                                                                    	Priority 5
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit6
                                                                    
                                                                    	Priority 6
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit7
                                                                    
                                                                    	Priority 7
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: res
                                                                    
                                                                    	Res
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: sbit
                                                                    
                                                                    	S Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: signal_type
                                                                    
                                                                    	Signal Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: stage
                                                                    
                                                                    	Array of Stages
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    .. attribute:: tbit
                                                                    
                                                                    	T Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: tsg
                                                                    
                                                                    	TSG
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                        self.yang_name = "flex-sub-tlv-value-common"
                                                                        self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                        self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                        self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                        self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                        self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                        self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                        self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                        self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                        self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                        self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                        self.res = YLeaf(YType.uint8, "res")

                                                                        self.sbit = YLeaf(YType.uint8, "sbit")

                                                                        self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                        self.stage = YLeaf(YType.str, "stage")

                                                                        self.tbit = YLeaf(YType.uint8, "tbit")

                                                                        self.tsg = YLeaf(YType.uint8, "tsg")

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in ("num_stages",
                                                                                        "priority_bit0",
                                                                                        "priority_bit1",
                                                                                        "priority_bit2",
                                                                                        "priority_bit3",
                                                                                        "priority_bit4",
                                                                                        "priority_bit5",
                                                                                        "priority_bit6",
                                                                                        "priority_bit7",
                                                                                        "res",
                                                                                        "sbit",
                                                                                        "signal_type",
                                                                                        "stage",
                                                                                        "tbit",
                                                                                        "tsg") and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)

                                                                    def has_data(self):
                                                                        return (
                                                                            self.num_stages.is_set or
                                                                            self.priority_bit0.is_set or
                                                                            self.priority_bit1.is_set or
                                                                            self.priority_bit2.is_set or
                                                                            self.priority_bit3.is_set or
                                                                            self.priority_bit4.is_set or
                                                                            self.priority_bit5.is_set or
                                                                            self.priority_bit6.is_set or
                                                                            self.priority_bit7.is_set or
                                                                            self.res.is_set or
                                                                            self.sbit.is_set or
                                                                            self.signal_type.is_set or
                                                                            self.stage.is_set or
                                                                            self.tbit.is_set or
                                                                            self.tsg.is_set)

                                                                    def has_operation(self):
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            self.num_stages.yfilter != YFilter.not_set or
                                                                            self.priority_bit0.yfilter != YFilter.not_set or
                                                                            self.priority_bit1.yfilter != YFilter.not_set or
                                                                            self.priority_bit2.yfilter != YFilter.not_set or
                                                                            self.priority_bit3.yfilter != YFilter.not_set or
                                                                            self.priority_bit4.yfilter != YFilter.not_set or
                                                                            self.priority_bit5.yfilter != YFilter.not_set or
                                                                            self.priority_bit6.yfilter != YFilter.not_set or
                                                                            self.priority_bit7.yfilter != YFilter.not_set or
                                                                            self.res.yfilter != YFilter.not_set or
                                                                            self.sbit.yfilter != YFilter.not_set or
                                                                            self.signal_type.yfilter != YFilter.not_set or
                                                                            self.stage.yfilter != YFilter.not_set or
                                                                            self.tbit.yfilter != YFilter.not_set or
                                                                            self.tsg.yfilter != YFilter.not_set)

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "flex-sub-tlv-value-common" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()
                                                                        if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                        if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                        if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                        if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                        if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                        if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                        if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                        if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                        if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                        if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.res.get_name_leafdata())
                                                                        if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                        if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                        if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.stage.get_name_leafdata())
                                                                        if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                        if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        if(value_path == "num-stages"):
                                                                            self.num_stages = value
                                                                            self.num_stages.value_namespace = name_space
                                                                            self.num_stages.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit0"):
                                                                            self.priority_bit0 = value
                                                                            self.priority_bit0.value_namespace = name_space
                                                                            self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit1"):
                                                                            self.priority_bit1 = value
                                                                            self.priority_bit1.value_namespace = name_space
                                                                            self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit2"):
                                                                            self.priority_bit2 = value
                                                                            self.priority_bit2.value_namespace = name_space
                                                                            self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit3"):
                                                                            self.priority_bit3 = value
                                                                            self.priority_bit3.value_namespace = name_space
                                                                            self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit4"):
                                                                            self.priority_bit4 = value
                                                                            self.priority_bit4.value_namespace = name_space
                                                                            self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit5"):
                                                                            self.priority_bit5 = value
                                                                            self.priority_bit5.value_namespace = name_space
                                                                            self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit6"):
                                                                            self.priority_bit6 = value
                                                                            self.priority_bit6.value_namespace = name_space
                                                                            self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "priority-bit7"):
                                                                            self.priority_bit7 = value
                                                                            self.priority_bit7.value_namespace = name_space
                                                                            self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "res"):
                                                                            self.res = value
                                                                            self.res.value_namespace = name_space
                                                                            self.res.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "sbit"):
                                                                            self.sbit = value
                                                                            self.sbit.value_namespace = name_space
                                                                            self.sbit.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "signal-type"):
                                                                            self.signal_type = value
                                                                            self.signal_type.value_namespace = name_space
                                                                            self.signal_type.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "stage"):
                                                                            self.stage = value
                                                                            self.stage.value_namespace = name_space
                                                                            self.stage.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "tbit"):
                                                                            self.tbit = value
                                                                            self.tbit.value_namespace = name_space
                                                                            self.tbit.value_namespace_prefix = name_space_prefix
                                                                        if(value_path == "tsg"):
                                                                            self.tsg = value
                                                                            self.tsg.value_namespace = name_space
                                                                            self.tsg.value_namespace_prefix = name_space_prefix


                                                                class UnresLspbw(Entity):
                                                                    """
                                                                    Array of Unres LSP BW
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..18446744073709551615
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                        self.yang_name = "unres-lspbw"
                                                                        self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                        self.entry = YLeaf(YType.uint64, "entry")

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in ("entry") and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)

                                                                    def has_data(self):
                                                                        return self.entry.is_set

                                                                    def has_operation(self):
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            self.entry.yfilter != YFilter.not_set)

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "unres-lspbw" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()
                                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "entry"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        if(value_path == "entry"):
                                                                            self.entry = value
                                                                            self.entry.value_namespace = name_space
                                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                                class MaxLspbw(Entity):
                                                                    """
                                                                    Max LSP BW Array
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..18446744073709551615
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                        self.yang_name = "max-lspbw"
                                                                        self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                        self.entry = YLeaf(YType.uint64, "entry")

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in ("entry") and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)

                                                                    def has_data(self):
                                                                        return self.entry.is_set

                                                                    def has_operation(self):
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            self.entry.yfilter != YFilter.not_set)

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "max-lspbw" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()
                                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "entry"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        if(value_path == "entry"):
                                                                            self.entry = value
                                                                            self.entry.value_namespace = name_space
                                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                                def has_data(self):
                                                                    for c in self.max_lspbw:
                                                                        if (c.has_data()):
                                                                            return True
                                                                    for c in self.unres_lspbw:
                                                                        if (c.has_data()):
                                                                            return True
                                                                    return (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_data())

                                                                def has_operation(self):
                                                                    for c in self.max_lspbw:
                                                                        if (c.has_operation()):
                                                                            return True
                                                                    for c in self.unres_lspbw:
                                                                        if (c.has_operation()):
                                                                            return True
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_operation()))

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "flex-bw-sub-tlv-value" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    if (child_yang_name == "flex-sub-tlv-value-common"):
                                                                        if (self.flex_sub_tlv_value_common is None):
                                                                            self.flex_sub_tlv_value_common = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                            self.flex_sub_tlv_value_common.parent = self
                                                                            self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                        return self.flex_sub_tlv_value_common

                                                                    if (child_yang_name == "max-lspbw"):
                                                                        for c in self.max_lspbw:
                                                                            segment = c.get_segment_path()
                                                                            if (segment_path == segment):
                                                                                return c
                                                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw()
                                                                        c.parent = self
                                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                                        self._local_refs[local_reference_key] = c
                                                                        self.max_lspbw.append(c)
                                                                        return c

                                                                    if (child_yang_name == "unres-lspbw"):
                                                                        for c in self.unres_lspbw:
                                                                            segment = c.get_segment_path()
                                                                            if (segment_path == segment):
                                                                                return c
                                                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw()
                                                                        c.parent = self
                                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                                        self._local_refs[local_reference_key] = c
                                                                        self.unres_lspbw.append(c)
                                                                        return c

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "flex-sub-tlv-value-common" or name == "max-lspbw" or name == "unres-lspbw"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    pass

                                                            def has_data(self):
                                                                return (
                                                                    self.ixcdbw_sub_tlv_type.is_set or
                                                                    (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_data()) or
                                                                    (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_data()))

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                    (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_operation()) or
                                                                    (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_operation()))

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "bw-sub-tlv-value" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.ixcdbw_sub_tlv_type.is_set or self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.ixcdbw_sub_tlv_type.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "fixed-bw-sub-tlv-value"):
                                                                    if (self.fixed_bw_sub_tlv_value is None):
                                                                        self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                        self.fixed_bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                    return self.fixed_bw_sub_tlv_value

                                                                if (child_yang_name == "flex-bw-sub-tlv-value"):
                                                                    if (self.flex_bw_sub_tlv_value is None):
                                                                        self.flex_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                        self.flex_bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                    return self.flex_bw_sub_tlv_value

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "fixed-bw-sub-tlv-value" or name == "flex-bw-sub-tlv-value" or name == "ixcdbw-sub-tlv-type"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "ixcdbw-sub-tlv-type"):
                                                                    self.ixcdbw_sub_tlv_type = value
                                                                    self.ixcdbw_sub_tlv_type.value_namespace = name_space
                                                                    self.ixcdbw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                        def has_data(self):
                                                            return (
                                                                self.bw_sub_tlv_length.is_set or
                                                                self.bw_sub_tlv_type.is_set or
                                                                (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.bw_sub_tlv_length.yfilter != YFilter.not_set or
                                                                self.bw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "arr-bw-sub-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.bw_sub_tlv_length.is_set or self.bw_sub_tlv_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bw_sub_tlv_length.get_name_leafdata())
                                                            if (self.bw_sub_tlv_type.is_set or self.bw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.bw_sub_tlv_type.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "bw-sub-tlv-value"):
                                                                if (self.bw_sub_tlv_value is None):
                                                                    self.bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                    self.bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                return self.bw_sub_tlv_value

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "bw-sub-tlv-value" or name == "bw-sub-tlv-length" or name == "bw-sub-tlv-type"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "bw-sub-tlv-length"):
                                                                self.bw_sub_tlv_length = value
                                                                self.bw_sub_tlv_length.value_namespace = name_space
                                                                self.bw_sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "bw-sub-tlv-type"):
                                                                self.bw_sub_tlv_type = value
                                                                self.bw_sub_tlv_type.value_namespace = name_space
                                                                self.bw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.arr_bw_sub_tlv:
                                                            if (c.has_data()):
                                                                return True
                                                        return False

                                                    def has_operation(self):
                                                        for c in self.arr_bw_sub_tlv:
                                                            if (c.has_operation()):
                                                                return True
                                                        return self.yfilter != YFilter.not_set

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ixcdbw-sub-tlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "arr-bw-sub-tlv"):
                                                            for c in self.arr_bw_sub_tlv:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.arr_bw_sub_tlv.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "arr-bw-sub-tlv"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        pass

                                                def has_data(self):
                                                    return (
                                                        self.switching_cap_type.is_set or
                                                        (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_data()) or
                                                        (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.switching_cap_type.yfilter != YFilter.not_set or
                                                        (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_operation()) or
                                                        (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ixcd-switching-cap-type" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.switching_cap_type.is_set or self.switching_cap_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.switching_cap_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ixcdbw-sub-tlv"):
                                                        if (self.ixcdbw_sub_tlv is None):
                                                            self.ixcdbw_sub_tlv = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                            self.ixcdbw_sub_tlv.parent = self
                                                            self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                        return self.ixcdbw_sub_tlv

                                                    if (child_yang_name == "ixcdpsc-info"):
                                                        if (self.ixcdpsc_info is None):
                                                            self.ixcdpsc_info = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                            self.ixcdpsc_info.parent = self
                                                            self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                        return self.ixcdpsc_info

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ixcdbw-sub-tlv" or name == "ixcdpsc-info" or name == "switching-cap-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "switching-cap-type"):
                                                        self.switching_cap_type = value
                                                        self.switching_cap_type.value_namespace = name_space
                                                        self.switching_cap_type.value_namespace_prefix = name_space_prefix


                                            class MaxLspbw(Entity):
                                                """
                                                Max LSP bandwidth array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** \-9223372036854775808..9223372036854775807
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                    self.yang_name = "max-lspbw"
                                                    self.yang_parent_name = "ixcdtlv-value"

                                                    self.entry = YLeaf(YType.int64, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "max-lspbw" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.max_lspbw:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.fixed_scsi_count.is_set or
                                                    self.flex_scsi_count.is_set or
                                                    self.rile_len_code.is_set or
                                                    self.switching_cap.is_set or
                                                    (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_data()))

                                            def has_operation(self):
                                                for c in self.max_lspbw:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.fixed_scsi_count.yfilter != YFilter.not_set or
                                                    self.flex_scsi_count.yfilter != YFilter.not_set or
                                                    self.rile_len_code.yfilter != YFilter.not_set or
                                                    self.switching_cap.yfilter != YFilter.not_set or
                                                    (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ixcdtlv-value" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.fixed_scsi_count.is_set or self.fixed_scsi_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fixed_scsi_count.get_name_leafdata())
                                                if (self.flex_scsi_count.is_set or self.flex_scsi_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flex_scsi_count.get_name_leafdata())
                                                if (self.rile_len_code.is_set or self.rile_len_code.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rile_len_code.get_name_leafdata())
                                                if (self.switching_cap.is_set or self.switching_cap.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.switching_cap.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ixcd-switching-cap-type"):
                                                    if (self.ixcd_switching_cap_type is None):
                                                        self.ixcd_switching_cap_type = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                        self.ixcd_switching_cap_type.parent = self
                                                        self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                    return self.ixcd_switching_cap_type

                                                if (child_yang_name == "max-lspbw"):
                                                    for c in self.max_lspbw:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.max_lspbw.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ixcd-switching-cap-type" or name == "max-lspbw" or name == "fixed-scsi-count" or name == "flex-scsi-count" or name == "rile-len-code" or name == "switching-cap"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "fixed-scsi-count"):
                                                    self.fixed_scsi_count = value
                                                    self.fixed_scsi_count.value_namespace = name_space
                                                    self.fixed_scsi_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flex-scsi-count"):
                                                    self.flex_scsi_count = value
                                                    self.flex_scsi_count.value_namespace = name_space
                                                    self.flex_scsi_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rile-len-code"):
                                                    self.rile_len_code = value
                                                    self.rile_len_code.value_namespace = name_space
                                                    self.rile_len_code.value_namespace_prefix = name_space_prefix
                                                if(value_path == "switching-cap"):
                                                    self.switching_cap = value
                                                    self.switching_cap.value_namespace = name_space
                                                    self.switching_cap.value_namespace_prefix = name_space_prefix


                                        class UnidtlvValue(Entity):
                                            """
                                            Value of Uni Delay TLV
                                            
                                            .. attribute:: uni_dir_delay
                                            
                                            	Uni Dir Delay
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                self.yang_name = "unidtlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("uni_dir_delay") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.uni_dir_delay.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.uni_dir_delay.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unidtlv-value" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.uni_dir_delay.is_set or self.uni_dir_delay.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.uni_dir_delay.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "uni-dir-delay"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "uni-dir-delay"):
                                                    self.uni_dir_delay = value
                                                    self.uni_dir_delay.value_namespace = name_space
                                                    self.uni_dir_delay.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.opaque_tlv_type.is_set or
                                                (self.bctlv_value is not None and self.bctlv_value.has_data()) or
                                                (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_data()) or
                                                (self.srlgtlv_value is not None and self.srlgtlv_value.has_data()) or
                                                (self.unidtlv_value is not None and self.unidtlv_value.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.opaque_tlv_type.yfilter != YFilter.not_set or
                                                (self.bctlv_value is not None and self.bctlv_value.has_operation()) or
                                                (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_operation()) or
                                                (self.srlgtlv_value is not None and self.srlgtlv_value.has_operation()) or
                                                (self.unidtlv_value is not None and self.unidtlv_value.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mplste-link-opt-tlv-value" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.opaque_tlv_type.is_set or self.opaque_tlv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.opaque_tlv_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "bctlv-value"):
                                                if (self.bctlv_value is None):
                                                    self.bctlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                    self.bctlv_value.parent = self
                                                    self._children_name_map["bctlv_value"] = "bctlv-value"
                                                return self.bctlv_value

                                            if (child_yang_name == "ixcdtlv-value"):
                                                if (self.ixcdtlv_value is None):
                                                    self.ixcdtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                    self.ixcdtlv_value.parent = self
                                                    self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                return self.ixcdtlv_value

                                            if (child_yang_name == "srlgtlv-value"):
                                                if (self.srlgtlv_value is None):
                                                    self.srlgtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                    self.srlgtlv_value.parent = self
                                                    self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                return self.srlgtlv_value

                                            if (child_yang_name == "unidtlv-value"):
                                                if (self.unidtlv_value is None):
                                                    self.unidtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                    self.unidtlv_value.parent = self
                                                    self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                return self.unidtlv_value

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bctlv-value" or name == "ixcdtlv-value" or name == "srlgtlv-value" or name == "unidtlv-value" or name == "opaque-tlv-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "opaque-tlv-type"):
                                                self.opaque_tlv_type = value
                                                self.opaque_tlv_type.value_namespace = name_space
                                                self.opaque_tlv_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.mplste_link_opt_tlv_value:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.mplste_link_opt_tlv_len.is_set or
                                            self.mplste_link_opt_tlv_type.is_set)

                                    def has_operation(self):
                                        for c in self.mplste_link_opt_tlv_value:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set or
                                            self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mplste-link-opt-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mplste_link_opt_tlv_len.is_set or self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mplste_link_opt_tlv_len.get_name_leafdata())
                                        if (self.mplste_link_opt_tlv_type.is_set or self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mplste_link_opt_tlv_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "mplste-link-opt-tlv-value"):
                                            for c in self.mplste_link_opt_tlv_value:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.mplste_link_opt_tlv_value.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mplste-link-opt-tlv-value" or name == "mplste-link-opt-tlv-len" or name == "mplste-link-opt-tlv-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mplste-link-opt-tlv-len"):
                                            self.mplste_link_opt_tlv_len = value
                                            self.mplste_link_opt_tlv_len.value_namespace = name_space
                                            self.mplste_link_opt_tlv_len.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mplste-link-opt-tlv-type"):
                                            self.mplste_link_opt_tlv_type = value
                                            self.mplste_link_opt_tlv_type.value_namespace = name_space
                                            self.mplste_link_opt_tlv_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.mplste_link_opt_tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.affinity.is_set or
                                        self.dste_allocation_model_id.is_set or
                                        self.dste_in_use.is_set or
                                        self.fragment_id.is_set or
                                        self.igp_metric.is_set or
                                        self.input_interface_id.is_set or
                                        self.link_address.is_set or
                                        self.maximum_link_bw.is_set or
                                        self.maximum_link_reservable_bw.is_set or
                                        self.maximum_link_sub_reservable_bw.is_set or
                                        self.mpls_link_instance.is_set or
                                        self.mpls_link_type.is_set or
                                        self.neighbor_ip_address.is_set or
                                        self.neighbor_system_id.is_set or
                                        self.new_link.is_set or
                                        self.number_of_optional_tl_vs.is_set or
                                        self.output_interface_id.is_set or
                                        self.priority_count.is_set or
                                        self.te_metric.is_set or
                                        (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_data()) or
                                        (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_data()) or
                                        (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_data()) or
                                        (self.link_sw_capability is not None and self.link_sw_capability.has_data()) or
                                        (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_data()))

                                def has_operation(self):
                                    for c in self.mplste_link_opt_tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.affinity.yfilter != YFilter.not_set or
                                        self.dste_allocation_model_id.yfilter != YFilter.not_set or
                                        self.dste_in_use.yfilter != YFilter.not_set or
                                        self.fragment_id.yfilter != YFilter.not_set or
                                        self.igp_metric.yfilter != YFilter.not_set or
                                        self.input_interface_id.yfilter != YFilter.not_set or
                                        self.link_address.yfilter != YFilter.not_set or
                                        self.maximum_link_bw.yfilter != YFilter.not_set or
                                        self.maximum_link_reservable_bw.yfilter != YFilter.not_set or
                                        self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set or
                                        self.mpls_link_instance.yfilter != YFilter.not_set or
                                        self.mpls_link_type.yfilter != YFilter.not_set or
                                        self.neighbor_ip_address.yfilter != YFilter.not_set or
                                        self.neighbor_system_id.yfilter != YFilter.not_set or
                                        self.new_link.yfilter != YFilter.not_set or
                                        self.number_of_optional_tl_vs.yfilter != YFilter.not_set or
                                        self.output_interface_id.yfilter != YFilter.not_set or
                                        self.priority_count.yfilter != YFilter.not_set or
                                        self.te_metric.yfilter != YFilter.not_set or
                                        (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_operation()) or
                                        (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_operation()) or
                                        (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_operation()) or
                                        (self.link_sw_capability is not None and self.link_sw_capability.has_operation()) or
                                        (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mpls-te-link" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.affinity.is_set or self.affinity.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.affinity.get_name_leafdata())
                                    if (self.dste_allocation_model_id.is_set or self.dste_allocation_model_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dste_allocation_model_id.get_name_leafdata())
                                    if (self.dste_in_use.is_set or self.dste_in_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dste_in_use.get_name_leafdata())
                                    if (self.fragment_id.is_set or self.fragment_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fragment_id.get_name_leafdata())
                                    if (self.igp_metric.is_set or self.igp_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igp_metric.get_name_leafdata())
                                    if (self.input_interface_id.is_set or self.input_interface_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.input_interface_id.get_name_leafdata())
                                    if (self.link_address.is_set or self.link_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.link_address.get_name_leafdata())
                                    if (self.maximum_link_bw.is_set or self.maximum_link_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_link_bw.get_name_leafdata())
                                    if (self.maximum_link_reservable_bw.is_set or self.maximum_link_reservable_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_link_reservable_bw.get_name_leafdata())
                                    if (self.maximum_link_sub_reservable_bw.is_set or self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_link_sub_reservable_bw.get_name_leafdata())
                                    if (self.mpls_link_instance.is_set or self.mpls_link_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_link_instance.get_name_leafdata())
                                    if (self.mpls_link_type.is_set or self.mpls_link_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mpls_link_type.get_name_leafdata())
                                    if (self.neighbor_ip_address.is_set or self.neighbor_ip_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_ip_address.get_name_leafdata())
                                    if (self.neighbor_system_id.is_set or self.neighbor_system_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_system_id.get_name_leafdata())
                                    if (self.new_link.is_set or self.new_link.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.new_link.get_name_leafdata())
                                    if (self.number_of_optional_tl_vs.is_set or self.number_of_optional_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number_of_optional_tl_vs.get_name_leafdata())
                                    if (self.output_interface_id.is_set or self.output_interface_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.output_interface_id.get_name_leafdata())
                                    if (self.priority_count.is_set or self.priority_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.priority_count.get_name_leafdata())
                                    if (self.te_metric.is_set or self.te_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "extended-admin-group-list"):
                                        if (self.extended_admin_group_list is None):
                                            self.extended_admin_group_list = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                            self.extended_admin_group_list.parent = self
                                            self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                        return self.extended_admin_group_list

                                    if (child_yang_name == "global-unreserve-bw-per-priority"):
                                        if (self.global_unreserve_bw_per_priority is None):
                                            self.global_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                            self.global_unreserve_bw_per_priority.parent = self
                                            self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                        return self.global_unreserve_bw_per_priority

                                    if (child_yang_name == "link-protocol-priority-capability"):
                                        if (self.link_protocol_priority_capability is None):
                                            self.link_protocol_priority_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                            self.link_protocol_priority_capability.parent = self
                                            self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                        return self.link_protocol_priority_capability

                                    if (child_yang_name == "link-sw-capability"):
                                        if (self.link_sw_capability is None):
                                            self.link_sw_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                            self.link_sw_capability.parent = self
                                            self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                        return self.link_sw_capability

                                    if (child_yang_name == "mplste-link-opt-tlv"):
                                        for c in self.mplste_link_opt_tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.mplste_link_opt_tlv.append(c)
                                        return c

                                    if (child_yang_name == "sub-pool-unreserve-bw-per-priority"):
                                        if (self.sub_pool_unreserve_bw_per_priority is None):
                                            self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                            self.sub_pool_unreserve_bw_per_priority.parent = self
                                            self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                        return self.sub_pool_unreserve_bw_per_priority

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "extended-admin-group-list" or name == "global-unreserve-bw-per-priority" or name == "link-protocol-priority-capability" or name == "link-sw-capability" or name == "mplste-link-opt-tlv" or name == "sub-pool-unreserve-bw-per-priority" or name == "affinity" or name == "dste-allocation-model-id" or name == "dste-in-use" or name == "fragment-id" or name == "igp-metric" or name == "input-interface-id" or name == "link-address" or name == "maximum-link-bw" or name == "maximum-link-reservable-bw" or name == "maximum-link-sub-reservable-bw" or name == "mpls-link-instance" or name == "mpls-link-type" or name == "neighbor-ip-address" or name == "neighbor-system-id" or name == "new-link" or name == "number-of-optional-tl-vs" or name == "output-interface-id" or name == "priority-count" or name == "te-metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "affinity"):
                                        self.affinity = value
                                        self.affinity.value_namespace = name_space
                                        self.affinity.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dste-allocation-model-id"):
                                        self.dste_allocation_model_id = value
                                        self.dste_allocation_model_id.value_namespace = name_space
                                        self.dste_allocation_model_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dste-in-use"):
                                        self.dste_in_use = value
                                        self.dste_in_use.value_namespace = name_space
                                        self.dste_in_use.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fragment-id"):
                                        self.fragment_id = value
                                        self.fragment_id.value_namespace = name_space
                                        self.fragment_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igp-metric"):
                                        self.igp_metric = value
                                        self.igp_metric.value_namespace = name_space
                                        self.igp_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "input-interface-id"):
                                        self.input_interface_id = value
                                        self.input_interface_id.value_namespace = name_space
                                        self.input_interface_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "link-address"):
                                        self.link_address = value
                                        self.link_address.value_namespace = name_space
                                        self.link_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-link-bw"):
                                        self.maximum_link_bw = value
                                        self.maximum_link_bw.value_namespace = name_space
                                        self.maximum_link_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-link-reservable-bw"):
                                        self.maximum_link_reservable_bw = value
                                        self.maximum_link_reservable_bw.value_namespace = name_space
                                        self.maximum_link_reservable_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-link-sub-reservable-bw"):
                                        self.maximum_link_sub_reservable_bw = value
                                        self.maximum_link_sub_reservable_bw.value_namespace = name_space
                                        self.maximum_link_sub_reservable_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-link-instance"):
                                        self.mpls_link_instance = value
                                        self.mpls_link_instance.value_namespace = name_space
                                        self.mpls_link_instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mpls-link-type"):
                                        self.mpls_link_type = value
                                        self.mpls_link_type.value_namespace = name_space
                                        self.mpls_link_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-ip-address"):
                                        self.neighbor_ip_address = value
                                        self.neighbor_ip_address.value_namespace = name_space
                                        self.neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-system-id"):
                                        self.neighbor_system_id = value
                                        self.neighbor_system_id.value_namespace = name_space
                                        self.neighbor_system_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "new-link"):
                                        self.new_link = value
                                        self.new_link.value_namespace = name_space
                                        self.new_link.value_namespace_prefix = name_space_prefix
                                    if(value_path == "number-of-optional-tl-vs"):
                                        self.number_of_optional_tl_vs = value
                                        self.number_of_optional_tl_vs.value_namespace = name_space
                                        self.number_of_optional_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "output-interface-id"):
                                        self.output_interface_id = value
                                        self.output_interface_id.value_namespace = name_space
                                        self.output_interface_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "priority-count"):
                                        self.priority_count = value
                                        self.priority_count.value_namespace = name_space
                                        self.priority_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-metric"):
                                        self.te_metric = value
                                        self.te_metric.value_namespace = name_space
                                        self.te_metric.value_namespace_prefix = name_space_prefix


                            class MplsTeFragment(Entity):
                                """
                                MPLS TE fragments in the area
                                
                                .. attribute:: dste_model_id
                                
                                	DS\-TE Allocation Model ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: fragment_id
                                
                                	Fragment ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fragment_instance
                                
                                	Fragment instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_te_link
                                
                                	List of fragment links
                                	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink>`
                                
                                .. attribute:: same_fragment_count
                                
                                	Number of fragment links which haven't changed since the last update
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment, self).__init__()

                                    self.yang_name = "mpls-te-fragment"
                                    self.yang_parent_name = "mpls-te-fragment"

                                    self.dste_model_id = YLeaf(YType.uint8, "dste-model-id")

                                    self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                    self.fragment_instance = YLeaf(YType.uint32, "fragment-instance")

                                    self.same_fragment_count = YLeaf(YType.uint8, "same-fragment-count")

                                    self.mpls_te_link = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dste_model_id",
                                                    "fragment_id",
                                                    "fragment_instance",
                                                    "same_fragment_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment, self).__setattr__(name, value)


                                class MplsTeLink(Entity):
                                    """
                                    List of fragment links
                                    
                                    .. attribute:: affinity
                                    
                                    	Affinity
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dste_allocation_model_id
                                    
                                    	DS\-TE Allocation Model ID
                                    	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                    
                                    .. attribute:: dste_in_use
                                    
                                    	A DS\-TE Allocation Model in use
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_admin_group_list
                                    
                                    	Extended Admin Group
                                    	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList>`
                                    
                                    .. attribute:: fragment_id
                                    
                                    	Fragment ID for this link
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: global_unreserve_bw_per_priority
                                    
                                    	Global pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                    
                                    .. attribute:: igp_metric
                                    
                                    	Link IGP metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: input_interface_id
                                    
                                    	Input interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_address
                                    
                                    	The local interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: link_protocol_priority_capability
                                    
                                    	Link protocol and protocol priority capability
                                    	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability>`
                                    
                                    .. attribute:: link_sw_capability
                                    
                                    	Link switching capability
                                    	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability>`
                                    
                                    .. attribute:: maximum_link_bw
                                    
                                    	Maximum link bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_reservable_bw
                                    
                                    	Maximum link global pool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_sub_reservable_bw
                                    
                                    	Maximum link subpool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: mpls_link_instance
                                    
                                    	Link instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mpls_link_type
                                    
                                    	Type of link
                                    	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                    
                                    .. attribute:: mplste_link_opt_tlv
                                    
                                    	List of Optional TLVs
                                    	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv>`
                                    
                                    .. attribute:: neighbor_ip_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_system_id
                                    
                                    	Neighbor system ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: new_link
                                    
                                    	If true, Link is new
                                    	**type**\:  bool
                                    
                                    .. attribute:: number_of_optional_tl_vs
                                    
                                    	Number of Optional TLVs
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: output_interface_id
                                    
                                    	Output interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: priority_count
                                    
                                    	Number of priorities
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_pool_unreserve_bw_per_priority
                                    
                                    	Sub pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                    
                                    .. attribute:: te_metric
                                    
                                    	Link TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink, self).__init__()

                                        self.yang_name = "mpls-te-link"
                                        self.yang_parent_name = "mpls-te-fragment"

                                        self.affinity = YLeaf(YType.uint32, "affinity")

                                        self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                        self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                        self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                        self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                        self.link_address = YLeaf(YType.str, "link-address")

                                        self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                        self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                        self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                        self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                        self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                        self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                        self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                        self.new_link = YLeaf(YType.boolean, "new-link")

                                        self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                        self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                        self.priority_count = YLeaf(YType.int32, "priority-count")

                                        self.te_metric = YLeaf(YType.uint32, "te-metric")

                                        self.extended_admin_group_list = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                        self.extended_admin_group_list.parent = self
                                        self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                        self._children_yang_names.add("extended-admin-group-list")

                                        self.global_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                        self.global_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                        self._children_yang_names.add("global-unreserve-bw-per-priority")

                                        self.link_protocol_priority_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                        self.link_protocol_priority_capability.parent = self
                                        self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                        self._children_yang_names.add("link-protocol-priority-capability")

                                        self.link_sw_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                        self.link_sw_capability.parent = self
                                        self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                        self._children_yang_names.add("link-sw-capability")

                                        self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                        self.sub_pool_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                        self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                        self.mplste_link_opt_tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("affinity",
                                                        "dste_allocation_model_id",
                                                        "dste_in_use",
                                                        "fragment_id",
                                                        "igp_metric",
                                                        "input_interface_id",
                                                        "link_address",
                                                        "maximum_link_bw",
                                                        "maximum_link_reservable_bw",
                                                        "maximum_link_sub_reservable_bw",
                                                        "mpls_link_instance",
                                                        "mpls_link_type",
                                                        "neighbor_ip_address",
                                                        "neighbor_system_id",
                                                        "new_link",
                                                        "number_of_optional_tl_vs",
                                                        "output_interface_id",
                                                        "priority_count",
                                                        "te_metric") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink, self).__setattr__(name, value)


                                    class GlobalUnreserveBwPerPriority(Entity):
                                        """
                                        Global pool unreserved bandwidth for each
                                        priority (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "global-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.bw_per_priority = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__setattr__(name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "global-unreserve-bw-per-priority"

                                                self.entry = YLeaf(YType.uint64, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "global-unreserve-bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "bw-per-priority"):
                                                for c in self.bw_per_priority:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.bw_per_priority.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bw-per-priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SubPoolUnreserveBwPerPriority(Entity):
                                        """
                                        Sub pool unreserved bandwidth for each priority
                                        (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.bw_per_priority = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__setattr__(name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"

                                                self.entry = YLeaf(YType.uint64, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.bw_per_priority:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sub-pool-unreserve-bw-per-priority" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "bw-per-priority"):
                                                for c in self.bw_per_priority:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.bw_per_priority.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bw-per-priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class LinkProtocolPriorityCapability(Entity):
                                        """
                                        Link protocol and protocol priority capability
                                        
                                        .. attribute:: link_protocol_capability
                                        
                                        	Link protocol capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_protocol_priority
                                        
                                        	Link protocol priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                            self.yang_name = "link-protocol-priority-capability"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                            self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("link_protocol_capability",
                                                            "link_protocol_priority") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.link_protocol_capability.is_set or
                                                self.link_protocol_priority.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.link_protocol_capability.yfilter != YFilter.not_set or
                                                self.link_protocol_priority.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "link-protocol-priority-capability" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.link_protocol_capability.is_set or self.link_protocol_capability.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_protocol_capability.get_name_leafdata())
                                            if (self.link_protocol_priority.is_set or self.link_protocol_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_protocol_priority.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "link-protocol-capability" or name == "link-protocol-priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "link-protocol-capability"):
                                                self.link_protocol_capability = value
                                                self.link_protocol_capability.value_namespace = name_space
                                                self.link_protocol_capability.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-protocol-priority"):
                                                self.link_protocol_priority = value
                                                self.link_protocol_priority.value_namespace = name_space
                                                self.link_protocol_priority.value_namespace_prefix = name_space_prefix


                                    class LinkSwCapability(Entity):
                                        """
                                        Link switching capability
                                        
                                        .. attribute:: link_encoding
                                        
                                        	Link Encoding
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_mtu
                                        
                                        	Link MTU size (bytes)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: link_switching_capability
                                        
                                        	Link Switching Capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: maximum_lsp_bw_per_priority
                                        
                                        	Maximum LSP bandwidth for each priority  (bytes/s)
                                        	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                        
                                        .. attribute:: minimum_lsp_bw
                                        
                                        	Minimum LSP bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__init__()

                                            self.yang_name = "link-sw-capability"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                            self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                            self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                            self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                            self.maximum_lsp_bw_per_priority = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("link_encoding",
                                                            "link_mtu",
                                                            "link_switching_capability",
                                                            "minimum_lsp_bw") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__setattr__(name, value)


                                        class MaximumLspBwPerPriority(Entity):
                                            """
                                            Maximum LSP bandwidth for each priority
                                            
                                            (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                                self.yang_name = "maximum-lsp-bw-per-priority"
                                                self.yang_parent_name = "link-sw-capability"

                                                self.entry = YLeaf(YType.uint64, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "maximum-lsp-bw-per-priority" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.maximum_lsp_bw_per_priority:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.link_encoding.is_set or
                                                self.link_mtu.is_set or
                                                self.link_switching_capability.is_set or
                                                self.minimum_lsp_bw.is_set)

                                        def has_operation(self):
                                            for c in self.maximum_lsp_bw_per_priority:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.link_encoding.yfilter != YFilter.not_set or
                                                self.link_mtu.yfilter != YFilter.not_set or
                                                self.link_switching_capability.yfilter != YFilter.not_set or
                                                self.minimum_lsp_bw.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "link-sw-capability" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.link_encoding.is_set or self.link_encoding.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_encoding.get_name_leafdata())
                                            if (self.link_mtu.is_set or self.link_mtu.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_mtu.get_name_leafdata())
                                            if (self.link_switching_capability.is_set or self.link_switching_capability.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_switching_capability.get_name_leafdata())
                                            if (self.minimum_lsp_bw.is_set or self.minimum_lsp_bw.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.minimum_lsp_bw.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "maximum-lsp-bw-per-priority"):
                                                for c in self.maximum_lsp_bw_per_priority:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.maximum_lsp_bw_per_priority.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "maximum-lsp-bw-per-priority" or name == "link-encoding" or name == "link-mtu" or name == "link-switching-capability" or name == "minimum-lsp-bw"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "link-encoding"):
                                                self.link_encoding = value
                                                self.link_encoding.value_namespace = name_space
                                                self.link_encoding.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-mtu"):
                                                self.link_mtu = value
                                                self.link_mtu.value_namespace = name_space
                                                self.link_mtu.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-switching-capability"):
                                                self.link_switching_capability = value
                                                self.link_switching_capability.value_namespace = name_space
                                                self.link_switching_capability.value_namespace_prefix = name_space_prefix
                                            if(value_path == "minimum-lsp-bw"):
                                                self.minimum_lsp_bw = value
                                                self.minimum_lsp_bw.value_namespace = name_space
                                                self.minimum_lsp_bw.value_namespace_prefix = name_space_prefix


                                    class ExtendedAdminGroupList(Entity):
                                        """
                                        Extended Admin Group
                                        
                                        .. attribute:: ext_admin_data
                                        
                                        	Value of Extended Admin Group
                                        	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                        
                                        .. attribute:: extended_admin_size
                                        
                                        	Size of the extended admin group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                            self.yang_name = "extended-admin-group-list"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                            self.ext_admin_data = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("extended_admin_size") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__setattr__(name, value)


                                        class ExtAdminData(Entity):
                                            """
                                            Value of Extended Admin Group
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                                self.yang_name = "ext-admin-data"
                                                self.yang_parent_name = "extended-admin-group-list"

                                                self.entry = YLeaf(YType.uint32, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ext-admin-data" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.ext_admin_data:
                                                if (c.has_data()):
                                                    return True
                                            return self.extended_admin_size.is_set

                                        def has_operation(self):
                                            for c in self.ext_admin_data:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.extended_admin_size.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "extended-admin-group-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.extended_admin_size.is_set or self.extended_admin_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.extended_admin_size.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "ext-admin-data"):
                                                for c in self.ext_admin_data:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ext_admin_data.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ext-admin-data" or name == "extended-admin-size"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "extended-admin-size"):
                                                self.extended_admin_size = value
                                                self.extended_admin_size.value_namespace = name_space
                                                self.extended_admin_size.value_namespace_prefix = name_space_prefix


                                    class MplsteLinkOptTlv(Entity):
                                        """
                                        List of Optional TLVs
                                        
                                        .. attribute:: mplste_link_opt_tlv_len
                                        
                                        	Length of Opt TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mplste_link_opt_tlv_type
                                        
                                        	Type of Opt TLV
                                        	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                        
                                        .. attribute:: mplste_link_opt_tlv_value
                                        
                                        	Value of Opt TLV
                                        	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                            self.yang_name = "mplste-link-opt-tlv"
                                            self.yang_parent_name = "mpls-te-link"

                                            self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                            self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                            self.mplste_link_opt_tlv_value = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("mplste_link_opt_tlv_len",
                                                            "mplste_link_opt_tlv_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__setattr__(name, value)


                                        class MplsteLinkOptTlvValue(Entity):
                                            """
                                            Value of Opt TLV
                                            
                                            .. attribute:: bctlv_value
                                            
                                            	Value of Bandwidth Constraints TLV
                                            	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                            
                                            .. attribute:: ixcdtlv_value
                                            
                                            	Value of IXCD TLV
                                            	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                            
                                            .. attribute:: opaque_tlv_type
                                            
                                            	OpaqueTLVType
                                            	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                            
                                            .. attribute:: srlgtlv_value
                                            
                                            	Value of SRLG TLV
                                            	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                            
                                            .. attribute:: unidtlv_value
                                            
                                            	Value of Uni Delay TLV
                                            	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                                self.yang_name = "mplste-link-opt-tlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv"

                                                self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                                self.bctlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                self.bctlv_value.parent = self
                                                self._children_name_map["bctlv_value"] = "bctlv-value"
                                                self._children_yang_names.add("bctlv-value")

                                                self.ixcdtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                self.ixcdtlv_value.parent = self
                                                self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                self._children_yang_names.add("ixcdtlv-value")

                                                self.srlgtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                self.srlgtlv_value.parent = self
                                                self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                self._children_yang_names.add("srlgtlv-value")

                                                self.unidtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                self.unidtlv_value.parent = self
                                                self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                self._children_yang_names.add("unidtlv-value")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("opaque_tlv_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__setattr__(name, value)


                                            class BctlvValue(Entity):
                                                """
                                                Value of Bandwidth Constraints TLV
                                                
                                                .. attribute:: model_id
                                                
                                                	Allocation Model ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mplste_link_bc_bandwidth
                                                
                                                	Value of BC TLV
                                                	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                                
                                                .. attribute:: num_b_cs
                                                
                                                	Number of BC TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                    self.yang_name = "bctlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.model_id = YLeaf(YType.uint8, "model-id")

                                                    self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                    self.mplste_link_bc_bandwidth = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("model_id",
                                                                    "num_b_cs") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__setattr__(name, value)


                                                class MplsteLinkBcBandwidth(Entity):
                                                    """
                                                    Value of BC TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                        self.yang_name = "mplste-link-bc-bandwidth"
                                                        self.yang_parent_name = "bctlv-value"

                                                        self.entry = YLeaf(YType.uint64, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "mplste-link-bc-bandwidth" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.mplste_link_bc_bandwidth:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.model_id.is_set or
                                                        self.num_b_cs.is_set)

                                                def has_operation(self):
                                                    for c in self.mplste_link_bc_bandwidth:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.model_id.yfilter != YFilter.not_set or
                                                        self.num_b_cs.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bctlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.model_id.is_set or self.model_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.model_id.get_name_leafdata())
                                                    if (self.num_b_cs.is_set or self.num_b_cs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_b_cs.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "mplste-link-bc-bandwidth"):
                                                        for c in self.mplste_link_bc_bandwidth:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.mplste_link_bc_bandwidth.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "mplste-link-bc-bandwidth" or name == "model-id" or name == "num-b-cs"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "model-id"):
                                                        self.model_id = value
                                                        self.model_id.value_namespace = name_space
                                                        self.model_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-b-cs"):
                                                        self.num_b_cs = value
                                                        self.num_b_cs.value_namespace = name_space
                                                        self.num_b_cs.value_namespace_prefix = name_space_prefix


                                            class SrlgtlvValue(Entity):
                                                """
                                                Value of SRLG TLV
                                                
                                                .. attribute:: mplste_link_srlg_data
                                                
                                                	Value of SRLG TLV
                                                	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                                
                                                .. attribute:: num_srl_gs
                                                
                                                	Number of SRLG TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: srlg_len
                                                
                                                	Length of SRLG TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                    self.yang_name = "srlgtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                    self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                    self.mplste_link_srlg_data = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("num_srl_gs",
                                                                    "srlg_len") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__setattr__(name, value)


                                                class MplsteLinkSrlgData(Entity):
                                                    """
                                                    Value of SRLG TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                        self.yang_name = "mplste-link-srlg-data"
                                                        self.yang_parent_name = "srlgtlv-value"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "mplste-link-srlg-data" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.mplste_link_srlg_data:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.num_srl_gs.is_set or
                                                        self.srlg_len.is_set)

                                                def has_operation(self):
                                                    for c in self.mplste_link_srlg_data:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.num_srl_gs.yfilter != YFilter.not_set or
                                                        self.srlg_len.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "srlgtlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.num_srl_gs.is_set or self.num_srl_gs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_srl_gs.get_name_leafdata())
                                                    if (self.srlg_len.is_set or self.srlg_len.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.srlg_len.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "mplste-link-srlg-data"):
                                                        for c in self.mplste_link_srlg_data:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.mplste_link_srlg_data.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "mplste-link-srlg-data" or name == "num-srl-gs" or name == "srlg-len"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "num-srl-gs"):
                                                        self.num_srl_gs = value
                                                        self.num_srl_gs.value_namespace = name_space
                                                        self.num_srl_gs.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "srlg-len"):
                                                        self.srlg_len = value
                                                        self.srlg_len.value_namespace = name_space
                                                        self.srlg_len.value_namespace_prefix = name_space_prefix


                                            class IxcdtlvValue(Entity):
                                                """
                                                Value of IXCD TLV
                                                
                                                .. attribute:: fixed_scsi_count
                                                
                                                	Fixed SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flex_scsi_count
                                                
                                                	Flexible SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ixcd_switching_cap_type
                                                
                                                	Switching Cap type
                                                	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                                
                                                .. attribute:: max_lspbw
                                                
                                                	Max LSP bandwidth array
                                                	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                                
                                                .. attribute:: rile_len_code
                                                
                                                	Rile LenCode
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: switching_cap
                                                
                                                	SCap
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                    self.yang_name = "ixcdtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                    self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                    self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                    self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                    self.ixcd_switching_cap_type = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                    self.ixcd_switching_cap_type.parent = self
                                                    self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                    self._children_yang_names.add("ixcd-switching-cap-type")

                                                    self.max_lspbw = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("fixed_scsi_count",
                                                                    "flex_scsi_count",
                                                                    "rile_len_code",
                                                                    "switching_cap") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__setattr__(name, value)


                                                class IxcdSwitchingCapType(Entity):
                                                    """
                                                    Switching Cap type
                                                    
                                                    .. attribute:: ixcdbw_sub_tlv
                                                    
                                                    	Sub TLVs
                                                    	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                    
                                                    .. attribute:: ixcdpsc_info
                                                    
                                                    	IXCD PSC information
                                                    	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                    
                                                    .. attribute:: switching_cap_type
                                                    
                                                    	SwitchingCapType
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                        self.yang_name = "ixcd-switching-cap-type"
                                                        self.yang_parent_name = "ixcdtlv-value"

                                                        self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                        self.ixcdbw_sub_tlv = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                        self.ixcdbw_sub_tlv.parent = self
                                                        self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                        self._children_yang_names.add("ixcdbw-sub-tlv")

                                                        self.ixcdpsc_info = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                        self.ixcdpsc_info.parent = self
                                                        self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                        self._children_yang_names.add("ixcdpsc-info")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("switching_cap_type") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__setattr__(name, value)


                                                    class IxcdpscInfo(Entity):
                                                        """
                                                        IXCD PSC information
                                                        
                                                        .. attribute:: min_lsp_bandwidth
                                                        
                                                        	Min LSP bandwidth
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: psc_interface_mtu
                                                        
                                                        	 Interface MTU
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                            self.yang_name = "ixcdpsc-info"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"

                                                            self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                            self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("min_lsp_bandwidth",
                                                                            "psc_interface_mtu") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.min_lsp_bandwidth.is_set or
                                                                self.psc_interface_mtu.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.min_lsp_bandwidth.yfilter != YFilter.not_set or
                                                                self.psc_interface_mtu.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ixcdpsc-info" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.min_lsp_bandwidth.is_set or self.min_lsp_bandwidth.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.min_lsp_bandwidth.get_name_leafdata())
                                                            if (self.psc_interface_mtu.is_set or self.psc_interface_mtu.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.psc_interface_mtu.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "min-lsp-bandwidth" or name == "psc-interface-mtu"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "min-lsp-bandwidth"):
                                                                self.min_lsp_bandwidth = value
                                                                self.min_lsp_bandwidth.value_namespace = name_space
                                                                self.min_lsp_bandwidth.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "psc-interface-mtu"):
                                                                self.psc_interface_mtu = value
                                                                self.psc_interface_mtu.value_namespace = name_space
                                                                self.psc_interface_mtu.value_namespace_prefix = name_space_prefix


                                                    class IxcdbwSubTlv(Entity):
                                                        """
                                                        Sub TLVs
                                                        
                                                        .. attribute:: arr_bw_sub_tlv
                                                        
                                                        	Array of sub tlvs
                                                        	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                            self.yang_name = "ixcdbw-sub-tlv"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"

                                                            self.arr_bw_sub_tlv = YList(self)

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in () and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__setattr__(name, value)


                                                        class ArrBwSubTlv(Entity):
                                                            """
                                                            Array of sub tlvs
                                                            
                                                            .. attribute:: bw_sub_tlv_length
                                                            
                                                            	Length of BW Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_type
                                                            
                                                            	Type of Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_value
                                                            
                                                            	Value of BW Sub TLV
                                                            	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                                self.yang_name = "arr-bw-sub-tlv"
                                                                self.yang_parent_name = "ixcdbw-sub-tlv"

                                                                self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                                self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                                self.bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                self.bw_sub_tlv_value.parent = self
                                                                self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                self._children_yang_names.add("bw-sub-tlv-value")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("bw_sub_tlv_length",
                                                                                "bw_sub_tlv_type") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__setattr__(name, value)


                                                            class BwSubTlvValue(Entity):
                                                                """
                                                                Value of BW Sub TLV
                                                                
                                                                .. attribute:: fixed_bw_sub_tlv_value
                                                                
                                                                	Value of Fixed Sub TLV
                                                                	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                                
                                                                .. attribute:: flex_bw_sub_tlv_value
                                                                
                                                                	Value of Flex Sub TLV
                                                                	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                                
                                                                .. attribute:: ixcdbw_sub_tlv_type
                                                                
                                                                	IXCDBWSubTLVType
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-01-02'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                    self.yang_name = "bw-sub-tlv-value"
                                                                    self.yang_parent_name = "arr-bw-sub-tlv"

                                                                    self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                    self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                    self.fixed_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                    self.flex_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                    self.flex_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("flex-bw-sub-tlv-value")

                                                                def __setattr__(self, name, value):
                                                                    self._check_monkey_patching_error(name, value)
                                                                    with _handle_type_error():
                                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                "Please use list append or extend method."
                                                                                                .format(value))
                                                                        if isinstance(value, Enum.YLeaf):
                                                                            value = value.name
                                                                        if name in ("ixcdbw_sub_tlv_type") and name in self.__dict__:
                                                                            if isinstance(value, YLeaf):
                                                                                self.__dict__[name].set(value.get())
                                                                            elif isinstance(value, YLeafList):
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)
                                                                            else:
                                                                                self.__dict__[name].set(value)
                                                                        else:
                                                                            if hasattr(value, "parent") and name != "parent":
                                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                    value.parent = self
                                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                    value.parent = self
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__setattr__(name, value)


                                                                class FixedBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Fixed Sub TLV
                                                                    
                                                                    .. attribute:: fixed_sub_tlv_value
                                                                    
                                                                    	Value of Fixed Sub TLV
                                                                    	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                    
                                                                    .. attribute:: unres_oduj_prio
                                                                    
                                                                    	Array of Unres Oduj Prio
                                                                    	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "fixed-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"

                                                                        self.fixed_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                        self.fixed_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                        self._children_yang_names.add("fixed-sub-tlv-value")

                                                                        self.unres_oduj_prio = YList(self)

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in () and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__setattr__(name, value)


                                                                    class FixedSubTlvValue(Entity):
                                                                        """
                                                                        Value of Fixed Sub TLV
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                            self.yang_name = "fixed-sub-tlv-value"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("num_stages",
                                                                                            "priority_bit0",
                                                                                            "priority_bit1",
                                                                                            "priority_bit2",
                                                                                            "priority_bit3",
                                                                                            "priority_bit4",
                                                                                            "priority_bit5",
                                                                                            "priority_bit6",
                                                                                            "priority_bit7",
                                                                                            "res",
                                                                                            "sbit",
                                                                                            "signal_type",
                                                                                            "stage",
                                                                                            "tbit",
                                                                                            "tsg") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return (
                                                                                self.num_stages.is_set or
                                                                                self.priority_bit0.is_set or
                                                                                self.priority_bit1.is_set or
                                                                                self.priority_bit2.is_set or
                                                                                self.priority_bit3.is_set or
                                                                                self.priority_bit4.is_set or
                                                                                self.priority_bit5.is_set or
                                                                                self.priority_bit6.is_set or
                                                                                self.priority_bit7.is_set or
                                                                                self.res.is_set or
                                                                                self.sbit.is_set or
                                                                                self.signal_type.is_set or
                                                                                self.stage.is_set or
                                                                                self.tbit.is_set or
                                                                                self.tsg.is_set)

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.num_stages.yfilter != YFilter.not_set or
                                                                                self.priority_bit0.yfilter != YFilter.not_set or
                                                                                self.priority_bit1.yfilter != YFilter.not_set or
                                                                                self.priority_bit2.yfilter != YFilter.not_set or
                                                                                self.priority_bit3.yfilter != YFilter.not_set or
                                                                                self.priority_bit4.yfilter != YFilter.not_set or
                                                                                self.priority_bit5.yfilter != YFilter.not_set or
                                                                                self.priority_bit6.yfilter != YFilter.not_set or
                                                                                self.priority_bit7.yfilter != YFilter.not_set or
                                                                                self.res.yfilter != YFilter.not_set or
                                                                                self.sbit.yfilter != YFilter.not_set or
                                                                                self.signal_type.yfilter != YFilter.not_set or
                                                                                self.stage.yfilter != YFilter.not_set or
                                                                                self.tbit.yfilter != YFilter.not_set or
                                                                                self.tsg.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "fixed-sub-tlv-value" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                            if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                            if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                            if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                            if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                            if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                            if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                            if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                            if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                            if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.res.get_name_leafdata())
                                                                            if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                            if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                            if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.stage.get_name_leafdata())
                                                                            if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                            if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "num-stages"):
                                                                                self.num_stages = value
                                                                                self.num_stages.value_namespace = name_space
                                                                                self.num_stages.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit0"):
                                                                                self.priority_bit0 = value
                                                                                self.priority_bit0.value_namespace = name_space
                                                                                self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit1"):
                                                                                self.priority_bit1 = value
                                                                                self.priority_bit1.value_namespace = name_space
                                                                                self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit2"):
                                                                                self.priority_bit2 = value
                                                                                self.priority_bit2.value_namespace = name_space
                                                                                self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit3"):
                                                                                self.priority_bit3 = value
                                                                                self.priority_bit3.value_namespace = name_space
                                                                                self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit4"):
                                                                                self.priority_bit4 = value
                                                                                self.priority_bit4.value_namespace = name_space
                                                                                self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit5"):
                                                                                self.priority_bit5 = value
                                                                                self.priority_bit5.value_namespace = name_space
                                                                                self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit6"):
                                                                                self.priority_bit6 = value
                                                                                self.priority_bit6.value_namespace = name_space
                                                                                self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit7"):
                                                                                self.priority_bit7 = value
                                                                                self.priority_bit7.value_namespace = name_space
                                                                                self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "res"):
                                                                                self.res = value
                                                                                self.res.value_namespace = name_space
                                                                                self.res.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "sbit"):
                                                                                self.sbit = value
                                                                                self.sbit.value_namespace = name_space
                                                                                self.sbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "signal-type"):
                                                                                self.signal_type = value
                                                                                self.signal_type.value_namespace = name_space
                                                                                self.signal_type.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "stage"):
                                                                                self.stage = value
                                                                                self.stage.value_namespace = name_space
                                                                                self.stage.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tbit"):
                                                                                self.tbit = value
                                                                                self.tbit.value_namespace = name_space
                                                                                self.tbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tsg"):
                                                                                self.tsg = value
                                                                                self.tsg.value_namespace = name_space
                                                                                self.tsg.value_namespace_prefix = name_space_prefix


                                                                    class UnresOdujPrio(Entity):
                                                                        """
                                                                        Array of Unres Oduj Prio
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                            self.yang_name = "unres-oduj-prio"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"

                                                                            self.entry = YLeaf(YType.uint32, "entry")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("entry") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return self.entry.is_set

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.entry.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "unres-oduj-prio" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "entry"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "entry"):
                                                                                self.entry = value
                                                                                self.entry.value_namespace = name_space
                                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                                    def has_data(self):
                                                                        for c in self.unres_oduj_prio:
                                                                            if (c.has_data()):
                                                                                return True
                                                                        return (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_data())

                                                                    def has_operation(self):
                                                                        for c in self.unres_oduj_prio:
                                                                            if (c.has_operation()):
                                                                                return True
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            (self.fixed_sub_tlv_value is not None and self.fixed_sub_tlv_value.has_operation()))

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "fixed-bw-sub-tlv-value" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        if (child_yang_name == "fixed-sub-tlv-value"):
                                                                            if (self.fixed_sub_tlv_value is None):
                                                                                self.fixed_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                                self.fixed_sub_tlv_value.parent = self
                                                                                self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                            return self.fixed_sub_tlv_value

                                                                        if (child_yang_name == "unres-oduj-prio"):
                                                                            for c in self.unres_oduj_prio:
                                                                                segment = c.get_segment_path()
                                                                                if (segment_path == segment):
                                                                                    return c
                                                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio()
                                                                            c.parent = self
                                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                                            self._local_refs[local_reference_key] = c
                                                                            self.unres_oduj_prio.append(c)
                                                                            return c

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "fixed-sub-tlv-value" or name == "unres-oduj-prio"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        pass


                                                                class FlexBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Flex Sub TLV
                                                                    
                                                                    .. attribute:: flex_sub_tlv_value_common
                                                                    
                                                                    	Flex Sub TLV Value
                                                                    	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                    
                                                                    .. attribute:: max_lspbw
                                                                    
                                                                    	Max LSP BW Array
                                                                    	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                    
                                                                    .. attribute:: unres_lspbw
                                                                    
                                                                    	Array of Unres LSP BW
                                                                    	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-01-02'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "flex-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"

                                                                        self.flex_sub_tlv_value_common = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                        self.flex_sub_tlv_value_common.parent = self
                                                                        self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                        self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                        self.max_lspbw = YList(self)
                                                                        self.unres_lspbw = YList(self)

                                                                    def __setattr__(self, name, value):
                                                                        self._check_monkey_patching_error(name, value)
                                                                        with _handle_type_error():
                                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                    "Please use list append or extend method."
                                                                                                    .format(value))
                                                                            if isinstance(value, Enum.YLeaf):
                                                                                value = value.name
                                                                            if name in () and name in self.__dict__:
                                                                                if isinstance(value, YLeaf):
                                                                                    self.__dict__[name].set(value.get())
                                                                                elif isinstance(value, YLeafList):
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)
                                                                                else:
                                                                                    self.__dict__[name].set(value)
                                                                            else:
                                                                                if hasattr(value, "parent") and name != "parent":
                                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                        value.parent = self
                                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                        value.parent = self
                                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__setattr__(name, value)


                                                                    class FlexSubTlvValueCommon(Entity):
                                                                        """
                                                                        Flex Sub TLV Value
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                            self.yang_name = "flex-sub-tlv-value-common"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("num_stages",
                                                                                            "priority_bit0",
                                                                                            "priority_bit1",
                                                                                            "priority_bit2",
                                                                                            "priority_bit3",
                                                                                            "priority_bit4",
                                                                                            "priority_bit5",
                                                                                            "priority_bit6",
                                                                                            "priority_bit7",
                                                                                            "res",
                                                                                            "sbit",
                                                                                            "signal_type",
                                                                                            "stage",
                                                                                            "tbit",
                                                                                            "tsg") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return (
                                                                                self.num_stages.is_set or
                                                                                self.priority_bit0.is_set or
                                                                                self.priority_bit1.is_set or
                                                                                self.priority_bit2.is_set or
                                                                                self.priority_bit3.is_set or
                                                                                self.priority_bit4.is_set or
                                                                                self.priority_bit5.is_set or
                                                                                self.priority_bit6.is_set or
                                                                                self.priority_bit7.is_set or
                                                                                self.res.is_set or
                                                                                self.sbit.is_set or
                                                                                self.signal_type.is_set or
                                                                                self.stage.is_set or
                                                                                self.tbit.is_set or
                                                                                self.tsg.is_set)

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.num_stages.yfilter != YFilter.not_set or
                                                                                self.priority_bit0.yfilter != YFilter.not_set or
                                                                                self.priority_bit1.yfilter != YFilter.not_set or
                                                                                self.priority_bit2.yfilter != YFilter.not_set or
                                                                                self.priority_bit3.yfilter != YFilter.not_set or
                                                                                self.priority_bit4.yfilter != YFilter.not_set or
                                                                                self.priority_bit5.yfilter != YFilter.not_set or
                                                                                self.priority_bit6.yfilter != YFilter.not_set or
                                                                                self.priority_bit7.yfilter != YFilter.not_set or
                                                                                self.res.yfilter != YFilter.not_set or
                                                                                self.sbit.yfilter != YFilter.not_set or
                                                                                self.signal_type.yfilter != YFilter.not_set or
                                                                                self.stage.yfilter != YFilter.not_set or
                                                                                self.tbit.yfilter != YFilter.not_set or
                                                                                self.tsg.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "flex-sub-tlv-value-common" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.num_stages.is_set or self.num_stages.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.num_stages.get_name_leafdata())
                                                                            if (self.priority_bit0.is_set or self.priority_bit0.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit0.get_name_leafdata())
                                                                            if (self.priority_bit1.is_set or self.priority_bit1.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit1.get_name_leafdata())
                                                                            if (self.priority_bit2.is_set or self.priority_bit2.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit2.get_name_leafdata())
                                                                            if (self.priority_bit3.is_set or self.priority_bit3.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit3.get_name_leafdata())
                                                                            if (self.priority_bit4.is_set or self.priority_bit4.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit4.get_name_leafdata())
                                                                            if (self.priority_bit5.is_set or self.priority_bit5.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit5.get_name_leafdata())
                                                                            if (self.priority_bit6.is_set or self.priority_bit6.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit6.get_name_leafdata())
                                                                            if (self.priority_bit7.is_set or self.priority_bit7.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.priority_bit7.get_name_leafdata())
                                                                            if (self.res.is_set or self.res.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.res.get_name_leafdata())
                                                                            if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.sbit.get_name_leafdata())
                                                                            if (self.signal_type.is_set or self.signal_type.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.signal_type.get_name_leafdata())
                                                                            if (self.stage.is_set or self.stage.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.stage.get_name_leafdata())
                                                                            if (self.tbit.is_set or self.tbit.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tbit.get_name_leafdata())
                                                                            if (self.tsg.is_set or self.tsg.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.tsg.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "num-stages" or name == "priority-bit0" or name == "priority-bit1" or name == "priority-bit2" or name == "priority-bit3" or name == "priority-bit4" or name == "priority-bit5" or name == "priority-bit6" or name == "priority-bit7" or name == "res" or name == "sbit" or name == "signal-type" or name == "stage" or name == "tbit" or name == "tsg"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "num-stages"):
                                                                                self.num_stages = value
                                                                                self.num_stages.value_namespace = name_space
                                                                                self.num_stages.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit0"):
                                                                                self.priority_bit0 = value
                                                                                self.priority_bit0.value_namespace = name_space
                                                                                self.priority_bit0.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit1"):
                                                                                self.priority_bit1 = value
                                                                                self.priority_bit1.value_namespace = name_space
                                                                                self.priority_bit1.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit2"):
                                                                                self.priority_bit2 = value
                                                                                self.priority_bit2.value_namespace = name_space
                                                                                self.priority_bit2.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit3"):
                                                                                self.priority_bit3 = value
                                                                                self.priority_bit3.value_namespace = name_space
                                                                                self.priority_bit3.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit4"):
                                                                                self.priority_bit4 = value
                                                                                self.priority_bit4.value_namespace = name_space
                                                                                self.priority_bit4.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit5"):
                                                                                self.priority_bit5 = value
                                                                                self.priority_bit5.value_namespace = name_space
                                                                                self.priority_bit5.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit6"):
                                                                                self.priority_bit6 = value
                                                                                self.priority_bit6.value_namespace = name_space
                                                                                self.priority_bit6.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "priority-bit7"):
                                                                                self.priority_bit7 = value
                                                                                self.priority_bit7.value_namespace = name_space
                                                                                self.priority_bit7.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "res"):
                                                                                self.res = value
                                                                                self.res.value_namespace = name_space
                                                                                self.res.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "sbit"):
                                                                                self.sbit = value
                                                                                self.sbit.value_namespace = name_space
                                                                                self.sbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "signal-type"):
                                                                                self.signal_type = value
                                                                                self.signal_type.value_namespace = name_space
                                                                                self.signal_type.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "stage"):
                                                                                self.stage = value
                                                                                self.stage.value_namespace = name_space
                                                                                self.stage.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tbit"):
                                                                                self.tbit = value
                                                                                self.tbit.value_namespace = name_space
                                                                                self.tbit.value_namespace_prefix = name_space_prefix
                                                                            if(value_path == "tsg"):
                                                                                self.tsg = value
                                                                                self.tsg.value_namespace = name_space
                                                                                self.tsg.value_namespace_prefix = name_space_prefix


                                                                    class UnresLspbw(Entity):
                                                                        """
                                                                        Array of Unres LSP BW
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                            self.yang_name = "unres-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                            self.entry = YLeaf(YType.uint64, "entry")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("entry") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return self.entry.is_set

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.entry.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "unres-lspbw" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "entry"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "entry"):
                                                                                self.entry = value
                                                                                self.entry.value_namespace = name_space
                                                                                self.entry.value_namespace_prefix = name_space_prefix


                                                                    class MaxLspbw(Entity):
                                                                        """
                                                                        Max LSP BW Array
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-01-02'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                            self.yang_name = "max-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"

                                                                            self.entry = YLeaf(YType.uint64, "entry")

                                                                        def __setattr__(self, name, value):
                                                                            self._check_monkey_patching_error(name, value)
                                                                            with _handle_type_error():
                                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                                        "Please use list append or extend method."
                                                                                                        .format(value))
                                                                                if isinstance(value, Enum.YLeaf):
                                                                                    value = value.name
                                                                                if name in ("entry") and name in self.__dict__:
                                                                                    if isinstance(value, YLeaf):
                                                                                        self.__dict__[name].set(value.get())
                                                                                    elif isinstance(value, YLeafList):
                                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                                    else:
                                                                                        self.__dict__[name].set(value)
                                                                                else:
                                                                                    if hasattr(value, "parent") and name != "parent":
                                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                            value.parent = self
                                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                            value.parent = self
                                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__setattr__(name, value)

                                                                        def has_data(self):
                                                                            return self.entry.is_set

                                                                        def has_operation(self):
                                                                            return (
                                                                                self.yfilter != YFilter.not_set or
                                                                                self.entry.yfilter != YFilter.not_set)

                                                                        def get_segment_path(self):
                                                                            path_buffer = ""
                                                                            path_buffer = "max-lspbw" + path_buffer

                                                                            return path_buffer

                                                                        def get_entity_path(self, ancestor):
                                                                            path_buffer = ""
                                                                            if (ancestor is None):
                                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                            else:
                                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                            leaf_name_data = LeafDataList()
                                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                            return entity_path

                                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                            if child is not None:
                                                                                return child

                                                                            return None

                                                                        def has_leaf_or_child_of_name(self, name):
                                                                            if(name == "entry"):
                                                                                return True
                                                                            return False

                                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                            if(value_path == "entry"):
                                                                                self.entry = value
                                                                                self.entry.value_namespace = name_space
                                                                                self.entry.value_namespace_prefix = name_space_prefix

                                                                    def has_data(self):
                                                                        for c in self.max_lspbw:
                                                                            if (c.has_data()):
                                                                                return True
                                                                        for c in self.unres_lspbw:
                                                                            if (c.has_data()):
                                                                                return True
                                                                        return (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_data())

                                                                    def has_operation(self):
                                                                        for c in self.max_lspbw:
                                                                            if (c.has_operation()):
                                                                                return True
                                                                        for c in self.unres_lspbw:
                                                                            if (c.has_operation()):
                                                                                return True
                                                                        return (
                                                                            self.yfilter != YFilter.not_set or
                                                                            (self.flex_sub_tlv_value_common is not None and self.flex_sub_tlv_value_common.has_operation()))

                                                                    def get_segment_path(self):
                                                                        path_buffer = ""
                                                                        path_buffer = "flex-bw-sub-tlv-value" + path_buffer

                                                                        return path_buffer

                                                                    def get_entity_path(self, ancestor):
                                                                        path_buffer = ""
                                                                        if (ancestor is None):
                                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                        else:
                                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                        leaf_name_data = LeafDataList()

                                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                        return entity_path

                                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                        if child is not None:
                                                                            return child

                                                                        if (child_yang_name == "flex-sub-tlv-value-common"):
                                                                            if (self.flex_sub_tlv_value_common is None):
                                                                                self.flex_sub_tlv_value_common = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                                self.flex_sub_tlv_value_common.parent = self
                                                                                self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                            return self.flex_sub_tlv_value_common

                                                                        if (child_yang_name == "max-lspbw"):
                                                                            for c in self.max_lspbw:
                                                                                segment = c.get_segment_path()
                                                                                if (segment_path == segment):
                                                                                    return c
                                                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw()
                                                                            c.parent = self
                                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                                            self._local_refs[local_reference_key] = c
                                                                            self.max_lspbw.append(c)
                                                                            return c

                                                                        if (child_yang_name == "unres-lspbw"):
                                                                            for c in self.unres_lspbw:
                                                                                segment = c.get_segment_path()
                                                                                if (segment_path == segment):
                                                                                    return c
                                                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw()
                                                                            c.parent = self
                                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                                            self._local_refs[local_reference_key] = c
                                                                            self.unres_lspbw.append(c)
                                                                            return c

                                                                        return None

                                                                    def has_leaf_or_child_of_name(self, name):
                                                                        if(name == "flex-sub-tlv-value-common" or name == "max-lspbw" or name == "unres-lspbw"):
                                                                            return True
                                                                        return False

                                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                        pass

                                                                def has_data(self):
                                                                    return (
                                                                        self.ixcdbw_sub_tlv_type.is_set or
                                                                        (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_data()) or
                                                                        (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_data()))

                                                                def has_operation(self):
                                                                    return (
                                                                        self.yfilter != YFilter.not_set or
                                                                        self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                        (self.fixed_bw_sub_tlv_value is not None and self.fixed_bw_sub_tlv_value.has_operation()) or
                                                                        (self.flex_bw_sub_tlv_value is not None and self.flex_bw_sub_tlv_value.has_operation()))

                                                                def get_segment_path(self):
                                                                    path_buffer = ""
                                                                    path_buffer = "bw-sub-tlv-value" + path_buffer

                                                                    return path_buffer

                                                                def get_entity_path(self, ancestor):
                                                                    path_buffer = ""
                                                                    if (ancestor is None):
                                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                    else:
                                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                    leaf_name_data = LeafDataList()
                                                                    if (self.ixcdbw_sub_tlv_type.is_set or self.ixcdbw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                        leaf_name_data.append(self.ixcdbw_sub_tlv_type.get_name_leafdata())

                                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                    return entity_path

                                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                    if child is not None:
                                                                        return child

                                                                    if (child_yang_name == "fixed-bw-sub-tlv-value"):
                                                                        if (self.fixed_bw_sub_tlv_value is None):
                                                                            self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                            self.fixed_bw_sub_tlv_value.parent = self
                                                                            self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                        return self.fixed_bw_sub_tlv_value

                                                                    if (child_yang_name == "flex-bw-sub-tlv-value"):
                                                                        if (self.flex_bw_sub_tlv_value is None):
                                                                            self.flex_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                            self.flex_bw_sub_tlv_value.parent = self
                                                                            self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                        return self.flex_bw_sub_tlv_value

                                                                    return None

                                                                def has_leaf_or_child_of_name(self, name):
                                                                    if(name == "fixed-bw-sub-tlv-value" or name == "flex-bw-sub-tlv-value" or name == "ixcdbw-sub-tlv-type"):
                                                                        return True
                                                                    return False

                                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                    if(value_path == "ixcdbw-sub-tlv-type"):
                                                                        self.ixcdbw_sub_tlv_type = value
                                                                        self.ixcdbw_sub_tlv_type.value_namespace = name_space
                                                                        self.ixcdbw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                            def has_data(self):
                                                                return (
                                                                    self.bw_sub_tlv_length.is_set or
                                                                    self.bw_sub_tlv_type.is_set or
                                                                    (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_data()))

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.bw_sub_tlv_length.yfilter != YFilter.not_set or
                                                                    self.bw_sub_tlv_type.yfilter != YFilter.not_set or
                                                                    (self.bw_sub_tlv_value is not None and self.bw_sub_tlv_value.has_operation()))

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "arr-bw-sub-tlv" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.bw_sub_tlv_length.is_set or self.bw_sub_tlv_length.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.bw_sub_tlv_length.get_name_leafdata())
                                                                if (self.bw_sub_tlv_type.is_set or self.bw_sub_tlv_type.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.bw_sub_tlv_type.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                if (child_yang_name == "bw-sub-tlv-value"):
                                                                    if (self.bw_sub_tlv_value is None):
                                                                        self.bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                        self.bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                    return self.bw_sub_tlv_value

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "bw-sub-tlv-value" or name == "bw-sub-tlv-length" or name == "bw-sub-tlv-type"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "bw-sub-tlv-length"):
                                                                    self.bw_sub_tlv_length = value
                                                                    self.bw_sub_tlv_length.value_namespace = name_space
                                                                    self.bw_sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "bw-sub-tlv-type"):
                                                                    self.bw_sub_tlv_type = value
                                                                    self.bw_sub_tlv_type.value_namespace = name_space
                                                                    self.bw_sub_tlv_type.value_namespace_prefix = name_space_prefix

                                                        def has_data(self):
                                                            for c in self.arr_bw_sub_tlv:
                                                                if (c.has_data()):
                                                                    return True
                                                            return False

                                                        def has_operation(self):
                                                            for c in self.arr_bw_sub_tlv:
                                                                if (c.has_operation()):
                                                                    return True
                                                            return self.yfilter != YFilter.not_set

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ixcdbw-sub-tlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "arr-bw-sub-tlv"):
                                                                for c in self.arr_bw_sub_tlv:
                                                                    segment = c.get_segment_path()
                                                                    if (segment_path == segment):
                                                                        return c
                                                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv()
                                                                c.parent = self
                                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                                self._local_refs[local_reference_key] = c
                                                                self.arr_bw_sub_tlv.append(c)
                                                                return c

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "arr-bw-sub-tlv"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            pass

                                                    def has_data(self):
                                                        return (
                                                            self.switching_cap_type.is_set or
                                                            (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_data()) or
                                                            (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_data()))

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.switching_cap_type.yfilter != YFilter.not_set or
                                                            (self.ixcdbw_sub_tlv is not None and self.ixcdbw_sub_tlv.has_operation()) or
                                                            (self.ixcdpsc_info is not None and self.ixcdpsc_info.has_operation()))

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ixcd-switching-cap-type" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.switching_cap_type.is_set or self.switching_cap_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.switching_cap_type.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ixcdbw-sub-tlv"):
                                                            if (self.ixcdbw_sub_tlv is None):
                                                                self.ixcdbw_sub_tlv = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                                self.ixcdbw_sub_tlv.parent = self
                                                                self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                            return self.ixcdbw_sub_tlv

                                                        if (child_yang_name == "ixcdpsc-info"):
                                                            if (self.ixcdpsc_info is None):
                                                                self.ixcdpsc_info = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                                self.ixcdpsc_info.parent = self
                                                                self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                            return self.ixcdpsc_info

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ixcdbw-sub-tlv" or name == "ixcdpsc-info" or name == "switching-cap-type"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "switching-cap-type"):
                                                            self.switching_cap_type = value
                                                            self.switching_cap_type.value_namespace = name_space
                                                            self.switching_cap_type.value_namespace_prefix = name_space_prefix


                                                class MaxLspbw(Entity):
                                                    """
                                                    Max LSP bandwidth array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-9223372036854775808..9223372036854775807
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                        self.yang_name = "max-lspbw"
                                                        self.yang_parent_name = "ixcdtlv-value"

                                                        self.entry = YLeaf(YType.int64, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "max-lspbw" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.max_lspbw:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.fixed_scsi_count.is_set or
                                                        self.flex_scsi_count.is_set or
                                                        self.rile_len_code.is_set or
                                                        self.switching_cap.is_set or
                                                        (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_data()))

                                                def has_operation(self):
                                                    for c in self.max_lspbw:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.fixed_scsi_count.yfilter != YFilter.not_set or
                                                        self.flex_scsi_count.yfilter != YFilter.not_set or
                                                        self.rile_len_code.yfilter != YFilter.not_set or
                                                        self.switching_cap.yfilter != YFilter.not_set or
                                                        (self.ixcd_switching_cap_type is not None and self.ixcd_switching_cap_type.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ixcdtlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.fixed_scsi_count.is_set or self.fixed_scsi_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fixed_scsi_count.get_name_leafdata())
                                                    if (self.flex_scsi_count.is_set or self.flex_scsi_count.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.flex_scsi_count.get_name_leafdata())
                                                    if (self.rile_len_code.is_set or self.rile_len_code.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rile_len_code.get_name_leafdata())
                                                    if (self.switching_cap.is_set or self.switching_cap.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.switching_cap.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ixcd-switching-cap-type"):
                                                        if (self.ixcd_switching_cap_type is None):
                                                            self.ixcd_switching_cap_type = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                            self.ixcd_switching_cap_type.parent = self
                                                            self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                        return self.ixcd_switching_cap_type

                                                    if (child_yang_name == "max-lspbw"):
                                                        for c in self.max_lspbw:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.max_lspbw.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ixcd-switching-cap-type" or name == "max-lspbw" or name == "fixed-scsi-count" or name == "flex-scsi-count" or name == "rile-len-code" or name == "switching-cap"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "fixed-scsi-count"):
                                                        self.fixed_scsi_count = value
                                                        self.fixed_scsi_count.value_namespace = name_space
                                                        self.fixed_scsi_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "flex-scsi-count"):
                                                        self.flex_scsi_count = value
                                                        self.flex_scsi_count.value_namespace = name_space
                                                        self.flex_scsi_count.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rile-len-code"):
                                                        self.rile_len_code = value
                                                        self.rile_len_code.value_namespace = name_space
                                                        self.rile_len_code.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "switching-cap"):
                                                        self.switching_cap = value
                                                        self.switching_cap.value_namespace = name_space
                                                        self.switching_cap.value_namespace_prefix = name_space_prefix


                                            class UnidtlvValue(Entity):
                                                """
                                                Value of Uni Delay TLV
                                                
                                                .. attribute:: uni_dir_delay
                                                
                                                	Uni Dir Delay
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                    self.yang_name = "unidtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"

                                                    self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("uni_dir_delay") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.uni_dir_delay.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.uni_dir_delay.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unidtlv-value" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.uni_dir_delay.is_set or self.uni_dir_delay.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.uni_dir_delay.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "uni-dir-delay"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "uni-dir-delay"):
                                                        self.uni_dir_delay = value
                                                        self.uni_dir_delay.value_namespace = name_space
                                                        self.uni_dir_delay.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.opaque_tlv_type.is_set or
                                                    (self.bctlv_value is not None and self.bctlv_value.has_data()) or
                                                    (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_data()) or
                                                    (self.srlgtlv_value is not None and self.srlgtlv_value.has_data()) or
                                                    (self.unidtlv_value is not None and self.unidtlv_value.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.opaque_tlv_type.yfilter != YFilter.not_set or
                                                    (self.bctlv_value is not None and self.bctlv_value.has_operation()) or
                                                    (self.ixcdtlv_value is not None and self.ixcdtlv_value.has_operation()) or
                                                    (self.srlgtlv_value is not None and self.srlgtlv_value.has_operation()) or
                                                    (self.unidtlv_value is not None and self.unidtlv_value.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mplste-link-opt-tlv-value" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.opaque_tlv_type.is_set or self.opaque_tlv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.opaque_tlv_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bctlv-value"):
                                                    if (self.bctlv_value is None):
                                                        self.bctlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                        self.bctlv_value.parent = self
                                                        self._children_name_map["bctlv_value"] = "bctlv-value"
                                                    return self.bctlv_value

                                                if (child_yang_name == "ixcdtlv-value"):
                                                    if (self.ixcdtlv_value is None):
                                                        self.ixcdtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                        self.ixcdtlv_value.parent = self
                                                        self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                    return self.ixcdtlv_value

                                                if (child_yang_name == "srlgtlv-value"):
                                                    if (self.srlgtlv_value is None):
                                                        self.srlgtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                        self.srlgtlv_value.parent = self
                                                        self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                    return self.srlgtlv_value

                                                if (child_yang_name == "unidtlv-value"):
                                                    if (self.unidtlv_value is None):
                                                        self.unidtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                        self.unidtlv_value.parent = self
                                                        self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                    return self.unidtlv_value

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bctlv-value" or name == "ixcdtlv-value" or name == "srlgtlv-value" or name == "unidtlv-value" or name == "opaque-tlv-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "opaque-tlv-type"):
                                                    self.opaque_tlv_type = value
                                                    self.opaque_tlv_type.value_namespace = name_space
                                                    self.opaque_tlv_type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.mplste_link_opt_tlv_value:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.mplste_link_opt_tlv_len.is_set or
                                                self.mplste_link_opt_tlv_type.is_set)

                                        def has_operation(self):
                                            for c in self.mplste_link_opt_tlv_value:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set or
                                                self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mplste-link-opt-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.mplste_link_opt_tlv_len.is_set or self.mplste_link_opt_tlv_len.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mplste_link_opt_tlv_len.get_name_leafdata())
                                            if (self.mplste_link_opt_tlv_type.is_set or self.mplste_link_opt_tlv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mplste_link_opt_tlv_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "mplste-link-opt-tlv-value"):
                                                for c in self.mplste_link_opt_tlv_value:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.mplste_link_opt_tlv_value.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "mplste-link-opt-tlv-value" or name == "mplste-link-opt-tlv-len" or name == "mplste-link-opt-tlv-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "mplste-link-opt-tlv-len"):
                                                self.mplste_link_opt_tlv_len = value
                                                self.mplste_link_opt_tlv_len.value_namespace = name_space
                                                self.mplste_link_opt_tlv_len.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mplste-link-opt-tlv-type"):
                                                self.mplste_link_opt_tlv_type = value
                                                self.mplste_link_opt_tlv_type.value_namespace = name_space
                                                self.mplste_link_opt_tlv_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.mplste_link_opt_tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.affinity.is_set or
                                            self.dste_allocation_model_id.is_set or
                                            self.dste_in_use.is_set or
                                            self.fragment_id.is_set or
                                            self.igp_metric.is_set or
                                            self.input_interface_id.is_set or
                                            self.link_address.is_set or
                                            self.maximum_link_bw.is_set or
                                            self.maximum_link_reservable_bw.is_set or
                                            self.maximum_link_sub_reservable_bw.is_set or
                                            self.mpls_link_instance.is_set or
                                            self.mpls_link_type.is_set or
                                            self.neighbor_ip_address.is_set or
                                            self.neighbor_system_id.is_set or
                                            self.new_link.is_set or
                                            self.number_of_optional_tl_vs.is_set or
                                            self.output_interface_id.is_set or
                                            self.priority_count.is_set or
                                            self.te_metric.is_set or
                                            (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_data()) or
                                            (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_data()) or
                                            (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_data()) or
                                            (self.link_sw_capability is not None and self.link_sw_capability.has_data()) or
                                            (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_data()))

                                    def has_operation(self):
                                        for c in self.mplste_link_opt_tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.affinity.yfilter != YFilter.not_set or
                                            self.dste_allocation_model_id.yfilter != YFilter.not_set or
                                            self.dste_in_use.yfilter != YFilter.not_set or
                                            self.fragment_id.yfilter != YFilter.not_set or
                                            self.igp_metric.yfilter != YFilter.not_set or
                                            self.input_interface_id.yfilter != YFilter.not_set or
                                            self.link_address.yfilter != YFilter.not_set or
                                            self.maximum_link_bw.yfilter != YFilter.not_set or
                                            self.maximum_link_reservable_bw.yfilter != YFilter.not_set or
                                            self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set or
                                            self.mpls_link_instance.yfilter != YFilter.not_set or
                                            self.mpls_link_type.yfilter != YFilter.not_set or
                                            self.neighbor_ip_address.yfilter != YFilter.not_set or
                                            self.neighbor_system_id.yfilter != YFilter.not_set or
                                            self.new_link.yfilter != YFilter.not_set or
                                            self.number_of_optional_tl_vs.yfilter != YFilter.not_set or
                                            self.output_interface_id.yfilter != YFilter.not_set or
                                            self.priority_count.yfilter != YFilter.not_set or
                                            self.te_metric.yfilter != YFilter.not_set or
                                            (self.extended_admin_group_list is not None and self.extended_admin_group_list.has_operation()) or
                                            (self.global_unreserve_bw_per_priority is not None and self.global_unreserve_bw_per_priority.has_operation()) or
                                            (self.link_protocol_priority_capability is not None and self.link_protocol_priority_capability.has_operation()) or
                                            (self.link_sw_capability is not None and self.link_sw_capability.has_operation()) or
                                            (self.sub_pool_unreserve_bw_per_priority is not None and self.sub_pool_unreserve_bw_per_priority.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls-te-link" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.affinity.is_set or self.affinity.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.affinity.get_name_leafdata())
                                        if (self.dste_allocation_model_id.is_set or self.dste_allocation_model_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dste_allocation_model_id.get_name_leafdata())
                                        if (self.dste_in_use.is_set or self.dste_in_use.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dste_in_use.get_name_leafdata())
                                        if (self.fragment_id.is_set or self.fragment_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fragment_id.get_name_leafdata())
                                        if (self.igp_metric.is_set or self.igp_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igp_metric.get_name_leafdata())
                                        if (self.input_interface_id.is_set or self.input_interface_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.input_interface_id.get_name_leafdata())
                                        if (self.link_address.is_set or self.link_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_address.get_name_leafdata())
                                        if (self.maximum_link_bw.is_set or self.maximum_link_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_link_bw.get_name_leafdata())
                                        if (self.maximum_link_reservable_bw.is_set or self.maximum_link_reservable_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_link_reservable_bw.get_name_leafdata())
                                        if (self.maximum_link_sub_reservable_bw.is_set or self.maximum_link_sub_reservable_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_link_sub_reservable_bw.get_name_leafdata())
                                        if (self.mpls_link_instance.is_set or self.mpls_link_instance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_link_instance.get_name_leafdata())
                                        if (self.mpls_link_type.is_set or self.mpls_link_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mpls_link_type.get_name_leafdata())
                                        if (self.neighbor_ip_address.is_set or self.neighbor_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_ip_address.get_name_leafdata())
                                        if (self.neighbor_system_id.is_set or self.neighbor_system_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_system_id.get_name_leafdata())
                                        if (self.new_link.is_set or self.new_link.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.new_link.get_name_leafdata())
                                        if (self.number_of_optional_tl_vs.is_set or self.number_of_optional_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number_of_optional_tl_vs.get_name_leafdata())
                                        if (self.output_interface_id.is_set or self.output_interface_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.output_interface_id.get_name_leafdata())
                                        if (self.priority_count.is_set or self.priority_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.priority_count.get_name_leafdata())
                                        if (self.te_metric.is_set or self.te_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_metric.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "extended-admin-group-list"):
                                            if (self.extended_admin_group_list is None):
                                                self.extended_admin_group_list = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                                self.extended_admin_group_list.parent = self
                                                self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                            return self.extended_admin_group_list

                                        if (child_yang_name == "global-unreserve-bw-per-priority"):
                                            if (self.global_unreserve_bw_per_priority is None):
                                                self.global_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                                self.global_unreserve_bw_per_priority.parent = self
                                                self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                            return self.global_unreserve_bw_per_priority

                                        if (child_yang_name == "link-protocol-priority-capability"):
                                            if (self.link_protocol_priority_capability is None):
                                                self.link_protocol_priority_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                                self.link_protocol_priority_capability.parent = self
                                                self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                            return self.link_protocol_priority_capability

                                        if (child_yang_name == "link-sw-capability"):
                                            if (self.link_sw_capability is None):
                                                self.link_sw_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                                self.link_sw_capability.parent = self
                                                self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                            return self.link_sw_capability

                                        if (child_yang_name == "mplste-link-opt-tlv"):
                                            for c in self.mplste_link_opt_tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.mplste_link_opt_tlv.append(c)
                                            return c

                                        if (child_yang_name == "sub-pool-unreserve-bw-per-priority"):
                                            if (self.sub_pool_unreserve_bw_per_priority is None):
                                                self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                                self.sub_pool_unreserve_bw_per_priority.parent = self
                                                self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                            return self.sub_pool_unreserve_bw_per_priority

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "extended-admin-group-list" or name == "global-unreserve-bw-per-priority" or name == "link-protocol-priority-capability" or name == "link-sw-capability" or name == "mplste-link-opt-tlv" or name == "sub-pool-unreserve-bw-per-priority" or name == "affinity" or name == "dste-allocation-model-id" or name == "dste-in-use" or name == "fragment-id" or name == "igp-metric" or name == "input-interface-id" or name == "link-address" or name == "maximum-link-bw" or name == "maximum-link-reservable-bw" or name == "maximum-link-sub-reservable-bw" or name == "mpls-link-instance" or name == "mpls-link-type" or name == "neighbor-ip-address" or name == "neighbor-system-id" or name == "new-link" or name == "number-of-optional-tl-vs" or name == "output-interface-id" or name == "priority-count" or name == "te-metric"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "affinity"):
                                            self.affinity = value
                                            self.affinity.value_namespace = name_space
                                            self.affinity.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dste-allocation-model-id"):
                                            self.dste_allocation_model_id = value
                                            self.dste_allocation_model_id.value_namespace = name_space
                                            self.dste_allocation_model_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dste-in-use"):
                                            self.dste_in_use = value
                                            self.dste_in_use.value_namespace = name_space
                                            self.dste_in_use.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fragment-id"):
                                            self.fragment_id = value
                                            self.fragment_id.value_namespace = name_space
                                            self.fragment_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igp-metric"):
                                            self.igp_metric = value
                                            self.igp_metric.value_namespace = name_space
                                            self.igp_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "input-interface-id"):
                                            self.input_interface_id = value
                                            self.input_interface_id.value_namespace = name_space
                                            self.input_interface_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-address"):
                                            self.link_address = value
                                            self.link_address.value_namespace = name_space
                                            self.link_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-link-bw"):
                                            self.maximum_link_bw = value
                                            self.maximum_link_bw.value_namespace = name_space
                                            self.maximum_link_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-link-reservable-bw"):
                                            self.maximum_link_reservable_bw = value
                                            self.maximum_link_reservable_bw.value_namespace = name_space
                                            self.maximum_link_reservable_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-link-sub-reservable-bw"):
                                            self.maximum_link_sub_reservable_bw = value
                                            self.maximum_link_sub_reservable_bw.value_namespace = name_space
                                            self.maximum_link_sub_reservable_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-link-instance"):
                                            self.mpls_link_instance = value
                                            self.mpls_link_instance.value_namespace = name_space
                                            self.mpls_link_instance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mpls-link-type"):
                                            self.mpls_link_type = value
                                            self.mpls_link_type.value_namespace = name_space
                                            self.mpls_link_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-ip-address"):
                                            self.neighbor_ip_address = value
                                            self.neighbor_ip_address.value_namespace = name_space
                                            self.neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-system-id"):
                                            self.neighbor_system_id = value
                                            self.neighbor_system_id.value_namespace = name_space
                                            self.neighbor_system_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "new-link"):
                                            self.new_link = value
                                            self.new_link.value_namespace = name_space
                                            self.new_link.value_namespace_prefix = name_space_prefix
                                        if(value_path == "number-of-optional-tl-vs"):
                                            self.number_of_optional_tl_vs = value
                                            self.number_of_optional_tl_vs.value_namespace = name_space
                                            self.number_of_optional_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "output-interface-id"):
                                            self.output_interface_id = value
                                            self.output_interface_id.value_namespace = name_space
                                            self.output_interface_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "priority-count"):
                                            self.priority_count = value
                                            self.priority_count.value_namespace = name_space
                                            self.priority_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-metric"):
                                            self.te_metric = value
                                            self.te_metric.value_namespace = name_space
                                            self.te_metric.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.mpls_te_link:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.dste_model_id.is_set or
                                        self.fragment_id.is_set or
                                        self.fragment_instance.is_set or
                                        self.same_fragment_count.is_set)

                                def has_operation(self):
                                    for c in self.mpls_te_link:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dste_model_id.yfilter != YFilter.not_set or
                                        self.fragment_id.yfilter != YFilter.not_set or
                                        self.fragment_instance.yfilter != YFilter.not_set or
                                        self.same_fragment_count.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mpls-te-fragment" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dste_model_id.is_set or self.dste_model_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dste_model_id.get_name_leafdata())
                                    if (self.fragment_id.is_set or self.fragment_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fragment_id.get_name_leafdata())
                                    if (self.fragment_instance.is_set or self.fragment_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fragment_instance.get_name_leafdata())
                                    if (self.same_fragment_count.is_set or self.same_fragment_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.same_fragment_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "mpls-te-link"):
                                        for c in self.mpls_te_link:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.mpls_te_link.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mpls-te-link" or name == "dste-model-id" or name == "fragment-id" or name == "fragment-instance" or name == "same-fragment-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dste-model-id"):
                                        self.dste_model_id = value
                                        self.dste_model_id.value_namespace = name_space
                                        self.dste_model_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fragment-id"):
                                        self.fragment_id = value
                                        self.fragment_id.value_namespace = name_space
                                        self.fragment_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fragment-instance"):
                                        self.fragment_instance = value
                                        self.fragment_instance.value_namespace = name_space
                                        self.fragment_instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "same-fragment-count"):
                                        self.same_fragment_count = value
                                        self.same_fragment_count.value_namespace = name_space
                                        self.same_fragment_count.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.mpls_te_fragment:
                                    if (c.has_data()):
                                        return True
                                for c in self.mpls_te_link:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.area_id.is_set or
                                    self.mpls_te_area_id.is_set or
                                    self.mpls_te_area_instance.is_set or
                                    self.mpls_te_enabled.is_set or
                                    self.mpls_te_initialized.is_set or
                                    self.mpls_te_next_fragment_id.is_set or
                                    self.mpls_te_router_address.is_set or
                                    self.mpls_te_router_id.is_set or
                                    self.spacious_fragment.is_set)

                            def has_operation(self):
                                for c in self.mpls_te_fragment:
                                    if (c.has_operation()):
                                        return True
                                for c in self.mpls_te_link:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.area_id.yfilter != YFilter.not_set or
                                    self.mpls_te_area_id.yfilter != YFilter.not_set or
                                    self.mpls_te_area_instance.yfilter != YFilter.not_set or
                                    self.mpls_te_enabled.yfilter != YFilter.not_set or
                                    self.mpls_te_initialized.yfilter != YFilter.not_set or
                                    self.mpls_te_next_fragment_id.yfilter != YFilter.not_set or
                                    self.mpls_te_router_address.yfilter != YFilter.not_set or
                                    self.mpls_te_router_id.yfilter != YFilter.not_set or
                                    self.spacious_fragment.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mpls-te-fragment" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                if (self.mpls_te_area_id.is_set or self.mpls_te_area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_area_id.get_name_leafdata())
                                if (self.mpls_te_area_instance.is_set or self.mpls_te_area_instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_area_instance.get_name_leafdata())
                                if (self.mpls_te_enabled.is_set or self.mpls_te_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_enabled.get_name_leafdata())
                                if (self.mpls_te_initialized.is_set or self.mpls_te_initialized.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_initialized.get_name_leafdata())
                                if (self.mpls_te_next_fragment_id.is_set or self.mpls_te_next_fragment_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_next_fragment_id.get_name_leafdata())
                                if (self.mpls_te_router_address.is_set or self.mpls_te_router_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_router_address.get_name_leafdata())
                                if (self.mpls_te_router_id.is_set or self.mpls_te_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_te_router_id.get_name_leafdata())
                                if (self.spacious_fragment.is_set or self.spacious_fragment.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spacious_fragment.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mpls-te-fragment"):
                                    for c in self.mpls_te_fragment:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.mpls_te_fragment.append(c)
                                    return c

                                if (child_yang_name == "mpls-te-link"):
                                    for c in self.mpls_te_link:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.mpls_te_link.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mpls-te-fragment" or name == "mpls-te-link" or name == "area-id" or name == "mpls-te-area-id" or name == "mpls-te-area-instance" or name == "mpls-te-enabled" or name == "mpls-te-initialized" or name == "mpls-te-next-fragment-id" or name == "mpls-te-router-address" or name == "mpls-te-router-id" or name == "spacious-fragment"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "area-id"):
                                    self.area_id = value
                                    self.area_id.value_namespace = name_space
                                    self.area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-area-id"):
                                    self.mpls_te_area_id = value
                                    self.mpls_te_area_id.value_namespace = name_space
                                    self.mpls_te_area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-area-instance"):
                                    self.mpls_te_area_instance = value
                                    self.mpls_te_area_instance.value_namespace = name_space
                                    self.mpls_te_area_instance.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-enabled"):
                                    self.mpls_te_enabled = value
                                    self.mpls_te_enabled.value_namespace = name_space
                                    self.mpls_te_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-initialized"):
                                    self.mpls_te_initialized = value
                                    self.mpls_te_initialized.value_namespace = name_space
                                    self.mpls_te_initialized.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-next-fragment-id"):
                                    self.mpls_te_next_fragment_id = value
                                    self.mpls_te_next_fragment_id.value_namespace = name_space
                                    self.mpls_te_next_fragment_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-router-address"):
                                    self.mpls_te_router_address = value
                                    self.mpls_te_router_address.value_namespace = name_space
                                    self.mpls_te_router_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-te-router-id"):
                                    self.mpls_te_router_id = value
                                    self.mpls_te_router_id.value_namespace = name_space
                                    self.mpls_te_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "spacious-fragment"):
                                    self.spacious_fragment = value
                                    self.spacious_fragment.value_namespace = name_space
                                    self.spacious_fragment.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.mpls_te_fragment:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.mpls_te_fragment:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mpls-te-fragments" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mpls-te-fragment"):
                                for c in self.mpls_te_fragment:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.mpls_te_fragment.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mpls-te-fragment"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.mpls_te_fragments is not None and self.mpls_te_fragments.has_data()) or
                            (self.mpls_te_links is not None and self.mpls_te_links.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.mpls_te_fragments is not None and self.mpls_te_fragments.has_operation()) or
                            (self.mpls_te_links is not None and self.mpls_te_links.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mpls-te" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "mpls-te-fragments"):
                            if (self.mpls_te_fragments is None):
                                self.mpls_te_fragments = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments()
                                self.mpls_te_fragments.parent = self
                                self._children_name_map["mpls_te_fragments"] = "mpls-te-fragments"
                            return self.mpls_te_fragments

                        if (child_yang_name == "mpls-te-links"):
                            if (self.mpls_te_links is None):
                                self.mpls_te_links = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks()
                                self.mpls_te_links.parent = self
                                self._children_name_map["mpls_te_links"] = "mpls-te-links"
                            return self.mpls_te_links

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "mpls-te-fragments" or name == "mpls-te-links"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Statistics(Entity):
                    """
                    Container for Statistics
                    
                    .. attribute:: frr_stats
                    
                    	OSPF fast\-reroute statistics
                    	**type**\:   :py:class:`FrrStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.FrrStats>`
                    
                    .. attribute:: interface_stats_entries
                    
                    	Statistics innformation Interface table
                    	**type**\:   :py:class:`InterfaceStatsEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries>`
                    
                    .. attribute:: issu_stats
                    
                    	OSPF ISSU statistics
                    	**type**\:   :py:class:`IssuStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats>`
                    
                    .. attribute:: nsr_pl_stats
                    
                    	OSPF NSR packet library statistics
                    	**type**\:   :py:class:`NsrPlStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats>`
                    
                    .. attribute:: nsr_stats
                    
                    	OSPF NSR thread statistics
                    	**type**\:   :py:class:`NsrStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats>`
                    
                    .. attribute:: protocol_stats
                    
                    	OSPF Protocol statistics
                    	**type**\:   :py:class:`ProtocolStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.ProtocolStats>`
                    
                    .. attribute:: raw_io_stats
                    
                    	OSPF RAW IO statistics
                    	**type**\:   :py:class:`RawIoStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RawIoStats>`
                    
                    .. attribute:: rib_batch_stats
                    
                    	Stats concerning RIB route updates using the Batching API
                    	**type**\:   :py:class:`RibBatchStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats>`
                    
                    .. attribute:: rib_thread_stats
                    
                    	OSPF RIB thread statistics
                    	**type**\:   :py:class:`RibThreadStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats>`
                    
                    .. attribute:: spf_stats
                    
                    	OSPF SPF statistics
                    	**type**\:   :py:class:`SpfStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats>`
                    
                    .. attribute:: te_stats
                    
                    	OSPF TE IO statistics
                    	**type**\:   :py:class:`TeStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.TeStats>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Statistics, self).__init__()

                        self.yang_name = "statistics"
                        self.yang_parent_name = "default-vrf"

                        self.frr_stats = Ospf.Processes.Process.DefaultVrf.Statistics.FrrStats()
                        self.frr_stats.parent = self
                        self._children_name_map["frr_stats"] = "frr-stats"
                        self._children_yang_names.add("frr-stats")

                        self.interface_stats_entries = Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries()
                        self.interface_stats_entries.parent = self
                        self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                        self._children_yang_names.add("interface-stats-entries")

                        self.issu_stats = Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats()
                        self.issu_stats.parent = self
                        self._children_name_map["issu_stats"] = "issu-stats"
                        self._children_yang_names.add("issu-stats")

                        self.nsr_pl_stats = Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats()
                        self.nsr_pl_stats.parent = self
                        self._children_name_map["nsr_pl_stats"] = "nsr-pl-stats"
                        self._children_yang_names.add("nsr-pl-stats")

                        self.nsr_stats = Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats()
                        self.nsr_stats.parent = self
                        self._children_name_map["nsr_stats"] = "nsr-stats"
                        self._children_yang_names.add("nsr-stats")

                        self.protocol_stats = Ospf.Processes.Process.DefaultVrf.Statistics.ProtocolStats()
                        self.protocol_stats.parent = self
                        self._children_name_map["protocol_stats"] = "protocol-stats"
                        self._children_yang_names.add("protocol-stats")

                        self.raw_io_stats = Ospf.Processes.Process.DefaultVrf.Statistics.RawIoStats()
                        self.raw_io_stats.parent = self
                        self._children_name_map["raw_io_stats"] = "raw-io-stats"
                        self._children_yang_names.add("raw-io-stats")

                        self.rib_batch_stats = Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats()
                        self.rib_batch_stats.parent = self
                        self._children_name_map["rib_batch_stats"] = "rib-batch-stats"
                        self._children_yang_names.add("rib-batch-stats")

                        self.rib_thread_stats = Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats()
                        self.rib_thread_stats.parent = self
                        self._children_name_map["rib_thread_stats"] = "rib-thread-stats"
                        self._children_yang_names.add("rib-thread-stats")

                        self.spf_stats = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats()
                        self.spf_stats.parent = self
                        self._children_name_map["spf_stats"] = "spf-stats"
                        self._children_yang_names.add("spf-stats")

                        self.te_stats = Ospf.Processes.Process.DefaultVrf.Statistics.TeStats()
                        self.te_stats.parent = self
                        self._children_name_map["te_stats"] = "te-stats"
                        self._children_yang_names.add("te-stats")


                    class SpfStats(Entity):
                        """
                        OSPF SPF statistics
                        
                        .. attribute:: os_ex_runtime
                        
                        	os ex runtime
                        	**type**\: list of    :py:class:`OsExRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime>`
                        
                        .. attribute:: os_runtime
                        
                        	os runtime
                        	**type**\: list of    :py:class:`OsRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime>`
                        
                        .. attribute:: os_sum_runtime
                        
                        	os sum runtime
                        	**type**\: list of    :py:class:`OsSumRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime>`
                        
                        .. attribute:: runtime
                        
                        	runtime
                        	**type**\: list of    :py:class:`Runtime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime>`
                        
                        .. attribute:: spf_header
                        
                        	spf header
                        	**type**\:   :py:class:`SpfHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats, self).__init__()

                            self.yang_name = "spf-stats"
                            self.yang_parent_name = "statistics"

                            self.spf_header = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader()
                            self.spf_header.parent = self
                            self._children_name_map["spf_header"] = "spf-header"
                            self._children_yang_names.add("spf-header")

                            self.os_ex_runtime = YList(self)
                            self.os_runtime = YList(self)
                            self.os_sum_runtime = YList(self)
                            self.runtime = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats, self).__setattr__(name, value)


                        class SpfHeader(Entity):
                            """
                            spf header
                            
                            .. attribute:: area_summ
                            
                            	area summ
                            	**type**\: list of    :py:class:`AreaSumm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader.AreaSumm>`
                            
                            .. attribute:: router_id
                            
                            	router id
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: spf_count
                            
                            	spf count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader, self).__init__()

                                self.yang_name = "spf-header"
                                self.yang_parent_name = "spf-stats"

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.spf_count = YLeaf(YType.uint32, "spf-count")

                                self.area_summ = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("router_id",
                                                "spf_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader, self).__setattr__(name, value)


                            class AreaSumm(Entity):
                                """
                                area summ
                                
                                .. attribute:: area_id
                                
                                	area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_count
                                
                                	spf count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader.AreaSumm, self).__init__()

                                    self.yang_name = "area-summ"
                                    self.yang_parent_name = "spf-header"

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.spf_count = YLeaf(YType.uint32, "spf-count")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_id",
                                                    "spf_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader.AreaSumm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader.AreaSumm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.area_id.is_set or
                                        self.spf_count.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.spf_count.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "area-summ" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.spf_count.is_set or self.spf_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spf_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "area-id" or name == "spf-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spf-count"):
                                        self.spf_count = value
                                        self.spf_count.value_namespace = name_space
                                        self.spf_count.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.area_summ:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.router_id.is_set or
                                    self.spf_count.is_set)

                            def has_operation(self):
                                for c in self.area_summ:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.router_id.yfilter != YFilter.not_set or
                                    self.spf_count.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "spf-header" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_id.get_name_leafdata())
                                if (self.spf_count.is_set or self.spf_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spf_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "area-summ"):
                                    for c in self.area_summ:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader.AreaSumm()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.area_summ.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "area-summ" or name == "router-id" or name == "spf-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "router-id"):
                                    self.router_id = value
                                    self.router_id.value_namespace = name_space
                                    self.router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "spf-count"):
                                    self.spf_count = value
                                    self.spf_count.value_namespace = name_space
                                    self.spf_count.value_namespace_prefix = name_space_prefix


                        class OsRuntime(Entity):
                            """
                            os runtime
                            
                            .. attribute:: si_area_id_str
                            
                            	si area id str
                            	**type**\:  str
                            
                            .. attribute:: si_change_flags
                            
                            	si change flags
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: si_duration
                            
                            	si duration
                            	**type**\:   :py:class:`SiDuration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiDuration>`
                            
                            .. attribute:: si_start_time
                            
                            	si start time
                            	**type**\:   :py:class:`SiStartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiStartTime>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime, self).__init__()

                                self.yang_name = "os-runtime"
                                self.yang_parent_name = "spf-stats"

                                self.si_area_id_str = YLeaf(YType.str, "si-area-id-str")

                                self.si_change_flags = YLeaf(YType.uint16, "si-change-flags")

                                self.si_duration = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiDuration()
                                self.si_duration.parent = self
                                self._children_name_map["si_duration"] = "si-duration"
                                self._children_yang_names.add("si-duration")

                                self.si_start_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiStartTime()
                                self.si_start_time.parent = self
                                self._children_name_map["si_start_time"] = "si-start-time"
                                self._children_yang_names.add("si-start-time")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("si_area_id_str",
                                                "si_change_flags") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime, self).__setattr__(name, value)


                            class SiStartTime(Entity):
                                """
                                si start time
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiStartTime, self).__init__()

                                    self.yang_name = "si-start-time"
                                    self.yang_parent_name = "os-runtime"

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nanosecond",
                                                    "second") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiStartTime, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiStartTime, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nanosecond.is_set or
                                        self.second.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nanosecond.yfilter != YFilter.not_set or
                                        self.second.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "si-start-time" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.second.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nanosecond" or name == "second"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nanosecond"):
                                        self.nanosecond = value
                                        self.nanosecond.value_namespace = name_space
                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                    if(value_path == "second"):
                                        self.second = value
                                        self.second.value_namespace = name_space
                                        self.second.value_namespace_prefix = name_space_prefix


                            class SiDuration(Entity):
                                """
                                si duration
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiDuration, self).__init__()

                                    self.yang_name = "si-duration"
                                    self.yang_parent_name = "os-runtime"

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nanosecond",
                                                    "second") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiDuration, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiDuration, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nanosecond.is_set or
                                        self.second.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nanosecond.yfilter != YFilter.not_set or
                                        self.second.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "si-duration" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.second.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nanosecond" or name == "second"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nanosecond"):
                                        self.nanosecond = value
                                        self.nanosecond.value_namespace = name_space
                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                    if(value_path == "second"):
                                        self.second = value
                                        self.second.value_namespace = name_space
                                        self.second.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.si_area_id_str.is_set or
                                    self.si_change_flags.is_set or
                                    (self.si_duration is not None and self.si_duration.has_data()) or
                                    (self.si_start_time is not None and self.si_start_time.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.si_area_id_str.yfilter != YFilter.not_set or
                                    self.si_change_flags.yfilter != YFilter.not_set or
                                    (self.si_duration is not None and self.si_duration.has_operation()) or
                                    (self.si_start_time is not None and self.si_start_time.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "os-runtime" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.si_area_id_str.is_set or self.si_area_id_str.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.si_area_id_str.get_name_leafdata())
                                if (self.si_change_flags.is_set or self.si_change_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.si_change_flags.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "si-duration"):
                                    if (self.si_duration is None):
                                        self.si_duration = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiDuration()
                                        self.si_duration.parent = self
                                        self._children_name_map["si_duration"] = "si-duration"
                                    return self.si_duration

                                if (child_yang_name == "si-start-time"):
                                    if (self.si_start_time is None):
                                        self.si_start_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiStartTime()
                                        self.si_start_time.parent = self
                                        self._children_name_map["si_start_time"] = "si-start-time"
                                    return self.si_start_time

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "si-duration" or name == "si-start-time" or name == "si-area-id-str" or name == "si-change-flags"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "si-area-id-str"):
                                    self.si_area_id_str = value
                                    self.si_area_id_str.value_namespace = name_space
                                    self.si_area_id_str.value_namespace_prefix = name_space_prefix
                                if(value_path == "si-change-flags"):
                                    self.si_change_flags = value
                                    self.si_change_flags.value_namespace = name_space
                                    self.si_change_flags.value_namespace_prefix = name_space_prefix


                        class OsSumRuntime(Entity):
                            """
                            os sum runtime
                            
                            .. attribute:: sp_adv_rtr_id
                            
                            	sp adv rtr id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_dest_addr
                            
                            	sp dest addr
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_dest_count
                            
                            	sp dest count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_duration
                            
                            	sp duration
                            	**type**\:   :py:class:`SpDuration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpDuration>`
                            
                            .. attribute:: sp_start_time
                            
                            	sp start time
                            	**type**\:   :py:class:`SpStartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpStartTime>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime, self).__init__()

                                self.yang_name = "os-sum-runtime"
                                self.yang_parent_name = "spf-stats"

                                self.sp_adv_rtr_id = YLeaf(YType.uint32, "sp-adv-rtr-id")

                                self.sp_dest_addr = YLeaf(YType.uint32, "sp-dest-addr")

                                self.sp_dest_count = YLeaf(YType.uint32, "sp-dest-count")

                                self.sp_duration = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpDuration()
                                self.sp_duration.parent = self
                                self._children_name_map["sp_duration"] = "sp-duration"
                                self._children_yang_names.add("sp-duration")

                                self.sp_start_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpStartTime()
                                self.sp_start_time.parent = self
                                self._children_name_map["sp_start_time"] = "sp-start-time"
                                self._children_yang_names.add("sp-start-time")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("sp_adv_rtr_id",
                                                "sp_dest_addr",
                                                "sp_dest_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime, self).__setattr__(name, value)


                            class SpStartTime(Entity):
                                """
                                sp start time
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpStartTime, self).__init__()

                                    self.yang_name = "sp-start-time"
                                    self.yang_parent_name = "os-sum-runtime"

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nanosecond",
                                                    "second") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpStartTime, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpStartTime, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nanosecond.is_set or
                                        self.second.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nanosecond.yfilter != YFilter.not_set or
                                        self.second.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sp-start-time" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.second.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nanosecond" or name == "second"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nanosecond"):
                                        self.nanosecond = value
                                        self.nanosecond.value_namespace = name_space
                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                    if(value_path == "second"):
                                        self.second = value
                                        self.second.value_namespace = name_space
                                        self.second.value_namespace_prefix = name_space_prefix


                            class SpDuration(Entity):
                                """
                                sp duration
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpDuration, self).__init__()

                                    self.yang_name = "sp-duration"
                                    self.yang_parent_name = "os-sum-runtime"

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nanosecond",
                                                    "second") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpDuration, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpDuration, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nanosecond.is_set or
                                        self.second.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nanosecond.yfilter != YFilter.not_set or
                                        self.second.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sp-duration" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.second.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nanosecond" or name == "second"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nanosecond"):
                                        self.nanosecond = value
                                        self.nanosecond.value_namespace = name_space
                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                    if(value_path == "second"):
                                        self.second = value
                                        self.second.value_namespace = name_space
                                        self.second.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.sp_adv_rtr_id.is_set or
                                    self.sp_dest_addr.is_set or
                                    self.sp_dest_count.is_set or
                                    (self.sp_duration is not None and self.sp_duration.has_data()) or
                                    (self.sp_start_time is not None and self.sp_start_time.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.sp_adv_rtr_id.yfilter != YFilter.not_set or
                                    self.sp_dest_addr.yfilter != YFilter.not_set or
                                    self.sp_dest_count.yfilter != YFilter.not_set or
                                    (self.sp_duration is not None and self.sp_duration.has_operation()) or
                                    (self.sp_start_time is not None and self.sp_start_time.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "os-sum-runtime" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.sp_adv_rtr_id.is_set or self.sp_adv_rtr_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sp_adv_rtr_id.get_name_leafdata())
                                if (self.sp_dest_addr.is_set or self.sp_dest_addr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sp_dest_addr.get_name_leafdata())
                                if (self.sp_dest_count.is_set or self.sp_dest_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sp_dest_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sp-duration"):
                                    if (self.sp_duration is None):
                                        self.sp_duration = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpDuration()
                                        self.sp_duration.parent = self
                                        self._children_name_map["sp_duration"] = "sp-duration"
                                    return self.sp_duration

                                if (child_yang_name == "sp-start-time"):
                                    if (self.sp_start_time is None):
                                        self.sp_start_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpStartTime()
                                        self.sp_start_time.parent = self
                                        self._children_name_map["sp_start_time"] = "sp-start-time"
                                    return self.sp_start_time

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sp-duration" or name == "sp-start-time" or name == "sp-adv-rtr-id" or name == "sp-dest-addr" or name == "sp-dest-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "sp-adv-rtr-id"):
                                    self.sp_adv_rtr_id = value
                                    self.sp_adv_rtr_id.value_namespace = name_space
                                    self.sp_adv_rtr_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sp-dest-addr"):
                                    self.sp_dest_addr = value
                                    self.sp_dest_addr.value_namespace = name_space
                                    self.sp_dest_addr.value_namespace_prefix = name_space_prefix
                                if(value_path == "sp-dest-count"):
                                    self.sp_dest_count = value
                                    self.sp_dest_count.value_namespace = name_space
                                    self.sp_dest_count.value_namespace_prefix = name_space_prefix


                        class OsExRuntime(Entity):
                            """
                            os ex runtime
                            
                            .. attribute:: sp_adv_rtr_id
                            
                            	sp adv rtr id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_dest_addr
                            
                            	sp dest addr
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_dest_count
                            
                            	sp dest count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_duration
                            
                            	sp duration
                            	**type**\:   :py:class:`SpDuration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpDuration>`
                            
                            .. attribute:: sp_start_time
                            
                            	sp start time
                            	**type**\:   :py:class:`SpStartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpStartTime>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime, self).__init__()

                                self.yang_name = "os-ex-runtime"
                                self.yang_parent_name = "spf-stats"

                                self.sp_adv_rtr_id = YLeaf(YType.uint32, "sp-adv-rtr-id")

                                self.sp_dest_addr = YLeaf(YType.uint32, "sp-dest-addr")

                                self.sp_dest_count = YLeaf(YType.uint32, "sp-dest-count")

                                self.sp_duration = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpDuration()
                                self.sp_duration.parent = self
                                self._children_name_map["sp_duration"] = "sp-duration"
                                self._children_yang_names.add("sp-duration")

                                self.sp_start_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpStartTime()
                                self.sp_start_time.parent = self
                                self._children_name_map["sp_start_time"] = "sp-start-time"
                                self._children_yang_names.add("sp-start-time")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("sp_adv_rtr_id",
                                                "sp_dest_addr",
                                                "sp_dest_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime, self).__setattr__(name, value)


                            class SpStartTime(Entity):
                                """
                                sp start time
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpStartTime, self).__init__()

                                    self.yang_name = "sp-start-time"
                                    self.yang_parent_name = "os-ex-runtime"

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nanosecond",
                                                    "second") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpStartTime, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpStartTime, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nanosecond.is_set or
                                        self.second.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nanosecond.yfilter != YFilter.not_set or
                                        self.second.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sp-start-time" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.second.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nanosecond" or name == "second"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nanosecond"):
                                        self.nanosecond = value
                                        self.nanosecond.value_namespace = name_space
                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                    if(value_path == "second"):
                                        self.second = value
                                        self.second.value_namespace = name_space
                                        self.second.value_namespace_prefix = name_space_prefix


                            class SpDuration(Entity):
                                """
                                sp duration
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpDuration, self).__init__()

                                    self.yang_name = "sp-duration"
                                    self.yang_parent_name = "os-ex-runtime"

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nanosecond",
                                                    "second") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpDuration, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpDuration, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nanosecond.is_set or
                                        self.second.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nanosecond.yfilter != YFilter.not_set or
                                        self.second.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sp-duration" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.second.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nanosecond" or name == "second"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nanosecond"):
                                        self.nanosecond = value
                                        self.nanosecond.value_namespace = name_space
                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                    if(value_path == "second"):
                                        self.second = value
                                        self.second.value_namespace = name_space
                                        self.second.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.sp_adv_rtr_id.is_set or
                                    self.sp_dest_addr.is_set or
                                    self.sp_dest_count.is_set or
                                    (self.sp_duration is not None and self.sp_duration.has_data()) or
                                    (self.sp_start_time is not None and self.sp_start_time.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.sp_adv_rtr_id.yfilter != YFilter.not_set or
                                    self.sp_dest_addr.yfilter != YFilter.not_set or
                                    self.sp_dest_count.yfilter != YFilter.not_set or
                                    (self.sp_duration is not None and self.sp_duration.has_operation()) or
                                    (self.sp_start_time is not None and self.sp_start_time.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "os-ex-runtime" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.sp_adv_rtr_id.is_set or self.sp_adv_rtr_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sp_adv_rtr_id.get_name_leafdata())
                                if (self.sp_dest_addr.is_set or self.sp_dest_addr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sp_dest_addr.get_name_leafdata())
                                if (self.sp_dest_count.is_set or self.sp_dest_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sp_dest_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sp-duration"):
                                    if (self.sp_duration is None):
                                        self.sp_duration = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpDuration()
                                        self.sp_duration.parent = self
                                        self._children_name_map["sp_duration"] = "sp-duration"
                                    return self.sp_duration

                                if (child_yang_name == "sp-start-time"):
                                    if (self.sp_start_time is None):
                                        self.sp_start_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpStartTime()
                                        self.sp_start_time.parent = self
                                        self._children_name_map["sp_start_time"] = "sp-start-time"
                                    return self.sp_start_time

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sp-duration" or name == "sp-start-time" or name == "sp-adv-rtr-id" or name == "sp-dest-addr" or name == "sp-dest-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "sp-adv-rtr-id"):
                                    self.sp_adv_rtr_id = value
                                    self.sp_adv_rtr_id.value_namespace = name_space
                                    self.sp_adv_rtr_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sp-dest-addr"):
                                    self.sp_dest_addr = value
                                    self.sp_dest_addr.value_namespace = name_space
                                    self.sp_dest_addr.value_namespace_prefix = name_space_prefix
                                if(value_path == "sp-dest-count"):
                                    self.sp_dest_count = value
                                    self.sp_dest_count.value_namespace = name_space
                                    self.sp_dest_count.value_namespace_prefix = name_space_prefix


                        class Runtime(Entity):
                            """
                            runtime
                            
                            .. attribute:: area_stat
                            
                            	area stat
                            	**type**\: list of    :py:class:`AreaStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat>`
                            
                            .. attribute:: gbl_spf_time
                            
                            	gbl spf time
                            	**type**\:   :py:class:`GblSpfTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.GblSpfTime>`
                            
                            .. attribute:: lsa_change_cnt
                            
                            	lsa change cnt
                            	**type**\:  int
                            
                            	**range:** \-32768..32767
                            
                            .. attribute:: lsa_info
                            
                            	lsa info
                            	**type**\: list of    :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.LsaInfo>`
                            
                            .. attribute:: spf_start_time
                            
                            	spf start time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime, self).__init__()

                                self.yang_name = "runtime"
                                self.yang_parent_name = "spf-stats"

                                self.lsa_change_cnt = YLeaf(YType.int16, "lsa-change-cnt")

                                self.spf_start_time = YLeaf(YType.uint32, "spf-start-time")

                                self.gbl_spf_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.GblSpfTime()
                                self.gbl_spf_time.parent = self
                                self._children_name_map["gbl_spf_time"] = "gbl-spf-time"
                                self._children_yang_names.add("gbl-spf-time")

                                self.area_stat = YList(self)
                                self.lsa_info = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("lsa_change_cnt",
                                                "spf_start_time") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime, self).__setattr__(name, value)


                            class GblSpfTime(Entity):
                                """
                                gbl spf time
                                
                                .. attribute:: spf_dijkstra
                                
                                	spf dijkstra
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_ext_prefix
                                
                                	spf ext prefix
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_ext_prefix_del
                                
                                	spf ext prefix del
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_inter_prefix
                                
                                	spf inter prefix
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_inter_prefix_del
                                
                                	spf inter prefix del
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_intra_prefix
                                
                                	spf intra prefix
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_intra_prefix_del
                                
                                	spf intra prefix del
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.GblSpfTime, self).__init__()

                                    self.yang_name = "gbl-spf-time"
                                    self.yang_parent_name = "runtime"

                                    self.spf_dijkstra = YLeaf(YType.uint32, "spf-dijkstra")

                                    self.spf_ext_prefix = YLeaf(YType.uint32, "spf-ext-prefix")

                                    self.spf_ext_prefix_del = YLeaf(YType.uint32, "spf-ext-prefix-del")

                                    self.spf_inter_prefix = YLeaf(YType.uint32, "spf-inter-prefix")

                                    self.spf_inter_prefix_del = YLeaf(YType.uint32, "spf-inter-prefix-del")

                                    self.spf_intra_prefix = YLeaf(YType.uint32, "spf-intra-prefix")

                                    self.spf_intra_prefix_del = YLeaf(YType.uint32, "spf-intra-prefix-del")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("spf_dijkstra",
                                                    "spf_ext_prefix",
                                                    "spf_ext_prefix_del",
                                                    "spf_inter_prefix",
                                                    "spf_inter_prefix_del",
                                                    "spf_intra_prefix",
                                                    "spf_intra_prefix_del") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.GblSpfTime, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.GblSpfTime, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.spf_dijkstra.is_set or
                                        self.spf_ext_prefix.is_set or
                                        self.spf_ext_prefix_del.is_set or
                                        self.spf_inter_prefix.is_set or
                                        self.spf_inter_prefix_del.is_set or
                                        self.spf_intra_prefix.is_set or
                                        self.spf_intra_prefix_del.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.spf_dijkstra.yfilter != YFilter.not_set or
                                        self.spf_ext_prefix.yfilter != YFilter.not_set or
                                        self.spf_ext_prefix_del.yfilter != YFilter.not_set or
                                        self.spf_inter_prefix.yfilter != YFilter.not_set or
                                        self.spf_inter_prefix_del.yfilter != YFilter.not_set or
                                        self.spf_intra_prefix.yfilter != YFilter.not_set or
                                        self.spf_intra_prefix_del.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "gbl-spf-time" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.spf_dijkstra.is_set or self.spf_dijkstra.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spf_dijkstra.get_name_leafdata())
                                    if (self.spf_ext_prefix.is_set or self.spf_ext_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spf_ext_prefix.get_name_leafdata())
                                    if (self.spf_ext_prefix_del.is_set or self.spf_ext_prefix_del.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spf_ext_prefix_del.get_name_leafdata())
                                    if (self.spf_inter_prefix.is_set or self.spf_inter_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spf_inter_prefix.get_name_leafdata())
                                    if (self.spf_inter_prefix_del.is_set or self.spf_inter_prefix_del.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spf_inter_prefix_del.get_name_leafdata())
                                    if (self.spf_intra_prefix.is_set or self.spf_intra_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spf_intra_prefix.get_name_leafdata())
                                    if (self.spf_intra_prefix_del.is_set or self.spf_intra_prefix_del.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spf_intra_prefix_del.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "spf-dijkstra" or name == "spf-ext-prefix" or name == "spf-ext-prefix-del" or name == "spf-inter-prefix" or name == "spf-inter-prefix-del" or name == "spf-intra-prefix" or name == "spf-intra-prefix-del"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "spf-dijkstra"):
                                        self.spf_dijkstra = value
                                        self.spf_dijkstra.value_namespace = name_space
                                        self.spf_dijkstra.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spf-ext-prefix"):
                                        self.spf_ext_prefix = value
                                        self.spf_ext_prefix.value_namespace = name_space
                                        self.spf_ext_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spf-ext-prefix-del"):
                                        self.spf_ext_prefix_del = value
                                        self.spf_ext_prefix_del.value_namespace = name_space
                                        self.spf_ext_prefix_del.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spf-inter-prefix"):
                                        self.spf_inter_prefix = value
                                        self.spf_inter_prefix.value_namespace = name_space
                                        self.spf_inter_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spf-inter-prefix-del"):
                                        self.spf_inter_prefix_del = value
                                        self.spf_inter_prefix_del.value_namespace = name_space
                                        self.spf_inter_prefix_del.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spf-intra-prefix"):
                                        self.spf_intra_prefix = value
                                        self.spf_intra_prefix.value_namespace = name_space
                                        self.spf_intra_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spf-intra-prefix-del"):
                                        self.spf_intra_prefix_del = value
                                        self.spf_intra_prefix_del.value_namespace = name_space
                                        self.spf_intra_prefix_del.value_namespace_prefix = name_space_prefix


                            class LsaInfo(Entity):
                                """
                                lsa info
                                
                                .. attribute:: adv_rtr
                                
                                	adv rtr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_id
                                
                                	area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flush
                                
                                	flush
                                	**type**\:  bool
                                
                                .. attribute:: id
                                
                                	id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.LsaInfo, self).__init__()

                                    self.yang_name = "lsa-info"
                                    self.yang_parent_name = "runtime"

                                    self.adv_rtr = YLeaf(YType.str, "adv-rtr")

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.flush = YLeaf(YType.boolean, "flush")

                                    self.id = YLeaf(YType.str, "id")

                                    self.type = YLeaf(YType.uint8, "type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("adv_rtr",
                                                    "area_id",
                                                    "flush",
                                                    "id",
                                                    "type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.LsaInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.LsaInfo, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.adv_rtr.is_set or
                                        self.area_id.is_set or
                                        self.flush.is_set or
                                        self.id.is_set or
                                        self.type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.adv_rtr.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.flush.yfilter != YFilter.not_set or
                                        self.id.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "lsa-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.adv_rtr.is_set or self.adv_rtr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.adv_rtr.get_name_leafdata())
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.flush.is_set or self.flush.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flush.get_name_leafdata())
                                    if (self.id.is_set or self.id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.id.get_name_leafdata())
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "adv-rtr" or name == "area-id" or name == "flush" or name == "id" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "adv-rtr"):
                                        self.adv_rtr = value
                                        self.adv_rtr.value_namespace = name_space
                                        self.adv_rtr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flush"):
                                        self.flush = value
                                        self.flush.value_namespace = name_space
                                        self.flush.value_namespace_prefix = name_space_prefix
                                    if(value_path == "id"):
                                        self.id = value
                                        self.id.value_namespace = name_space
                                        self.id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix


                            class AreaStat(Entity):
                                """
                                area stat
                                
                                .. attribute:: area_id
                                
                                	area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_type_cnt
                                
                                	lsa type cnt
                                	**type**\: list of    :py:class:`LsaTypeCnt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt>`
                                
                                .. attribute:: spf_time
                                
                                	spf time
                                	**type**\:   :py:class:`SpfTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat, self).__init__()

                                    self.yang_name = "area-stat"
                                    self.yang_parent_name = "runtime"

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.spf_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime()
                                    self.spf_time.parent = self
                                    self._children_name_map["spf_time"] = "spf-time"
                                    self._children_yang_names.add("spf-time")

                                    self.lsa_type_cnt = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat, self).__setattr__(name, value)


                                class SpfTime(Entity):
                                    """
                                    spf time
                                    
                                    .. attribute:: spf_dijkstra
                                    
                                    	spf dijkstra
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_ext_prefix
                                    
                                    	spf ext prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_ext_prefix_del
                                    
                                    	spf ext prefix del
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_inter_prefix
                                    
                                    	spf inter prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_inter_prefix_del
                                    
                                    	spf inter prefix del
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_intra_prefix
                                    
                                    	spf intra prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_intra_prefix_del
                                    
                                    	spf intra prefix del
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime, self).__init__()

                                        self.yang_name = "spf-time"
                                        self.yang_parent_name = "area-stat"

                                        self.spf_dijkstra = YLeaf(YType.uint32, "spf-dijkstra")

                                        self.spf_ext_prefix = YLeaf(YType.uint32, "spf-ext-prefix")

                                        self.spf_ext_prefix_del = YLeaf(YType.uint32, "spf-ext-prefix-del")

                                        self.spf_inter_prefix = YLeaf(YType.uint32, "spf-inter-prefix")

                                        self.spf_inter_prefix_del = YLeaf(YType.uint32, "spf-inter-prefix-del")

                                        self.spf_intra_prefix = YLeaf(YType.uint32, "spf-intra-prefix")

                                        self.spf_intra_prefix_del = YLeaf(YType.uint32, "spf-intra-prefix-del")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("spf_dijkstra",
                                                        "spf_ext_prefix",
                                                        "spf_ext_prefix_del",
                                                        "spf_inter_prefix",
                                                        "spf_inter_prefix_del",
                                                        "spf_intra_prefix",
                                                        "spf_intra_prefix_del") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.spf_dijkstra.is_set or
                                            self.spf_ext_prefix.is_set or
                                            self.spf_ext_prefix_del.is_set or
                                            self.spf_inter_prefix.is_set or
                                            self.spf_inter_prefix_del.is_set or
                                            self.spf_intra_prefix.is_set or
                                            self.spf_intra_prefix_del.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.spf_dijkstra.yfilter != YFilter.not_set or
                                            self.spf_ext_prefix.yfilter != YFilter.not_set or
                                            self.spf_ext_prefix_del.yfilter != YFilter.not_set or
                                            self.spf_inter_prefix.yfilter != YFilter.not_set or
                                            self.spf_inter_prefix_del.yfilter != YFilter.not_set or
                                            self.spf_intra_prefix.yfilter != YFilter.not_set or
                                            self.spf_intra_prefix_del.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "spf-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.spf_dijkstra.is_set or self.spf_dijkstra.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_dijkstra.get_name_leafdata())
                                        if (self.spf_ext_prefix.is_set or self.spf_ext_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_ext_prefix.get_name_leafdata())
                                        if (self.spf_ext_prefix_del.is_set or self.spf_ext_prefix_del.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_ext_prefix_del.get_name_leafdata())
                                        if (self.spf_inter_prefix.is_set or self.spf_inter_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_inter_prefix.get_name_leafdata())
                                        if (self.spf_inter_prefix_del.is_set or self.spf_inter_prefix_del.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_inter_prefix_del.get_name_leafdata())
                                        if (self.spf_intra_prefix.is_set or self.spf_intra_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_intra_prefix.get_name_leafdata())
                                        if (self.spf_intra_prefix_del.is_set or self.spf_intra_prefix_del.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spf_intra_prefix_del.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "spf-dijkstra" or name == "spf-ext-prefix" or name == "spf-ext-prefix-del" or name == "spf-inter-prefix" or name == "spf-inter-prefix-del" or name == "spf-intra-prefix" or name == "spf-intra-prefix-del"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "spf-dijkstra"):
                                            self.spf_dijkstra = value
                                            self.spf_dijkstra.value_namespace = name_space
                                            self.spf_dijkstra.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spf-ext-prefix"):
                                            self.spf_ext_prefix = value
                                            self.spf_ext_prefix.value_namespace = name_space
                                            self.spf_ext_prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spf-ext-prefix-del"):
                                            self.spf_ext_prefix_del = value
                                            self.spf_ext_prefix_del.value_namespace = name_space
                                            self.spf_ext_prefix_del.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spf-inter-prefix"):
                                            self.spf_inter_prefix = value
                                            self.spf_inter_prefix.value_namespace = name_space
                                            self.spf_inter_prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spf-inter-prefix-del"):
                                            self.spf_inter_prefix_del = value
                                            self.spf_inter_prefix_del.value_namespace = name_space
                                            self.spf_inter_prefix_del.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spf-intra-prefix"):
                                            self.spf_intra_prefix = value
                                            self.spf_intra_prefix.value_namespace = name_space
                                            self.spf_intra_prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spf-intra-prefix-del"):
                                            self.spf_intra_prefix_del = value
                                            self.spf_intra_prefix_del.value_namespace = name_space
                                            self.spf_intra_prefix_del.value_namespace_prefix = name_space_prefix


                                class LsaTypeCnt(Entity):
                                    """
                                    lsa type cnt
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt, self).__init__()

                                        self.yang_name = "lsa-type-cnt"
                                        self.yang_parent_name = "area-stat"

                                        self.entry = YLeaf(YType.uint32, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lsa-type-cnt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.lsa_type_cnt:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.area_id.is_set or
                                        (self.spf_time is not None and self.spf_time.has_data()))

                                def has_operation(self):
                                    for c in self.lsa_type_cnt:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        (self.spf_time is not None and self.spf_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "area-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "lsa-type-cnt"):
                                        for c in self.lsa_type_cnt:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.lsa_type_cnt.append(c)
                                        return c

                                    if (child_yang_name == "spf-time"):
                                        if (self.spf_time is None):
                                            self.spf_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime()
                                            self.spf_time.parent = self
                                            self._children_name_map["spf_time"] = "spf-time"
                                        return self.spf_time

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lsa-type-cnt" or name == "spf-time" or name == "area-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.area_stat:
                                    if (c.has_data()):
                                        return True
                                for c in self.lsa_info:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.lsa_change_cnt.is_set or
                                    self.spf_start_time.is_set or
                                    (self.gbl_spf_time is not None and self.gbl_spf_time.has_data()))

                            def has_operation(self):
                                for c in self.area_stat:
                                    if (c.has_operation()):
                                        return True
                                for c in self.lsa_info:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.lsa_change_cnt.yfilter != YFilter.not_set or
                                    self.spf_start_time.yfilter != YFilter.not_set or
                                    (self.gbl_spf_time is not None and self.gbl_spf_time.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "runtime" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.lsa_change_cnt.is_set or self.lsa_change_cnt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsa_change_cnt.get_name_leafdata())
                                if (self.spf_start_time.is_set or self.spf_start_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spf_start_time.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "area-stat"):
                                    for c in self.area_stat:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.area_stat.append(c)
                                    return c

                                if (child_yang_name == "gbl-spf-time"):
                                    if (self.gbl_spf_time is None):
                                        self.gbl_spf_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.GblSpfTime()
                                        self.gbl_spf_time.parent = self
                                        self._children_name_map["gbl_spf_time"] = "gbl-spf-time"
                                    return self.gbl_spf_time

                                if (child_yang_name == "lsa-info"):
                                    for c in self.lsa_info:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.LsaInfo()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.lsa_info.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "area-stat" or name == "gbl-spf-time" or name == "lsa-info" or name == "lsa-change-cnt" or name == "spf-start-time"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "lsa-change-cnt"):
                                    self.lsa_change_cnt = value
                                    self.lsa_change_cnt.value_namespace = name_space
                                    self.lsa_change_cnt.value_namespace_prefix = name_space_prefix
                                if(value_path == "spf-start-time"):
                                    self.spf_start_time = value
                                    self.spf_start_time.value_namespace = name_space
                                    self.spf_start_time.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.os_ex_runtime:
                                if (c.has_data()):
                                    return True
                            for c in self.os_runtime:
                                if (c.has_data()):
                                    return True
                            for c in self.os_sum_runtime:
                                if (c.has_data()):
                                    return True
                            for c in self.runtime:
                                if (c.has_data()):
                                    return True
                            return (self.spf_header is not None and self.spf_header.has_data())

                        def has_operation(self):
                            for c in self.os_ex_runtime:
                                if (c.has_operation()):
                                    return True
                            for c in self.os_runtime:
                                if (c.has_operation()):
                                    return True
                            for c in self.os_sum_runtime:
                                if (c.has_operation()):
                                    return True
                            for c in self.runtime:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.spf_header is not None and self.spf_header.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "spf-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "os-ex-runtime"):
                                for c in self.os_ex_runtime:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.os_ex_runtime.append(c)
                                return c

                            if (child_yang_name == "os-runtime"):
                                for c in self.os_runtime:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.os_runtime.append(c)
                                return c

                            if (child_yang_name == "os-sum-runtime"):
                                for c in self.os_sum_runtime:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.os_sum_runtime.append(c)
                                return c

                            if (child_yang_name == "runtime"):
                                for c in self.runtime:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.runtime.append(c)
                                return c

                            if (child_yang_name == "spf-header"):
                                if (self.spf_header is None):
                                    self.spf_header = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader()
                                    self.spf_header.parent = self
                                    self._children_name_map["spf_header"] = "spf-header"
                                return self.spf_header

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "os-ex-runtime" or name == "os-runtime" or name == "os-sum-runtime" or name == "runtime" or name == "spf-header"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class RibBatchStats(Entity):
                        """
                        Stats concerning RIB route updates using the
                        Batching API
                        
                        .. attribute:: priority_batch
                        
                        	priority batch
                        	**type**\: list of    :py:class:`PriorityBatch <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats.PriorityBatch>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats, self).__init__()

                            self.yang_name = "rib-batch-stats"
                            self.yang_parent_name = "statistics"

                            self.priority_batch = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats, self).__setattr__(name, value)


                        class PriorityBatch(Entity):
                            """
                            priority batch
                            
                            .. attribute:: batches_sent
                            
                            	batches sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lfas_add
                            
                            	lfas add
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lfas_del
                            
                            	lfas del
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lfas_pending
                            
                            	lfas pending
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lfas_sent
                            
                            	lfas sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_routes
                            
                            	max routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_add
                            
                            	paths add
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_add_errs
                            
                            	paths add errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_del
                            
                            	paths del
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_del_errs
                            
                            	paths del errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_pending
                            
                            	paths pending
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_sent
                            
                            	paths sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: priority_level
                            
                            	priority level
                            	**type**\:  str
                            
                            	**length:** 0..40
                            
                            .. attribute:: routes_pending
                            
                            	routes pending
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: routes_sent
                            
                            	routes sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats.PriorityBatch, self).__init__()

                                self.yang_name = "priority-batch"
                                self.yang_parent_name = "rib-batch-stats"

                                self.batches_sent = YLeaf(YType.uint32, "batches-sent")

                                self.lfas_add = YLeaf(YType.uint32, "lfas-add")

                                self.lfas_del = YLeaf(YType.uint32, "lfas-del")

                                self.lfas_pending = YLeaf(YType.uint32, "lfas-pending")

                                self.lfas_sent = YLeaf(YType.uint32, "lfas-sent")

                                self.max_routes = YLeaf(YType.uint32, "max-routes")

                                self.paths_add = YLeaf(YType.uint32, "paths-add")

                                self.paths_add_errs = YLeaf(YType.uint32, "paths-add-errs")

                                self.paths_del = YLeaf(YType.uint32, "paths-del")

                                self.paths_del_errs = YLeaf(YType.uint32, "paths-del-errs")

                                self.paths_pending = YLeaf(YType.uint32, "paths-pending")

                                self.paths_sent = YLeaf(YType.uint32, "paths-sent")

                                self.priority_level = YLeaf(YType.str, "priority-level")

                                self.routes_pending = YLeaf(YType.uint32, "routes-pending")

                                self.routes_sent = YLeaf(YType.uint32, "routes-sent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("batches_sent",
                                                "lfas_add",
                                                "lfas_del",
                                                "lfas_pending",
                                                "lfas_sent",
                                                "max_routes",
                                                "paths_add",
                                                "paths_add_errs",
                                                "paths_del",
                                                "paths_del_errs",
                                                "paths_pending",
                                                "paths_sent",
                                                "priority_level",
                                                "routes_pending",
                                                "routes_sent") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats.PriorityBatch, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats.PriorityBatch, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.batches_sent.is_set or
                                    self.lfas_add.is_set or
                                    self.lfas_del.is_set or
                                    self.lfas_pending.is_set or
                                    self.lfas_sent.is_set or
                                    self.max_routes.is_set or
                                    self.paths_add.is_set or
                                    self.paths_add_errs.is_set or
                                    self.paths_del.is_set or
                                    self.paths_del_errs.is_set or
                                    self.paths_pending.is_set or
                                    self.paths_sent.is_set or
                                    self.priority_level.is_set or
                                    self.routes_pending.is_set or
                                    self.routes_sent.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.batches_sent.yfilter != YFilter.not_set or
                                    self.lfas_add.yfilter != YFilter.not_set or
                                    self.lfas_del.yfilter != YFilter.not_set or
                                    self.lfas_pending.yfilter != YFilter.not_set or
                                    self.lfas_sent.yfilter != YFilter.not_set or
                                    self.max_routes.yfilter != YFilter.not_set or
                                    self.paths_add.yfilter != YFilter.not_set or
                                    self.paths_add_errs.yfilter != YFilter.not_set or
                                    self.paths_del.yfilter != YFilter.not_set or
                                    self.paths_del_errs.yfilter != YFilter.not_set or
                                    self.paths_pending.yfilter != YFilter.not_set or
                                    self.paths_sent.yfilter != YFilter.not_set or
                                    self.priority_level.yfilter != YFilter.not_set or
                                    self.routes_pending.yfilter != YFilter.not_set or
                                    self.routes_sent.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "priority-batch" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.batches_sent.is_set or self.batches_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.batches_sent.get_name_leafdata())
                                if (self.lfas_add.is_set or self.lfas_add.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lfas_add.get_name_leafdata())
                                if (self.lfas_del.is_set or self.lfas_del.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lfas_del.get_name_leafdata())
                                if (self.lfas_pending.is_set or self.lfas_pending.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lfas_pending.get_name_leafdata())
                                if (self.lfas_sent.is_set or self.lfas_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lfas_sent.get_name_leafdata())
                                if (self.max_routes.is_set or self.max_routes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_routes.get_name_leafdata())
                                if (self.paths_add.is_set or self.paths_add.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.paths_add.get_name_leafdata())
                                if (self.paths_add_errs.is_set or self.paths_add_errs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.paths_add_errs.get_name_leafdata())
                                if (self.paths_del.is_set or self.paths_del.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.paths_del.get_name_leafdata())
                                if (self.paths_del_errs.is_set or self.paths_del_errs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.paths_del_errs.get_name_leafdata())
                                if (self.paths_pending.is_set or self.paths_pending.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.paths_pending.get_name_leafdata())
                                if (self.paths_sent.is_set or self.paths_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.paths_sent.get_name_leafdata())
                                if (self.priority_level.is_set or self.priority_level.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority_level.get_name_leafdata())
                                if (self.routes_pending.is_set or self.routes_pending.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.routes_pending.get_name_leafdata())
                                if (self.routes_sent.is_set or self.routes_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.routes_sent.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "batches-sent" or name == "lfas-add" or name == "lfas-del" or name == "lfas-pending" or name == "lfas-sent" or name == "max-routes" or name == "paths-add" or name == "paths-add-errs" or name == "paths-del" or name == "paths-del-errs" or name == "paths-pending" or name == "paths-sent" or name == "priority-level" or name == "routes-pending" or name == "routes-sent"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "batches-sent"):
                                    self.batches_sent = value
                                    self.batches_sent.value_namespace = name_space
                                    self.batches_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "lfas-add"):
                                    self.lfas_add = value
                                    self.lfas_add.value_namespace = name_space
                                    self.lfas_add.value_namespace_prefix = name_space_prefix
                                if(value_path == "lfas-del"):
                                    self.lfas_del = value
                                    self.lfas_del.value_namespace = name_space
                                    self.lfas_del.value_namespace_prefix = name_space_prefix
                                if(value_path == "lfas-pending"):
                                    self.lfas_pending = value
                                    self.lfas_pending.value_namespace = name_space
                                    self.lfas_pending.value_namespace_prefix = name_space_prefix
                                if(value_path == "lfas-sent"):
                                    self.lfas_sent = value
                                    self.lfas_sent.value_namespace = name_space
                                    self.lfas_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-routes"):
                                    self.max_routes = value
                                    self.max_routes.value_namespace = name_space
                                    self.max_routes.value_namespace_prefix = name_space_prefix
                                if(value_path == "paths-add"):
                                    self.paths_add = value
                                    self.paths_add.value_namespace = name_space
                                    self.paths_add.value_namespace_prefix = name_space_prefix
                                if(value_path == "paths-add-errs"):
                                    self.paths_add_errs = value
                                    self.paths_add_errs.value_namespace = name_space
                                    self.paths_add_errs.value_namespace_prefix = name_space_prefix
                                if(value_path == "paths-del"):
                                    self.paths_del = value
                                    self.paths_del.value_namespace = name_space
                                    self.paths_del.value_namespace_prefix = name_space_prefix
                                if(value_path == "paths-del-errs"):
                                    self.paths_del_errs = value
                                    self.paths_del_errs.value_namespace = name_space
                                    self.paths_del_errs.value_namespace_prefix = name_space_prefix
                                if(value_path == "paths-pending"):
                                    self.paths_pending = value
                                    self.paths_pending.value_namespace = name_space
                                    self.paths_pending.value_namespace_prefix = name_space_prefix
                                if(value_path == "paths-sent"):
                                    self.paths_sent = value
                                    self.paths_sent.value_namespace = name_space
                                    self.paths_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority-level"):
                                    self.priority_level = value
                                    self.priority_level.value_namespace = name_space
                                    self.priority_level.value_namespace_prefix = name_space_prefix
                                if(value_path == "routes-pending"):
                                    self.routes_pending = value
                                    self.routes_pending.value_namespace = name_space
                                    self.routes_pending.value_namespace_prefix = name_space_prefix
                                if(value_path == "routes-sent"):
                                    self.routes_sent = value
                                    self.routes_sent.value_namespace = name_space
                                    self.routes_sent.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.priority_batch:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.priority_batch:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rib-batch-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "priority-batch"):
                                for c in self.priority_batch:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats.PriorityBatch()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.priority_batch.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "priority-batch"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class IssuStats(Entity):
                        """
                        OSPF ISSU statistics
                        
                        .. attribute:: nsr_conn_to_active_attempts
                        
                        	nsr conn to active attempts
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_closes
                        
                        	nsr conn to active closes
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_errors
                        
                        	nsr conn to active errors
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_fails
                        
                        	nsr conn to active fails
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_opens
                        
                        	nsr conn to active opens
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_fsm_state
                        
                        	nsr fsm state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_intf_seq_no
                        
                        	nsr intf seq no
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_lsa_init_sync_pend_count
                        
                        	nsr lsa init sync pend count
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_lsa_qad_mdata_count
                        
                        	nsr lsa qad mdata count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_lsa_qad_qid
                        
                        	nsr lsa qad qid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_mtu
                        
                        	nsr mtu
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nbr_init_sync_pend_count
                        
                        	nsr nbr init sync pend count
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_nbr_qad_mdata_count
                        
                        	nsr nbr qad mdata count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nbr_qad_qid
                        
                        	nsr nbr qad qid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nbr_seq_no
                        
                        	nsr nbr seq no
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nodeid
                        
                        	nsr nodeid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_peer_nodeid
                        
                        	nsr peer nodeid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_peer_version
                        
                        	nsr peer version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_rev
                        
                        	nsr rev
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_rtr_thd_sched
                        
                        	nsr rtr thd sched
                        	**type**\:   :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched>`
                        
                        .. attribute:: nsr_thd_sched
                        
                        	nsr thd sched
                        	**type**\:   :py:class:`NsrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched>`
                        
                        .. attribute:: nsr_tmr_quant
                        
                        	nsr tmr quant
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_version
                        
                        	nsr version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats, self).__init__()

                            self.yang_name = "issu-stats"
                            self.yang_parent_name = "statistics"

                            self.nsr_conn_to_active_attempts = YLeaf(YType.uint64, "nsr-conn-to-active-attempts")

                            self.nsr_conn_to_active_closes = YLeaf(YType.uint64, "nsr-conn-to-active-closes")

                            self.nsr_conn_to_active_errors = YLeaf(YType.uint64, "nsr-conn-to-active-errors")

                            self.nsr_conn_to_active_fails = YLeaf(YType.uint64, "nsr-conn-to-active-fails")

                            self.nsr_conn_to_active_opens = YLeaf(YType.uint64, "nsr-conn-to-active-opens")

                            self.nsr_fsm_state = YLeaf(YType.int32, "nsr-fsm-state")

                            self.nsr_intf_seq_no = YLeaf(YType.uint32, "nsr-intf-seq-no")

                            self.nsr_lsa_init_sync_pend_count = YLeaf(YType.int32, "nsr-lsa-init-sync-pend-count")

                            self.nsr_lsa_qad_mdata_count = YLeaf(YType.uint32, "nsr-lsa-qad-mdata-count")

                            self.nsr_lsa_qad_qid = YLeaf(YType.uint32, "nsr-lsa-qad-qid")

                            self.nsr_mtu = YLeaf(YType.uint32, "nsr-mtu")

                            self.nsr_nbr_init_sync_pend_count = YLeaf(YType.int32, "nsr-nbr-init-sync-pend-count")

                            self.nsr_nbr_qad_mdata_count = YLeaf(YType.uint32, "nsr-nbr-qad-mdata-count")

                            self.nsr_nbr_qad_qid = YLeaf(YType.uint32, "nsr-nbr-qad-qid")

                            self.nsr_nbr_seq_no = YLeaf(YType.uint32, "nsr-nbr-seq-no")

                            self.nsr_nodeid = YLeaf(YType.uint32, "nsr-nodeid")

                            self.nsr_peer_nodeid = YLeaf(YType.uint32, "nsr-peer-nodeid")

                            self.nsr_peer_version = YLeaf(YType.uint32, "nsr-peer-version")

                            self.nsr_rev = YLeaf(YType.int32, "nsr-rev")

                            self.nsr_tmr_quant = YLeaf(YType.int32, "nsr-tmr-quant")

                            self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                            self.nsr_rtr_thd_sched = Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched()
                            self.nsr_rtr_thd_sched.parent = self
                            self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                            self._children_yang_names.add("nsr-rtr-thd-sched")

                            self.nsr_thd_sched = Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched()
                            self.nsr_thd_sched.parent = self
                            self._children_name_map["nsr_thd_sched"] = "nsr-thd-sched"
                            self._children_yang_names.add("nsr-thd-sched")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("nsr_conn_to_active_attempts",
                                            "nsr_conn_to_active_closes",
                                            "nsr_conn_to_active_errors",
                                            "nsr_conn_to_active_fails",
                                            "nsr_conn_to_active_opens",
                                            "nsr_fsm_state",
                                            "nsr_intf_seq_no",
                                            "nsr_lsa_init_sync_pend_count",
                                            "nsr_lsa_qad_mdata_count",
                                            "nsr_lsa_qad_qid",
                                            "nsr_mtu",
                                            "nsr_nbr_init_sync_pend_count",
                                            "nsr_nbr_qad_mdata_count",
                                            "nsr_nbr_qad_qid",
                                            "nsr_nbr_seq_no",
                                            "nsr_nodeid",
                                            "nsr_peer_nodeid",
                                            "nsr_peer_version",
                                            "nsr_rev",
                                            "nsr_tmr_quant",
                                            "nsr_version") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats, self).__setattr__(name, value)


                        class NsrThdSched(Entity):
                            """
                            nsr thd sched
                            
                            .. attribute:: nsr_bad_pulses_rx
                            
                            	nsr bad pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_in_q
                            
                            	nsr events in q
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_events_rx
                            
                            	nsr events rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_tx
                            
                            	nsr events tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_good_pulses_rx
                            
                            	nsr good pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pri
                            
                            	nsr pri
                            	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched.NsrPri>`
                            
                            .. attribute:: nsr_pulse_quant
                            
                            	nsr pulse quant
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_pulse_tx_fails
                            
                            	nsr pulse tx fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pulses_tx
                            
                            	nsr pulses tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched, self).__init__()

                                self.yang_name = "nsr-thd-sched"
                                self.yang_parent_name = "issu-stats"

                                self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                self.nsr_pri = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nsr_bad_pulses_rx",
                                                "nsr_events_in_q",
                                                "nsr_events_rx",
                                                "nsr_events_tx",
                                                "nsr_good_pulses_rx",
                                                "nsr_pulse_quant",
                                                "nsr_pulse_tx_fails",
                                                "nsr_pulses_tx") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched, self).__setattr__(name, value)


                            class NsrPri(Entity):
                                """
                                nsr pri
                                
                                .. attribute:: nsr_sched_enq_fails
                                
                                	nsr sched enq fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_deqd
                                
                                	nsr sched evs deqd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_in_q
                                
                                	nsr sched evs in q
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_evs_qd
                                
                                	nsr sched evs qd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_max_evs
                                
                                	nsr sched max evs
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_peak_q_len
                                
                                	nsr sched peak q len
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_pri
                                
                                	nsr sched pri
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sched_quant
                                
                                	nsr sched quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nsr_sched_remain_quant
                                
                                	nsr sched remain quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched.NsrPri, self).__init__()

                                    self.yang_name = "nsr-pri"
                                    self.yang_parent_name = "nsr-thd-sched"

                                    self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                    self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                    self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                    self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                    self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                    self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                    self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                    self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                    self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nsr_sched_enq_fails",
                                                    "nsr_sched_evs_deqd",
                                                    "nsr_sched_evs_in_q",
                                                    "nsr_sched_evs_qd",
                                                    "nsr_sched_max_evs",
                                                    "nsr_sched_peak_q_len",
                                                    "nsr_sched_pri",
                                                    "nsr_sched_quant",
                                                    "nsr_sched_remain_quant") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched.NsrPri, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched.NsrPri, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nsr_sched_enq_fails.is_set or
                                        self.nsr_sched_evs_deqd.is_set or
                                        self.nsr_sched_evs_in_q.is_set or
                                        self.nsr_sched_evs_qd.is_set or
                                        self.nsr_sched_max_evs.is_set or
                                        self.nsr_sched_peak_q_len.is_set or
                                        self.nsr_sched_pri.is_set or
                                        self.nsr_sched_quant.is_set or
                                        self.nsr_sched_remain_quant.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nsr_sched_enq_fails.yfilter != YFilter.not_set or
                                        self.nsr_sched_evs_deqd.yfilter != YFilter.not_set or
                                        self.nsr_sched_evs_in_q.yfilter != YFilter.not_set or
                                        self.nsr_sched_evs_qd.yfilter != YFilter.not_set or
                                        self.nsr_sched_max_evs.yfilter != YFilter.not_set or
                                        self.nsr_sched_peak_q_len.yfilter != YFilter.not_set or
                                        self.nsr_sched_pri.yfilter != YFilter.not_set or
                                        self.nsr_sched_quant.yfilter != YFilter.not_set or
                                        self.nsr_sched_remain_quant.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "nsr-pri" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nsr_sched_enq_fails.is_set or self.nsr_sched_enq_fails.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_enq_fails.get_name_leafdata())
                                    if (self.nsr_sched_evs_deqd.is_set or self.nsr_sched_evs_deqd.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_evs_deqd.get_name_leafdata())
                                    if (self.nsr_sched_evs_in_q.is_set or self.nsr_sched_evs_in_q.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_evs_in_q.get_name_leafdata())
                                    if (self.nsr_sched_evs_qd.is_set or self.nsr_sched_evs_qd.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_evs_qd.get_name_leafdata())
                                    if (self.nsr_sched_max_evs.is_set or self.nsr_sched_max_evs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_max_evs.get_name_leafdata())
                                    if (self.nsr_sched_peak_q_len.is_set or self.nsr_sched_peak_q_len.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_peak_q_len.get_name_leafdata())
                                    if (self.nsr_sched_pri.is_set or self.nsr_sched_pri.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_pri.get_name_leafdata())
                                    if (self.nsr_sched_quant.is_set or self.nsr_sched_quant.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_quant.get_name_leafdata())
                                    if (self.nsr_sched_remain_quant.is_set or self.nsr_sched_remain_quant.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_remain_quant.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nsr-sched-enq-fails" or name == "nsr-sched-evs-deqd" or name == "nsr-sched-evs-in-q" or name == "nsr-sched-evs-qd" or name == "nsr-sched-max-evs" or name == "nsr-sched-peak-q-len" or name == "nsr-sched-pri" or name == "nsr-sched-quant" or name == "nsr-sched-remain-quant"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nsr-sched-enq-fails"):
                                        self.nsr_sched_enq_fails = value
                                        self.nsr_sched_enq_fails.value_namespace = name_space
                                        self.nsr_sched_enq_fails.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-evs-deqd"):
                                        self.nsr_sched_evs_deqd = value
                                        self.nsr_sched_evs_deqd.value_namespace = name_space
                                        self.nsr_sched_evs_deqd.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-evs-in-q"):
                                        self.nsr_sched_evs_in_q = value
                                        self.nsr_sched_evs_in_q.value_namespace = name_space
                                        self.nsr_sched_evs_in_q.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-evs-qd"):
                                        self.nsr_sched_evs_qd = value
                                        self.nsr_sched_evs_qd.value_namespace = name_space
                                        self.nsr_sched_evs_qd.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-max-evs"):
                                        self.nsr_sched_max_evs = value
                                        self.nsr_sched_max_evs.value_namespace = name_space
                                        self.nsr_sched_max_evs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-peak-q-len"):
                                        self.nsr_sched_peak_q_len = value
                                        self.nsr_sched_peak_q_len.value_namespace = name_space
                                        self.nsr_sched_peak_q_len.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-pri"):
                                        self.nsr_sched_pri = value
                                        self.nsr_sched_pri.value_namespace = name_space
                                        self.nsr_sched_pri.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-quant"):
                                        self.nsr_sched_quant = value
                                        self.nsr_sched_quant.value_namespace = name_space
                                        self.nsr_sched_quant.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-remain-quant"):
                                        self.nsr_sched_remain_quant = value
                                        self.nsr_sched_remain_quant.value_namespace = name_space
                                        self.nsr_sched_remain_quant.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.nsr_pri:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.nsr_bad_pulses_rx.is_set or
                                    self.nsr_events_in_q.is_set or
                                    self.nsr_events_rx.is_set or
                                    self.nsr_events_tx.is_set or
                                    self.nsr_good_pulses_rx.is_set or
                                    self.nsr_pulse_quant.is_set or
                                    self.nsr_pulse_tx_fails.is_set or
                                    self.nsr_pulses_tx.is_set)

                            def has_operation(self):
                                for c in self.nsr_pri:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nsr_bad_pulses_rx.yfilter != YFilter.not_set or
                                    self.nsr_events_in_q.yfilter != YFilter.not_set or
                                    self.nsr_events_rx.yfilter != YFilter.not_set or
                                    self.nsr_events_tx.yfilter != YFilter.not_set or
                                    self.nsr_good_pulses_rx.yfilter != YFilter.not_set or
                                    self.nsr_pulse_quant.yfilter != YFilter.not_set or
                                    self.nsr_pulse_tx_fails.yfilter != YFilter.not_set or
                                    self.nsr_pulses_tx.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nsr-thd-sched" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nsr_bad_pulses_rx.is_set or self.nsr_bad_pulses_rx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_bad_pulses_rx.get_name_leafdata())
                                if (self.nsr_events_in_q.is_set or self.nsr_events_in_q.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_events_in_q.get_name_leafdata())
                                if (self.nsr_events_rx.is_set or self.nsr_events_rx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_events_rx.get_name_leafdata())
                                if (self.nsr_events_tx.is_set or self.nsr_events_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_events_tx.get_name_leafdata())
                                if (self.nsr_good_pulses_rx.is_set or self.nsr_good_pulses_rx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_good_pulses_rx.get_name_leafdata())
                                if (self.nsr_pulse_quant.is_set or self.nsr_pulse_quant.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_pulse_quant.get_name_leafdata())
                                if (self.nsr_pulse_tx_fails.is_set or self.nsr_pulse_tx_fails.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_pulse_tx_fails.get_name_leafdata())
                                if (self.nsr_pulses_tx.is_set or self.nsr_pulses_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_pulses_tx.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "nsr-pri"):
                                    for c in self.nsr_pri:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched.NsrPri()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.nsr_pri.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nsr-pri" or name == "nsr-bad-pulses-rx" or name == "nsr-events-in-q" or name == "nsr-events-rx" or name == "nsr-events-tx" or name == "nsr-good-pulses-rx" or name == "nsr-pulse-quant" or name == "nsr-pulse-tx-fails" or name == "nsr-pulses-tx"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nsr-bad-pulses-rx"):
                                    self.nsr_bad_pulses_rx = value
                                    self.nsr_bad_pulses_rx.value_namespace = name_space
                                    self.nsr_bad_pulses_rx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-events-in-q"):
                                    self.nsr_events_in_q = value
                                    self.nsr_events_in_q.value_namespace = name_space
                                    self.nsr_events_in_q.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-events-rx"):
                                    self.nsr_events_rx = value
                                    self.nsr_events_rx.value_namespace = name_space
                                    self.nsr_events_rx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-events-tx"):
                                    self.nsr_events_tx = value
                                    self.nsr_events_tx.value_namespace = name_space
                                    self.nsr_events_tx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-good-pulses-rx"):
                                    self.nsr_good_pulses_rx = value
                                    self.nsr_good_pulses_rx.value_namespace = name_space
                                    self.nsr_good_pulses_rx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-pulse-quant"):
                                    self.nsr_pulse_quant = value
                                    self.nsr_pulse_quant.value_namespace = name_space
                                    self.nsr_pulse_quant.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-pulse-tx-fails"):
                                    self.nsr_pulse_tx_fails = value
                                    self.nsr_pulse_tx_fails.value_namespace = name_space
                                    self.nsr_pulse_tx_fails.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-pulses-tx"):
                                    self.nsr_pulses_tx = value
                                    self.nsr_pulses_tx.value_namespace = name_space
                                    self.nsr_pulses_tx.value_namespace_prefix = name_space_prefix


                        class NsrRtrThdSched(Entity):
                            """
                            nsr rtr thd sched
                            
                            .. attribute:: nsr_bad_pulses_rx
                            
                            	nsr bad pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_in_q
                            
                            	nsr events in q
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_events_rx
                            
                            	nsr events rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_tx
                            
                            	nsr events tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_good_pulses_rx
                            
                            	nsr good pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pri
                            
                            	nsr pri
                            	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri>`
                            
                            .. attribute:: nsr_pulse_quant
                            
                            	nsr pulse quant
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_pulse_tx_fails
                            
                            	nsr pulse tx fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pulses_tx
                            
                            	nsr pulses tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched, self).__init__()

                                self.yang_name = "nsr-rtr-thd-sched"
                                self.yang_parent_name = "issu-stats"

                                self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                self.nsr_pri = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nsr_bad_pulses_rx",
                                                "nsr_events_in_q",
                                                "nsr_events_rx",
                                                "nsr_events_tx",
                                                "nsr_good_pulses_rx",
                                                "nsr_pulse_quant",
                                                "nsr_pulse_tx_fails",
                                                "nsr_pulses_tx") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched, self).__setattr__(name, value)


                            class NsrPri(Entity):
                                """
                                nsr pri
                                
                                .. attribute:: nsr_sched_enq_fails
                                
                                	nsr sched enq fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_deqd
                                
                                	nsr sched evs deqd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_in_q
                                
                                	nsr sched evs in q
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_evs_qd
                                
                                	nsr sched evs qd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_max_evs
                                
                                	nsr sched max evs
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_peak_q_len
                                
                                	nsr sched peak q len
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_pri
                                
                                	nsr sched pri
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sched_quant
                                
                                	nsr sched quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nsr_sched_remain_quant
                                
                                	nsr sched remain quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri, self).__init__()

                                    self.yang_name = "nsr-pri"
                                    self.yang_parent_name = "nsr-rtr-thd-sched"

                                    self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                    self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                    self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                    self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                    self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                    self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                    self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                    self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                    self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nsr_sched_enq_fails",
                                                    "nsr_sched_evs_deqd",
                                                    "nsr_sched_evs_in_q",
                                                    "nsr_sched_evs_qd",
                                                    "nsr_sched_max_evs",
                                                    "nsr_sched_peak_q_len",
                                                    "nsr_sched_pri",
                                                    "nsr_sched_quant",
                                                    "nsr_sched_remain_quant") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nsr_sched_enq_fails.is_set or
                                        self.nsr_sched_evs_deqd.is_set or
                                        self.nsr_sched_evs_in_q.is_set or
                                        self.nsr_sched_evs_qd.is_set or
                                        self.nsr_sched_max_evs.is_set or
                                        self.nsr_sched_peak_q_len.is_set or
                                        self.nsr_sched_pri.is_set or
                                        self.nsr_sched_quant.is_set or
                                        self.nsr_sched_remain_quant.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nsr_sched_enq_fails.yfilter != YFilter.not_set or
                                        self.nsr_sched_evs_deqd.yfilter != YFilter.not_set or
                                        self.nsr_sched_evs_in_q.yfilter != YFilter.not_set or
                                        self.nsr_sched_evs_qd.yfilter != YFilter.not_set or
                                        self.nsr_sched_max_evs.yfilter != YFilter.not_set or
                                        self.nsr_sched_peak_q_len.yfilter != YFilter.not_set or
                                        self.nsr_sched_pri.yfilter != YFilter.not_set or
                                        self.nsr_sched_quant.yfilter != YFilter.not_set or
                                        self.nsr_sched_remain_quant.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "nsr-pri" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nsr_sched_enq_fails.is_set or self.nsr_sched_enq_fails.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_enq_fails.get_name_leafdata())
                                    if (self.nsr_sched_evs_deqd.is_set or self.nsr_sched_evs_deqd.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_evs_deqd.get_name_leafdata())
                                    if (self.nsr_sched_evs_in_q.is_set or self.nsr_sched_evs_in_q.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_evs_in_q.get_name_leafdata())
                                    if (self.nsr_sched_evs_qd.is_set or self.nsr_sched_evs_qd.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_evs_qd.get_name_leafdata())
                                    if (self.nsr_sched_max_evs.is_set or self.nsr_sched_max_evs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_max_evs.get_name_leafdata())
                                    if (self.nsr_sched_peak_q_len.is_set or self.nsr_sched_peak_q_len.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_peak_q_len.get_name_leafdata())
                                    if (self.nsr_sched_pri.is_set or self.nsr_sched_pri.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_pri.get_name_leafdata())
                                    if (self.nsr_sched_quant.is_set or self.nsr_sched_quant.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_quant.get_name_leafdata())
                                    if (self.nsr_sched_remain_quant.is_set or self.nsr_sched_remain_quant.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_remain_quant.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nsr-sched-enq-fails" or name == "nsr-sched-evs-deqd" or name == "nsr-sched-evs-in-q" or name == "nsr-sched-evs-qd" or name == "nsr-sched-max-evs" or name == "nsr-sched-peak-q-len" or name == "nsr-sched-pri" or name == "nsr-sched-quant" or name == "nsr-sched-remain-quant"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nsr-sched-enq-fails"):
                                        self.nsr_sched_enq_fails = value
                                        self.nsr_sched_enq_fails.value_namespace = name_space
                                        self.nsr_sched_enq_fails.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-evs-deqd"):
                                        self.nsr_sched_evs_deqd = value
                                        self.nsr_sched_evs_deqd.value_namespace = name_space
                                        self.nsr_sched_evs_deqd.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-evs-in-q"):
                                        self.nsr_sched_evs_in_q = value
                                        self.nsr_sched_evs_in_q.value_namespace = name_space
                                        self.nsr_sched_evs_in_q.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-evs-qd"):
                                        self.nsr_sched_evs_qd = value
                                        self.nsr_sched_evs_qd.value_namespace = name_space
                                        self.nsr_sched_evs_qd.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-max-evs"):
                                        self.nsr_sched_max_evs = value
                                        self.nsr_sched_max_evs.value_namespace = name_space
                                        self.nsr_sched_max_evs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-peak-q-len"):
                                        self.nsr_sched_peak_q_len = value
                                        self.nsr_sched_peak_q_len.value_namespace = name_space
                                        self.nsr_sched_peak_q_len.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-pri"):
                                        self.nsr_sched_pri = value
                                        self.nsr_sched_pri.value_namespace = name_space
                                        self.nsr_sched_pri.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-quant"):
                                        self.nsr_sched_quant = value
                                        self.nsr_sched_quant.value_namespace = name_space
                                        self.nsr_sched_quant.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-remain-quant"):
                                        self.nsr_sched_remain_quant = value
                                        self.nsr_sched_remain_quant.value_namespace = name_space
                                        self.nsr_sched_remain_quant.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.nsr_pri:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.nsr_bad_pulses_rx.is_set or
                                    self.nsr_events_in_q.is_set or
                                    self.nsr_events_rx.is_set or
                                    self.nsr_events_tx.is_set or
                                    self.nsr_good_pulses_rx.is_set or
                                    self.nsr_pulse_quant.is_set or
                                    self.nsr_pulse_tx_fails.is_set or
                                    self.nsr_pulses_tx.is_set)

                            def has_operation(self):
                                for c in self.nsr_pri:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nsr_bad_pulses_rx.yfilter != YFilter.not_set or
                                    self.nsr_events_in_q.yfilter != YFilter.not_set or
                                    self.nsr_events_rx.yfilter != YFilter.not_set or
                                    self.nsr_events_tx.yfilter != YFilter.not_set or
                                    self.nsr_good_pulses_rx.yfilter != YFilter.not_set or
                                    self.nsr_pulse_quant.yfilter != YFilter.not_set or
                                    self.nsr_pulse_tx_fails.yfilter != YFilter.not_set or
                                    self.nsr_pulses_tx.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nsr-rtr-thd-sched" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nsr_bad_pulses_rx.is_set or self.nsr_bad_pulses_rx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_bad_pulses_rx.get_name_leafdata())
                                if (self.nsr_events_in_q.is_set or self.nsr_events_in_q.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_events_in_q.get_name_leafdata())
                                if (self.nsr_events_rx.is_set or self.nsr_events_rx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_events_rx.get_name_leafdata())
                                if (self.nsr_events_tx.is_set or self.nsr_events_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_events_tx.get_name_leafdata())
                                if (self.nsr_good_pulses_rx.is_set or self.nsr_good_pulses_rx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_good_pulses_rx.get_name_leafdata())
                                if (self.nsr_pulse_quant.is_set or self.nsr_pulse_quant.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_pulse_quant.get_name_leafdata())
                                if (self.nsr_pulse_tx_fails.is_set or self.nsr_pulse_tx_fails.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_pulse_tx_fails.get_name_leafdata())
                                if (self.nsr_pulses_tx.is_set or self.nsr_pulses_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_pulses_tx.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "nsr-pri"):
                                    for c in self.nsr_pri:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.nsr_pri.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nsr-pri" or name == "nsr-bad-pulses-rx" or name == "nsr-events-in-q" or name == "nsr-events-rx" or name == "nsr-events-tx" or name == "nsr-good-pulses-rx" or name == "nsr-pulse-quant" or name == "nsr-pulse-tx-fails" or name == "nsr-pulses-tx"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nsr-bad-pulses-rx"):
                                    self.nsr_bad_pulses_rx = value
                                    self.nsr_bad_pulses_rx.value_namespace = name_space
                                    self.nsr_bad_pulses_rx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-events-in-q"):
                                    self.nsr_events_in_q = value
                                    self.nsr_events_in_q.value_namespace = name_space
                                    self.nsr_events_in_q.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-events-rx"):
                                    self.nsr_events_rx = value
                                    self.nsr_events_rx.value_namespace = name_space
                                    self.nsr_events_rx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-events-tx"):
                                    self.nsr_events_tx = value
                                    self.nsr_events_tx.value_namespace = name_space
                                    self.nsr_events_tx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-good-pulses-rx"):
                                    self.nsr_good_pulses_rx = value
                                    self.nsr_good_pulses_rx.value_namespace = name_space
                                    self.nsr_good_pulses_rx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-pulse-quant"):
                                    self.nsr_pulse_quant = value
                                    self.nsr_pulse_quant.value_namespace = name_space
                                    self.nsr_pulse_quant.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-pulse-tx-fails"):
                                    self.nsr_pulse_tx_fails = value
                                    self.nsr_pulse_tx_fails.value_namespace = name_space
                                    self.nsr_pulse_tx_fails.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-pulses-tx"):
                                    self.nsr_pulses_tx = value
                                    self.nsr_pulses_tx.value_namespace = name_space
                                    self.nsr_pulses_tx.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.nsr_conn_to_active_attempts.is_set or
                                self.nsr_conn_to_active_closes.is_set or
                                self.nsr_conn_to_active_errors.is_set or
                                self.nsr_conn_to_active_fails.is_set or
                                self.nsr_conn_to_active_opens.is_set or
                                self.nsr_fsm_state.is_set or
                                self.nsr_intf_seq_no.is_set or
                                self.nsr_lsa_init_sync_pend_count.is_set or
                                self.nsr_lsa_qad_mdata_count.is_set or
                                self.nsr_lsa_qad_qid.is_set or
                                self.nsr_mtu.is_set or
                                self.nsr_nbr_init_sync_pend_count.is_set or
                                self.nsr_nbr_qad_mdata_count.is_set or
                                self.nsr_nbr_qad_qid.is_set or
                                self.nsr_nbr_seq_no.is_set or
                                self.nsr_nodeid.is_set or
                                self.nsr_peer_nodeid.is_set or
                                self.nsr_peer_version.is_set or
                                self.nsr_rev.is_set or
                                self.nsr_tmr_quant.is_set or
                                self.nsr_version.is_set or
                                (self.nsr_rtr_thd_sched is not None and self.nsr_rtr_thd_sched.has_data()) or
                                (self.nsr_thd_sched is not None and self.nsr_thd_sched.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.nsr_conn_to_active_attempts.yfilter != YFilter.not_set or
                                self.nsr_conn_to_active_closes.yfilter != YFilter.not_set or
                                self.nsr_conn_to_active_errors.yfilter != YFilter.not_set or
                                self.nsr_conn_to_active_fails.yfilter != YFilter.not_set or
                                self.nsr_conn_to_active_opens.yfilter != YFilter.not_set or
                                self.nsr_fsm_state.yfilter != YFilter.not_set or
                                self.nsr_intf_seq_no.yfilter != YFilter.not_set or
                                self.nsr_lsa_init_sync_pend_count.yfilter != YFilter.not_set or
                                self.nsr_lsa_qad_mdata_count.yfilter != YFilter.not_set or
                                self.nsr_lsa_qad_qid.yfilter != YFilter.not_set or
                                self.nsr_mtu.yfilter != YFilter.not_set or
                                self.nsr_nbr_init_sync_pend_count.yfilter != YFilter.not_set or
                                self.nsr_nbr_qad_mdata_count.yfilter != YFilter.not_set or
                                self.nsr_nbr_qad_qid.yfilter != YFilter.not_set or
                                self.nsr_nbr_seq_no.yfilter != YFilter.not_set or
                                self.nsr_nodeid.yfilter != YFilter.not_set or
                                self.nsr_peer_nodeid.yfilter != YFilter.not_set or
                                self.nsr_peer_version.yfilter != YFilter.not_set or
                                self.nsr_rev.yfilter != YFilter.not_set or
                                self.nsr_tmr_quant.yfilter != YFilter.not_set or
                                self.nsr_version.yfilter != YFilter.not_set or
                                (self.nsr_rtr_thd_sched is not None and self.nsr_rtr_thd_sched.has_operation()) or
                                (self.nsr_thd_sched is not None and self.nsr_thd_sched.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "issu-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.nsr_conn_to_active_attempts.is_set or self.nsr_conn_to_active_attempts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_conn_to_active_attempts.get_name_leafdata())
                            if (self.nsr_conn_to_active_closes.is_set or self.nsr_conn_to_active_closes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_conn_to_active_closes.get_name_leafdata())
                            if (self.nsr_conn_to_active_errors.is_set or self.nsr_conn_to_active_errors.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_conn_to_active_errors.get_name_leafdata())
                            if (self.nsr_conn_to_active_fails.is_set or self.nsr_conn_to_active_fails.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_conn_to_active_fails.get_name_leafdata())
                            if (self.nsr_conn_to_active_opens.is_set or self.nsr_conn_to_active_opens.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_conn_to_active_opens.get_name_leafdata())
                            if (self.nsr_fsm_state.is_set or self.nsr_fsm_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_fsm_state.get_name_leafdata())
                            if (self.nsr_intf_seq_no.is_set or self.nsr_intf_seq_no.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_intf_seq_no.get_name_leafdata())
                            if (self.nsr_lsa_init_sync_pend_count.is_set or self.nsr_lsa_init_sync_pend_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_lsa_init_sync_pend_count.get_name_leafdata())
                            if (self.nsr_lsa_qad_mdata_count.is_set or self.nsr_lsa_qad_mdata_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_lsa_qad_mdata_count.get_name_leafdata())
                            if (self.nsr_lsa_qad_qid.is_set or self.nsr_lsa_qad_qid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_lsa_qad_qid.get_name_leafdata())
                            if (self.nsr_mtu.is_set or self.nsr_mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_mtu.get_name_leafdata())
                            if (self.nsr_nbr_init_sync_pend_count.is_set or self.nsr_nbr_init_sync_pend_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_nbr_init_sync_pend_count.get_name_leafdata())
                            if (self.nsr_nbr_qad_mdata_count.is_set or self.nsr_nbr_qad_mdata_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_nbr_qad_mdata_count.get_name_leafdata())
                            if (self.nsr_nbr_qad_qid.is_set or self.nsr_nbr_qad_qid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_nbr_qad_qid.get_name_leafdata())
                            if (self.nsr_nbr_seq_no.is_set or self.nsr_nbr_seq_no.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_nbr_seq_no.get_name_leafdata())
                            if (self.nsr_nodeid.is_set or self.nsr_nodeid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_nodeid.get_name_leafdata())
                            if (self.nsr_peer_nodeid.is_set or self.nsr_peer_nodeid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_peer_nodeid.get_name_leafdata())
                            if (self.nsr_peer_version.is_set or self.nsr_peer_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_peer_version.get_name_leafdata())
                            if (self.nsr_rev.is_set or self.nsr_rev.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_rev.get_name_leafdata())
                            if (self.nsr_tmr_quant.is_set or self.nsr_tmr_quant.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_tmr_quant.get_name_leafdata())
                            if (self.nsr_version.is_set or self.nsr_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_version.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "nsr-rtr-thd-sched"):
                                if (self.nsr_rtr_thd_sched is None):
                                    self.nsr_rtr_thd_sched = Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched()
                                    self.nsr_rtr_thd_sched.parent = self
                                    self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                                return self.nsr_rtr_thd_sched

                            if (child_yang_name == "nsr-thd-sched"):
                                if (self.nsr_thd_sched is None):
                                    self.nsr_thd_sched = Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched()
                                    self.nsr_thd_sched.parent = self
                                    self._children_name_map["nsr_thd_sched"] = "nsr-thd-sched"
                                return self.nsr_thd_sched

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nsr-rtr-thd-sched" or name == "nsr-thd-sched" or name == "nsr-conn-to-active-attempts" or name == "nsr-conn-to-active-closes" or name == "nsr-conn-to-active-errors" or name == "nsr-conn-to-active-fails" or name == "nsr-conn-to-active-opens" or name == "nsr-fsm-state" or name == "nsr-intf-seq-no" or name == "nsr-lsa-init-sync-pend-count" or name == "nsr-lsa-qad-mdata-count" or name == "nsr-lsa-qad-qid" or name == "nsr-mtu" or name == "nsr-nbr-init-sync-pend-count" or name == "nsr-nbr-qad-mdata-count" or name == "nsr-nbr-qad-qid" or name == "nsr-nbr-seq-no" or name == "nsr-nodeid" or name == "nsr-peer-nodeid" or name == "nsr-peer-version" or name == "nsr-rev" or name == "nsr-tmr-quant" or name == "nsr-version"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "nsr-conn-to-active-attempts"):
                                self.nsr_conn_to_active_attempts = value
                                self.nsr_conn_to_active_attempts.value_namespace = name_space
                                self.nsr_conn_to_active_attempts.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-conn-to-active-closes"):
                                self.nsr_conn_to_active_closes = value
                                self.nsr_conn_to_active_closes.value_namespace = name_space
                                self.nsr_conn_to_active_closes.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-conn-to-active-errors"):
                                self.nsr_conn_to_active_errors = value
                                self.nsr_conn_to_active_errors.value_namespace = name_space
                                self.nsr_conn_to_active_errors.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-conn-to-active-fails"):
                                self.nsr_conn_to_active_fails = value
                                self.nsr_conn_to_active_fails.value_namespace = name_space
                                self.nsr_conn_to_active_fails.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-conn-to-active-opens"):
                                self.nsr_conn_to_active_opens = value
                                self.nsr_conn_to_active_opens.value_namespace = name_space
                                self.nsr_conn_to_active_opens.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-fsm-state"):
                                self.nsr_fsm_state = value
                                self.nsr_fsm_state.value_namespace = name_space
                                self.nsr_fsm_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-intf-seq-no"):
                                self.nsr_intf_seq_no = value
                                self.nsr_intf_seq_no.value_namespace = name_space
                                self.nsr_intf_seq_no.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-lsa-init-sync-pend-count"):
                                self.nsr_lsa_init_sync_pend_count = value
                                self.nsr_lsa_init_sync_pend_count.value_namespace = name_space
                                self.nsr_lsa_init_sync_pend_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-lsa-qad-mdata-count"):
                                self.nsr_lsa_qad_mdata_count = value
                                self.nsr_lsa_qad_mdata_count.value_namespace = name_space
                                self.nsr_lsa_qad_mdata_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-lsa-qad-qid"):
                                self.nsr_lsa_qad_qid = value
                                self.nsr_lsa_qad_qid.value_namespace = name_space
                                self.nsr_lsa_qad_qid.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-mtu"):
                                self.nsr_mtu = value
                                self.nsr_mtu.value_namespace = name_space
                                self.nsr_mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-nbr-init-sync-pend-count"):
                                self.nsr_nbr_init_sync_pend_count = value
                                self.nsr_nbr_init_sync_pend_count.value_namespace = name_space
                                self.nsr_nbr_init_sync_pend_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-nbr-qad-mdata-count"):
                                self.nsr_nbr_qad_mdata_count = value
                                self.nsr_nbr_qad_mdata_count.value_namespace = name_space
                                self.nsr_nbr_qad_mdata_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-nbr-qad-qid"):
                                self.nsr_nbr_qad_qid = value
                                self.nsr_nbr_qad_qid.value_namespace = name_space
                                self.nsr_nbr_qad_qid.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-nbr-seq-no"):
                                self.nsr_nbr_seq_no = value
                                self.nsr_nbr_seq_no.value_namespace = name_space
                                self.nsr_nbr_seq_no.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-nodeid"):
                                self.nsr_nodeid = value
                                self.nsr_nodeid.value_namespace = name_space
                                self.nsr_nodeid.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-peer-nodeid"):
                                self.nsr_peer_nodeid = value
                                self.nsr_peer_nodeid.value_namespace = name_space
                                self.nsr_peer_nodeid.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-peer-version"):
                                self.nsr_peer_version = value
                                self.nsr_peer_version.value_namespace = name_space
                                self.nsr_peer_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-rev"):
                                self.nsr_rev = value
                                self.nsr_rev.value_namespace = name_space
                                self.nsr_rev.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-tmr-quant"):
                                self.nsr_tmr_quant = value
                                self.nsr_tmr_quant.value_namespace = name_space
                                self.nsr_tmr_quant.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-version"):
                                self.nsr_version = value
                                self.nsr_version.value_namespace = name_space
                                self.nsr_version.value_namespace_prefix = name_space_prefix


                    class RibThreadStats(Entity):
                        """
                        OSPF RIB thread statistics
                        
                        .. attribute:: internalwq
                        
                        	internalwq
                        	**type**\:   :py:class:`Internalwq <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq>`
                        
                        .. attribute:: ribqueue
                        
                        	ribqueue
                        	**type**\: list of    :py:class:`Ribqueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats, self).__init__()

                            self.yang_name = "rib-thread-stats"
                            self.yang_parent_name = "statistics"

                            self.internalwq = Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq()
                            self.internalwq.parent = self
                            self._children_name_map["internalwq"] = "internalwq"
                            self._children_yang_names.add("internalwq")

                            self.ribqueue = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats, self).__setattr__(name, value)


                        class Internalwq(Entity):
                            """
                            internalwq
                            
                            .. attribute:: priority_level
                            
                            	priority level
                            	**type**\:  str
                            
                            	**length:** 0..40
                            
                            .. attribute:: rib_base_clock
                            
                            	rib base clock
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: rib_base_time
                            
                            	rib base time
                            	**type**\:   :py:class:`RibBaseTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq.RibBaseTime>`
                            
                            .. attribute:: rib_dequeue_errs
                            
                            	rib dequeue errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_drop_after
                            
                            	rib drop after
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_drop_before
                            
                            	rib drop before
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_drop_conn
                            
                            	rib drop conn
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_empty_batches
                            
                            	rib empty batches
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_pfx_limit_errs
                            
                            	rib pfx limit errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_pkts_sent
                            
                            	rib pkts sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_queue_errs
                            
                            	rib queue errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_send_errs
                            
                            	rib send errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_signals
                            
                            	rib signals
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_table_not_created
                            
                            	rib table not created
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_version
                            
                            	rib version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wq_dqtime
                            
                            	wq dqtime
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: wq_len_cur
                            
                            	wq len cur
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: wq_len_max
                            
                            	wq len max
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: wq_thread_active
                            
                            	wq thread active
                            	**type**\:  bool
                            
                            .. attribute:: wq_total_dequeued
                            
                            	wq total dequeued
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wq_total_queued
                            
                            	wq total queued
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wqe_qtime
                            
                            	wqe qtime
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq, self).__init__()

                                self.yang_name = "internalwq"
                                self.yang_parent_name = "rib-thread-stats"

                                self.priority_level = YLeaf(YType.str, "priority-level")

                                self.rib_base_clock = YLeaf(YType.uint64, "rib-base-clock")

                                self.rib_dequeue_errs = YLeaf(YType.uint32, "rib-dequeue-errs")

                                self.rib_drop_after = YLeaf(YType.uint32, "rib-drop-after")

                                self.rib_drop_before = YLeaf(YType.uint32, "rib-drop-before")

                                self.rib_drop_conn = YLeaf(YType.uint32, "rib-drop-conn")

                                self.rib_empty_batches = YLeaf(YType.uint32, "rib-empty-batches")

                                self.rib_pfx_limit_errs = YLeaf(YType.uint32, "rib-pfx-limit-errs")

                                self.rib_pkts_sent = YLeaf(YType.uint32, "rib-pkts-sent")

                                self.rib_queue_errs = YLeaf(YType.uint32, "rib-queue-errs")

                                self.rib_send_errs = YLeaf(YType.uint32, "rib-send-errs")

                                self.rib_signals = YLeaf(YType.uint32, "rib-signals")

                                self.rib_table_not_created = YLeaf(YType.uint32, "rib-table-not-created")

                                self.rib_version = YLeaf(YType.uint32, "rib-version")

                                self.wq_dqtime = YLeaf(YType.uint64, "wq-dqtime")

                                self.wq_len_cur = YLeaf(YType.int32, "wq-len-cur")

                                self.wq_len_max = YLeaf(YType.int32, "wq-len-max")

                                self.wq_thread_active = YLeaf(YType.boolean, "wq-thread-active")

                                self.wq_total_dequeued = YLeaf(YType.uint32, "wq-total-dequeued")

                                self.wq_total_queued = YLeaf(YType.uint32, "wq-total-queued")

                                self.wqe_qtime = YLeaf(YType.uint64, "wqe-qtime")

                                self.rib_base_time = Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq.RibBaseTime()
                                self.rib_base_time.parent = self
                                self._children_name_map["rib_base_time"] = "rib-base-time"
                                self._children_yang_names.add("rib-base-time")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("priority_level",
                                                "rib_base_clock",
                                                "rib_dequeue_errs",
                                                "rib_drop_after",
                                                "rib_drop_before",
                                                "rib_drop_conn",
                                                "rib_empty_batches",
                                                "rib_pfx_limit_errs",
                                                "rib_pkts_sent",
                                                "rib_queue_errs",
                                                "rib_send_errs",
                                                "rib_signals",
                                                "rib_table_not_created",
                                                "rib_version",
                                                "wq_dqtime",
                                                "wq_len_cur",
                                                "wq_len_max",
                                                "wq_thread_active",
                                                "wq_total_dequeued",
                                                "wq_total_queued",
                                                "wqe_qtime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq, self).__setattr__(name, value)


                            class RibBaseTime(Entity):
                                """
                                rib base time
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq.RibBaseTime, self).__init__()

                                    self.yang_name = "rib-base-time"
                                    self.yang_parent_name = "internalwq"

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nanosecond",
                                                    "second") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq.RibBaseTime, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq.RibBaseTime, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nanosecond.is_set or
                                        self.second.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nanosecond.yfilter != YFilter.not_set or
                                        self.second.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rib-base-time" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.second.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nanosecond" or name == "second"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nanosecond"):
                                        self.nanosecond = value
                                        self.nanosecond.value_namespace = name_space
                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                    if(value_path == "second"):
                                        self.second = value
                                        self.second.value_namespace = name_space
                                        self.second.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.priority_level.is_set or
                                    self.rib_base_clock.is_set or
                                    self.rib_dequeue_errs.is_set or
                                    self.rib_drop_after.is_set or
                                    self.rib_drop_before.is_set or
                                    self.rib_drop_conn.is_set or
                                    self.rib_empty_batches.is_set or
                                    self.rib_pfx_limit_errs.is_set or
                                    self.rib_pkts_sent.is_set or
                                    self.rib_queue_errs.is_set or
                                    self.rib_send_errs.is_set or
                                    self.rib_signals.is_set or
                                    self.rib_table_not_created.is_set or
                                    self.rib_version.is_set or
                                    self.wq_dqtime.is_set or
                                    self.wq_len_cur.is_set or
                                    self.wq_len_max.is_set or
                                    self.wq_thread_active.is_set or
                                    self.wq_total_dequeued.is_set or
                                    self.wq_total_queued.is_set or
                                    self.wqe_qtime.is_set or
                                    (self.rib_base_time is not None and self.rib_base_time.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.priority_level.yfilter != YFilter.not_set or
                                    self.rib_base_clock.yfilter != YFilter.not_set or
                                    self.rib_dequeue_errs.yfilter != YFilter.not_set or
                                    self.rib_drop_after.yfilter != YFilter.not_set or
                                    self.rib_drop_before.yfilter != YFilter.not_set or
                                    self.rib_drop_conn.yfilter != YFilter.not_set or
                                    self.rib_empty_batches.yfilter != YFilter.not_set or
                                    self.rib_pfx_limit_errs.yfilter != YFilter.not_set or
                                    self.rib_pkts_sent.yfilter != YFilter.not_set or
                                    self.rib_queue_errs.yfilter != YFilter.not_set or
                                    self.rib_send_errs.yfilter != YFilter.not_set or
                                    self.rib_signals.yfilter != YFilter.not_set or
                                    self.rib_table_not_created.yfilter != YFilter.not_set or
                                    self.rib_version.yfilter != YFilter.not_set or
                                    self.wq_dqtime.yfilter != YFilter.not_set or
                                    self.wq_len_cur.yfilter != YFilter.not_set or
                                    self.wq_len_max.yfilter != YFilter.not_set or
                                    self.wq_thread_active.yfilter != YFilter.not_set or
                                    self.wq_total_dequeued.yfilter != YFilter.not_set or
                                    self.wq_total_queued.yfilter != YFilter.not_set or
                                    self.wqe_qtime.yfilter != YFilter.not_set or
                                    (self.rib_base_time is not None and self.rib_base_time.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "internalwq" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.priority_level.is_set or self.priority_level.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority_level.get_name_leafdata())
                                if (self.rib_base_clock.is_set or self.rib_base_clock.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_base_clock.get_name_leafdata())
                                if (self.rib_dequeue_errs.is_set or self.rib_dequeue_errs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_dequeue_errs.get_name_leafdata())
                                if (self.rib_drop_after.is_set or self.rib_drop_after.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_drop_after.get_name_leafdata())
                                if (self.rib_drop_before.is_set or self.rib_drop_before.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_drop_before.get_name_leafdata())
                                if (self.rib_drop_conn.is_set or self.rib_drop_conn.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_drop_conn.get_name_leafdata())
                                if (self.rib_empty_batches.is_set or self.rib_empty_batches.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_empty_batches.get_name_leafdata())
                                if (self.rib_pfx_limit_errs.is_set or self.rib_pfx_limit_errs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_pfx_limit_errs.get_name_leafdata())
                                if (self.rib_pkts_sent.is_set or self.rib_pkts_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_pkts_sent.get_name_leafdata())
                                if (self.rib_queue_errs.is_set or self.rib_queue_errs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_queue_errs.get_name_leafdata())
                                if (self.rib_send_errs.is_set or self.rib_send_errs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_send_errs.get_name_leafdata())
                                if (self.rib_signals.is_set or self.rib_signals.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_signals.get_name_leafdata())
                                if (self.rib_table_not_created.is_set or self.rib_table_not_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_table_not_created.get_name_leafdata())
                                if (self.rib_version.is_set or self.rib_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_version.get_name_leafdata())
                                if (self.wq_dqtime.is_set or self.wq_dqtime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wq_dqtime.get_name_leafdata())
                                if (self.wq_len_cur.is_set or self.wq_len_cur.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wq_len_cur.get_name_leafdata())
                                if (self.wq_len_max.is_set or self.wq_len_max.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wq_len_max.get_name_leafdata())
                                if (self.wq_thread_active.is_set or self.wq_thread_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wq_thread_active.get_name_leafdata())
                                if (self.wq_total_dequeued.is_set or self.wq_total_dequeued.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wq_total_dequeued.get_name_leafdata())
                                if (self.wq_total_queued.is_set or self.wq_total_queued.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wq_total_queued.get_name_leafdata())
                                if (self.wqe_qtime.is_set or self.wqe_qtime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wqe_qtime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rib-base-time"):
                                    if (self.rib_base_time is None):
                                        self.rib_base_time = Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq.RibBaseTime()
                                        self.rib_base_time.parent = self
                                        self._children_name_map["rib_base_time"] = "rib-base-time"
                                    return self.rib_base_time

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rib-base-time" or name == "priority-level" or name == "rib-base-clock" or name == "rib-dequeue-errs" or name == "rib-drop-after" or name == "rib-drop-before" or name == "rib-drop-conn" or name == "rib-empty-batches" or name == "rib-pfx-limit-errs" or name == "rib-pkts-sent" or name == "rib-queue-errs" or name == "rib-send-errs" or name == "rib-signals" or name == "rib-table-not-created" or name == "rib-version" or name == "wq-dqtime" or name == "wq-len-cur" or name == "wq-len-max" or name == "wq-thread-active" or name == "wq-total-dequeued" or name == "wq-total-queued" or name == "wqe-qtime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "priority-level"):
                                    self.priority_level = value
                                    self.priority_level.value_namespace = name_space
                                    self.priority_level.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-base-clock"):
                                    self.rib_base_clock = value
                                    self.rib_base_clock.value_namespace = name_space
                                    self.rib_base_clock.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-dequeue-errs"):
                                    self.rib_dequeue_errs = value
                                    self.rib_dequeue_errs.value_namespace = name_space
                                    self.rib_dequeue_errs.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-drop-after"):
                                    self.rib_drop_after = value
                                    self.rib_drop_after.value_namespace = name_space
                                    self.rib_drop_after.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-drop-before"):
                                    self.rib_drop_before = value
                                    self.rib_drop_before.value_namespace = name_space
                                    self.rib_drop_before.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-drop-conn"):
                                    self.rib_drop_conn = value
                                    self.rib_drop_conn.value_namespace = name_space
                                    self.rib_drop_conn.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-empty-batches"):
                                    self.rib_empty_batches = value
                                    self.rib_empty_batches.value_namespace = name_space
                                    self.rib_empty_batches.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-pfx-limit-errs"):
                                    self.rib_pfx_limit_errs = value
                                    self.rib_pfx_limit_errs.value_namespace = name_space
                                    self.rib_pfx_limit_errs.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-pkts-sent"):
                                    self.rib_pkts_sent = value
                                    self.rib_pkts_sent.value_namespace = name_space
                                    self.rib_pkts_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-queue-errs"):
                                    self.rib_queue_errs = value
                                    self.rib_queue_errs.value_namespace = name_space
                                    self.rib_queue_errs.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-send-errs"):
                                    self.rib_send_errs = value
                                    self.rib_send_errs.value_namespace = name_space
                                    self.rib_send_errs.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-signals"):
                                    self.rib_signals = value
                                    self.rib_signals.value_namespace = name_space
                                    self.rib_signals.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-table-not-created"):
                                    self.rib_table_not_created = value
                                    self.rib_table_not_created.value_namespace = name_space
                                    self.rib_table_not_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-version"):
                                    self.rib_version = value
                                    self.rib_version.value_namespace = name_space
                                    self.rib_version.value_namespace_prefix = name_space_prefix
                                if(value_path == "wq-dqtime"):
                                    self.wq_dqtime = value
                                    self.wq_dqtime.value_namespace = name_space
                                    self.wq_dqtime.value_namespace_prefix = name_space_prefix
                                if(value_path == "wq-len-cur"):
                                    self.wq_len_cur = value
                                    self.wq_len_cur.value_namespace = name_space
                                    self.wq_len_cur.value_namespace_prefix = name_space_prefix
                                if(value_path == "wq-len-max"):
                                    self.wq_len_max = value
                                    self.wq_len_max.value_namespace = name_space
                                    self.wq_len_max.value_namespace_prefix = name_space_prefix
                                if(value_path == "wq-thread-active"):
                                    self.wq_thread_active = value
                                    self.wq_thread_active.value_namespace = name_space
                                    self.wq_thread_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "wq-total-dequeued"):
                                    self.wq_total_dequeued = value
                                    self.wq_total_dequeued.value_namespace = name_space
                                    self.wq_total_dequeued.value_namespace_prefix = name_space_prefix
                                if(value_path == "wq-total-queued"):
                                    self.wq_total_queued = value
                                    self.wq_total_queued.value_namespace = name_space
                                    self.wq_total_queued.value_namespace_prefix = name_space_prefix
                                if(value_path == "wqe-qtime"):
                                    self.wqe_qtime = value
                                    self.wqe_qtime.value_namespace = name_space
                                    self.wqe_qtime.value_namespace_prefix = name_space_prefix


                        class Ribqueue(Entity):
                            """
                            ribqueue
                            
                            .. attribute:: priority_level
                            
                            	priority level
                            	**type**\:  str
                            
                            	**length:** 0..40
                            
                            .. attribute:: rib_base_clock
                            
                            	rib base clock
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: rib_base_time
                            
                            	rib base time
                            	**type**\:   :py:class:`RibBaseTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime>`
                            
                            .. attribute:: rib_dequeue_errs
                            
                            	rib dequeue errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_drop_after
                            
                            	rib drop after
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_drop_before
                            
                            	rib drop before
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_drop_conn
                            
                            	rib drop conn
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_empty_batches
                            
                            	rib empty batches
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_pfx_limit_errs
                            
                            	rib pfx limit errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_pkts_sent
                            
                            	rib pkts sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_queue_errs
                            
                            	rib queue errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_send_errs
                            
                            	rib send errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_signals
                            
                            	rib signals
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_table_not_created
                            
                            	rib table not created
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_version
                            
                            	rib version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wq_dqtime
                            
                            	wq dqtime
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: wq_len_cur
                            
                            	wq len cur
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: wq_len_max
                            
                            	wq len max
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: wq_thread_active
                            
                            	wq thread active
                            	**type**\:  bool
                            
                            .. attribute:: wq_total_dequeued
                            
                            	wq total dequeued
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wq_total_queued
                            
                            	wq total queued
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wqe_qtime
                            
                            	wqe qtime
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue, self).__init__()

                                self.yang_name = "ribqueue"
                                self.yang_parent_name = "rib-thread-stats"

                                self.priority_level = YLeaf(YType.str, "priority-level")

                                self.rib_base_clock = YLeaf(YType.uint64, "rib-base-clock")

                                self.rib_dequeue_errs = YLeaf(YType.uint32, "rib-dequeue-errs")

                                self.rib_drop_after = YLeaf(YType.uint32, "rib-drop-after")

                                self.rib_drop_before = YLeaf(YType.uint32, "rib-drop-before")

                                self.rib_drop_conn = YLeaf(YType.uint32, "rib-drop-conn")

                                self.rib_empty_batches = YLeaf(YType.uint32, "rib-empty-batches")

                                self.rib_pfx_limit_errs = YLeaf(YType.uint32, "rib-pfx-limit-errs")

                                self.rib_pkts_sent = YLeaf(YType.uint32, "rib-pkts-sent")

                                self.rib_queue_errs = YLeaf(YType.uint32, "rib-queue-errs")

                                self.rib_send_errs = YLeaf(YType.uint32, "rib-send-errs")

                                self.rib_signals = YLeaf(YType.uint32, "rib-signals")

                                self.rib_table_not_created = YLeaf(YType.uint32, "rib-table-not-created")

                                self.rib_version = YLeaf(YType.uint32, "rib-version")

                                self.wq_dqtime = YLeaf(YType.uint64, "wq-dqtime")

                                self.wq_len_cur = YLeaf(YType.int32, "wq-len-cur")

                                self.wq_len_max = YLeaf(YType.int32, "wq-len-max")

                                self.wq_thread_active = YLeaf(YType.boolean, "wq-thread-active")

                                self.wq_total_dequeued = YLeaf(YType.uint32, "wq-total-dequeued")

                                self.wq_total_queued = YLeaf(YType.uint32, "wq-total-queued")

                                self.wqe_qtime = YLeaf(YType.uint64, "wqe-qtime")

                                self.rib_base_time = Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime()
                                self.rib_base_time.parent = self
                                self._children_name_map["rib_base_time"] = "rib-base-time"
                                self._children_yang_names.add("rib-base-time")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("priority_level",
                                                "rib_base_clock",
                                                "rib_dequeue_errs",
                                                "rib_drop_after",
                                                "rib_drop_before",
                                                "rib_drop_conn",
                                                "rib_empty_batches",
                                                "rib_pfx_limit_errs",
                                                "rib_pkts_sent",
                                                "rib_queue_errs",
                                                "rib_send_errs",
                                                "rib_signals",
                                                "rib_table_not_created",
                                                "rib_version",
                                                "wq_dqtime",
                                                "wq_len_cur",
                                                "wq_len_max",
                                                "wq_thread_active",
                                                "wq_total_dequeued",
                                                "wq_total_queued",
                                                "wqe_qtime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue, self).__setattr__(name, value)


                            class RibBaseTime(Entity):
                                """
                                rib base time
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime, self).__init__()

                                    self.yang_name = "rib-base-time"
                                    self.yang_parent_name = "ribqueue"

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nanosecond",
                                                    "second") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nanosecond.is_set or
                                        self.second.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nanosecond.yfilter != YFilter.not_set or
                                        self.second.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rib-base-time" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.second.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nanosecond" or name == "second"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nanosecond"):
                                        self.nanosecond = value
                                        self.nanosecond.value_namespace = name_space
                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                    if(value_path == "second"):
                                        self.second = value
                                        self.second.value_namespace = name_space
                                        self.second.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.priority_level.is_set or
                                    self.rib_base_clock.is_set or
                                    self.rib_dequeue_errs.is_set or
                                    self.rib_drop_after.is_set or
                                    self.rib_drop_before.is_set or
                                    self.rib_drop_conn.is_set or
                                    self.rib_empty_batches.is_set or
                                    self.rib_pfx_limit_errs.is_set or
                                    self.rib_pkts_sent.is_set or
                                    self.rib_queue_errs.is_set or
                                    self.rib_send_errs.is_set or
                                    self.rib_signals.is_set or
                                    self.rib_table_not_created.is_set or
                                    self.rib_version.is_set or
                                    self.wq_dqtime.is_set or
                                    self.wq_len_cur.is_set or
                                    self.wq_len_max.is_set or
                                    self.wq_thread_active.is_set or
                                    self.wq_total_dequeued.is_set or
                                    self.wq_total_queued.is_set or
                                    self.wqe_qtime.is_set or
                                    (self.rib_base_time is not None and self.rib_base_time.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.priority_level.yfilter != YFilter.not_set or
                                    self.rib_base_clock.yfilter != YFilter.not_set or
                                    self.rib_dequeue_errs.yfilter != YFilter.not_set or
                                    self.rib_drop_after.yfilter != YFilter.not_set or
                                    self.rib_drop_before.yfilter != YFilter.not_set or
                                    self.rib_drop_conn.yfilter != YFilter.not_set or
                                    self.rib_empty_batches.yfilter != YFilter.not_set or
                                    self.rib_pfx_limit_errs.yfilter != YFilter.not_set or
                                    self.rib_pkts_sent.yfilter != YFilter.not_set or
                                    self.rib_queue_errs.yfilter != YFilter.not_set or
                                    self.rib_send_errs.yfilter != YFilter.not_set or
                                    self.rib_signals.yfilter != YFilter.not_set or
                                    self.rib_table_not_created.yfilter != YFilter.not_set or
                                    self.rib_version.yfilter != YFilter.not_set or
                                    self.wq_dqtime.yfilter != YFilter.not_set or
                                    self.wq_len_cur.yfilter != YFilter.not_set or
                                    self.wq_len_max.yfilter != YFilter.not_set or
                                    self.wq_thread_active.yfilter != YFilter.not_set or
                                    self.wq_total_dequeued.yfilter != YFilter.not_set or
                                    self.wq_total_queued.yfilter != YFilter.not_set or
                                    self.wqe_qtime.yfilter != YFilter.not_set or
                                    (self.rib_base_time is not None and self.rib_base_time.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ribqueue" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.priority_level.is_set or self.priority_level.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority_level.get_name_leafdata())
                                if (self.rib_base_clock.is_set or self.rib_base_clock.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_base_clock.get_name_leafdata())
                                if (self.rib_dequeue_errs.is_set or self.rib_dequeue_errs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_dequeue_errs.get_name_leafdata())
                                if (self.rib_drop_after.is_set or self.rib_drop_after.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_drop_after.get_name_leafdata())
                                if (self.rib_drop_before.is_set or self.rib_drop_before.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_drop_before.get_name_leafdata())
                                if (self.rib_drop_conn.is_set or self.rib_drop_conn.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_drop_conn.get_name_leafdata())
                                if (self.rib_empty_batches.is_set or self.rib_empty_batches.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_empty_batches.get_name_leafdata())
                                if (self.rib_pfx_limit_errs.is_set or self.rib_pfx_limit_errs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_pfx_limit_errs.get_name_leafdata())
                                if (self.rib_pkts_sent.is_set or self.rib_pkts_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_pkts_sent.get_name_leafdata())
                                if (self.rib_queue_errs.is_set or self.rib_queue_errs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_queue_errs.get_name_leafdata())
                                if (self.rib_send_errs.is_set or self.rib_send_errs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_send_errs.get_name_leafdata())
                                if (self.rib_signals.is_set or self.rib_signals.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_signals.get_name_leafdata())
                                if (self.rib_table_not_created.is_set or self.rib_table_not_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_table_not_created.get_name_leafdata())
                                if (self.rib_version.is_set or self.rib_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_version.get_name_leafdata())
                                if (self.wq_dqtime.is_set or self.wq_dqtime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wq_dqtime.get_name_leafdata())
                                if (self.wq_len_cur.is_set or self.wq_len_cur.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wq_len_cur.get_name_leafdata())
                                if (self.wq_len_max.is_set or self.wq_len_max.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wq_len_max.get_name_leafdata())
                                if (self.wq_thread_active.is_set or self.wq_thread_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wq_thread_active.get_name_leafdata())
                                if (self.wq_total_dequeued.is_set or self.wq_total_dequeued.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wq_total_dequeued.get_name_leafdata())
                                if (self.wq_total_queued.is_set or self.wq_total_queued.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wq_total_queued.get_name_leafdata())
                                if (self.wqe_qtime.is_set or self.wqe_qtime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wqe_qtime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rib-base-time"):
                                    if (self.rib_base_time is None):
                                        self.rib_base_time = Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime()
                                        self.rib_base_time.parent = self
                                        self._children_name_map["rib_base_time"] = "rib-base-time"
                                    return self.rib_base_time

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rib-base-time" or name == "priority-level" or name == "rib-base-clock" or name == "rib-dequeue-errs" or name == "rib-drop-after" or name == "rib-drop-before" or name == "rib-drop-conn" or name == "rib-empty-batches" or name == "rib-pfx-limit-errs" or name == "rib-pkts-sent" or name == "rib-queue-errs" or name == "rib-send-errs" or name == "rib-signals" or name == "rib-table-not-created" or name == "rib-version" or name == "wq-dqtime" or name == "wq-len-cur" or name == "wq-len-max" or name == "wq-thread-active" or name == "wq-total-dequeued" or name == "wq-total-queued" or name == "wqe-qtime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "priority-level"):
                                    self.priority_level = value
                                    self.priority_level.value_namespace = name_space
                                    self.priority_level.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-base-clock"):
                                    self.rib_base_clock = value
                                    self.rib_base_clock.value_namespace = name_space
                                    self.rib_base_clock.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-dequeue-errs"):
                                    self.rib_dequeue_errs = value
                                    self.rib_dequeue_errs.value_namespace = name_space
                                    self.rib_dequeue_errs.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-drop-after"):
                                    self.rib_drop_after = value
                                    self.rib_drop_after.value_namespace = name_space
                                    self.rib_drop_after.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-drop-before"):
                                    self.rib_drop_before = value
                                    self.rib_drop_before.value_namespace = name_space
                                    self.rib_drop_before.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-drop-conn"):
                                    self.rib_drop_conn = value
                                    self.rib_drop_conn.value_namespace = name_space
                                    self.rib_drop_conn.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-empty-batches"):
                                    self.rib_empty_batches = value
                                    self.rib_empty_batches.value_namespace = name_space
                                    self.rib_empty_batches.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-pfx-limit-errs"):
                                    self.rib_pfx_limit_errs = value
                                    self.rib_pfx_limit_errs.value_namespace = name_space
                                    self.rib_pfx_limit_errs.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-pkts-sent"):
                                    self.rib_pkts_sent = value
                                    self.rib_pkts_sent.value_namespace = name_space
                                    self.rib_pkts_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-queue-errs"):
                                    self.rib_queue_errs = value
                                    self.rib_queue_errs.value_namespace = name_space
                                    self.rib_queue_errs.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-send-errs"):
                                    self.rib_send_errs = value
                                    self.rib_send_errs.value_namespace = name_space
                                    self.rib_send_errs.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-signals"):
                                    self.rib_signals = value
                                    self.rib_signals.value_namespace = name_space
                                    self.rib_signals.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-table-not-created"):
                                    self.rib_table_not_created = value
                                    self.rib_table_not_created.value_namespace = name_space
                                    self.rib_table_not_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-version"):
                                    self.rib_version = value
                                    self.rib_version.value_namespace = name_space
                                    self.rib_version.value_namespace_prefix = name_space_prefix
                                if(value_path == "wq-dqtime"):
                                    self.wq_dqtime = value
                                    self.wq_dqtime.value_namespace = name_space
                                    self.wq_dqtime.value_namespace_prefix = name_space_prefix
                                if(value_path == "wq-len-cur"):
                                    self.wq_len_cur = value
                                    self.wq_len_cur.value_namespace = name_space
                                    self.wq_len_cur.value_namespace_prefix = name_space_prefix
                                if(value_path == "wq-len-max"):
                                    self.wq_len_max = value
                                    self.wq_len_max.value_namespace = name_space
                                    self.wq_len_max.value_namespace_prefix = name_space_prefix
                                if(value_path == "wq-thread-active"):
                                    self.wq_thread_active = value
                                    self.wq_thread_active.value_namespace = name_space
                                    self.wq_thread_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "wq-total-dequeued"):
                                    self.wq_total_dequeued = value
                                    self.wq_total_dequeued.value_namespace = name_space
                                    self.wq_total_dequeued.value_namespace_prefix = name_space_prefix
                                if(value_path == "wq-total-queued"):
                                    self.wq_total_queued = value
                                    self.wq_total_queued.value_namespace = name_space
                                    self.wq_total_queued.value_namespace_prefix = name_space_prefix
                                if(value_path == "wqe-qtime"):
                                    self.wqe_qtime = value
                                    self.wqe_qtime.value_namespace = name_space
                                    self.wqe_qtime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.ribqueue:
                                if (c.has_data()):
                                    return True
                            return (self.internalwq is not None and self.internalwq.has_data())

                        def has_operation(self):
                            for c in self.ribqueue:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.internalwq is not None and self.internalwq.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rib-thread-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "internalwq"):
                                if (self.internalwq is None):
                                    self.internalwq = Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq()
                                    self.internalwq.parent = self
                                    self._children_name_map["internalwq"] = "internalwq"
                                return self.internalwq

                            if (child_yang_name == "ribqueue"):
                                for c in self.ribqueue:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ribqueue.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "internalwq" or name == "ribqueue"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class NsrPlStats(Entity):
                        """
                        OSPF NSR packet library statistics
                        
                        .. attribute:: ncd_pri
                        
                        	ncd pri
                        	**type**\: list of    :py:class:`NcdPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats, self).__init__()

                            self.yang_name = "nsr-pl-stats"
                            self.yang_parent_name = "statistics"

                            self.ncd_pri = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats, self).__setattr__(name, value)


                        class NcdPri(Entity):
                            """
                            ncd pri
                            
                            .. attribute:: num_recv
                            
                            	Total recvd
                            	**type**\: list of    :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecv>`
                            
                            .. attribute:: num_recv_drop
                            
                            	Recv Errors/drops
                            	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop>`
                            
                            .. attribute:: num_sent
                            
                            	Total sent
                            	**type**\: list of    :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSent>`
                            
                            .. attribute:: num_sent_drop
                            
                            	Sent Error/drops
                            	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri, self).__init__()

                                self.yang_name = "ncd-pri"
                                self.yang_parent_name = "nsr-pl-stats"

                                self.num_recv = YList(self)
                                self.num_recv_drop = YList(self)
                                self.num_sent = YList(self)
                                self.num_sent_drop = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri, self).__setattr__(name, value)


                            class NumSent(Entity):
                                """
                                Total sent
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSent, self).__init__()

                                    self.yang_name = "num-sent"
                                    self.yang_parent_name = "ncd-pri"

                                    self.entry = YLeaf(YType.uint64, "entry")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("entry") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSent, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSent, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.entry.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.entry.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "num-sent" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "entry"):
                                        self.entry = value
                                        self.entry.value_namespace = name_space
                                        self.entry.value_namespace_prefix = name_space_prefix


                            class NumRecv(Entity):
                                """
                                Total recvd
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecv, self).__init__()

                                    self.yang_name = "num-recv"
                                    self.yang_parent_name = "ncd-pri"

                                    self.entry = YLeaf(YType.uint64, "entry")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("entry") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecv, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.entry.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.entry.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "num-recv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "entry"):
                                        self.entry = value
                                        self.entry.value_namespace = name_space
                                        self.entry.value_namespace_prefix = name_space_prefix


                            class NumSentDrop(Entity):
                                """
                                Sent Error/drops
                                
                                .. attribute:: nsr_pl_send_drop_array
                                
                                	nsr pl send drop array
                                	**type**\: list of    :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop, self).__init__()

                                    self.yang_name = "num-sent-drop"
                                    self.yang_parent_name = "ncd-pri"

                                    self.nsr_pl_send_drop_array = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop, self).__setattr__(name, value)


                                class NsrPlSendDropArray(Entity):
                                    """
                                    nsr pl send drop array
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray, self).__init__()

                                        self.yang_name = "nsr-pl-send-drop-array"
                                        self.yang_parent_name = "num-sent-drop"

                                        self.entry = YLeaf(YType.uint32, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "nsr-pl-send-drop-array" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.nsr_pl_send_drop_array:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.nsr_pl_send_drop_array:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "num-sent-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "nsr-pl-send-drop-array"):
                                        for c in self.nsr_pl_send_drop_array:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.nsr_pl_send_drop_array.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nsr-pl-send-drop-array"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class NumRecvDrop(Entity):
                                """
                                Recv Errors/drops
                                
                                .. attribute:: nsr_pl_recv_drop_array
                                
                                	nsr pl recv drop array
                                	**type**\: list of    :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop, self).__init__()

                                    self.yang_name = "num-recv-drop"
                                    self.yang_parent_name = "ncd-pri"

                                    self.nsr_pl_recv_drop_array = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop, self).__setattr__(name, value)


                                class NsrPlRecvDropArray(Entity):
                                    """
                                    nsr pl recv drop array
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray, self).__init__()

                                        self.yang_name = "nsr-pl-recv-drop-array"
                                        self.yang_parent_name = "num-recv-drop"

                                        self.entry = YLeaf(YType.uint32, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "nsr-pl-recv-drop-array" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.nsr_pl_recv_drop_array:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.nsr_pl_recv_drop_array:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "num-recv-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "nsr-pl-recv-drop-array"):
                                        for c in self.nsr_pl_recv_drop_array:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.nsr_pl_recv_drop_array.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nsr-pl-recv-drop-array"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                for c in self.num_recv:
                                    if (c.has_data()):
                                        return True
                                for c in self.num_recv_drop:
                                    if (c.has_data()):
                                        return True
                                for c in self.num_sent:
                                    if (c.has_data()):
                                        return True
                                for c in self.num_sent_drop:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.num_recv:
                                    if (c.has_operation()):
                                        return True
                                for c in self.num_recv_drop:
                                    if (c.has_operation()):
                                        return True
                                for c in self.num_sent:
                                    if (c.has_operation()):
                                        return True
                                for c in self.num_sent_drop:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ncd-pri" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "num-recv"):
                                    for c in self.num_recv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.num_recv.append(c)
                                    return c

                                if (child_yang_name == "num-recv-drop"):
                                    for c in self.num_recv_drop:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.num_recv_drop.append(c)
                                    return c

                                if (child_yang_name == "num-sent"):
                                    for c in self.num_sent:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSent()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.num_sent.append(c)
                                    return c

                                if (child_yang_name == "num-sent-drop"):
                                    for c in self.num_sent_drop:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.num_sent_drop.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "num-recv" or name == "num-recv-drop" or name == "num-sent" or name == "num-sent-drop"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            for c in self.ncd_pri:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.ncd_pri:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "nsr-pl-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ncd-pri"):
                                for c in self.ncd_pri:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ncd_pri.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ncd-pri"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class NsrStats(Entity):
                        """
                        OSPF NSR thread statistics
                        
                        .. attribute:: nsr_conn_to_active_attempts
                        
                        	nsr conn to active attempts
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_closes
                        
                        	nsr conn to active closes
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_errors
                        
                        	nsr conn to active errors
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_fails
                        
                        	nsr conn to active fails
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_opens
                        
                        	nsr conn to active opens
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_fsm_state
                        
                        	nsr fsm state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_intf_seq_no
                        
                        	nsr intf seq no
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_lsa_init_sync_pend_count
                        
                        	nsr lsa init sync pend count
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_lsa_qad_mdata_count
                        
                        	nsr lsa qad mdata count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_lsa_qad_qid
                        
                        	nsr lsa qad qid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_mtu
                        
                        	nsr mtu
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nbr_init_sync_pend_count
                        
                        	nsr nbr init sync pend count
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_nbr_qad_mdata_count
                        
                        	nsr nbr qad mdata count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nbr_qad_qid
                        
                        	nsr nbr qad qid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nbr_seq_no
                        
                        	nsr nbr seq no
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nodeid
                        
                        	nsr nodeid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_peer_nodeid
                        
                        	nsr peer nodeid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_peer_version
                        
                        	nsr peer version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_rev
                        
                        	nsr rev
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_rtr_thd_sched
                        
                        	nsr rtr thd sched
                        	**type**\:   :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched>`
                        
                        .. attribute:: nsr_thd_sched
                        
                        	nsr thd sched
                        	**type**\:   :py:class:`NsrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched>`
                        
                        .. attribute:: nsr_tmr_quant
                        
                        	nsr tmr quant
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_version
                        
                        	nsr version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats, self).__init__()

                            self.yang_name = "nsr-stats"
                            self.yang_parent_name = "statistics"

                            self.nsr_conn_to_active_attempts = YLeaf(YType.uint64, "nsr-conn-to-active-attempts")

                            self.nsr_conn_to_active_closes = YLeaf(YType.uint64, "nsr-conn-to-active-closes")

                            self.nsr_conn_to_active_errors = YLeaf(YType.uint64, "nsr-conn-to-active-errors")

                            self.nsr_conn_to_active_fails = YLeaf(YType.uint64, "nsr-conn-to-active-fails")

                            self.nsr_conn_to_active_opens = YLeaf(YType.uint64, "nsr-conn-to-active-opens")

                            self.nsr_fsm_state = YLeaf(YType.int32, "nsr-fsm-state")

                            self.nsr_intf_seq_no = YLeaf(YType.uint32, "nsr-intf-seq-no")

                            self.nsr_lsa_init_sync_pend_count = YLeaf(YType.int32, "nsr-lsa-init-sync-pend-count")

                            self.nsr_lsa_qad_mdata_count = YLeaf(YType.uint32, "nsr-lsa-qad-mdata-count")

                            self.nsr_lsa_qad_qid = YLeaf(YType.uint32, "nsr-lsa-qad-qid")

                            self.nsr_mtu = YLeaf(YType.uint32, "nsr-mtu")

                            self.nsr_nbr_init_sync_pend_count = YLeaf(YType.int32, "nsr-nbr-init-sync-pend-count")

                            self.nsr_nbr_qad_mdata_count = YLeaf(YType.uint32, "nsr-nbr-qad-mdata-count")

                            self.nsr_nbr_qad_qid = YLeaf(YType.uint32, "nsr-nbr-qad-qid")

                            self.nsr_nbr_seq_no = YLeaf(YType.uint32, "nsr-nbr-seq-no")

                            self.nsr_nodeid = YLeaf(YType.uint32, "nsr-nodeid")

                            self.nsr_peer_nodeid = YLeaf(YType.uint32, "nsr-peer-nodeid")

                            self.nsr_peer_version = YLeaf(YType.uint32, "nsr-peer-version")

                            self.nsr_rev = YLeaf(YType.int32, "nsr-rev")

                            self.nsr_tmr_quant = YLeaf(YType.int32, "nsr-tmr-quant")

                            self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                            self.nsr_rtr_thd_sched = Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched()
                            self.nsr_rtr_thd_sched.parent = self
                            self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                            self._children_yang_names.add("nsr-rtr-thd-sched")

                            self.nsr_thd_sched = Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched()
                            self.nsr_thd_sched.parent = self
                            self._children_name_map["nsr_thd_sched"] = "nsr-thd-sched"
                            self._children_yang_names.add("nsr-thd-sched")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("nsr_conn_to_active_attempts",
                                            "nsr_conn_to_active_closes",
                                            "nsr_conn_to_active_errors",
                                            "nsr_conn_to_active_fails",
                                            "nsr_conn_to_active_opens",
                                            "nsr_fsm_state",
                                            "nsr_intf_seq_no",
                                            "nsr_lsa_init_sync_pend_count",
                                            "nsr_lsa_qad_mdata_count",
                                            "nsr_lsa_qad_qid",
                                            "nsr_mtu",
                                            "nsr_nbr_init_sync_pend_count",
                                            "nsr_nbr_qad_mdata_count",
                                            "nsr_nbr_qad_qid",
                                            "nsr_nbr_seq_no",
                                            "nsr_nodeid",
                                            "nsr_peer_nodeid",
                                            "nsr_peer_version",
                                            "nsr_rev",
                                            "nsr_tmr_quant",
                                            "nsr_version") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats, self).__setattr__(name, value)


                        class NsrThdSched(Entity):
                            """
                            nsr thd sched
                            
                            .. attribute:: nsr_bad_pulses_rx
                            
                            	nsr bad pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_in_q
                            
                            	nsr events in q
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_events_rx
                            
                            	nsr events rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_tx
                            
                            	nsr events tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_good_pulses_rx
                            
                            	nsr good pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pri
                            
                            	nsr pri
                            	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched.NsrPri>`
                            
                            .. attribute:: nsr_pulse_quant
                            
                            	nsr pulse quant
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_pulse_tx_fails
                            
                            	nsr pulse tx fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pulses_tx
                            
                            	nsr pulses tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched, self).__init__()

                                self.yang_name = "nsr-thd-sched"
                                self.yang_parent_name = "nsr-stats"

                                self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                self.nsr_pri = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nsr_bad_pulses_rx",
                                                "nsr_events_in_q",
                                                "nsr_events_rx",
                                                "nsr_events_tx",
                                                "nsr_good_pulses_rx",
                                                "nsr_pulse_quant",
                                                "nsr_pulse_tx_fails",
                                                "nsr_pulses_tx") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched, self).__setattr__(name, value)


                            class NsrPri(Entity):
                                """
                                nsr pri
                                
                                .. attribute:: nsr_sched_enq_fails
                                
                                	nsr sched enq fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_deqd
                                
                                	nsr sched evs deqd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_in_q
                                
                                	nsr sched evs in q
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_evs_qd
                                
                                	nsr sched evs qd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_max_evs
                                
                                	nsr sched max evs
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_peak_q_len
                                
                                	nsr sched peak q len
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_pri
                                
                                	nsr sched pri
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sched_quant
                                
                                	nsr sched quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nsr_sched_remain_quant
                                
                                	nsr sched remain quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched.NsrPri, self).__init__()

                                    self.yang_name = "nsr-pri"
                                    self.yang_parent_name = "nsr-thd-sched"

                                    self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                    self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                    self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                    self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                    self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                    self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                    self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                    self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                    self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nsr_sched_enq_fails",
                                                    "nsr_sched_evs_deqd",
                                                    "nsr_sched_evs_in_q",
                                                    "nsr_sched_evs_qd",
                                                    "nsr_sched_max_evs",
                                                    "nsr_sched_peak_q_len",
                                                    "nsr_sched_pri",
                                                    "nsr_sched_quant",
                                                    "nsr_sched_remain_quant") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched.NsrPri, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched.NsrPri, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nsr_sched_enq_fails.is_set or
                                        self.nsr_sched_evs_deqd.is_set or
                                        self.nsr_sched_evs_in_q.is_set or
                                        self.nsr_sched_evs_qd.is_set or
                                        self.nsr_sched_max_evs.is_set or
                                        self.nsr_sched_peak_q_len.is_set or
                                        self.nsr_sched_pri.is_set or
                                        self.nsr_sched_quant.is_set or
                                        self.nsr_sched_remain_quant.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nsr_sched_enq_fails.yfilter != YFilter.not_set or
                                        self.nsr_sched_evs_deqd.yfilter != YFilter.not_set or
                                        self.nsr_sched_evs_in_q.yfilter != YFilter.not_set or
                                        self.nsr_sched_evs_qd.yfilter != YFilter.not_set or
                                        self.nsr_sched_max_evs.yfilter != YFilter.not_set or
                                        self.nsr_sched_peak_q_len.yfilter != YFilter.not_set or
                                        self.nsr_sched_pri.yfilter != YFilter.not_set or
                                        self.nsr_sched_quant.yfilter != YFilter.not_set or
                                        self.nsr_sched_remain_quant.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "nsr-pri" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nsr_sched_enq_fails.is_set or self.nsr_sched_enq_fails.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_enq_fails.get_name_leafdata())
                                    if (self.nsr_sched_evs_deqd.is_set or self.nsr_sched_evs_deqd.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_evs_deqd.get_name_leafdata())
                                    if (self.nsr_sched_evs_in_q.is_set or self.nsr_sched_evs_in_q.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_evs_in_q.get_name_leafdata())
                                    if (self.nsr_sched_evs_qd.is_set or self.nsr_sched_evs_qd.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_evs_qd.get_name_leafdata())
                                    if (self.nsr_sched_max_evs.is_set or self.nsr_sched_max_evs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_max_evs.get_name_leafdata())
                                    if (self.nsr_sched_peak_q_len.is_set or self.nsr_sched_peak_q_len.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_peak_q_len.get_name_leafdata())
                                    if (self.nsr_sched_pri.is_set or self.nsr_sched_pri.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_pri.get_name_leafdata())
                                    if (self.nsr_sched_quant.is_set or self.nsr_sched_quant.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_quant.get_name_leafdata())
                                    if (self.nsr_sched_remain_quant.is_set or self.nsr_sched_remain_quant.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_remain_quant.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nsr-sched-enq-fails" or name == "nsr-sched-evs-deqd" or name == "nsr-sched-evs-in-q" or name == "nsr-sched-evs-qd" or name == "nsr-sched-max-evs" or name == "nsr-sched-peak-q-len" or name == "nsr-sched-pri" or name == "nsr-sched-quant" or name == "nsr-sched-remain-quant"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nsr-sched-enq-fails"):
                                        self.nsr_sched_enq_fails = value
                                        self.nsr_sched_enq_fails.value_namespace = name_space
                                        self.nsr_sched_enq_fails.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-evs-deqd"):
                                        self.nsr_sched_evs_deqd = value
                                        self.nsr_sched_evs_deqd.value_namespace = name_space
                                        self.nsr_sched_evs_deqd.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-evs-in-q"):
                                        self.nsr_sched_evs_in_q = value
                                        self.nsr_sched_evs_in_q.value_namespace = name_space
                                        self.nsr_sched_evs_in_q.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-evs-qd"):
                                        self.nsr_sched_evs_qd = value
                                        self.nsr_sched_evs_qd.value_namespace = name_space
                                        self.nsr_sched_evs_qd.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-max-evs"):
                                        self.nsr_sched_max_evs = value
                                        self.nsr_sched_max_evs.value_namespace = name_space
                                        self.nsr_sched_max_evs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-peak-q-len"):
                                        self.nsr_sched_peak_q_len = value
                                        self.nsr_sched_peak_q_len.value_namespace = name_space
                                        self.nsr_sched_peak_q_len.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-pri"):
                                        self.nsr_sched_pri = value
                                        self.nsr_sched_pri.value_namespace = name_space
                                        self.nsr_sched_pri.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-quant"):
                                        self.nsr_sched_quant = value
                                        self.nsr_sched_quant.value_namespace = name_space
                                        self.nsr_sched_quant.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-remain-quant"):
                                        self.nsr_sched_remain_quant = value
                                        self.nsr_sched_remain_quant.value_namespace = name_space
                                        self.nsr_sched_remain_quant.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.nsr_pri:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.nsr_bad_pulses_rx.is_set or
                                    self.nsr_events_in_q.is_set or
                                    self.nsr_events_rx.is_set or
                                    self.nsr_events_tx.is_set or
                                    self.nsr_good_pulses_rx.is_set or
                                    self.nsr_pulse_quant.is_set or
                                    self.nsr_pulse_tx_fails.is_set or
                                    self.nsr_pulses_tx.is_set)

                            def has_operation(self):
                                for c in self.nsr_pri:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nsr_bad_pulses_rx.yfilter != YFilter.not_set or
                                    self.nsr_events_in_q.yfilter != YFilter.not_set or
                                    self.nsr_events_rx.yfilter != YFilter.not_set or
                                    self.nsr_events_tx.yfilter != YFilter.not_set or
                                    self.nsr_good_pulses_rx.yfilter != YFilter.not_set or
                                    self.nsr_pulse_quant.yfilter != YFilter.not_set or
                                    self.nsr_pulse_tx_fails.yfilter != YFilter.not_set or
                                    self.nsr_pulses_tx.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nsr-thd-sched" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nsr_bad_pulses_rx.is_set or self.nsr_bad_pulses_rx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_bad_pulses_rx.get_name_leafdata())
                                if (self.nsr_events_in_q.is_set or self.nsr_events_in_q.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_events_in_q.get_name_leafdata())
                                if (self.nsr_events_rx.is_set or self.nsr_events_rx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_events_rx.get_name_leafdata())
                                if (self.nsr_events_tx.is_set or self.nsr_events_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_events_tx.get_name_leafdata())
                                if (self.nsr_good_pulses_rx.is_set or self.nsr_good_pulses_rx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_good_pulses_rx.get_name_leafdata())
                                if (self.nsr_pulse_quant.is_set or self.nsr_pulse_quant.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_pulse_quant.get_name_leafdata())
                                if (self.nsr_pulse_tx_fails.is_set or self.nsr_pulse_tx_fails.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_pulse_tx_fails.get_name_leafdata())
                                if (self.nsr_pulses_tx.is_set or self.nsr_pulses_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_pulses_tx.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "nsr-pri"):
                                    for c in self.nsr_pri:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched.NsrPri()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.nsr_pri.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nsr-pri" or name == "nsr-bad-pulses-rx" or name == "nsr-events-in-q" or name == "nsr-events-rx" or name == "nsr-events-tx" or name == "nsr-good-pulses-rx" or name == "nsr-pulse-quant" or name == "nsr-pulse-tx-fails" or name == "nsr-pulses-tx"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nsr-bad-pulses-rx"):
                                    self.nsr_bad_pulses_rx = value
                                    self.nsr_bad_pulses_rx.value_namespace = name_space
                                    self.nsr_bad_pulses_rx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-events-in-q"):
                                    self.nsr_events_in_q = value
                                    self.nsr_events_in_q.value_namespace = name_space
                                    self.nsr_events_in_q.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-events-rx"):
                                    self.nsr_events_rx = value
                                    self.nsr_events_rx.value_namespace = name_space
                                    self.nsr_events_rx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-events-tx"):
                                    self.nsr_events_tx = value
                                    self.nsr_events_tx.value_namespace = name_space
                                    self.nsr_events_tx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-good-pulses-rx"):
                                    self.nsr_good_pulses_rx = value
                                    self.nsr_good_pulses_rx.value_namespace = name_space
                                    self.nsr_good_pulses_rx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-pulse-quant"):
                                    self.nsr_pulse_quant = value
                                    self.nsr_pulse_quant.value_namespace = name_space
                                    self.nsr_pulse_quant.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-pulse-tx-fails"):
                                    self.nsr_pulse_tx_fails = value
                                    self.nsr_pulse_tx_fails.value_namespace = name_space
                                    self.nsr_pulse_tx_fails.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-pulses-tx"):
                                    self.nsr_pulses_tx = value
                                    self.nsr_pulses_tx.value_namespace = name_space
                                    self.nsr_pulses_tx.value_namespace_prefix = name_space_prefix


                        class NsrRtrThdSched(Entity):
                            """
                            nsr rtr thd sched
                            
                            .. attribute:: nsr_bad_pulses_rx
                            
                            	nsr bad pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_in_q
                            
                            	nsr events in q
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_events_rx
                            
                            	nsr events rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_tx
                            
                            	nsr events tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_good_pulses_rx
                            
                            	nsr good pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pri
                            
                            	nsr pri
                            	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri>`
                            
                            .. attribute:: nsr_pulse_quant
                            
                            	nsr pulse quant
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_pulse_tx_fails
                            
                            	nsr pulse tx fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pulses_tx
                            
                            	nsr pulses tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched, self).__init__()

                                self.yang_name = "nsr-rtr-thd-sched"
                                self.yang_parent_name = "nsr-stats"

                                self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                self.nsr_pri = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nsr_bad_pulses_rx",
                                                "nsr_events_in_q",
                                                "nsr_events_rx",
                                                "nsr_events_tx",
                                                "nsr_good_pulses_rx",
                                                "nsr_pulse_quant",
                                                "nsr_pulse_tx_fails",
                                                "nsr_pulses_tx") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched, self).__setattr__(name, value)


                            class NsrPri(Entity):
                                """
                                nsr pri
                                
                                .. attribute:: nsr_sched_enq_fails
                                
                                	nsr sched enq fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_deqd
                                
                                	nsr sched evs deqd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_in_q
                                
                                	nsr sched evs in q
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_evs_qd
                                
                                	nsr sched evs qd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_max_evs
                                
                                	nsr sched max evs
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_peak_q_len
                                
                                	nsr sched peak q len
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_pri
                                
                                	nsr sched pri
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sched_quant
                                
                                	nsr sched quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nsr_sched_remain_quant
                                
                                	nsr sched remain quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri, self).__init__()

                                    self.yang_name = "nsr-pri"
                                    self.yang_parent_name = "nsr-rtr-thd-sched"

                                    self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                    self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                    self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                    self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                    self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                    self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                    self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                    self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                    self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nsr_sched_enq_fails",
                                                    "nsr_sched_evs_deqd",
                                                    "nsr_sched_evs_in_q",
                                                    "nsr_sched_evs_qd",
                                                    "nsr_sched_max_evs",
                                                    "nsr_sched_peak_q_len",
                                                    "nsr_sched_pri",
                                                    "nsr_sched_quant",
                                                    "nsr_sched_remain_quant") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nsr_sched_enq_fails.is_set or
                                        self.nsr_sched_evs_deqd.is_set or
                                        self.nsr_sched_evs_in_q.is_set or
                                        self.nsr_sched_evs_qd.is_set or
                                        self.nsr_sched_max_evs.is_set or
                                        self.nsr_sched_peak_q_len.is_set or
                                        self.nsr_sched_pri.is_set or
                                        self.nsr_sched_quant.is_set or
                                        self.nsr_sched_remain_quant.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nsr_sched_enq_fails.yfilter != YFilter.not_set or
                                        self.nsr_sched_evs_deqd.yfilter != YFilter.not_set or
                                        self.nsr_sched_evs_in_q.yfilter != YFilter.not_set or
                                        self.nsr_sched_evs_qd.yfilter != YFilter.not_set or
                                        self.nsr_sched_max_evs.yfilter != YFilter.not_set or
                                        self.nsr_sched_peak_q_len.yfilter != YFilter.not_set or
                                        self.nsr_sched_pri.yfilter != YFilter.not_set or
                                        self.nsr_sched_quant.yfilter != YFilter.not_set or
                                        self.nsr_sched_remain_quant.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "nsr-pri" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nsr_sched_enq_fails.is_set or self.nsr_sched_enq_fails.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_enq_fails.get_name_leafdata())
                                    if (self.nsr_sched_evs_deqd.is_set or self.nsr_sched_evs_deqd.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_evs_deqd.get_name_leafdata())
                                    if (self.nsr_sched_evs_in_q.is_set or self.nsr_sched_evs_in_q.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_evs_in_q.get_name_leafdata())
                                    if (self.nsr_sched_evs_qd.is_set or self.nsr_sched_evs_qd.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_evs_qd.get_name_leafdata())
                                    if (self.nsr_sched_max_evs.is_set or self.nsr_sched_max_evs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_max_evs.get_name_leafdata())
                                    if (self.nsr_sched_peak_q_len.is_set or self.nsr_sched_peak_q_len.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_peak_q_len.get_name_leafdata())
                                    if (self.nsr_sched_pri.is_set or self.nsr_sched_pri.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_pri.get_name_leafdata())
                                    if (self.nsr_sched_quant.is_set or self.nsr_sched_quant.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_quant.get_name_leafdata())
                                    if (self.nsr_sched_remain_quant.is_set or self.nsr_sched_remain_quant.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsr_sched_remain_quant.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nsr-sched-enq-fails" or name == "nsr-sched-evs-deqd" or name == "nsr-sched-evs-in-q" or name == "nsr-sched-evs-qd" or name == "nsr-sched-max-evs" or name == "nsr-sched-peak-q-len" or name == "nsr-sched-pri" or name == "nsr-sched-quant" or name == "nsr-sched-remain-quant"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nsr-sched-enq-fails"):
                                        self.nsr_sched_enq_fails = value
                                        self.nsr_sched_enq_fails.value_namespace = name_space
                                        self.nsr_sched_enq_fails.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-evs-deqd"):
                                        self.nsr_sched_evs_deqd = value
                                        self.nsr_sched_evs_deqd.value_namespace = name_space
                                        self.nsr_sched_evs_deqd.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-evs-in-q"):
                                        self.nsr_sched_evs_in_q = value
                                        self.nsr_sched_evs_in_q.value_namespace = name_space
                                        self.nsr_sched_evs_in_q.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-evs-qd"):
                                        self.nsr_sched_evs_qd = value
                                        self.nsr_sched_evs_qd.value_namespace = name_space
                                        self.nsr_sched_evs_qd.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-max-evs"):
                                        self.nsr_sched_max_evs = value
                                        self.nsr_sched_max_evs.value_namespace = name_space
                                        self.nsr_sched_max_evs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-peak-q-len"):
                                        self.nsr_sched_peak_q_len = value
                                        self.nsr_sched_peak_q_len.value_namespace = name_space
                                        self.nsr_sched_peak_q_len.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-pri"):
                                        self.nsr_sched_pri = value
                                        self.nsr_sched_pri.value_namespace = name_space
                                        self.nsr_sched_pri.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-quant"):
                                        self.nsr_sched_quant = value
                                        self.nsr_sched_quant.value_namespace = name_space
                                        self.nsr_sched_quant.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsr-sched-remain-quant"):
                                        self.nsr_sched_remain_quant = value
                                        self.nsr_sched_remain_quant.value_namespace = name_space
                                        self.nsr_sched_remain_quant.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.nsr_pri:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.nsr_bad_pulses_rx.is_set or
                                    self.nsr_events_in_q.is_set or
                                    self.nsr_events_rx.is_set or
                                    self.nsr_events_tx.is_set or
                                    self.nsr_good_pulses_rx.is_set or
                                    self.nsr_pulse_quant.is_set or
                                    self.nsr_pulse_tx_fails.is_set or
                                    self.nsr_pulses_tx.is_set)

                            def has_operation(self):
                                for c in self.nsr_pri:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nsr_bad_pulses_rx.yfilter != YFilter.not_set or
                                    self.nsr_events_in_q.yfilter != YFilter.not_set or
                                    self.nsr_events_rx.yfilter != YFilter.not_set or
                                    self.nsr_events_tx.yfilter != YFilter.not_set or
                                    self.nsr_good_pulses_rx.yfilter != YFilter.not_set or
                                    self.nsr_pulse_quant.yfilter != YFilter.not_set or
                                    self.nsr_pulse_tx_fails.yfilter != YFilter.not_set or
                                    self.nsr_pulses_tx.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nsr-rtr-thd-sched" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nsr_bad_pulses_rx.is_set or self.nsr_bad_pulses_rx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_bad_pulses_rx.get_name_leafdata())
                                if (self.nsr_events_in_q.is_set or self.nsr_events_in_q.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_events_in_q.get_name_leafdata())
                                if (self.nsr_events_rx.is_set or self.nsr_events_rx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_events_rx.get_name_leafdata())
                                if (self.nsr_events_tx.is_set or self.nsr_events_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_events_tx.get_name_leafdata())
                                if (self.nsr_good_pulses_rx.is_set or self.nsr_good_pulses_rx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_good_pulses_rx.get_name_leafdata())
                                if (self.nsr_pulse_quant.is_set or self.nsr_pulse_quant.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_pulse_quant.get_name_leafdata())
                                if (self.nsr_pulse_tx_fails.is_set or self.nsr_pulse_tx_fails.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_pulse_tx_fails.get_name_leafdata())
                                if (self.nsr_pulses_tx.is_set or self.nsr_pulses_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_pulses_tx.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "nsr-pri"):
                                    for c in self.nsr_pri:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.nsr_pri.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nsr-pri" or name == "nsr-bad-pulses-rx" or name == "nsr-events-in-q" or name == "nsr-events-rx" or name == "nsr-events-tx" or name == "nsr-good-pulses-rx" or name == "nsr-pulse-quant" or name == "nsr-pulse-tx-fails" or name == "nsr-pulses-tx"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nsr-bad-pulses-rx"):
                                    self.nsr_bad_pulses_rx = value
                                    self.nsr_bad_pulses_rx.value_namespace = name_space
                                    self.nsr_bad_pulses_rx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-events-in-q"):
                                    self.nsr_events_in_q = value
                                    self.nsr_events_in_q.value_namespace = name_space
                                    self.nsr_events_in_q.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-events-rx"):
                                    self.nsr_events_rx = value
                                    self.nsr_events_rx.value_namespace = name_space
                                    self.nsr_events_rx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-events-tx"):
                                    self.nsr_events_tx = value
                                    self.nsr_events_tx.value_namespace = name_space
                                    self.nsr_events_tx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-good-pulses-rx"):
                                    self.nsr_good_pulses_rx = value
                                    self.nsr_good_pulses_rx.value_namespace = name_space
                                    self.nsr_good_pulses_rx.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-pulse-quant"):
                                    self.nsr_pulse_quant = value
                                    self.nsr_pulse_quant.value_namespace = name_space
                                    self.nsr_pulse_quant.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-pulse-tx-fails"):
                                    self.nsr_pulse_tx_fails = value
                                    self.nsr_pulse_tx_fails.value_namespace = name_space
                                    self.nsr_pulse_tx_fails.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-pulses-tx"):
                                    self.nsr_pulses_tx = value
                                    self.nsr_pulses_tx.value_namespace = name_space
                                    self.nsr_pulses_tx.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.nsr_conn_to_active_attempts.is_set or
                                self.nsr_conn_to_active_closes.is_set or
                                self.nsr_conn_to_active_errors.is_set or
                                self.nsr_conn_to_active_fails.is_set or
                                self.nsr_conn_to_active_opens.is_set or
                                self.nsr_fsm_state.is_set or
                                self.nsr_intf_seq_no.is_set or
                                self.nsr_lsa_init_sync_pend_count.is_set or
                                self.nsr_lsa_qad_mdata_count.is_set or
                                self.nsr_lsa_qad_qid.is_set or
                                self.nsr_mtu.is_set or
                                self.nsr_nbr_init_sync_pend_count.is_set or
                                self.nsr_nbr_qad_mdata_count.is_set or
                                self.nsr_nbr_qad_qid.is_set or
                                self.nsr_nbr_seq_no.is_set or
                                self.nsr_nodeid.is_set or
                                self.nsr_peer_nodeid.is_set or
                                self.nsr_peer_version.is_set or
                                self.nsr_rev.is_set or
                                self.nsr_tmr_quant.is_set or
                                self.nsr_version.is_set or
                                (self.nsr_rtr_thd_sched is not None and self.nsr_rtr_thd_sched.has_data()) or
                                (self.nsr_thd_sched is not None and self.nsr_thd_sched.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.nsr_conn_to_active_attempts.yfilter != YFilter.not_set or
                                self.nsr_conn_to_active_closes.yfilter != YFilter.not_set or
                                self.nsr_conn_to_active_errors.yfilter != YFilter.not_set or
                                self.nsr_conn_to_active_fails.yfilter != YFilter.not_set or
                                self.nsr_conn_to_active_opens.yfilter != YFilter.not_set or
                                self.nsr_fsm_state.yfilter != YFilter.not_set or
                                self.nsr_intf_seq_no.yfilter != YFilter.not_set or
                                self.nsr_lsa_init_sync_pend_count.yfilter != YFilter.not_set or
                                self.nsr_lsa_qad_mdata_count.yfilter != YFilter.not_set or
                                self.nsr_lsa_qad_qid.yfilter != YFilter.not_set or
                                self.nsr_mtu.yfilter != YFilter.not_set or
                                self.nsr_nbr_init_sync_pend_count.yfilter != YFilter.not_set or
                                self.nsr_nbr_qad_mdata_count.yfilter != YFilter.not_set or
                                self.nsr_nbr_qad_qid.yfilter != YFilter.not_set or
                                self.nsr_nbr_seq_no.yfilter != YFilter.not_set or
                                self.nsr_nodeid.yfilter != YFilter.not_set or
                                self.nsr_peer_nodeid.yfilter != YFilter.not_set or
                                self.nsr_peer_version.yfilter != YFilter.not_set or
                                self.nsr_rev.yfilter != YFilter.not_set or
                                self.nsr_tmr_quant.yfilter != YFilter.not_set or
                                self.nsr_version.yfilter != YFilter.not_set or
                                (self.nsr_rtr_thd_sched is not None and self.nsr_rtr_thd_sched.has_operation()) or
                                (self.nsr_thd_sched is not None and self.nsr_thd_sched.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "nsr-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.nsr_conn_to_active_attempts.is_set or self.nsr_conn_to_active_attempts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_conn_to_active_attempts.get_name_leafdata())
                            if (self.nsr_conn_to_active_closes.is_set or self.nsr_conn_to_active_closes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_conn_to_active_closes.get_name_leafdata())
                            if (self.nsr_conn_to_active_errors.is_set or self.nsr_conn_to_active_errors.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_conn_to_active_errors.get_name_leafdata())
                            if (self.nsr_conn_to_active_fails.is_set or self.nsr_conn_to_active_fails.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_conn_to_active_fails.get_name_leafdata())
                            if (self.nsr_conn_to_active_opens.is_set or self.nsr_conn_to_active_opens.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_conn_to_active_opens.get_name_leafdata())
                            if (self.nsr_fsm_state.is_set or self.nsr_fsm_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_fsm_state.get_name_leafdata())
                            if (self.nsr_intf_seq_no.is_set or self.nsr_intf_seq_no.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_intf_seq_no.get_name_leafdata())
                            if (self.nsr_lsa_init_sync_pend_count.is_set or self.nsr_lsa_init_sync_pend_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_lsa_init_sync_pend_count.get_name_leafdata())
                            if (self.nsr_lsa_qad_mdata_count.is_set or self.nsr_lsa_qad_mdata_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_lsa_qad_mdata_count.get_name_leafdata())
                            if (self.nsr_lsa_qad_qid.is_set or self.nsr_lsa_qad_qid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_lsa_qad_qid.get_name_leafdata())
                            if (self.nsr_mtu.is_set or self.nsr_mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_mtu.get_name_leafdata())
                            if (self.nsr_nbr_init_sync_pend_count.is_set or self.nsr_nbr_init_sync_pend_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_nbr_init_sync_pend_count.get_name_leafdata())
                            if (self.nsr_nbr_qad_mdata_count.is_set or self.nsr_nbr_qad_mdata_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_nbr_qad_mdata_count.get_name_leafdata())
                            if (self.nsr_nbr_qad_qid.is_set or self.nsr_nbr_qad_qid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_nbr_qad_qid.get_name_leafdata())
                            if (self.nsr_nbr_seq_no.is_set or self.nsr_nbr_seq_no.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_nbr_seq_no.get_name_leafdata())
                            if (self.nsr_nodeid.is_set or self.nsr_nodeid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_nodeid.get_name_leafdata())
                            if (self.nsr_peer_nodeid.is_set or self.nsr_peer_nodeid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_peer_nodeid.get_name_leafdata())
                            if (self.nsr_peer_version.is_set or self.nsr_peer_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_peer_version.get_name_leafdata())
                            if (self.nsr_rev.is_set or self.nsr_rev.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_rev.get_name_leafdata())
                            if (self.nsr_tmr_quant.is_set or self.nsr_tmr_quant.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_tmr_quant.get_name_leafdata())
                            if (self.nsr_version.is_set or self.nsr_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_version.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "nsr-rtr-thd-sched"):
                                if (self.nsr_rtr_thd_sched is None):
                                    self.nsr_rtr_thd_sched = Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched()
                                    self.nsr_rtr_thd_sched.parent = self
                                    self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                                return self.nsr_rtr_thd_sched

                            if (child_yang_name == "nsr-thd-sched"):
                                if (self.nsr_thd_sched is None):
                                    self.nsr_thd_sched = Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched()
                                    self.nsr_thd_sched.parent = self
                                    self._children_name_map["nsr_thd_sched"] = "nsr-thd-sched"
                                return self.nsr_thd_sched

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nsr-rtr-thd-sched" or name == "nsr-thd-sched" or name == "nsr-conn-to-active-attempts" or name == "nsr-conn-to-active-closes" or name == "nsr-conn-to-active-errors" or name == "nsr-conn-to-active-fails" or name == "nsr-conn-to-active-opens" or name == "nsr-fsm-state" or name == "nsr-intf-seq-no" or name == "nsr-lsa-init-sync-pend-count" or name == "nsr-lsa-qad-mdata-count" or name == "nsr-lsa-qad-qid" or name == "nsr-mtu" or name == "nsr-nbr-init-sync-pend-count" or name == "nsr-nbr-qad-mdata-count" or name == "nsr-nbr-qad-qid" or name == "nsr-nbr-seq-no" or name == "nsr-nodeid" or name == "nsr-peer-nodeid" or name == "nsr-peer-version" or name == "nsr-rev" or name == "nsr-tmr-quant" or name == "nsr-version"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "nsr-conn-to-active-attempts"):
                                self.nsr_conn_to_active_attempts = value
                                self.nsr_conn_to_active_attempts.value_namespace = name_space
                                self.nsr_conn_to_active_attempts.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-conn-to-active-closes"):
                                self.nsr_conn_to_active_closes = value
                                self.nsr_conn_to_active_closes.value_namespace = name_space
                                self.nsr_conn_to_active_closes.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-conn-to-active-errors"):
                                self.nsr_conn_to_active_errors = value
                                self.nsr_conn_to_active_errors.value_namespace = name_space
                                self.nsr_conn_to_active_errors.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-conn-to-active-fails"):
                                self.nsr_conn_to_active_fails = value
                                self.nsr_conn_to_active_fails.value_namespace = name_space
                                self.nsr_conn_to_active_fails.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-conn-to-active-opens"):
                                self.nsr_conn_to_active_opens = value
                                self.nsr_conn_to_active_opens.value_namespace = name_space
                                self.nsr_conn_to_active_opens.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-fsm-state"):
                                self.nsr_fsm_state = value
                                self.nsr_fsm_state.value_namespace = name_space
                                self.nsr_fsm_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-intf-seq-no"):
                                self.nsr_intf_seq_no = value
                                self.nsr_intf_seq_no.value_namespace = name_space
                                self.nsr_intf_seq_no.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-lsa-init-sync-pend-count"):
                                self.nsr_lsa_init_sync_pend_count = value
                                self.nsr_lsa_init_sync_pend_count.value_namespace = name_space
                                self.nsr_lsa_init_sync_pend_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-lsa-qad-mdata-count"):
                                self.nsr_lsa_qad_mdata_count = value
                                self.nsr_lsa_qad_mdata_count.value_namespace = name_space
                                self.nsr_lsa_qad_mdata_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-lsa-qad-qid"):
                                self.nsr_lsa_qad_qid = value
                                self.nsr_lsa_qad_qid.value_namespace = name_space
                                self.nsr_lsa_qad_qid.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-mtu"):
                                self.nsr_mtu = value
                                self.nsr_mtu.value_namespace = name_space
                                self.nsr_mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-nbr-init-sync-pend-count"):
                                self.nsr_nbr_init_sync_pend_count = value
                                self.nsr_nbr_init_sync_pend_count.value_namespace = name_space
                                self.nsr_nbr_init_sync_pend_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-nbr-qad-mdata-count"):
                                self.nsr_nbr_qad_mdata_count = value
                                self.nsr_nbr_qad_mdata_count.value_namespace = name_space
                                self.nsr_nbr_qad_mdata_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-nbr-qad-qid"):
                                self.nsr_nbr_qad_qid = value
                                self.nsr_nbr_qad_qid.value_namespace = name_space
                                self.nsr_nbr_qad_qid.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-nbr-seq-no"):
                                self.nsr_nbr_seq_no = value
                                self.nsr_nbr_seq_no.value_namespace = name_space
                                self.nsr_nbr_seq_no.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-nodeid"):
                                self.nsr_nodeid = value
                                self.nsr_nodeid.value_namespace = name_space
                                self.nsr_nodeid.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-peer-nodeid"):
                                self.nsr_peer_nodeid = value
                                self.nsr_peer_nodeid.value_namespace = name_space
                                self.nsr_peer_nodeid.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-peer-version"):
                                self.nsr_peer_version = value
                                self.nsr_peer_version.value_namespace = name_space
                                self.nsr_peer_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-rev"):
                                self.nsr_rev = value
                                self.nsr_rev.value_namespace = name_space
                                self.nsr_rev.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-tmr-quant"):
                                self.nsr_tmr_quant = value
                                self.nsr_tmr_quant.value_namespace = name_space
                                self.nsr_tmr_quant.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-version"):
                                self.nsr_version = value
                                self.nsr_version.value_namespace = name_space
                                self.nsr_version.value_namespace_prefix = name_space_prefix


                    class FrrStats(Entity):
                        """
                        OSPF fast\-reroute statistics
                        
                        .. attribute:: fs_paths
                        
                        	Number of IPFRR paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fs_paths_eligible
                        
                        	Number of paths enabled for protection
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fs_paths_protected
                        
                        	Number of paths protected
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.FrrStats, self).__init__()

                            self.yang_name = "frr-stats"
                            self.yang_parent_name = "statistics"

                            self.fs_paths = YLeaf(YType.uint32, "fs-paths")

                            self.fs_paths_eligible = YLeaf(YType.uint32, "fs-paths-eligible")

                            self.fs_paths_protected = YLeaf(YType.uint32, "fs-paths-protected")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("fs_paths",
                                            "fs_paths_eligible",
                                            "fs_paths_protected") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.FrrStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.FrrStats, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.fs_paths.is_set or
                                self.fs_paths_eligible.is_set or
                                self.fs_paths_protected.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.fs_paths.yfilter != YFilter.not_set or
                                self.fs_paths_eligible.yfilter != YFilter.not_set or
                                self.fs_paths_protected.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "frr-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.fs_paths.is_set or self.fs_paths.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fs_paths.get_name_leafdata())
                            if (self.fs_paths_eligible.is_set or self.fs_paths_eligible.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fs_paths_eligible.get_name_leafdata())
                            if (self.fs_paths_protected.is_set or self.fs_paths_protected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fs_paths_protected.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "fs-paths" or name == "fs-paths-eligible" or name == "fs-paths-protected"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "fs-paths"):
                                self.fs_paths = value
                                self.fs_paths.value_namespace = name_space
                                self.fs_paths.value_namespace_prefix = name_space_prefix
                            if(value_path == "fs-paths-eligible"):
                                self.fs_paths_eligible = value
                                self.fs_paths_eligible.value_namespace = name_space
                                self.fs_paths_eligible.value_namespace_prefix = name_space_prefix
                            if(value_path == "fs-paths-protected"):
                                self.fs_paths_protected = value
                                self.fs_paths_protected.value_namespace = name_space
                                self.fs_paths_protected.value_namespace_prefix = name_space_prefix


                    class TeStats(Entity):
                        """
                        OSPF TE IO statistics
                        
                        .. attribute:: adj_changes
                        
                        	adj changes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: adj_gets
                        
                        	adj gets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: control_batch_reads
                        
                        	control batch reads
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: control_batch_writes
                        
                        	control batch writes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: control_disconnects
                        
                        	control disconnects
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: data_trans_completes
                        
                        	data trans completes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fragment_announces
                        
                        	fragment announces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fragment_deletes
                        
                        	fragment deletes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: link_batch_reads
                        
                        	link batch reads
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: link_batch_writes
                        
                        	link batch writes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: link_floods
                        
                        	link floods
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: link_fragment_floods
                        
                        	link fragment floods
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsp_gets
                        
                        	lsp gets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_br_lkup_num_dests
                        
                        	pce br lkup num dests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_br_lookup
                        
                        	pce br lookup
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_br_resp_fails
                        
                        	pce br resp fails
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_flood
                        
                        	pce flood
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_get
                        
                        	pce get
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_listen
                        
                        	pce listen
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_node_announce_batches
                        
                        	pce node announce batches
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_node_delete_batches
                        
                        	pce node delete batches
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_node_send_fails
                        
                        	pce node send fails
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_num_node_announce
                        
                        	pce num node announce
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_num_node_delete
                        
                        	pce num node delete
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_stoplisten
                        
                        	pce stoplisten
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sr_num_area_enabled
                        
                        	sr num area enabled
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: te_connected
                        
                        	te connected
                        	**type**\:  bool
                        
                        .. attribute:: te_disconnects
                        
                        	te disconnects
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: te_sr_idt_sent
                        
                        	te sr idt sent
                        	**type**\:  bool
                        
                        .. attribute:: te_sr_path_reg_idt_recvd
                        
                        	te sr path reg idt recvd
                        	**type**\:  bool
                        
                        .. attribute:: total_tunnels
                        
                        	total tunnels
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_announces
                        
                        	tunnel announces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.TeStats, self).__init__()

                            self.yang_name = "te-stats"
                            self.yang_parent_name = "statistics"

                            self.adj_changes = YLeaf(YType.uint32, "adj-changes")

                            self.adj_gets = YLeaf(YType.uint32, "adj-gets")

                            self.control_batch_reads = YLeaf(YType.uint32, "control-batch-reads")

                            self.control_batch_writes = YLeaf(YType.uint32, "control-batch-writes")

                            self.control_disconnects = YLeaf(YType.uint32, "control-disconnects")

                            self.data_trans_completes = YLeaf(YType.uint32, "data-trans-completes")

                            self.fragment_announces = YLeaf(YType.uint32, "fragment-announces")

                            self.fragment_deletes = YLeaf(YType.uint32, "fragment-deletes")

                            self.link_batch_reads = YLeaf(YType.uint32, "link-batch-reads")

                            self.link_batch_writes = YLeaf(YType.uint32, "link-batch-writes")

                            self.link_floods = YLeaf(YType.uint32, "link-floods")

                            self.link_fragment_floods = YLeaf(YType.uint32, "link-fragment-floods")

                            self.lsp_gets = YLeaf(YType.uint32, "lsp-gets")

                            self.pce_br_lkup_num_dests = YLeaf(YType.uint32, "pce-br-lkup-num-dests")

                            self.pce_br_lookup = YLeaf(YType.uint32, "pce-br-lookup")

                            self.pce_br_resp_fails = YLeaf(YType.uint32, "pce-br-resp-fails")

                            self.pce_flood = YLeaf(YType.uint32, "pce-flood")

                            self.pce_get = YLeaf(YType.uint32, "pce-get")

                            self.pce_listen = YLeaf(YType.uint32, "pce-listen")

                            self.pce_node_announce_batches = YLeaf(YType.uint32, "pce-node-announce-batches")

                            self.pce_node_delete_batches = YLeaf(YType.uint32, "pce-node-delete-batches")

                            self.pce_node_send_fails = YLeaf(YType.uint32, "pce-node-send-fails")

                            self.pce_num_node_announce = YLeaf(YType.uint32, "pce-num-node-announce")

                            self.pce_num_node_delete = YLeaf(YType.uint32, "pce-num-node-delete")

                            self.pce_stoplisten = YLeaf(YType.uint32, "pce-stoplisten")

                            self.sr_num_area_enabled = YLeaf(YType.uint32, "sr-num-area-enabled")

                            self.te_connected = YLeaf(YType.boolean, "te-connected")

                            self.te_disconnects = YLeaf(YType.uint32, "te-disconnects")

                            self.te_sr_idt_sent = YLeaf(YType.boolean, "te-sr-idt-sent")

                            self.te_sr_path_reg_idt_recvd = YLeaf(YType.boolean, "te-sr-path-reg-idt-recvd")

                            self.total_tunnels = YLeaf(YType.uint32, "total-tunnels")

                            self.tunnel_announces = YLeaf(YType.uint32, "tunnel-announces")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("adj_changes",
                                            "adj_gets",
                                            "control_batch_reads",
                                            "control_batch_writes",
                                            "control_disconnects",
                                            "data_trans_completes",
                                            "fragment_announces",
                                            "fragment_deletes",
                                            "link_batch_reads",
                                            "link_batch_writes",
                                            "link_floods",
                                            "link_fragment_floods",
                                            "lsp_gets",
                                            "pce_br_lkup_num_dests",
                                            "pce_br_lookup",
                                            "pce_br_resp_fails",
                                            "pce_flood",
                                            "pce_get",
                                            "pce_listen",
                                            "pce_node_announce_batches",
                                            "pce_node_delete_batches",
                                            "pce_node_send_fails",
                                            "pce_num_node_announce",
                                            "pce_num_node_delete",
                                            "pce_stoplisten",
                                            "sr_num_area_enabled",
                                            "te_connected",
                                            "te_disconnects",
                                            "te_sr_idt_sent",
                                            "te_sr_path_reg_idt_recvd",
                                            "total_tunnels",
                                            "tunnel_announces") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.TeStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.TeStats, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.adj_changes.is_set or
                                self.adj_gets.is_set or
                                self.control_batch_reads.is_set or
                                self.control_batch_writes.is_set or
                                self.control_disconnects.is_set or
                                self.data_trans_completes.is_set or
                                self.fragment_announces.is_set or
                                self.fragment_deletes.is_set or
                                self.link_batch_reads.is_set or
                                self.link_batch_writes.is_set or
                                self.link_floods.is_set or
                                self.link_fragment_floods.is_set or
                                self.lsp_gets.is_set or
                                self.pce_br_lkup_num_dests.is_set or
                                self.pce_br_lookup.is_set or
                                self.pce_br_resp_fails.is_set or
                                self.pce_flood.is_set or
                                self.pce_get.is_set or
                                self.pce_listen.is_set or
                                self.pce_node_announce_batches.is_set or
                                self.pce_node_delete_batches.is_set or
                                self.pce_node_send_fails.is_set or
                                self.pce_num_node_announce.is_set or
                                self.pce_num_node_delete.is_set or
                                self.pce_stoplisten.is_set or
                                self.sr_num_area_enabled.is_set or
                                self.te_connected.is_set or
                                self.te_disconnects.is_set or
                                self.te_sr_idt_sent.is_set or
                                self.te_sr_path_reg_idt_recvd.is_set or
                                self.total_tunnels.is_set or
                                self.tunnel_announces.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.adj_changes.yfilter != YFilter.not_set or
                                self.adj_gets.yfilter != YFilter.not_set or
                                self.control_batch_reads.yfilter != YFilter.not_set or
                                self.control_batch_writes.yfilter != YFilter.not_set or
                                self.control_disconnects.yfilter != YFilter.not_set or
                                self.data_trans_completes.yfilter != YFilter.not_set or
                                self.fragment_announces.yfilter != YFilter.not_set or
                                self.fragment_deletes.yfilter != YFilter.not_set or
                                self.link_batch_reads.yfilter != YFilter.not_set or
                                self.link_batch_writes.yfilter != YFilter.not_set or
                                self.link_floods.yfilter != YFilter.not_set or
                                self.link_fragment_floods.yfilter != YFilter.not_set or
                                self.lsp_gets.yfilter != YFilter.not_set or
                                self.pce_br_lkup_num_dests.yfilter != YFilter.not_set or
                                self.pce_br_lookup.yfilter != YFilter.not_set or
                                self.pce_br_resp_fails.yfilter != YFilter.not_set or
                                self.pce_flood.yfilter != YFilter.not_set or
                                self.pce_get.yfilter != YFilter.not_set or
                                self.pce_listen.yfilter != YFilter.not_set or
                                self.pce_node_announce_batches.yfilter != YFilter.not_set or
                                self.pce_node_delete_batches.yfilter != YFilter.not_set or
                                self.pce_node_send_fails.yfilter != YFilter.not_set or
                                self.pce_num_node_announce.yfilter != YFilter.not_set or
                                self.pce_num_node_delete.yfilter != YFilter.not_set or
                                self.pce_stoplisten.yfilter != YFilter.not_set or
                                self.sr_num_area_enabled.yfilter != YFilter.not_set or
                                self.te_connected.yfilter != YFilter.not_set or
                                self.te_disconnects.yfilter != YFilter.not_set or
                                self.te_sr_idt_sent.yfilter != YFilter.not_set or
                                self.te_sr_path_reg_idt_recvd.yfilter != YFilter.not_set or
                                self.total_tunnels.yfilter != YFilter.not_set or
                                self.tunnel_announces.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "te-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.adj_changes.is_set or self.adj_changes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.adj_changes.get_name_leafdata())
                            if (self.adj_gets.is_set or self.adj_gets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.adj_gets.get_name_leafdata())
                            if (self.control_batch_reads.is_set or self.control_batch_reads.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.control_batch_reads.get_name_leafdata())
                            if (self.control_batch_writes.is_set or self.control_batch_writes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.control_batch_writes.get_name_leafdata())
                            if (self.control_disconnects.is_set or self.control_disconnects.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.control_disconnects.get_name_leafdata())
                            if (self.data_trans_completes.is_set or self.data_trans_completes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_trans_completes.get_name_leafdata())
                            if (self.fragment_announces.is_set or self.fragment_announces.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fragment_announces.get_name_leafdata())
                            if (self.fragment_deletes.is_set or self.fragment_deletes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fragment_deletes.get_name_leafdata())
                            if (self.link_batch_reads.is_set or self.link_batch_reads.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.link_batch_reads.get_name_leafdata())
                            if (self.link_batch_writes.is_set or self.link_batch_writes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.link_batch_writes.get_name_leafdata())
                            if (self.link_floods.is_set or self.link_floods.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.link_floods.get_name_leafdata())
                            if (self.link_fragment_floods.is_set or self.link_fragment_floods.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.link_fragment_floods.get_name_leafdata())
                            if (self.lsp_gets.is_set or self.lsp_gets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsp_gets.get_name_leafdata())
                            if (self.pce_br_lkup_num_dests.is_set or self.pce_br_lkup_num_dests.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pce_br_lkup_num_dests.get_name_leafdata())
                            if (self.pce_br_lookup.is_set or self.pce_br_lookup.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pce_br_lookup.get_name_leafdata())
                            if (self.pce_br_resp_fails.is_set or self.pce_br_resp_fails.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pce_br_resp_fails.get_name_leafdata())
                            if (self.pce_flood.is_set or self.pce_flood.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pce_flood.get_name_leafdata())
                            if (self.pce_get.is_set or self.pce_get.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pce_get.get_name_leafdata())
                            if (self.pce_listen.is_set or self.pce_listen.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pce_listen.get_name_leafdata())
                            if (self.pce_node_announce_batches.is_set or self.pce_node_announce_batches.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pce_node_announce_batches.get_name_leafdata())
                            if (self.pce_node_delete_batches.is_set or self.pce_node_delete_batches.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pce_node_delete_batches.get_name_leafdata())
                            if (self.pce_node_send_fails.is_set or self.pce_node_send_fails.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pce_node_send_fails.get_name_leafdata())
                            if (self.pce_num_node_announce.is_set or self.pce_num_node_announce.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pce_num_node_announce.get_name_leafdata())
                            if (self.pce_num_node_delete.is_set or self.pce_num_node_delete.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pce_num_node_delete.get_name_leafdata())
                            if (self.pce_stoplisten.is_set or self.pce_stoplisten.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pce_stoplisten.get_name_leafdata())
                            if (self.sr_num_area_enabled.is_set or self.sr_num_area_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sr_num_area_enabled.get_name_leafdata())
                            if (self.te_connected.is_set or self.te_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.te_connected.get_name_leafdata())
                            if (self.te_disconnects.is_set or self.te_disconnects.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.te_disconnects.get_name_leafdata())
                            if (self.te_sr_idt_sent.is_set or self.te_sr_idt_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.te_sr_idt_sent.get_name_leafdata())
                            if (self.te_sr_path_reg_idt_recvd.is_set or self.te_sr_path_reg_idt_recvd.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.te_sr_path_reg_idt_recvd.get_name_leafdata())
                            if (self.total_tunnels.is_set or self.total_tunnels.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_tunnels.get_name_leafdata())
                            if (self.tunnel_announces.is_set or self.tunnel_announces.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_announces.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "adj-changes" or name == "adj-gets" or name == "control-batch-reads" or name == "control-batch-writes" or name == "control-disconnects" or name == "data-trans-completes" or name == "fragment-announces" or name == "fragment-deletes" or name == "link-batch-reads" or name == "link-batch-writes" or name == "link-floods" or name == "link-fragment-floods" or name == "lsp-gets" or name == "pce-br-lkup-num-dests" or name == "pce-br-lookup" or name == "pce-br-resp-fails" or name == "pce-flood" or name == "pce-get" or name == "pce-listen" or name == "pce-node-announce-batches" or name == "pce-node-delete-batches" or name == "pce-node-send-fails" or name == "pce-num-node-announce" or name == "pce-num-node-delete" or name == "pce-stoplisten" or name == "sr-num-area-enabled" or name == "te-connected" or name == "te-disconnects" or name == "te-sr-idt-sent" or name == "te-sr-path-reg-idt-recvd" or name == "total-tunnels" or name == "tunnel-announces"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "adj-changes"):
                                self.adj_changes = value
                                self.adj_changes.value_namespace = name_space
                                self.adj_changes.value_namespace_prefix = name_space_prefix
                            if(value_path == "adj-gets"):
                                self.adj_gets = value
                                self.adj_gets.value_namespace = name_space
                                self.adj_gets.value_namespace_prefix = name_space_prefix
                            if(value_path == "control-batch-reads"):
                                self.control_batch_reads = value
                                self.control_batch_reads.value_namespace = name_space
                                self.control_batch_reads.value_namespace_prefix = name_space_prefix
                            if(value_path == "control-batch-writes"):
                                self.control_batch_writes = value
                                self.control_batch_writes.value_namespace = name_space
                                self.control_batch_writes.value_namespace_prefix = name_space_prefix
                            if(value_path == "control-disconnects"):
                                self.control_disconnects = value
                                self.control_disconnects.value_namespace = name_space
                                self.control_disconnects.value_namespace_prefix = name_space_prefix
                            if(value_path == "data-trans-completes"):
                                self.data_trans_completes = value
                                self.data_trans_completes.value_namespace = name_space
                                self.data_trans_completes.value_namespace_prefix = name_space_prefix
                            if(value_path == "fragment-announces"):
                                self.fragment_announces = value
                                self.fragment_announces.value_namespace = name_space
                                self.fragment_announces.value_namespace_prefix = name_space_prefix
                            if(value_path == "fragment-deletes"):
                                self.fragment_deletes = value
                                self.fragment_deletes.value_namespace = name_space
                                self.fragment_deletes.value_namespace_prefix = name_space_prefix
                            if(value_path == "link-batch-reads"):
                                self.link_batch_reads = value
                                self.link_batch_reads.value_namespace = name_space
                                self.link_batch_reads.value_namespace_prefix = name_space_prefix
                            if(value_path == "link-batch-writes"):
                                self.link_batch_writes = value
                                self.link_batch_writes.value_namespace = name_space
                                self.link_batch_writes.value_namespace_prefix = name_space_prefix
                            if(value_path == "link-floods"):
                                self.link_floods = value
                                self.link_floods.value_namespace = name_space
                                self.link_floods.value_namespace_prefix = name_space_prefix
                            if(value_path == "link-fragment-floods"):
                                self.link_fragment_floods = value
                                self.link_fragment_floods.value_namespace = name_space
                                self.link_fragment_floods.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsp-gets"):
                                self.lsp_gets = value
                                self.lsp_gets.value_namespace = name_space
                                self.lsp_gets.value_namespace_prefix = name_space_prefix
                            if(value_path == "pce-br-lkup-num-dests"):
                                self.pce_br_lkup_num_dests = value
                                self.pce_br_lkup_num_dests.value_namespace = name_space
                                self.pce_br_lkup_num_dests.value_namespace_prefix = name_space_prefix
                            if(value_path == "pce-br-lookup"):
                                self.pce_br_lookup = value
                                self.pce_br_lookup.value_namespace = name_space
                                self.pce_br_lookup.value_namespace_prefix = name_space_prefix
                            if(value_path == "pce-br-resp-fails"):
                                self.pce_br_resp_fails = value
                                self.pce_br_resp_fails.value_namespace = name_space
                                self.pce_br_resp_fails.value_namespace_prefix = name_space_prefix
                            if(value_path == "pce-flood"):
                                self.pce_flood = value
                                self.pce_flood.value_namespace = name_space
                                self.pce_flood.value_namespace_prefix = name_space_prefix
                            if(value_path == "pce-get"):
                                self.pce_get = value
                                self.pce_get.value_namespace = name_space
                                self.pce_get.value_namespace_prefix = name_space_prefix
                            if(value_path == "pce-listen"):
                                self.pce_listen = value
                                self.pce_listen.value_namespace = name_space
                                self.pce_listen.value_namespace_prefix = name_space_prefix
                            if(value_path == "pce-node-announce-batches"):
                                self.pce_node_announce_batches = value
                                self.pce_node_announce_batches.value_namespace = name_space
                                self.pce_node_announce_batches.value_namespace_prefix = name_space_prefix
                            if(value_path == "pce-node-delete-batches"):
                                self.pce_node_delete_batches = value
                                self.pce_node_delete_batches.value_namespace = name_space
                                self.pce_node_delete_batches.value_namespace_prefix = name_space_prefix
                            if(value_path == "pce-node-send-fails"):
                                self.pce_node_send_fails = value
                                self.pce_node_send_fails.value_namespace = name_space
                                self.pce_node_send_fails.value_namespace_prefix = name_space_prefix
                            if(value_path == "pce-num-node-announce"):
                                self.pce_num_node_announce = value
                                self.pce_num_node_announce.value_namespace = name_space
                                self.pce_num_node_announce.value_namespace_prefix = name_space_prefix
                            if(value_path == "pce-num-node-delete"):
                                self.pce_num_node_delete = value
                                self.pce_num_node_delete.value_namespace = name_space
                                self.pce_num_node_delete.value_namespace_prefix = name_space_prefix
                            if(value_path == "pce-stoplisten"):
                                self.pce_stoplisten = value
                                self.pce_stoplisten.value_namespace = name_space
                                self.pce_stoplisten.value_namespace_prefix = name_space_prefix
                            if(value_path == "sr-num-area-enabled"):
                                self.sr_num_area_enabled = value
                                self.sr_num_area_enabled.value_namespace = name_space
                                self.sr_num_area_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "te-connected"):
                                self.te_connected = value
                                self.te_connected.value_namespace = name_space
                                self.te_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "te-disconnects"):
                                self.te_disconnects = value
                                self.te_disconnects.value_namespace = name_space
                                self.te_disconnects.value_namespace_prefix = name_space_prefix
                            if(value_path == "te-sr-idt-sent"):
                                self.te_sr_idt_sent = value
                                self.te_sr_idt_sent.value_namespace = name_space
                                self.te_sr_idt_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "te-sr-path-reg-idt-recvd"):
                                self.te_sr_path_reg_idt_recvd = value
                                self.te_sr_path_reg_idt_recvd.value_namespace = name_space
                                self.te_sr_path_reg_idt_recvd.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-tunnels"):
                                self.total_tunnels = value
                                self.total_tunnels.value_namespace = name_space
                                self.total_tunnels.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-announces"):
                                self.tunnel_announces = value
                                self.tunnel_announces.value_namespace = name_space
                                self.tunnel_announces.value_namespace_prefix = name_space_prefix


                    class ProtocolStats(Entity):
                        """
                        OSPF Protocol statistics
                        
                        .. attribute:: checksumerr
                        
                        	checksumerr
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: h_input_ack
                        
                        	h input ack
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: h_input_dbdes
                        
                        	h input dbdes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: h_input_lsupd
                        
                        	h input lsupd
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: h_input_req
                        
                        	h input req
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_ack
                        
                        	input ack
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_ack_lsa
                        
                        	input ack lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_autherr
                        
                        	input autherr
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_dbdes
                        
                        	input dbdes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_dbdes_lsa
                        
                        	input dbdes lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	input hello
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_lsupd
                        
                        	input lsupd
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_lsupd_lsa
                        
                        	input lsupd lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_req
                        
                        	input req
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_req_lsa
                        
                        	input req lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: inputs
                        
                        	inputs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_ack
                        
                        	output ack
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_ack_lsa
                        
                        	output ack lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_autherr
                        
                        	output autherr
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_dbdes
                        
                        	output dbdes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_dbdes_lsa
                        
                        	output dbdes lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	output hello
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_lsupd
                        
                        	output lsupd
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_lsupd_lsa
                        
                        	output lsupd lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_req
                        
                        	output req
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_req_lsa
                        
                        	output req lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: outputs
                        
                        	outputs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.ProtocolStats, self).__init__()

                            self.yang_name = "protocol-stats"
                            self.yang_parent_name = "statistics"

                            self.checksumerr = YLeaf(YType.uint32, "checksumerr")

                            self.h_input_ack = YLeaf(YType.uint32, "h-input-ack")

                            self.h_input_dbdes = YLeaf(YType.uint32, "h-input-dbdes")

                            self.h_input_lsupd = YLeaf(YType.uint32, "h-input-lsupd")

                            self.h_input_req = YLeaf(YType.uint32, "h-input-req")

                            self.input_ack = YLeaf(YType.uint32, "input-ack")

                            self.input_ack_lsa = YLeaf(YType.uint32, "input-ack-lsa")

                            self.input_autherr = YLeaf(YType.uint32, "input-autherr")

                            self.input_dbdes = YLeaf(YType.uint32, "input-dbdes")

                            self.input_dbdes_lsa = YLeaf(YType.uint32, "input-dbdes-lsa")

                            self.input_hello = YLeaf(YType.uint32, "input-hello")

                            self.input_lsupd = YLeaf(YType.uint32, "input-lsupd")

                            self.input_lsupd_lsa = YLeaf(YType.uint32, "input-lsupd-lsa")

                            self.input_req = YLeaf(YType.uint32, "input-req")

                            self.input_req_lsa = YLeaf(YType.uint32, "input-req-lsa")

                            self.inputs = YLeaf(YType.uint32, "inputs")

                            self.output_ack = YLeaf(YType.uint32, "output-ack")

                            self.output_ack_lsa = YLeaf(YType.uint32, "output-ack-lsa")

                            self.output_autherr = YLeaf(YType.uint32, "output-autherr")

                            self.output_dbdes = YLeaf(YType.uint32, "output-dbdes")

                            self.output_dbdes_lsa = YLeaf(YType.uint32, "output-dbdes-lsa")

                            self.output_hello = YLeaf(YType.uint32, "output-hello")

                            self.output_lsupd = YLeaf(YType.uint32, "output-lsupd")

                            self.output_lsupd_lsa = YLeaf(YType.uint32, "output-lsupd-lsa")

                            self.output_req = YLeaf(YType.uint32, "output-req")

                            self.output_req_lsa = YLeaf(YType.uint32, "output-req-lsa")

                            self.outputs = YLeaf(YType.uint32, "outputs")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("checksumerr",
                                            "h_input_ack",
                                            "h_input_dbdes",
                                            "h_input_lsupd",
                                            "h_input_req",
                                            "input_ack",
                                            "input_ack_lsa",
                                            "input_autherr",
                                            "input_dbdes",
                                            "input_dbdes_lsa",
                                            "input_hello",
                                            "input_lsupd",
                                            "input_lsupd_lsa",
                                            "input_req",
                                            "input_req_lsa",
                                            "inputs",
                                            "output_ack",
                                            "output_ack_lsa",
                                            "output_autherr",
                                            "output_dbdes",
                                            "output_dbdes_lsa",
                                            "output_hello",
                                            "output_lsupd",
                                            "output_lsupd_lsa",
                                            "output_req",
                                            "output_req_lsa",
                                            "outputs") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.ProtocolStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.ProtocolStats, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.checksumerr.is_set or
                                self.h_input_ack.is_set or
                                self.h_input_dbdes.is_set or
                                self.h_input_lsupd.is_set or
                                self.h_input_req.is_set or
                                self.input_ack.is_set or
                                self.input_ack_lsa.is_set or
                                self.input_autherr.is_set or
                                self.input_dbdes.is_set or
                                self.input_dbdes_lsa.is_set or
                                self.input_hello.is_set or
                                self.input_lsupd.is_set or
                                self.input_lsupd_lsa.is_set or
                                self.input_req.is_set or
                                self.input_req_lsa.is_set or
                                self.inputs.is_set or
                                self.output_ack.is_set or
                                self.output_ack_lsa.is_set or
                                self.output_autherr.is_set or
                                self.output_dbdes.is_set or
                                self.output_dbdes_lsa.is_set or
                                self.output_hello.is_set or
                                self.output_lsupd.is_set or
                                self.output_lsupd_lsa.is_set or
                                self.output_req.is_set or
                                self.output_req_lsa.is_set or
                                self.outputs.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.checksumerr.yfilter != YFilter.not_set or
                                self.h_input_ack.yfilter != YFilter.not_set or
                                self.h_input_dbdes.yfilter != YFilter.not_set or
                                self.h_input_lsupd.yfilter != YFilter.not_set or
                                self.h_input_req.yfilter != YFilter.not_set or
                                self.input_ack.yfilter != YFilter.not_set or
                                self.input_ack_lsa.yfilter != YFilter.not_set or
                                self.input_autherr.yfilter != YFilter.not_set or
                                self.input_dbdes.yfilter != YFilter.not_set or
                                self.input_dbdes_lsa.yfilter != YFilter.not_set or
                                self.input_hello.yfilter != YFilter.not_set or
                                self.input_lsupd.yfilter != YFilter.not_set or
                                self.input_lsupd_lsa.yfilter != YFilter.not_set or
                                self.input_req.yfilter != YFilter.not_set or
                                self.input_req_lsa.yfilter != YFilter.not_set or
                                self.inputs.yfilter != YFilter.not_set or
                                self.output_ack.yfilter != YFilter.not_set or
                                self.output_ack_lsa.yfilter != YFilter.not_set or
                                self.output_autherr.yfilter != YFilter.not_set or
                                self.output_dbdes.yfilter != YFilter.not_set or
                                self.output_dbdes_lsa.yfilter != YFilter.not_set or
                                self.output_hello.yfilter != YFilter.not_set or
                                self.output_lsupd.yfilter != YFilter.not_set or
                                self.output_lsupd_lsa.yfilter != YFilter.not_set or
                                self.output_req.yfilter != YFilter.not_set or
                                self.output_req_lsa.yfilter != YFilter.not_set or
                                self.outputs.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "protocol-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.checksumerr.is_set or self.checksumerr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.checksumerr.get_name_leafdata())
                            if (self.h_input_ack.is_set or self.h_input_ack.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.h_input_ack.get_name_leafdata())
                            if (self.h_input_dbdes.is_set or self.h_input_dbdes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.h_input_dbdes.get_name_leafdata())
                            if (self.h_input_lsupd.is_set or self.h_input_lsupd.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.h_input_lsupd.get_name_leafdata())
                            if (self.h_input_req.is_set or self.h_input_req.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.h_input_req.get_name_leafdata())
                            if (self.input_ack.is_set or self.input_ack.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_ack.get_name_leafdata())
                            if (self.input_ack_lsa.is_set or self.input_ack_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_ack_lsa.get_name_leafdata())
                            if (self.input_autherr.is_set or self.input_autherr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_autherr.get_name_leafdata())
                            if (self.input_dbdes.is_set or self.input_dbdes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_dbdes.get_name_leafdata())
                            if (self.input_dbdes_lsa.is_set or self.input_dbdes_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_dbdes_lsa.get_name_leafdata())
                            if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_hello.get_name_leafdata())
                            if (self.input_lsupd.is_set or self.input_lsupd.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_lsupd.get_name_leafdata())
                            if (self.input_lsupd_lsa.is_set or self.input_lsupd_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_lsupd_lsa.get_name_leafdata())
                            if (self.input_req.is_set or self.input_req.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_req.get_name_leafdata())
                            if (self.input_req_lsa.is_set or self.input_req_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_req_lsa.get_name_leafdata())
                            if (self.inputs.is_set or self.inputs.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.inputs.get_name_leafdata())
                            if (self.output_ack.is_set or self.output_ack.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_ack.get_name_leafdata())
                            if (self.output_ack_lsa.is_set or self.output_ack_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_ack_lsa.get_name_leafdata())
                            if (self.output_autherr.is_set or self.output_autherr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_autherr.get_name_leafdata())
                            if (self.output_dbdes.is_set or self.output_dbdes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_dbdes.get_name_leafdata())
                            if (self.output_dbdes_lsa.is_set or self.output_dbdes_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_dbdes_lsa.get_name_leafdata())
                            if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_hello.get_name_leafdata())
                            if (self.output_lsupd.is_set or self.output_lsupd.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_lsupd.get_name_leafdata())
                            if (self.output_lsupd_lsa.is_set or self.output_lsupd_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_lsupd_lsa.get_name_leafdata())
                            if (self.output_req.is_set or self.output_req.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_req.get_name_leafdata())
                            if (self.output_req_lsa.is_set or self.output_req_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_req_lsa.get_name_leafdata())
                            if (self.outputs.is_set or self.outputs.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.outputs.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "checksumerr" or name == "h-input-ack" or name == "h-input-dbdes" or name == "h-input-lsupd" or name == "h-input-req" or name == "input-ack" or name == "input-ack-lsa" or name == "input-autherr" or name == "input-dbdes" or name == "input-dbdes-lsa" or name == "input-hello" or name == "input-lsupd" or name == "input-lsupd-lsa" or name == "input-req" or name == "input-req-lsa" or name == "inputs" or name == "output-ack" or name == "output-ack-lsa" or name == "output-autherr" or name == "output-dbdes" or name == "output-dbdes-lsa" or name == "output-hello" or name == "output-lsupd" or name == "output-lsupd-lsa" or name == "output-req" or name == "output-req-lsa" or name == "outputs"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "checksumerr"):
                                self.checksumerr = value
                                self.checksumerr.value_namespace = name_space
                                self.checksumerr.value_namespace_prefix = name_space_prefix
                            if(value_path == "h-input-ack"):
                                self.h_input_ack = value
                                self.h_input_ack.value_namespace = name_space
                                self.h_input_ack.value_namespace_prefix = name_space_prefix
                            if(value_path == "h-input-dbdes"):
                                self.h_input_dbdes = value
                                self.h_input_dbdes.value_namespace = name_space
                                self.h_input_dbdes.value_namespace_prefix = name_space_prefix
                            if(value_path == "h-input-lsupd"):
                                self.h_input_lsupd = value
                                self.h_input_lsupd.value_namespace = name_space
                                self.h_input_lsupd.value_namespace_prefix = name_space_prefix
                            if(value_path == "h-input-req"):
                                self.h_input_req = value
                                self.h_input_req.value_namespace = name_space
                                self.h_input_req.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-ack"):
                                self.input_ack = value
                                self.input_ack.value_namespace = name_space
                                self.input_ack.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-ack-lsa"):
                                self.input_ack_lsa = value
                                self.input_ack_lsa.value_namespace = name_space
                                self.input_ack_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-autherr"):
                                self.input_autherr = value
                                self.input_autherr.value_namespace = name_space
                                self.input_autherr.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-dbdes"):
                                self.input_dbdes = value
                                self.input_dbdes.value_namespace = name_space
                                self.input_dbdes.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-dbdes-lsa"):
                                self.input_dbdes_lsa = value
                                self.input_dbdes_lsa.value_namespace = name_space
                                self.input_dbdes_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-hello"):
                                self.input_hello = value
                                self.input_hello.value_namespace = name_space
                                self.input_hello.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-lsupd"):
                                self.input_lsupd = value
                                self.input_lsupd.value_namespace = name_space
                                self.input_lsupd.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-lsupd-lsa"):
                                self.input_lsupd_lsa = value
                                self.input_lsupd_lsa.value_namespace = name_space
                                self.input_lsupd_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-req"):
                                self.input_req = value
                                self.input_req.value_namespace = name_space
                                self.input_req.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-req-lsa"):
                                self.input_req_lsa = value
                                self.input_req_lsa.value_namespace = name_space
                                self.input_req_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "inputs"):
                                self.inputs = value
                                self.inputs.value_namespace = name_space
                                self.inputs.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-ack"):
                                self.output_ack = value
                                self.output_ack.value_namespace = name_space
                                self.output_ack.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-ack-lsa"):
                                self.output_ack_lsa = value
                                self.output_ack_lsa.value_namespace = name_space
                                self.output_ack_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-autherr"):
                                self.output_autherr = value
                                self.output_autherr.value_namespace = name_space
                                self.output_autherr.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-dbdes"):
                                self.output_dbdes = value
                                self.output_dbdes.value_namespace = name_space
                                self.output_dbdes.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-dbdes-lsa"):
                                self.output_dbdes_lsa = value
                                self.output_dbdes_lsa.value_namespace = name_space
                                self.output_dbdes_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-hello"):
                                self.output_hello = value
                                self.output_hello.value_namespace = name_space
                                self.output_hello.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-lsupd"):
                                self.output_lsupd = value
                                self.output_lsupd.value_namespace = name_space
                                self.output_lsupd.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-lsupd-lsa"):
                                self.output_lsupd_lsa = value
                                self.output_lsupd_lsa.value_namespace = name_space
                                self.output_lsupd_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-req"):
                                self.output_req = value
                                self.output_req.value_namespace = name_space
                                self.output_req.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-req-lsa"):
                                self.output_req_lsa = value
                                self.output_req_lsa.value_namespace = name_space
                                self.output_req_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "outputs"):
                                self.outputs = value
                                self.outputs.value_namespace = name_space
                                self.outputs.value_namespace_prefix = name_space_prefix


                    class RawIoStats(Entity):
                        """
                        OSPF RAW IO statistics
                        
                        .. attribute:: disconnects
                        
                        	disconnects
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: in_bytes_rcv
                        
                        	in bytes rcv
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: in_no_mem_discarded
                        
                        	in no mem discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: in_raw_event
                        
                        	in raw event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: in_rcv
                        
                        	in rcv
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: in_short_msg_discarded
                        
                        	in short msg discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: in_standby_discarded
                        
                        	in standby discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_not_ready_discarded
                        
                        	nsr not ready discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_bytes_sent
                        
                        	out bytes sent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_ipv4_hdr_err_discarded
                        
                        	out ipv4 hdr err discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_no_conn_discarded
                        
                        	out no conn discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_no_pak_discarded
                        
                        	out no pak discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_null_src_discarded
                        
                        	out null src discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_send_pak_err_discarded
                        
                        	out send pak err discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_sent
                        
                        	out sent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: raw_connected
                        
                        	raw connected
                        	**type**\:  bool
                        
                        .. attribute:: sl_raw_connected
                        
                        	sl raw connected
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.RawIoStats, self).__init__()

                            self.yang_name = "raw-io-stats"
                            self.yang_parent_name = "statistics"

                            self.disconnects = YLeaf(YType.uint32, "disconnects")

                            self.in_bytes_rcv = YLeaf(YType.uint32, "in-bytes-rcv")

                            self.in_no_mem_discarded = YLeaf(YType.uint32, "in-no-mem-discarded")

                            self.in_raw_event = YLeaf(YType.uint32, "in-raw-event")

                            self.in_rcv = YLeaf(YType.uint32, "in-rcv")

                            self.in_short_msg_discarded = YLeaf(YType.uint32, "in-short-msg-discarded")

                            self.in_standby_discarded = YLeaf(YType.uint32, "in-standby-discarded")

                            self.nsr_not_ready_discarded = YLeaf(YType.uint32, "nsr-not-ready-discarded")

                            self.out_bytes_sent = YLeaf(YType.uint32, "out-bytes-sent")

                            self.out_ipv4_hdr_err_discarded = YLeaf(YType.uint32, "out-ipv4-hdr-err-discarded")

                            self.out_no_conn_discarded = YLeaf(YType.uint32, "out-no-conn-discarded")

                            self.out_no_pak_discarded = YLeaf(YType.uint32, "out-no-pak-discarded")

                            self.out_null_src_discarded = YLeaf(YType.uint32, "out-null-src-discarded")

                            self.out_send_pak_err_discarded = YLeaf(YType.uint32, "out-send-pak-err-discarded")

                            self.out_sent = YLeaf(YType.uint32, "out-sent")

                            self.raw_connected = YLeaf(YType.boolean, "raw-connected")

                            self.sl_raw_connected = YLeaf(YType.boolean, "sl-raw-connected")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("disconnects",
                                            "in_bytes_rcv",
                                            "in_no_mem_discarded",
                                            "in_raw_event",
                                            "in_rcv",
                                            "in_short_msg_discarded",
                                            "in_standby_discarded",
                                            "nsr_not_ready_discarded",
                                            "out_bytes_sent",
                                            "out_ipv4_hdr_err_discarded",
                                            "out_no_conn_discarded",
                                            "out_no_pak_discarded",
                                            "out_null_src_discarded",
                                            "out_send_pak_err_discarded",
                                            "out_sent",
                                            "raw_connected",
                                            "sl_raw_connected") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.RawIoStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.RawIoStats, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.disconnects.is_set or
                                self.in_bytes_rcv.is_set or
                                self.in_no_mem_discarded.is_set or
                                self.in_raw_event.is_set or
                                self.in_rcv.is_set or
                                self.in_short_msg_discarded.is_set or
                                self.in_standby_discarded.is_set or
                                self.nsr_not_ready_discarded.is_set or
                                self.out_bytes_sent.is_set or
                                self.out_ipv4_hdr_err_discarded.is_set or
                                self.out_no_conn_discarded.is_set or
                                self.out_no_pak_discarded.is_set or
                                self.out_null_src_discarded.is_set or
                                self.out_send_pak_err_discarded.is_set or
                                self.out_sent.is_set or
                                self.raw_connected.is_set or
                                self.sl_raw_connected.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.disconnects.yfilter != YFilter.not_set or
                                self.in_bytes_rcv.yfilter != YFilter.not_set or
                                self.in_no_mem_discarded.yfilter != YFilter.not_set or
                                self.in_raw_event.yfilter != YFilter.not_set or
                                self.in_rcv.yfilter != YFilter.not_set or
                                self.in_short_msg_discarded.yfilter != YFilter.not_set or
                                self.in_standby_discarded.yfilter != YFilter.not_set or
                                self.nsr_not_ready_discarded.yfilter != YFilter.not_set or
                                self.out_bytes_sent.yfilter != YFilter.not_set or
                                self.out_ipv4_hdr_err_discarded.yfilter != YFilter.not_set or
                                self.out_no_conn_discarded.yfilter != YFilter.not_set or
                                self.out_no_pak_discarded.yfilter != YFilter.not_set or
                                self.out_null_src_discarded.yfilter != YFilter.not_set or
                                self.out_send_pak_err_discarded.yfilter != YFilter.not_set or
                                self.out_sent.yfilter != YFilter.not_set or
                                self.raw_connected.yfilter != YFilter.not_set or
                                self.sl_raw_connected.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "raw-io-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.disconnects.is_set or self.disconnects.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disconnects.get_name_leafdata())
                            if (self.in_bytes_rcv.is_set or self.in_bytes_rcv.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.in_bytes_rcv.get_name_leafdata())
                            if (self.in_no_mem_discarded.is_set or self.in_no_mem_discarded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.in_no_mem_discarded.get_name_leafdata())
                            if (self.in_raw_event.is_set or self.in_raw_event.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.in_raw_event.get_name_leafdata())
                            if (self.in_rcv.is_set or self.in_rcv.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.in_rcv.get_name_leafdata())
                            if (self.in_short_msg_discarded.is_set or self.in_short_msg_discarded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.in_short_msg_discarded.get_name_leafdata())
                            if (self.in_standby_discarded.is_set or self.in_standby_discarded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.in_standby_discarded.get_name_leafdata())
                            if (self.nsr_not_ready_discarded.is_set or self.nsr_not_ready_discarded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_not_ready_discarded.get_name_leafdata())
                            if (self.out_bytes_sent.is_set or self.out_bytes_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_bytes_sent.get_name_leafdata())
                            if (self.out_ipv4_hdr_err_discarded.is_set or self.out_ipv4_hdr_err_discarded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_ipv4_hdr_err_discarded.get_name_leafdata())
                            if (self.out_no_conn_discarded.is_set or self.out_no_conn_discarded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_no_conn_discarded.get_name_leafdata())
                            if (self.out_no_pak_discarded.is_set or self.out_no_pak_discarded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_no_pak_discarded.get_name_leafdata())
                            if (self.out_null_src_discarded.is_set or self.out_null_src_discarded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_null_src_discarded.get_name_leafdata())
                            if (self.out_send_pak_err_discarded.is_set or self.out_send_pak_err_discarded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_send_pak_err_discarded.get_name_leafdata())
                            if (self.out_sent.is_set or self.out_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_sent.get_name_leafdata())
                            if (self.raw_connected.is_set or self.raw_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.raw_connected.get_name_leafdata())
                            if (self.sl_raw_connected.is_set or self.sl_raw_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sl_raw_connected.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "disconnects" or name == "in-bytes-rcv" or name == "in-no-mem-discarded" or name == "in-raw-event" or name == "in-rcv" or name == "in-short-msg-discarded" or name == "in-standby-discarded" or name == "nsr-not-ready-discarded" or name == "out-bytes-sent" or name == "out-ipv4-hdr-err-discarded" or name == "out-no-conn-discarded" or name == "out-no-pak-discarded" or name == "out-null-src-discarded" or name == "out-send-pak-err-discarded" or name == "out-sent" or name == "raw-connected" or name == "sl-raw-connected"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "disconnects"):
                                self.disconnects = value
                                self.disconnects.value_namespace = name_space
                                self.disconnects.value_namespace_prefix = name_space_prefix
                            if(value_path == "in-bytes-rcv"):
                                self.in_bytes_rcv = value
                                self.in_bytes_rcv.value_namespace = name_space
                                self.in_bytes_rcv.value_namespace_prefix = name_space_prefix
                            if(value_path == "in-no-mem-discarded"):
                                self.in_no_mem_discarded = value
                                self.in_no_mem_discarded.value_namespace = name_space
                                self.in_no_mem_discarded.value_namespace_prefix = name_space_prefix
                            if(value_path == "in-raw-event"):
                                self.in_raw_event = value
                                self.in_raw_event.value_namespace = name_space
                                self.in_raw_event.value_namespace_prefix = name_space_prefix
                            if(value_path == "in-rcv"):
                                self.in_rcv = value
                                self.in_rcv.value_namespace = name_space
                                self.in_rcv.value_namespace_prefix = name_space_prefix
                            if(value_path == "in-short-msg-discarded"):
                                self.in_short_msg_discarded = value
                                self.in_short_msg_discarded.value_namespace = name_space
                                self.in_short_msg_discarded.value_namespace_prefix = name_space_prefix
                            if(value_path == "in-standby-discarded"):
                                self.in_standby_discarded = value
                                self.in_standby_discarded.value_namespace = name_space
                                self.in_standby_discarded.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-not-ready-discarded"):
                                self.nsr_not_ready_discarded = value
                                self.nsr_not_ready_discarded.value_namespace = name_space
                                self.nsr_not_ready_discarded.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-bytes-sent"):
                                self.out_bytes_sent = value
                                self.out_bytes_sent.value_namespace = name_space
                                self.out_bytes_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-ipv4-hdr-err-discarded"):
                                self.out_ipv4_hdr_err_discarded = value
                                self.out_ipv4_hdr_err_discarded.value_namespace = name_space
                                self.out_ipv4_hdr_err_discarded.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-no-conn-discarded"):
                                self.out_no_conn_discarded = value
                                self.out_no_conn_discarded.value_namespace = name_space
                                self.out_no_conn_discarded.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-no-pak-discarded"):
                                self.out_no_pak_discarded = value
                                self.out_no_pak_discarded.value_namespace = name_space
                                self.out_no_pak_discarded.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-null-src-discarded"):
                                self.out_null_src_discarded = value
                                self.out_null_src_discarded.value_namespace = name_space
                                self.out_null_src_discarded.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-send-pak-err-discarded"):
                                self.out_send_pak_err_discarded = value
                                self.out_send_pak_err_discarded.value_namespace = name_space
                                self.out_send_pak_err_discarded.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-sent"):
                                self.out_sent = value
                                self.out_sent.value_namespace = name_space
                                self.out_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "raw-connected"):
                                self.raw_connected = value
                                self.raw_connected.value_namespace = name_space
                                self.raw_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "sl-raw-connected"):
                                self.sl_raw_connected = value
                                self.sl_raw_connected.value_namespace = name_space
                                self.sl_raw_connected.value_namespace_prefix = name_space_prefix


                    class InterfaceStatsEntries(Entity):
                        """
                        Statistics innformation Interface table
                        
                        .. attribute:: interface_stats_entry
                        
                        	Statistics information for a specific interface
                        	**type**\: list of    :py:class:`InterfaceStatsEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries, self).__init__()

                            self.yang_name = "interface-stats-entries"
                            self.yang_parent_name = "statistics"

                            self.interface_stats_entry = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries, self).__setattr__(name, value)


                        class InterfaceStatsEntry(Entity):
                            """
                            Statistics information for a specific interface
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: handle
                            
                            	interface handle type
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: if_entry
                            
                            	interface entry
                            	**type**\: list of    :py:class:`IfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry>`
                            
                            .. attribute:: if_name_str
                            
                            	interface name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__init__()

                                self.yang_name = "interface-stats-entry"
                                self.yang_parent_name = "interface-stats-entries"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.handle = YLeaf(YType.str, "handle")

                                self.if_name_str = YLeaf(YType.str, "if-name-str")

                                self.if_entry = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "handle",
                                                "if_name_str") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__setattr__(name, value)


                            class IfEntry(Entity):
                                """
                                interface entry
                                
                                .. attribute:: area_id
                                
                                	OSPF area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_id_str
                                
                                	OSPF aread id string
                                	**type**\:  str
                                
                                .. attribute:: if_stat
                                
                                	OSPF interface statistics
                                	**type**\: list of    :py:class:`IfStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat>`
                                
                                .. attribute:: madj_intf
                                
                                	OSPF madj interface
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__init__()

                                    self.yang_name = "if-entry"
                                    self.yang_parent_name = "interface-stats-entry"

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.area_id_str = YLeaf(YType.str, "area-id-str")

                                    self.madj_intf = YLeaf(YType.boolean, "madj-intf")

                                    self.if_stat = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_id",
                                                    "area_id_str",
                                                    "madj_intf") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__setattr__(name, value)


                                class IfStat(Entity):
                                    """
                                    OSPF interface statistics
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__init__()

                                        self.yang_name = "if-stat"
                                        self.yang_parent_name = "if-entry"

                                        self.entry = YLeaf(YType.uint32, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "if-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.if_stat:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.area_id.is_set or
                                        self.area_id_str.is_set or
                                        self.madj_intf.is_set)

                                def has_operation(self):
                                    for c in self.if_stat:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.area_id_str.yfilter != YFilter.not_set or
                                        self.madj_intf.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "if-entry" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.area_id_str.is_set or self.area_id_str.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id_str.get_name_leafdata())
                                    if (self.madj_intf.is_set or self.madj_intf.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.madj_intf.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "if-stat"):
                                        for c in self.if_stat:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.if_stat.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "if-stat" or name == "area-id" or name == "area-id-str" or name == "madj-intf"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-id-str"):
                                        self.area_id_str = value
                                        self.area_id_str.value_namespace = name_space
                                        self.area_id_str.value_namespace_prefix = name_space_prefix
                                    if(value_path == "madj-intf"):
                                        self.madj_intf = value
                                        self.madj_intf.value_namespace = name_space
                                        self.madj_intf.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.if_entry:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.interface_name.is_set or
                                    self.handle.is_set or
                                    self.if_name_str.is_set)

                            def has_operation(self):
                                for c in self.if_entry:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.handle.yfilter != YFilter.not_set or
                                    self.if_name_str.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-stats-entry" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.handle.is_set or self.handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.handle.get_name_leafdata())
                                if (self.if_name_str.is_set or self.if_name_str.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.if_name_str.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "if-entry"):
                                    for c in self.if_entry:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.if_entry.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "if-entry" or name == "interface-name" or name == "handle" or name == "if-name-str"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "handle"):
                                    self.handle = value
                                    self.handle.value_namespace = name_space
                                    self.handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "if-name-str"):
                                    self.if_name_str = value
                                    self.if_name_str.value_namespace = name_space
                                    self.if_name_str.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_stats_entry:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.interface_stats_entry:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-stats-entries" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface-stats-entry"):
                                for c in self.interface_stats_entry:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_stats_entry.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-stats-entry"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.frr_stats is not None and self.frr_stats.has_data()) or
                            (self.interface_stats_entries is not None and self.interface_stats_entries.has_data()) or
                            (self.issu_stats is not None and self.issu_stats.has_data()) or
                            (self.nsr_pl_stats is not None and self.nsr_pl_stats.has_data()) or
                            (self.nsr_stats is not None and self.nsr_stats.has_data()) or
                            (self.protocol_stats is not None and self.protocol_stats.has_data()) or
                            (self.raw_io_stats is not None and self.raw_io_stats.has_data()) or
                            (self.rib_batch_stats is not None and self.rib_batch_stats.has_data()) or
                            (self.rib_thread_stats is not None and self.rib_thread_stats.has_data()) or
                            (self.spf_stats is not None and self.spf_stats.has_data()) or
                            (self.te_stats is not None and self.te_stats.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.frr_stats is not None and self.frr_stats.has_operation()) or
                            (self.interface_stats_entries is not None and self.interface_stats_entries.has_operation()) or
                            (self.issu_stats is not None and self.issu_stats.has_operation()) or
                            (self.nsr_pl_stats is not None and self.nsr_pl_stats.has_operation()) or
                            (self.nsr_stats is not None and self.nsr_stats.has_operation()) or
                            (self.protocol_stats is not None and self.protocol_stats.has_operation()) or
                            (self.raw_io_stats is not None and self.raw_io_stats.has_operation()) or
                            (self.rib_batch_stats is not None and self.rib_batch_stats.has_operation()) or
                            (self.rib_thread_stats is not None and self.rib_thread_stats.has_operation()) or
                            (self.spf_stats is not None and self.spf_stats.has_operation()) or
                            (self.te_stats is not None and self.te_stats.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "frr-stats"):
                            if (self.frr_stats is None):
                                self.frr_stats = Ospf.Processes.Process.DefaultVrf.Statistics.FrrStats()
                                self.frr_stats.parent = self
                                self._children_name_map["frr_stats"] = "frr-stats"
                            return self.frr_stats

                        if (child_yang_name == "interface-stats-entries"):
                            if (self.interface_stats_entries is None):
                                self.interface_stats_entries = Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries()
                                self.interface_stats_entries.parent = self
                                self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                            return self.interface_stats_entries

                        if (child_yang_name == "issu-stats"):
                            if (self.issu_stats is None):
                                self.issu_stats = Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats()
                                self.issu_stats.parent = self
                                self._children_name_map["issu_stats"] = "issu-stats"
                            return self.issu_stats

                        if (child_yang_name == "nsr-pl-stats"):
                            if (self.nsr_pl_stats is None):
                                self.nsr_pl_stats = Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats()
                                self.nsr_pl_stats.parent = self
                                self._children_name_map["nsr_pl_stats"] = "nsr-pl-stats"
                            return self.nsr_pl_stats

                        if (child_yang_name == "nsr-stats"):
                            if (self.nsr_stats is None):
                                self.nsr_stats = Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats()
                                self.nsr_stats.parent = self
                                self._children_name_map["nsr_stats"] = "nsr-stats"
                            return self.nsr_stats

                        if (child_yang_name == "protocol-stats"):
                            if (self.protocol_stats is None):
                                self.protocol_stats = Ospf.Processes.Process.DefaultVrf.Statistics.ProtocolStats()
                                self.protocol_stats.parent = self
                                self._children_name_map["protocol_stats"] = "protocol-stats"
                            return self.protocol_stats

                        if (child_yang_name == "raw-io-stats"):
                            if (self.raw_io_stats is None):
                                self.raw_io_stats = Ospf.Processes.Process.DefaultVrf.Statistics.RawIoStats()
                                self.raw_io_stats.parent = self
                                self._children_name_map["raw_io_stats"] = "raw-io-stats"
                            return self.raw_io_stats

                        if (child_yang_name == "rib-batch-stats"):
                            if (self.rib_batch_stats is None):
                                self.rib_batch_stats = Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats()
                                self.rib_batch_stats.parent = self
                                self._children_name_map["rib_batch_stats"] = "rib-batch-stats"
                            return self.rib_batch_stats

                        if (child_yang_name == "rib-thread-stats"):
                            if (self.rib_thread_stats is None):
                                self.rib_thread_stats = Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats()
                                self.rib_thread_stats.parent = self
                                self._children_name_map["rib_thread_stats"] = "rib-thread-stats"
                            return self.rib_thread_stats

                        if (child_yang_name == "spf-stats"):
                            if (self.spf_stats is None):
                                self.spf_stats = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats()
                                self.spf_stats.parent = self
                                self._children_name_map["spf_stats"] = "spf-stats"
                            return self.spf_stats

                        if (child_yang_name == "te-stats"):
                            if (self.te_stats is None):
                                self.te_stats = Ospf.Processes.Process.DefaultVrf.Statistics.TeStats()
                                self.te_stats.parent = self
                                self._children_name_map["te_stats"] = "te-stats"
                            return self.te_stats

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "frr-stats" or name == "interface-stats-entries" or name == "issu-stats" or name == "nsr-pl-stats" or name == "nsr-stats" or name == "protocol-stats" or name == "raw-io-stats" or name == "rib-batch-stats" or name == "rib-thread-stats" or name == "spf-stats" or name == "te-stats"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class AdjacencyInformation(Entity):
                    """
                    Container for OSPF Interfaces
                    
                    .. attribute:: neighbor_details
                    
                    	Neighbor detail table
                    	**type**\:   :py:class:`NeighborDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails>`
                    
                    .. attribute:: neighbors
                    
                    	Neighbor table
                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors>`
                    
                    .. attribute:: requests
                    
                    	Request List table
                    	**type**\:   :py:class:`Requests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests>`
                    
                    .. attribute:: retransmissions
                    
                    	Retransmission list table
                    	**type**\:   :py:class:`Retransmissions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation, self).__init__()

                        self.yang_name = "adjacency-information"
                        self.yang_parent_name = "default-vrf"

                        self.neighbor_details = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails()
                        self.neighbor_details.parent = self
                        self._children_name_map["neighbor_details"] = "neighbor-details"
                        self._children_yang_names.add("neighbor-details")

                        self.neighbors = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"
                        self._children_yang_names.add("neighbors")

                        self.requests = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests()
                        self.requests.parent = self
                        self._children_name_map["requests"] = "requests"
                        self._children_yang_names.add("requests")

                        self.retransmissions = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions()
                        self.retransmissions.parent = self
                        self._children_name_map["retransmissions"] = "retransmissions"
                        self._children_yang_names.add("retransmissions")


                    class Neighbors(Entity):
                        """
                        Neighbor table
                        
                        .. attribute:: neighbor
                        
                        	Neighbor information
                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors, self).__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "adjacency-information"

                            self.neighbor = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors, self).__setattr__(name, value)


                        class Neighbor(Entity):
                            """
                            Neighbor information
                            
                            .. attribute:: dr_bdr_state
                            
                            	Designated Router state
                            	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_bfd_information
                            
                            	Neighbor BFD information
                            	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation>`
                            
                            .. attribute:: neighbor_dead_timer
                            
                            	Time until neighbor's dead timer expires (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_dr_priority
                            
                            	Neighbor's DR priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: neighbor_id
                            
                            	Neighbor ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_interface_name
                            
                            	Interface via which the neighbor is seen
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: neighbor_madj_interface
                            
                            	Interface is MADJ
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_state
                            
                            	Neighbor's state
                            	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                            
                            .. attribute:: neighbor_up_time
                            
                            	Amount of time since the adjacency is up (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"

                                self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation()
                                self.neighbor_bfd_information.parent = self
                                self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                self._children_yang_names.add("neighbor-bfd-information")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dr_bdr_state",
                                                "interface_name",
                                                "neighbor_address",
                                                "neighbor_address_xr",
                                                "neighbor_dead_timer",
                                                "neighbor_dr_priority",
                                                "neighbor_id",
                                                "neighbor_interface_name",
                                                "neighbor_madj_interface",
                                                "neighbor_state",
                                                "neighbor_up_time") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor, self).__setattr__(name, value)


                            class NeighborBfdInformation(Entity):
                                """
                                Neighbor BFD information
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD enable mode \- Default/Strict
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_status_flag
                                
                                	Status of the BFD Session
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation, self).__init__()

                                    self.yang_name = "neighbor-bfd-information"
                                    self.yang_parent_name = "neighbor"

                                    self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                    self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bfd_intf_enable_mode",
                                                    "bfd_status_flag") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bfd_intf_enable_mode.is_set or
                                        self.bfd_status_flag.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                        self.bfd_status_flag.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "neighbor-bfd-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                    if (self.bfd_status_flag.is_set or self.bfd_status_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_status_flag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bfd-intf-enable-mode" or name == "bfd-status-flag"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bfd-intf-enable-mode"):
                                        self.bfd_intf_enable_mode = value
                                        self.bfd_intf_enable_mode.value_namespace = name_space
                                        self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-status-flag"):
                                        self.bfd_status_flag = value
                                        self.bfd_status_flag.value_namespace = name_space
                                        self.bfd_status_flag.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.dr_bdr_state.is_set or
                                    self.interface_name.is_set or
                                    self.neighbor_address.is_set or
                                    self.neighbor_address_xr.is_set or
                                    self.neighbor_dead_timer.is_set or
                                    self.neighbor_dr_priority.is_set or
                                    self.neighbor_id.is_set or
                                    self.neighbor_interface_name.is_set or
                                    self.neighbor_madj_interface.is_set or
                                    self.neighbor_state.is_set or
                                    self.neighbor_up_time.is_set or
                                    (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dr_bdr_state.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.neighbor_address.yfilter != YFilter.not_set or
                                    self.neighbor_address_xr.yfilter != YFilter.not_set or
                                    self.neighbor_dead_timer.yfilter != YFilter.not_set or
                                    self.neighbor_dr_priority.yfilter != YFilter.not_set or
                                    self.neighbor_id.yfilter != YFilter.not_set or
                                    self.neighbor_interface_name.yfilter != YFilter.not_set or
                                    self.neighbor_madj_interface.yfilter != YFilter.not_set or
                                    self.neighbor_state.yfilter != YFilter.not_set or
                                    self.neighbor_up_time.yfilter != YFilter.not_set or
                                    (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dr_bdr_state.is_set or self.dr_bdr_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dr_bdr_state.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                if (self.neighbor_address_xr.is_set or self.neighbor_address_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_address_xr.get_name_leafdata())
                                if (self.neighbor_dead_timer.is_set or self.neighbor_dead_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_dead_timer.get_name_leafdata())
                                if (self.neighbor_dr_priority.is_set or self.neighbor_dr_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_dr_priority.get_name_leafdata())
                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                if (self.neighbor_interface_name.is_set or self.neighbor_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_interface_name.get_name_leafdata())
                                if (self.neighbor_madj_interface.is_set or self.neighbor_madj_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_madj_interface.get_name_leafdata())
                                if (self.neighbor_state.is_set or self.neighbor_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_state.get_name_leafdata())
                                if (self.neighbor_up_time.is_set or self.neighbor_up_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_up_time.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "neighbor-bfd-information"):
                                    if (self.neighbor_bfd_information is None):
                                        self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation()
                                        self.neighbor_bfd_information.parent = self
                                        self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                    return self.neighbor_bfd_information

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "neighbor-bfd-information" or name == "dr-bdr-state" or name == "interface-name" or name == "neighbor-address" or name == "neighbor-address-xr" or name == "neighbor-dead-timer" or name == "neighbor-dr-priority" or name == "neighbor-id" or name == "neighbor-interface-name" or name == "neighbor-madj-interface" or name == "neighbor-state" or name == "neighbor-up-time"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dr-bdr-state"):
                                    self.dr_bdr_state = value
                                    self.dr_bdr_state.value_namespace = name_space
                                    self.dr_bdr_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-address"):
                                    self.neighbor_address = value
                                    self.neighbor_address.value_namespace = name_space
                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-address-xr"):
                                    self.neighbor_address_xr = value
                                    self.neighbor_address_xr.value_namespace = name_space
                                    self.neighbor_address_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-dead-timer"):
                                    self.neighbor_dead_timer = value
                                    self.neighbor_dead_timer.value_namespace = name_space
                                    self.neighbor_dead_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-dr-priority"):
                                    self.neighbor_dr_priority = value
                                    self.neighbor_dr_priority.value_namespace = name_space
                                    self.neighbor_dr_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-id"):
                                    self.neighbor_id = value
                                    self.neighbor_id.value_namespace = name_space
                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-interface-name"):
                                    self.neighbor_interface_name = value
                                    self.neighbor_interface_name.value_namespace = name_space
                                    self.neighbor_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-madj-interface"):
                                    self.neighbor_madj_interface = value
                                    self.neighbor_madj_interface.value_namespace = name_space
                                    self.neighbor_madj_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-state"):
                                    self.neighbor_state = value
                                    self.neighbor_state.value_namespace = name_space
                                    self.neighbor_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-up-time"):
                                    self.neighbor_up_time = value
                                    self.neighbor_up_time.value_namespace = name_space
                                    self.neighbor_up_time.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.neighbor:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.neighbor:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbors" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "neighbor"):
                                for c in self.neighbor:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.neighbor.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Requests(Entity):
                        """
                        Request List table
                        
                        .. attribute:: request
                        
                        	Request list for a particular adjacency
                        	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests, self).__init__()

                            self.yang_name = "requests"
                            self.yang_parent_name = "adjacency-information"

                            self.request = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests, self).__setattr__(name, value)


                        class Request(Entity):
                            """
                            Request list for a particular adjacency
                            
                            .. attribute:: interface_name
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: request
                            
                            	List of request list entries
                            	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request.Request>`
                            
                            .. attribute:: request_interface_name
                            
                            	Request list interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: request_neighbor_address
                            
                            	Neighbor IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: request_neighbor_id
                            
                            	Neighbor ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "requests"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.request_interface_name = YLeaf(YType.str, "request-interface-name")

                                self.request_neighbor_address = YLeaf(YType.str, "request-neighbor-address")

                                self.request_neighbor_id = YLeaf(YType.str, "request-neighbor-id")

                                self.request = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "neighbor_address",
                                                "request_interface_name",
                                                "request_neighbor_address",
                                                "request_neighbor_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request, self).__setattr__(name, value)


                            class Request(Entity):
                                """
                                List of request list entries
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_ls_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_checksum
                                
                                	Checksum of the LSA
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA Type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request.Request, self).__init__()

                                    self.yang_name = "request"
                                    self.yang_parent_name = "request"

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("header_advertising_router",
                                                    "header_ls_id",
                                                    "header_lsa_age",
                                                    "header_lsa_checksum",
                                                    "header_lsa_type",
                                                    "header_sequence_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request.Request, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request.Request, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.header_advertising_router.is_set or
                                        self.header_ls_id.is_set or
                                        self.header_lsa_age.is_set or
                                        self.header_lsa_checksum.is_set or
                                        self.header_lsa_type.is_set or
                                        self.header_sequence_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.header_advertising_router.yfilter != YFilter.not_set or
                                        self.header_ls_id.yfilter != YFilter.not_set or
                                        self.header_lsa_age.yfilter != YFilter.not_set or
                                        self.header_lsa_checksum.yfilter != YFilter.not_set or
                                        self.header_lsa_type.yfilter != YFilter.not_set or
                                        self.header_sequence_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "request" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                    if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                    if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                    if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                    if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                    if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "header-advertising-router"):
                                        self.header_advertising_router = value
                                        self.header_advertising_router.value_namespace = name_space
                                        self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-ls-id"):
                                        self.header_ls_id = value
                                        self.header_ls_id.value_namespace = name_space
                                        self.header_ls_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-age"):
                                        self.header_lsa_age = value
                                        self.header_lsa_age.value_namespace = name_space
                                        self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-checksum"):
                                        self.header_lsa_checksum = value
                                        self.header_lsa_checksum.value_namespace = name_space
                                        self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-type"):
                                        self.header_lsa_type = value
                                        self.header_lsa_type.value_namespace = name_space
                                        self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-sequence-number"):
                                        self.header_sequence_number = value
                                        self.header_sequence_number.value_namespace = name_space
                                        self.header_sequence_number.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.request:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.interface_name.is_set or
                                    self.neighbor_address.is_set or
                                    self.request_interface_name.is_set or
                                    self.request_neighbor_address.is_set or
                                    self.request_neighbor_id.is_set)

                            def has_operation(self):
                                for c in self.request:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.neighbor_address.yfilter != YFilter.not_set or
                                    self.request_interface_name.yfilter != YFilter.not_set or
                                    self.request_neighbor_address.yfilter != YFilter.not_set or
                                    self.request_neighbor_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "request" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                if (self.request_interface_name.is_set or self.request_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.request_interface_name.get_name_leafdata())
                                if (self.request_neighbor_address.is_set or self.request_neighbor_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.request_neighbor_address.get_name_leafdata())
                                if (self.request_neighbor_id.is_set or self.request_neighbor_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.request_neighbor_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "request"):
                                    for c in self.request:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request.Request()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.request.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "request" or name == "interface-name" or name == "neighbor-address" or name == "request-interface-name" or name == "request-neighbor-address" or name == "request-neighbor-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-address"):
                                    self.neighbor_address = value
                                    self.neighbor_address.value_namespace = name_space
                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "request-interface-name"):
                                    self.request_interface_name = value
                                    self.request_interface_name.value_namespace = name_space
                                    self.request_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "request-neighbor-address"):
                                    self.request_neighbor_address = value
                                    self.request_neighbor_address.value_namespace = name_space
                                    self.request_neighbor_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "request-neighbor-id"):
                                    self.request_neighbor_id = value
                                    self.request_neighbor_id.value_namespace = name_space
                                    self.request_neighbor_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.request:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.request:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "requests" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "request"):
                                for c in self.request:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.request.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "request"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Retransmissions(Entity):
                        """
                        Retransmission list table
                        
                        .. attribute:: retransmission
                        
                        	Retransmission list for a particular adjacency
                        	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions, self).__init__()

                            self.yang_name = "retransmissions"
                            self.yang_parent_name = "adjacency-information"

                            self.retransmission = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions, self).__setattr__(name, value)


                        class Retransmission(Entity):
                            """
                            Retransmission list for a particular adjacency
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: retransmission_area_db
                            
                            	List of Area scope entries
                            	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb>`
                            
                            .. attribute:: retransmission_asdb
                            
                            	List of AS Scope entries
                            	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb>`
                            
                            .. attribute:: retransmission_count
                            
                            	Retransmission queue length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmission_interface_name
                            
                            	Retransmission list interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: retransmission_neighbor_id
                            
                            	Neighbor ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: retransmission_neighbor_ip_address
                            
                            	Neighbor IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: retransmission_timer
                            
                            	Amount of time remaining on retransmission timer (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission, self).__init__()

                                self.yang_name = "retransmission"
                                self.yang_parent_name = "retransmissions"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.retransmission_count = YLeaf(YType.uint32, "retransmission-count")

                                self.retransmission_interface_name = YLeaf(YType.str, "retransmission-interface-name")

                                self.retransmission_neighbor_id = YLeaf(YType.str, "retransmission-neighbor-id")

                                self.retransmission_neighbor_ip_address = YLeaf(YType.str, "retransmission-neighbor-ip-address")

                                self.retransmission_timer = YLeaf(YType.uint32, "retransmission-timer")

                                self.retransmission_area_db = YList(self)
                                self.retransmission_asdb = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "neighbor_address",
                                                "retransmission_count",
                                                "retransmission_interface_name",
                                                "retransmission_neighbor_id",
                                                "retransmission_neighbor_ip_address",
                                                "retransmission_timer") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission, self).__setattr__(name, value)


                            class RetransmissionAreaDb(Entity):
                                """
                                List of Area scope entries
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_ls_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_checksum
                                
                                	Checksum of the LSA
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA Type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb, self).__init__()

                                    self.yang_name = "retransmission-area-db"
                                    self.yang_parent_name = "retransmission"

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("header_advertising_router",
                                                    "header_ls_id",
                                                    "header_lsa_age",
                                                    "header_lsa_checksum",
                                                    "header_lsa_type",
                                                    "header_sequence_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.header_advertising_router.is_set or
                                        self.header_ls_id.is_set or
                                        self.header_lsa_age.is_set or
                                        self.header_lsa_checksum.is_set or
                                        self.header_lsa_type.is_set or
                                        self.header_sequence_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.header_advertising_router.yfilter != YFilter.not_set or
                                        self.header_ls_id.yfilter != YFilter.not_set or
                                        self.header_lsa_age.yfilter != YFilter.not_set or
                                        self.header_lsa_checksum.yfilter != YFilter.not_set or
                                        self.header_lsa_type.yfilter != YFilter.not_set or
                                        self.header_sequence_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "retransmission-area-db" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                    if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                    if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                    if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                    if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                    if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "header-advertising-router"):
                                        self.header_advertising_router = value
                                        self.header_advertising_router.value_namespace = name_space
                                        self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-ls-id"):
                                        self.header_ls_id = value
                                        self.header_ls_id.value_namespace = name_space
                                        self.header_ls_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-age"):
                                        self.header_lsa_age = value
                                        self.header_lsa_age.value_namespace = name_space
                                        self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-checksum"):
                                        self.header_lsa_checksum = value
                                        self.header_lsa_checksum.value_namespace = name_space
                                        self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-type"):
                                        self.header_lsa_type = value
                                        self.header_lsa_type.value_namespace = name_space
                                        self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-sequence-number"):
                                        self.header_sequence_number = value
                                        self.header_sequence_number.value_namespace = name_space
                                        self.header_sequence_number.value_namespace_prefix = name_space_prefix


                            class RetransmissionAsdb(Entity):
                                """
                                List of AS Scope entries
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_ls_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_checksum
                                
                                	Checksum of the LSA
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA Type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb, self).__init__()

                                    self.yang_name = "retransmission-asdb"
                                    self.yang_parent_name = "retransmission"

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("header_advertising_router",
                                                    "header_ls_id",
                                                    "header_lsa_age",
                                                    "header_lsa_checksum",
                                                    "header_lsa_type",
                                                    "header_sequence_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.header_advertising_router.is_set or
                                        self.header_ls_id.is_set or
                                        self.header_lsa_age.is_set or
                                        self.header_lsa_checksum.is_set or
                                        self.header_lsa_type.is_set or
                                        self.header_sequence_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.header_advertising_router.yfilter != YFilter.not_set or
                                        self.header_ls_id.yfilter != YFilter.not_set or
                                        self.header_lsa_age.yfilter != YFilter.not_set or
                                        self.header_lsa_checksum.yfilter != YFilter.not_set or
                                        self.header_lsa_type.yfilter != YFilter.not_set or
                                        self.header_sequence_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "retransmission-asdb" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                    if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                    if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                    if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                    if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                    if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "header-advertising-router"):
                                        self.header_advertising_router = value
                                        self.header_advertising_router.value_namespace = name_space
                                        self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-ls-id"):
                                        self.header_ls_id = value
                                        self.header_ls_id.value_namespace = name_space
                                        self.header_ls_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-age"):
                                        self.header_lsa_age = value
                                        self.header_lsa_age.value_namespace = name_space
                                        self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-checksum"):
                                        self.header_lsa_checksum = value
                                        self.header_lsa_checksum.value_namespace = name_space
                                        self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-lsa-type"):
                                        self.header_lsa_type = value
                                        self.header_lsa_type.value_namespace = name_space
                                        self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "header-sequence-number"):
                                        self.header_sequence_number = value
                                        self.header_sequence_number.value_namespace = name_space
                                        self.header_sequence_number.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.retransmission_area_db:
                                    if (c.has_data()):
                                        return True
                                for c in self.retransmission_asdb:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.interface_name.is_set or
                                    self.neighbor_address.is_set or
                                    self.retransmission_count.is_set or
                                    self.retransmission_interface_name.is_set or
                                    self.retransmission_neighbor_id.is_set or
                                    self.retransmission_neighbor_ip_address.is_set or
                                    self.retransmission_timer.is_set)

                            def has_operation(self):
                                for c in self.retransmission_area_db:
                                    if (c.has_operation()):
                                        return True
                                for c in self.retransmission_asdb:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.neighbor_address.yfilter != YFilter.not_set or
                                    self.retransmission_count.yfilter != YFilter.not_set or
                                    self.retransmission_interface_name.yfilter != YFilter.not_set or
                                    self.retransmission_neighbor_id.yfilter != YFilter.not_set or
                                    self.retransmission_neighbor_ip_address.yfilter != YFilter.not_set or
                                    self.retransmission_timer.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "retransmission" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                if (self.retransmission_count.is_set or self.retransmission_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.retransmission_count.get_name_leafdata())
                                if (self.retransmission_interface_name.is_set or self.retransmission_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.retransmission_interface_name.get_name_leafdata())
                                if (self.retransmission_neighbor_id.is_set or self.retransmission_neighbor_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.retransmission_neighbor_id.get_name_leafdata())
                                if (self.retransmission_neighbor_ip_address.is_set or self.retransmission_neighbor_ip_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.retransmission_neighbor_ip_address.get_name_leafdata())
                                if (self.retransmission_timer.is_set or self.retransmission_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.retransmission_timer.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "retransmission-area-db"):
                                    for c in self.retransmission_area_db:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.retransmission_area_db.append(c)
                                    return c

                                if (child_yang_name == "retransmission-asdb"):
                                    for c in self.retransmission_asdb:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.retransmission_asdb.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "retransmission-area-db" or name == "retransmission-asdb" or name == "interface-name" or name == "neighbor-address" or name == "retransmission-count" or name == "retransmission-interface-name" or name == "retransmission-neighbor-id" or name == "retransmission-neighbor-ip-address" or name == "retransmission-timer"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-address"):
                                    self.neighbor_address = value
                                    self.neighbor_address.value_namespace = name_space
                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "retransmission-count"):
                                    self.retransmission_count = value
                                    self.retransmission_count.value_namespace = name_space
                                    self.retransmission_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "retransmission-interface-name"):
                                    self.retransmission_interface_name = value
                                    self.retransmission_interface_name.value_namespace = name_space
                                    self.retransmission_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "retransmission-neighbor-id"):
                                    self.retransmission_neighbor_id = value
                                    self.retransmission_neighbor_id.value_namespace = name_space
                                    self.retransmission_neighbor_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "retransmission-neighbor-ip-address"):
                                    self.retransmission_neighbor_ip_address = value
                                    self.retransmission_neighbor_ip_address.value_namespace = name_space
                                    self.retransmission_neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "retransmission-timer"):
                                    self.retransmission_timer = value
                                    self.retransmission_timer.value_namespace = name_space
                                    self.retransmission_timer.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.retransmission:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.retransmission:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "retransmissions" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "retransmission"):
                                for c in self.retransmission:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.retransmission.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "retransmission"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class NeighborDetails(Entity):
                        """
                        Neighbor detail table
                        
                        .. attribute:: neighbor_detail
                        
                        	A single neighbor's detail information
                        	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails, self).__init__()

                            self.yang_name = "neighbor-details"
                            self.yang_parent_name = "adjacency-information"

                            self.neighbor_detail = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails, self).__setattr__(name, value)


                        class NeighborDetail(Entity):
                            """
                            A single neighbor's detail information
                            
                            .. attribute:: adjacency_sid_label
                            
                            	SR Adjacency SID Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adjacency_sid_protected
                            
                            	SR Adjacency SID Protected
                            	**type**\:  bool
                            
                            .. attribute:: adjacency_sid_unprotected_label
                            
                            	SR Adjacency SID Unprotected Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: interface_type
                            
                            	Interface type
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                            
                            .. attribute:: last_oob_time
                            
                            	The amount of time in seconds since last time Out\-Of\-Band resynchronization was done with this neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: lfa_interface
                            
                            	LFA Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: lfa_neighbor_id
                            
                            	LFA Neighbor ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: lfa_neighbor_revision
                            
                            	LFA Neighbor Revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lfa_next_hop
                            
                            	LFA Next Hop
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_ack_list_count
                            
                            	Ack List Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_ack_list_high_watermark
                            
                            	Ack List High Watermark
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_area_id
                            
                            	Area ID string in decimal or dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: neighbor_backup_designated_router_address
                            
                            	Address of backup designated router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_bfd_information
                            
                            	Neighbor BFD information
                            	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation>`
                            
                            .. attribute:: neighbor_cost
                            
                            	Cost of path to this neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_designated_router_address
                            
                            	Address of designated router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_filter
                            
                            	If true, filter outgoing LSAs
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_lls_option
                            
                            	This is a bitmask of Link Local signalling options received from the neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_option
                            
                            	 This is bitmaks of neighbor's option field received
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: neighbor_retransmission_information
                            
                            	Retransmission information with this neighbor
                            	**type**\:   :py:class:`NeighborRetransmissionInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation>`
                            
                            .. attribute:: neighbor_summary
                            
                            	Neighbor summary information
                            	**type**\:   :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary>`
                            
                            .. attribute:: next_poll_interval
                            
                            	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nsf_router_state
                            
                            	For cisco NSF, the router is either Requester or Receiver
                            	**type**\:   :py:class:`NsfRtr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NsfRtr>`
                            
                            .. attribute:: oob_resynchronization
                            
                            	Out\-Of\-Bound resynchronization in progress
                            	**type**\:  bool
                            
                            .. attribute:: pending_events
                            
                            	Number of pending events
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: poll_interval
                            
                            	Poll interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state_change_count
                            
                            	Number of state changes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail, self).__init__()

                                self.yang_name = "neighbor-detail"
                                self.yang_parent_name = "neighbor-details"

                                self.adjacency_sid_label = YLeaf(YType.uint32, "adjacency-sid-label")

                                self.adjacency_sid_protected = YLeaf(YType.boolean, "adjacency-sid-protected")

                                self.adjacency_sid_unprotected_label = YLeaf(YType.uint32, "adjacency-sid-unprotected-label")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                self.last_oob_time = YLeaf(YType.uint32, "last-oob-time")

                                self.lfa_interface = YLeaf(YType.str, "lfa-interface")

                                self.lfa_neighbor_id = YLeaf(YType.str, "lfa-neighbor-id")

                                self.lfa_neighbor_revision = YLeaf(YType.uint32, "lfa-neighbor-revision")

                                self.lfa_next_hop = YLeaf(YType.str, "lfa-next-hop")

                                self.neighbor_ack_list_count = YLeaf(YType.uint32, "neighbor-ack-list-count")

                                self.neighbor_ack_list_high_watermark = YLeaf(YType.uint32, "neighbor-ack-list-high-watermark")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.neighbor_area_id = YLeaf(YType.str, "neighbor-area-id")

                                self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                self.neighbor_filter = YLeaf(YType.boolean, "neighbor-filter")

                                self.neighbor_lls_option = YLeaf(YType.uint16, "neighbor-lls-option")

                                self.neighbor_option = YLeaf(YType.uint8, "neighbor-option")

                                self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                self.nsf_router_state = YLeaf(YType.enumeration, "nsf-router-state")

                                self.oob_resynchronization = YLeaf(YType.boolean, "oob-resynchronization")

                                self.pending_events = YLeaf(YType.uint16, "pending-events")

                                self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                self.state_change_count = YLeaf(YType.uint16, "state-change-count")

                                self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation()
                                self.neighbor_bfd_information.parent = self
                                self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                self._children_yang_names.add("neighbor-bfd-information")

                                self.neighbor_retransmission_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation()
                                self.neighbor_retransmission_information.parent = self
                                self._children_name_map["neighbor_retransmission_information"] = "neighbor-retransmission-information"
                                self._children_yang_names.add("neighbor-retransmission-information")

                                self.neighbor_summary = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary()
                                self.neighbor_summary.parent = self
                                self._children_name_map["neighbor_summary"] = "neighbor-summary"
                                self._children_yang_names.add("neighbor-summary")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("adjacency_sid_label",
                                                "adjacency_sid_protected",
                                                "adjacency_sid_unprotected_label",
                                                "interface_name",
                                                "interface_type",
                                                "last_oob_time",
                                                "lfa_interface",
                                                "lfa_neighbor_id",
                                                "lfa_neighbor_revision",
                                                "lfa_next_hop",
                                                "neighbor_ack_list_count",
                                                "neighbor_ack_list_high_watermark",
                                                "neighbor_address",
                                                "neighbor_area_id",
                                                "neighbor_backup_designated_router_address",
                                                "neighbor_cost",
                                                "neighbor_designated_router_address",
                                                "neighbor_filter",
                                                "neighbor_lls_option",
                                                "neighbor_option",
                                                "next_poll_interval",
                                                "nsf_router_state",
                                                "oob_resynchronization",
                                                "pending_events",
                                                "poll_interval",
                                                "state_change_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail, self).__setattr__(name, value)


                            class NeighborSummary(Entity):
                                """
                                Neighbor summary information
                                
                                .. attribute:: dr_bdr_state
                                
                                	Designated Router state
                                	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                
                                .. attribute:: neighbor_address_xr
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_information
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation>`
                                
                                .. attribute:: neighbor_dead_timer
                                
                                	Time until neighbor's dead timer expires (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_dr_priority
                                
                                	Neighbor's DR priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_interface_name
                                
                                	Interface via which the neighbor is seen
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: neighbor_madj_interface
                                
                                	Interface is MADJ
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_state
                                
                                	Neighbor's state
                                	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                
                                .. attribute:: neighbor_up_time
                                
                                	Amount of time since the adjacency is up (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary, self).__init__()

                                    self.yang_name = "neighbor-summary"
                                    self.yang_parent_name = "neighbor-detail"

                                    self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                    self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                    self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                    self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                    self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                    self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                    self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                    self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                    self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation()
                                    self.neighbor_bfd_information.parent = self
                                    self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                    self._children_yang_names.add("neighbor-bfd-information")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dr_bdr_state",
                                                    "neighbor_address_xr",
                                                    "neighbor_dead_timer",
                                                    "neighbor_dr_priority",
                                                    "neighbor_id",
                                                    "neighbor_interface_name",
                                                    "neighbor_madj_interface",
                                                    "neighbor_state",
                                                    "neighbor_up_time") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary, self).__setattr__(name, value)


                                class NeighborBfdInformation(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__init__()

                                        self.yang_name = "neighbor-bfd-information"
                                        self.yang_parent_name = "neighbor-summary"

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bfd_intf_enable_mode",
                                                        "bfd_status_flag") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bfd_intf_enable_mode.is_set or
                                            self.bfd_status_flag.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                            self.bfd_status_flag.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-bfd-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                        if (self.bfd_status_flag.is_set or self.bfd_status_flag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bfd_status_flag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bfd-intf-enable-mode" or name == "bfd-status-flag"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bfd-intf-enable-mode"):
                                            self.bfd_intf_enable_mode = value
                                            self.bfd_intf_enable_mode.value_namespace = name_space
                                            self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bfd-status-flag"):
                                            self.bfd_status_flag = value
                                            self.bfd_status_flag.value_namespace = name_space
                                            self.bfd_status_flag.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.dr_bdr_state.is_set or
                                        self.neighbor_address_xr.is_set or
                                        self.neighbor_dead_timer.is_set or
                                        self.neighbor_dr_priority.is_set or
                                        self.neighbor_id.is_set or
                                        self.neighbor_interface_name.is_set or
                                        self.neighbor_madj_interface.is_set or
                                        self.neighbor_state.is_set or
                                        self.neighbor_up_time.is_set or
                                        (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dr_bdr_state.yfilter != YFilter.not_set or
                                        self.neighbor_address_xr.yfilter != YFilter.not_set or
                                        self.neighbor_dead_timer.yfilter != YFilter.not_set or
                                        self.neighbor_dr_priority.yfilter != YFilter.not_set or
                                        self.neighbor_id.yfilter != YFilter.not_set or
                                        self.neighbor_interface_name.yfilter != YFilter.not_set or
                                        self.neighbor_madj_interface.yfilter != YFilter.not_set or
                                        self.neighbor_state.yfilter != YFilter.not_set or
                                        self.neighbor_up_time.yfilter != YFilter.not_set or
                                        (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "neighbor-summary" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dr_bdr_state.is_set or self.dr_bdr_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dr_bdr_state.get_name_leafdata())
                                    if (self.neighbor_address_xr.is_set or self.neighbor_address_xr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address_xr.get_name_leafdata())
                                    if (self.neighbor_dead_timer.is_set or self.neighbor_dead_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_dead_timer.get_name_leafdata())
                                    if (self.neighbor_dr_priority.is_set or self.neighbor_dr_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_dr_priority.get_name_leafdata())
                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                    if (self.neighbor_interface_name.is_set or self.neighbor_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_interface_name.get_name_leafdata())
                                    if (self.neighbor_madj_interface.is_set or self.neighbor_madj_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_madj_interface.get_name_leafdata())
                                    if (self.neighbor_state.is_set or self.neighbor_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_state.get_name_leafdata())
                                    if (self.neighbor_up_time.is_set or self.neighbor_up_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_up_time.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "neighbor-bfd-information"):
                                        if (self.neighbor_bfd_information is None):
                                            self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation()
                                            self.neighbor_bfd_information.parent = self
                                            self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                        return self.neighbor_bfd_information

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "neighbor-bfd-information" or name == "dr-bdr-state" or name == "neighbor-address-xr" or name == "neighbor-dead-timer" or name == "neighbor-dr-priority" or name == "neighbor-id" or name == "neighbor-interface-name" or name == "neighbor-madj-interface" or name == "neighbor-state" or name == "neighbor-up-time"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dr-bdr-state"):
                                        self.dr_bdr_state = value
                                        self.dr_bdr_state.value_namespace = name_space
                                        self.dr_bdr_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-address-xr"):
                                        self.neighbor_address_xr = value
                                        self.neighbor_address_xr.value_namespace = name_space
                                        self.neighbor_address_xr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-dead-timer"):
                                        self.neighbor_dead_timer = value
                                        self.neighbor_dead_timer.value_namespace = name_space
                                        self.neighbor_dead_timer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-dr-priority"):
                                        self.neighbor_dr_priority = value
                                        self.neighbor_dr_priority.value_namespace = name_space
                                        self.neighbor_dr_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-id"):
                                        self.neighbor_id = value
                                        self.neighbor_id.value_namespace = name_space
                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-interface-name"):
                                        self.neighbor_interface_name = value
                                        self.neighbor_interface_name.value_namespace = name_space
                                        self.neighbor_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-madj-interface"):
                                        self.neighbor_madj_interface = value
                                        self.neighbor_madj_interface.value_namespace = name_space
                                        self.neighbor_madj_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-state"):
                                        self.neighbor_state = value
                                        self.neighbor_state.value_namespace = name_space
                                        self.neighbor_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-up-time"):
                                        self.neighbor_up_time = value
                                        self.neighbor_up_time.value_namespace = name_space
                                        self.neighbor_up_time.value_namespace_prefix = name_space_prefix


                            class NeighborBfdInformation(Entity):
                                """
                                Neighbor BFD information
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD enable mode \- Default/Strict
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_status_flag
                                
                                	Status of the BFD Session
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__init__()

                                    self.yang_name = "neighbor-bfd-information"
                                    self.yang_parent_name = "neighbor-detail"

                                    self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                    self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bfd_intf_enable_mode",
                                                    "bfd_status_flag") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bfd_intf_enable_mode.is_set or
                                        self.bfd_status_flag.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                        self.bfd_status_flag.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "neighbor-bfd-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                    if (self.bfd_status_flag.is_set or self.bfd_status_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_status_flag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bfd-intf-enable-mode" or name == "bfd-status-flag"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bfd-intf-enable-mode"):
                                        self.bfd_intf_enable_mode = value
                                        self.bfd_intf_enable_mode.value_namespace = name_space
                                        self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bfd-status-flag"):
                                        self.bfd_status_flag = value
                                        self.bfd_status_flag.value_namespace = name_space
                                        self.bfd_status_flag.value_namespace_prefix = name_space_prefix


                            class NeighborRetransmissionInformation(Entity):
                                """
                                Retransmission information with this neighbor
                                
                                .. attribute:: area_first_flood_information
                                
                                	First flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_information_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flooding_index
                                
                                	Area scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_information
                                
                                	Next flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_information_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_information
                                
                                	First flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_information_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_information
                                
                                	Next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_information_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dbd_retransmission_count
                                
                                	Number of DBD retransmissions during last exchange
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dbd_retransmission_total_count
                                
                                	Total number of DBD retransmissions for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmission_count
                                
                                	Retransmission queue length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__init__()

                                    self.yang_name = "neighbor-retransmission-information"
                                    self.yang_parent_name = "neighbor-detail"

                                    self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                    self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                    self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                    self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                    self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                    self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                    self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                    self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                    self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                    self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                    self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                    self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                    self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                    self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                    self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                    self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                    self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                    self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                    self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_first_flood_information",
                                                    "area_first_flood_information_index",
                                                    "area_flooding_index",
                                                    "area_next_flood_information",
                                                    "area_next_flood_information_index",
                                                    "as_first_flood_information",
                                                    "as_first_flood_information_index",
                                                    "as_flood_index",
                                                    "as_next_flood_information",
                                                    "as_next_flood_information_index",
                                                    "dbd_retransmission_count",
                                                    "dbd_retransmission_total_count",
                                                    "last_retransmission_length",
                                                    "last_retransmission_time",
                                                    "lsa_retransmission_timer",
                                                    "maximum_retransmission_length",
                                                    "maximum_retransmission_time",
                                                    "neighbor_retransmission_count",
                                                    "number_of_retransmissions") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.area_first_flood_information.is_set or
                                        self.area_first_flood_information_index.is_set or
                                        self.area_flooding_index.is_set or
                                        self.area_next_flood_information.is_set or
                                        self.area_next_flood_information_index.is_set or
                                        self.as_first_flood_information.is_set or
                                        self.as_first_flood_information_index.is_set or
                                        self.as_flood_index.is_set or
                                        self.as_next_flood_information.is_set or
                                        self.as_next_flood_information_index.is_set or
                                        self.dbd_retransmission_count.is_set or
                                        self.dbd_retransmission_total_count.is_set or
                                        self.last_retransmission_length.is_set or
                                        self.last_retransmission_time.is_set or
                                        self.lsa_retransmission_timer.is_set or
                                        self.maximum_retransmission_length.is_set or
                                        self.maximum_retransmission_time.is_set or
                                        self.neighbor_retransmission_count.is_set or
                                        self.number_of_retransmissions.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_first_flood_information.yfilter != YFilter.not_set or
                                        self.area_first_flood_information_index.yfilter != YFilter.not_set or
                                        self.area_flooding_index.yfilter != YFilter.not_set or
                                        self.area_next_flood_information.yfilter != YFilter.not_set or
                                        self.area_next_flood_information_index.yfilter != YFilter.not_set or
                                        self.as_first_flood_information.yfilter != YFilter.not_set or
                                        self.as_first_flood_information_index.yfilter != YFilter.not_set or
                                        self.as_flood_index.yfilter != YFilter.not_set or
                                        self.as_next_flood_information.yfilter != YFilter.not_set or
                                        self.as_next_flood_information_index.yfilter != YFilter.not_set or
                                        self.dbd_retransmission_count.yfilter != YFilter.not_set or
                                        self.dbd_retransmission_total_count.yfilter != YFilter.not_set or
                                        self.last_retransmission_length.yfilter != YFilter.not_set or
                                        self.last_retransmission_time.yfilter != YFilter.not_set or
                                        self.lsa_retransmission_timer.yfilter != YFilter.not_set or
                                        self.maximum_retransmission_length.yfilter != YFilter.not_set or
                                        self.maximum_retransmission_time.yfilter != YFilter.not_set or
                                        self.neighbor_retransmission_count.yfilter != YFilter.not_set or
                                        self.number_of_retransmissions.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "neighbor-retransmission-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_first_flood_information.is_set or self.area_first_flood_information.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_first_flood_information.get_name_leafdata())
                                    if (self.area_first_flood_information_index.is_set or self.area_first_flood_information_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_first_flood_information_index.get_name_leafdata())
                                    if (self.area_flooding_index.is_set or self.area_flooding_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_flooding_index.get_name_leafdata())
                                    if (self.area_next_flood_information.is_set or self.area_next_flood_information.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_next_flood_information.get_name_leafdata())
                                    if (self.area_next_flood_information_index.is_set or self.area_next_flood_information_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_next_flood_information_index.get_name_leafdata())
                                    if (self.as_first_flood_information.is_set or self.as_first_flood_information.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_first_flood_information.get_name_leafdata())
                                    if (self.as_first_flood_information_index.is_set or self.as_first_flood_information_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_first_flood_information_index.get_name_leafdata())
                                    if (self.as_flood_index.is_set or self.as_flood_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_flood_index.get_name_leafdata())
                                    if (self.as_next_flood_information.is_set or self.as_next_flood_information.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_next_flood_information.get_name_leafdata())
                                    if (self.as_next_flood_information_index.is_set or self.as_next_flood_information_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_next_flood_information_index.get_name_leafdata())
                                    if (self.dbd_retransmission_count.is_set or self.dbd_retransmission_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dbd_retransmission_count.get_name_leafdata())
                                    if (self.dbd_retransmission_total_count.is_set or self.dbd_retransmission_total_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dbd_retransmission_total_count.get_name_leafdata())
                                    if (self.last_retransmission_length.is_set or self.last_retransmission_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_retransmission_length.get_name_leafdata())
                                    if (self.last_retransmission_time.is_set or self.last_retransmission_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_retransmission_time.get_name_leafdata())
                                    if (self.lsa_retransmission_timer.is_set or self.lsa_retransmission_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_retransmission_timer.get_name_leafdata())
                                    if (self.maximum_retransmission_length.is_set or self.maximum_retransmission_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_retransmission_length.get_name_leafdata())
                                    if (self.maximum_retransmission_time.is_set or self.maximum_retransmission_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_retransmission_time.get_name_leafdata())
                                    if (self.neighbor_retransmission_count.is_set or self.neighbor_retransmission_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_retransmission_count.get_name_leafdata())
                                    if (self.number_of_retransmissions.is_set or self.number_of_retransmissions.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number_of_retransmissions.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "area-first-flood-information" or name == "area-first-flood-information-index" or name == "area-flooding-index" or name == "area-next-flood-information" or name == "area-next-flood-information-index" or name == "as-first-flood-information" or name == "as-first-flood-information-index" or name == "as-flood-index" or name == "as-next-flood-information" or name == "as-next-flood-information-index" or name == "dbd-retransmission-count" or name == "dbd-retransmission-total-count" or name == "last-retransmission-length" or name == "last-retransmission-time" or name == "lsa-retransmission-timer" or name == "maximum-retransmission-length" or name == "maximum-retransmission-time" or name == "neighbor-retransmission-count" or name == "number-of-retransmissions"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-first-flood-information"):
                                        self.area_first_flood_information = value
                                        self.area_first_flood_information.value_namespace = name_space
                                        self.area_first_flood_information.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-first-flood-information-index"):
                                        self.area_first_flood_information_index = value
                                        self.area_first_flood_information_index.value_namespace = name_space
                                        self.area_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-flooding-index"):
                                        self.area_flooding_index = value
                                        self.area_flooding_index.value_namespace = name_space
                                        self.area_flooding_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-next-flood-information"):
                                        self.area_next_flood_information = value
                                        self.area_next_flood_information.value_namespace = name_space
                                        self.area_next_flood_information.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-next-flood-information-index"):
                                        self.area_next_flood_information_index = value
                                        self.area_next_flood_information_index.value_namespace = name_space
                                        self.area_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as-first-flood-information"):
                                        self.as_first_flood_information = value
                                        self.as_first_flood_information.value_namespace = name_space
                                        self.as_first_flood_information.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as-first-flood-information-index"):
                                        self.as_first_flood_information_index = value
                                        self.as_first_flood_information_index.value_namespace = name_space
                                        self.as_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as-flood-index"):
                                        self.as_flood_index = value
                                        self.as_flood_index.value_namespace = name_space
                                        self.as_flood_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as-next-flood-information"):
                                        self.as_next_flood_information = value
                                        self.as_next_flood_information.value_namespace = name_space
                                        self.as_next_flood_information.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as-next-flood-information-index"):
                                        self.as_next_flood_information_index = value
                                        self.as_next_flood_information_index.value_namespace = name_space
                                        self.as_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dbd-retransmission-count"):
                                        self.dbd_retransmission_count = value
                                        self.dbd_retransmission_count.value_namespace = name_space
                                        self.dbd_retransmission_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dbd-retransmission-total-count"):
                                        self.dbd_retransmission_total_count = value
                                        self.dbd_retransmission_total_count.value_namespace = name_space
                                        self.dbd_retransmission_total_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-retransmission-length"):
                                        self.last_retransmission_length = value
                                        self.last_retransmission_length.value_namespace = name_space
                                        self.last_retransmission_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-retransmission-time"):
                                        self.last_retransmission_time = value
                                        self.last_retransmission_time.value_namespace = name_space
                                        self.last_retransmission_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-retransmission-timer"):
                                        self.lsa_retransmission_timer = value
                                        self.lsa_retransmission_timer.value_namespace = name_space
                                        self.lsa_retransmission_timer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-retransmission-length"):
                                        self.maximum_retransmission_length = value
                                        self.maximum_retransmission_length.value_namespace = name_space
                                        self.maximum_retransmission_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-retransmission-time"):
                                        self.maximum_retransmission_time = value
                                        self.maximum_retransmission_time.value_namespace = name_space
                                        self.maximum_retransmission_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-retransmission-count"):
                                        self.neighbor_retransmission_count = value
                                        self.neighbor_retransmission_count.value_namespace = name_space
                                        self.neighbor_retransmission_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "number-of-retransmissions"):
                                        self.number_of_retransmissions = value
                                        self.number_of_retransmissions.value_namespace = name_space
                                        self.number_of_retransmissions.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.adjacency_sid_label.is_set or
                                    self.adjacency_sid_protected.is_set or
                                    self.adjacency_sid_unprotected_label.is_set or
                                    self.interface_name.is_set or
                                    self.interface_type.is_set or
                                    self.last_oob_time.is_set or
                                    self.lfa_interface.is_set or
                                    self.lfa_neighbor_id.is_set or
                                    self.lfa_neighbor_revision.is_set or
                                    self.lfa_next_hop.is_set or
                                    self.neighbor_ack_list_count.is_set or
                                    self.neighbor_ack_list_high_watermark.is_set or
                                    self.neighbor_address.is_set or
                                    self.neighbor_area_id.is_set or
                                    self.neighbor_backup_designated_router_address.is_set or
                                    self.neighbor_cost.is_set or
                                    self.neighbor_designated_router_address.is_set or
                                    self.neighbor_filter.is_set or
                                    self.neighbor_lls_option.is_set or
                                    self.neighbor_option.is_set or
                                    self.next_poll_interval.is_set or
                                    self.nsf_router_state.is_set or
                                    self.oob_resynchronization.is_set or
                                    self.pending_events.is_set or
                                    self.poll_interval.is_set or
                                    self.state_change_count.is_set or
                                    (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_data()) or
                                    (self.neighbor_retransmission_information is not None and self.neighbor_retransmission_information.has_data()) or
                                    (self.neighbor_summary is not None and self.neighbor_summary.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.adjacency_sid_label.yfilter != YFilter.not_set or
                                    self.adjacency_sid_protected.yfilter != YFilter.not_set or
                                    self.adjacency_sid_unprotected_label.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.interface_type.yfilter != YFilter.not_set or
                                    self.last_oob_time.yfilter != YFilter.not_set or
                                    self.lfa_interface.yfilter != YFilter.not_set or
                                    self.lfa_neighbor_id.yfilter != YFilter.not_set or
                                    self.lfa_neighbor_revision.yfilter != YFilter.not_set or
                                    self.lfa_next_hop.yfilter != YFilter.not_set or
                                    self.neighbor_ack_list_count.yfilter != YFilter.not_set or
                                    self.neighbor_ack_list_high_watermark.yfilter != YFilter.not_set or
                                    self.neighbor_address.yfilter != YFilter.not_set or
                                    self.neighbor_area_id.yfilter != YFilter.not_set or
                                    self.neighbor_backup_designated_router_address.yfilter != YFilter.not_set or
                                    self.neighbor_cost.yfilter != YFilter.not_set or
                                    self.neighbor_designated_router_address.yfilter != YFilter.not_set or
                                    self.neighbor_filter.yfilter != YFilter.not_set or
                                    self.neighbor_lls_option.yfilter != YFilter.not_set or
                                    self.neighbor_option.yfilter != YFilter.not_set or
                                    self.next_poll_interval.yfilter != YFilter.not_set or
                                    self.nsf_router_state.yfilter != YFilter.not_set or
                                    self.oob_resynchronization.yfilter != YFilter.not_set or
                                    self.pending_events.yfilter != YFilter.not_set or
                                    self.poll_interval.yfilter != YFilter.not_set or
                                    self.state_change_count.yfilter != YFilter.not_set or
                                    (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_operation()) or
                                    (self.neighbor_retransmission_information is not None and self.neighbor_retransmission_information.has_operation()) or
                                    (self.neighbor_summary is not None and self.neighbor_summary.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbor-detail" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.adjacency_sid_label.is_set or self.adjacency_sid_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_sid_label.get_name_leafdata())
                                if (self.adjacency_sid_protected.is_set or self.adjacency_sid_protected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_sid_protected.get_name_leafdata())
                                if (self.adjacency_sid_unprotected_label.is_set or self.adjacency_sid_unprotected_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_sid_unprotected_label.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.interface_type.is_set or self.interface_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_type.get_name_leafdata())
                                if (self.last_oob_time.is_set or self.last_oob_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_oob_time.get_name_leafdata())
                                if (self.lfa_interface.is_set or self.lfa_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lfa_interface.get_name_leafdata())
                                if (self.lfa_neighbor_id.is_set or self.lfa_neighbor_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lfa_neighbor_id.get_name_leafdata())
                                if (self.lfa_neighbor_revision.is_set or self.lfa_neighbor_revision.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lfa_neighbor_revision.get_name_leafdata())
                                if (self.lfa_next_hop.is_set or self.lfa_next_hop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lfa_next_hop.get_name_leafdata())
                                if (self.neighbor_ack_list_count.is_set or self.neighbor_ack_list_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_ack_list_count.get_name_leafdata())
                                if (self.neighbor_ack_list_high_watermark.is_set or self.neighbor_ack_list_high_watermark.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_ack_list_high_watermark.get_name_leafdata())
                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                if (self.neighbor_area_id.is_set or self.neighbor_area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_area_id.get_name_leafdata())
                                if (self.neighbor_backup_designated_router_address.is_set or self.neighbor_backup_designated_router_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_backup_designated_router_address.get_name_leafdata())
                                if (self.neighbor_cost.is_set or self.neighbor_cost.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_cost.get_name_leafdata())
                                if (self.neighbor_designated_router_address.is_set or self.neighbor_designated_router_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_designated_router_address.get_name_leafdata())
                                if (self.neighbor_filter.is_set or self.neighbor_filter.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_filter.get_name_leafdata())
                                if (self.neighbor_lls_option.is_set or self.neighbor_lls_option.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_lls_option.get_name_leafdata())
                                if (self.neighbor_option.is_set or self.neighbor_option.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_option.get_name_leafdata())
                                if (self.next_poll_interval.is_set or self.next_poll_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_poll_interval.get_name_leafdata())
                                if (self.nsf_router_state.is_set or self.nsf_router_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsf_router_state.get_name_leafdata())
                                if (self.oob_resynchronization.is_set or self.oob_resynchronization.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.oob_resynchronization.get_name_leafdata())
                                if (self.pending_events.is_set or self.pending_events.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pending_events.get_name_leafdata())
                                if (self.poll_interval.is_set or self.poll_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.poll_interval.get_name_leafdata())
                                if (self.state_change_count.is_set or self.state_change_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state_change_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "neighbor-bfd-information"):
                                    if (self.neighbor_bfd_information is None):
                                        self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation()
                                        self.neighbor_bfd_information.parent = self
                                        self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                    return self.neighbor_bfd_information

                                if (child_yang_name == "neighbor-retransmission-information"):
                                    if (self.neighbor_retransmission_information is None):
                                        self.neighbor_retransmission_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation()
                                        self.neighbor_retransmission_information.parent = self
                                        self._children_name_map["neighbor_retransmission_information"] = "neighbor-retransmission-information"
                                    return self.neighbor_retransmission_information

                                if (child_yang_name == "neighbor-summary"):
                                    if (self.neighbor_summary is None):
                                        self.neighbor_summary = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary()
                                        self.neighbor_summary.parent = self
                                        self._children_name_map["neighbor_summary"] = "neighbor-summary"
                                    return self.neighbor_summary

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "neighbor-bfd-information" or name == "neighbor-retransmission-information" or name == "neighbor-summary" or name == "adjacency-sid-label" or name == "adjacency-sid-protected" or name == "adjacency-sid-unprotected-label" or name == "interface-name" or name == "interface-type" or name == "last-oob-time" or name == "lfa-interface" or name == "lfa-neighbor-id" or name == "lfa-neighbor-revision" or name == "lfa-next-hop" or name == "neighbor-ack-list-count" or name == "neighbor-ack-list-high-watermark" or name == "neighbor-address" or name == "neighbor-area-id" or name == "neighbor-backup-designated-router-address" or name == "neighbor-cost" or name == "neighbor-designated-router-address" or name == "neighbor-filter" or name == "neighbor-lls-option" or name == "neighbor-option" or name == "next-poll-interval" or name == "nsf-router-state" or name == "oob-resynchronization" or name == "pending-events" or name == "poll-interval" or name == "state-change-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "adjacency-sid-label"):
                                    self.adjacency_sid_label = value
                                    self.adjacency_sid_label.value_namespace = name_space
                                    self.adjacency_sid_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-sid-protected"):
                                    self.adjacency_sid_protected = value
                                    self.adjacency_sid_protected.value_namespace = name_space
                                    self.adjacency_sid_protected.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-sid-unprotected-label"):
                                    self.adjacency_sid_unprotected_label = value
                                    self.adjacency_sid_unprotected_label.value_namespace = name_space
                                    self.adjacency_sid_unprotected_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-type"):
                                    self.interface_type = value
                                    self.interface_type.value_namespace = name_space
                                    self.interface_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-oob-time"):
                                    self.last_oob_time = value
                                    self.last_oob_time.value_namespace = name_space
                                    self.last_oob_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "lfa-interface"):
                                    self.lfa_interface = value
                                    self.lfa_interface.value_namespace = name_space
                                    self.lfa_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "lfa-neighbor-id"):
                                    self.lfa_neighbor_id = value
                                    self.lfa_neighbor_id.value_namespace = name_space
                                    self.lfa_neighbor_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "lfa-neighbor-revision"):
                                    self.lfa_neighbor_revision = value
                                    self.lfa_neighbor_revision.value_namespace = name_space
                                    self.lfa_neighbor_revision.value_namespace_prefix = name_space_prefix
                                if(value_path == "lfa-next-hop"):
                                    self.lfa_next_hop = value
                                    self.lfa_next_hop.value_namespace = name_space
                                    self.lfa_next_hop.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-ack-list-count"):
                                    self.neighbor_ack_list_count = value
                                    self.neighbor_ack_list_count.value_namespace = name_space
                                    self.neighbor_ack_list_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-ack-list-high-watermark"):
                                    self.neighbor_ack_list_high_watermark = value
                                    self.neighbor_ack_list_high_watermark.value_namespace = name_space
                                    self.neighbor_ack_list_high_watermark.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-address"):
                                    self.neighbor_address = value
                                    self.neighbor_address.value_namespace = name_space
                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-area-id"):
                                    self.neighbor_area_id = value
                                    self.neighbor_area_id.value_namespace = name_space
                                    self.neighbor_area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-backup-designated-router-address"):
                                    self.neighbor_backup_designated_router_address = value
                                    self.neighbor_backup_designated_router_address.value_namespace = name_space
                                    self.neighbor_backup_designated_router_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-cost"):
                                    self.neighbor_cost = value
                                    self.neighbor_cost.value_namespace = name_space
                                    self.neighbor_cost.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-designated-router-address"):
                                    self.neighbor_designated_router_address = value
                                    self.neighbor_designated_router_address.value_namespace = name_space
                                    self.neighbor_designated_router_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-filter"):
                                    self.neighbor_filter = value
                                    self.neighbor_filter.value_namespace = name_space
                                    self.neighbor_filter.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-lls-option"):
                                    self.neighbor_lls_option = value
                                    self.neighbor_lls_option.value_namespace = name_space
                                    self.neighbor_lls_option.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-option"):
                                    self.neighbor_option = value
                                    self.neighbor_option.value_namespace = name_space
                                    self.neighbor_option.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-poll-interval"):
                                    self.next_poll_interval = value
                                    self.next_poll_interval.value_namespace = name_space
                                    self.next_poll_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsf-router-state"):
                                    self.nsf_router_state = value
                                    self.nsf_router_state.value_namespace = name_space
                                    self.nsf_router_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "oob-resynchronization"):
                                    self.oob_resynchronization = value
                                    self.oob_resynchronization.value_namespace = name_space
                                    self.oob_resynchronization.value_namespace_prefix = name_space_prefix
                                if(value_path == "pending-events"):
                                    self.pending_events = value
                                    self.pending_events.value_namespace = name_space
                                    self.pending_events.value_namespace_prefix = name_space_prefix
                                if(value_path == "poll-interval"):
                                    self.poll_interval = value
                                    self.poll_interval.value_namespace = name_space
                                    self.poll_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "state-change-count"):
                                    self.state_change_count = value
                                    self.state_change_count.value_namespace = name_space
                                    self.state_change_count.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.neighbor_detail:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.neighbor_detail:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-details" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "neighbor-detail"):
                                for c in self.neighbor_detail:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.neighbor_detail.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor-detail"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.neighbor_details is not None and self.neighbor_details.has_data()) or
                            (self.neighbors is not None and self.neighbors.has_data()) or
                            (self.requests is not None and self.requests.has_data()) or
                            (self.retransmissions is not None and self.retransmissions.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.neighbor_details is not None and self.neighbor_details.has_operation()) or
                            (self.neighbors is not None and self.neighbors.has_operation()) or
                            (self.requests is not None and self.requests.has_operation()) or
                            (self.retransmissions is not None and self.retransmissions.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "adjacency-information" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-details"):
                            if (self.neighbor_details is None):
                                self.neighbor_details = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails()
                                self.neighbor_details.parent = self
                                self._children_name_map["neighbor_details"] = "neighbor-details"
                            return self.neighbor_details

                        if (child_yang_name == "neighbors"):
                            if (self.neighbors is None):
                                self.neighbors = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors()
                                self.neighbors.parent = self
                                self._children_name_map["neighbors"] = "neighbors"
                            return self.neighbors

                        if (child_yang_name == "requests"):
                            if (self.requests is None):
                                self.requests = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests()
                                self.requests.parent = self
                                self._children_name_map["requests"] = "requests"
                            return self.requests

                        if (child_yang_name == "retransmissions"):
                            if (self.retransmissions is None):
                                self.retransmissions = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions()
                                self.retransmissions.parent = self
                                self._children_name_map["retransmissions"] = "retransmissions"
                            return self.retransmissions

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-details" or name == "neighbors" or name == "requests" or name == "retransmissions"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RouteInformation(Entity):
                    """
                    Container for OSPF routing tables
                    
                    .. attribute:: backup_routes
                    
                    	OSPF Route Table Including Backup Paths
                    	**type**\:   :py:class:`BackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes>`
                    
                    .. attribute:: connected_routes
                    
                    	OSPF Connected Route Table
                    	**type**\:   :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes>`
                    
                    .. attribute:: external_routes
                    
                    	OSPF External Route Table
                    	**type**\:   :py:class:`ExternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes>`
                    
                    .. attribute:: local_routes
                    
                    	OSPF Local Route Table
                    	**type**\:   :py:class:`LocalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes>`
                    
                    .. attribute:: multicast_intact_backup_routes
                    
                    	OSPF Route Table Including Multicast intact Backup Paths
                    	**type**\:   :py:class:`MulticastIntactBackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes>`
                    
                    .. attribute:: multicast_intact_route_table
                    
                    	OSPF Route Table including multicast\-intact routes
                    	**type**\:   :py:class:`MulticastIntactRouteTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable>`
                    
                    .. attribute:: route_areas
                    
                    	OSPF Area Route Table
                    	**type**\:   :py:class:`RouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas>`
                    
                    .. attribute:: route_table
                    
                    	OSPF Route Table
                    	**type**\:   :py:class:`RouteTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable>`
                    
                    .. attribute:: summary_information
                    
                    	OSPF route summary statistics
                    	**type**\:   :py:class:`SummaryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation, self).__init__()

                        self.yang_name = "route-information"
                        self.yang_parent_name = "default-vrf"

                        self.backup_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes()
                        self.backup_routes.parent = self
                        self._children_name_map["backup_routes"] = "backup-routes"
                        self._children_yang_names.add("backup-routes")

                        self.connected_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes()
                        self.connected_routes.parent = self
                        self._children_name_map["connected_routes"] = "connected-routes"
                        self._children_yang_names.add("connected-routes")

                        self.external_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes()
                        self.external_routes.parent = self
                        self._children_name_map["external_routes"] = "external-routes"
                        self._children_yang_names.add("external-routes")

                        self.local_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes()
                        self.local_routes.parent = self
                        self._children_name_map["local_routes"] = "local-routes"
                        self._children_yang_names.add("local-routes")

                        self.multicast_intact_backup_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes()
                        self.multicast_intact_backup_routes.parent = self
                        self._children_name_map["multicast_intact_backup_routes"] = "multicast-intact-backup-routes"
                        self._children_yang_names.add("multicast-intact-backup-routes")

                        self.multicast_intact_route_table = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable()
                        self.multicast_intact_route_table.parent = self
                        self._children_name_map["multicast_intact_route_table"] = "multicast-intact-route-table"
                        self._children_yang_names.add("multicast-intact-route-table")

                        self.route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas()
                        self.route_areas.parent = self
                        self._children_name_map["route_areas"] = "route-areas"
                        self._children_yang_names.add("route-areas")

                        self.route_table = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable()
                        self.route_table.parent = self
                        self._children_name_map["route_table"] = "route-table"
                        self._children_yang_names.add("route-table")

                        self.summary_information = Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation()
                        self.summary_information.parent = self
                        self._children_name_map["summary_information"] = "summary-information"
                        self._children_yang_names.add("summary-information")


                    class BackupRoutes(Entity):
                        """
                        OSPF Route Table Including Backup Paths
                        
                        .. attribute:: backup_route
                        
                        	OSPF route including backup paths
                        	**type**\: list of    :py:class:`BackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes, self).__init__()

                            self.yang_name = "backup-routes"
                            self.yang_parent_name = "route-information"

                            self.backup_route = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes, self).__setattr__(name, value)


                        class BackupRoute(Entity):
                            """
                            OSPF route including backup paths
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: route_connected
                            
                            	If true, connected route
                            	**type**\:  bool
                            
                            .. attribute:: route_info
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo>`
                            
                            .. attribute:: route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath>`
                            
                            .. attribute:: route_prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute, self).__init__()

                                self.yang_name = "backup-route"
                                self.yang_parent_name = "backup-routes"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_connected = YLeaf(YType.boolean, "route-connected")

                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                self.route_prefix = YLeaf(YType.str, "route-prefix")

                                self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo()
                                self.route_info.parent = self
                                self._children_name_map["route_info"] = "route-info"
                                self._children_yang_names.add("route-info")

                                self.route_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length",
                                                "route_connected",
                                                "route_metric",
                                                "route_prefix",
                                                "route_prefix_length",
                                                "route_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute, self).__setattr__(name, value)


                            class RouteInfo(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_auto_excluded
                                
                                	If true, exclude from TE paths
                                	**type**\:  bool
                                
                                .. attribute:: route_fail_time
                                
                                	Last time update failed
                                	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime>`
                                
                                .. attribute:: route_forward_distance
                                
                                	Forward distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_source
                                
                                	Protocol source
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_spf_priority
                                
                                	SPF priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: route_srte_nbr_registered
                                
                                	SRTE registered neigbhor count on route
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_srte_prefix_registered
                                
                                	If true, SRTE registered prefix route
                                	**type**\:  bool
                                
                                .. attribute:: route_te_metric
                                
                                	TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_update_time
                                
                                	Last time updated
                                	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo, self).__init__()

                                    self.yang_name = "route-info"
                                    self.yang_parent_name = "backup-route"

                                    self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                    self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                    self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                    self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                    self.route_source = YLeaf(YType.uint16, "route-source")

                                    self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                    self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                    self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                    self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                    self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime()
                                    self.route_fail_time.parent = self
                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                    self._children_yang_names.add("route-fail-time")

                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime()
                                    self.route_update_time.parent = self
                                    self._children_name_map["route_update_time"] = "route-update-time"
                                    self._children_yang_names.add("route-update-time")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("route_area_id",
                                                    "route_auto_excluded",
                                                    "route_forward_distance",
                                                    "route_rib_version",
                                                    "route_source",
                                                    "route_spf_priority",
                                                    "route_spf_version",
                                                    "route_srte_nbr_registered",
                                                    "route_srte_prefix_registered",
                                                    "route_te_metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo, self).__setattr__(name, value)


                                class RouteUpdateTime(Entity):
                                    """
                                    Last time updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                        self.yang_name = "route-update-time"
                                        self.yang_parent_name = "route-info"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-update-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix


                                class RouteFailTime(Entity):
                                    """
                                    Last time update failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime, self).__init__()

                                        self.yang_name = "route-fail-time"
                                        self.yang_parent_name = "route-info"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-fail-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.route_area_id.is_set or
                                        self.route_auto_excluded.is_set or
                                        self.route_forward_distance.is_set or
                                        self.route_rib_version.is_set or
                                        self.route_source.is_set or
                                        self.route_spf_priority.is_set or
                                        self.route_spf_version.is_set or
                                        self.route_srte_nbr_registered.is_set or
                                        self.route_srte_prefix_registered.is_set or
                                        self.route_te_metric.is_set or
                                        (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                        (self.route_update_time is not None and self.route_update_time.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.route_area_id.yfilter != YFilter.not_set or
                                        self.route_auto_excluded.yfilter != YFilter.not_set or
                                        self.route_forward_distance.yfilter != YFilter.not_set or
                                        self.route_rib_version.yfilter != YFilter.not_set or
                                        self.route_source.yfilter != YFilter.not_set or
                                        self.route_spf_priority.yfilter != YFilter.not_set or
                                        self.route_spf_version.yfilter != YFilter.not_set or
                                        self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                        self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                        self.route_te_metric.yfilter != YFilter.not_set or
                                        (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                        (self.route_update_time is not None and self.route_update_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                    if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                    if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                    if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                    if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_source.get_name_leafdata())
                                    if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                    if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                    if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                    if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                    if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-fail-time"):
                                        if (self.route_fail_time is None):
                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                        return self.route_fail_time

                                    if (child_yang_name == "route-update-time"):
                                        if (self.route_update_time is None):
                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                        return self.route_update_time

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "route-area-id"):
                                        self.route_area_id = value
                                        self.route_area_id.value_namespace = name_space
                                        self.route_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-auto-excluded"):
                                        self.route_auto_excluded = value
                                        self.route_auto_excluded.value_namespace = name_space
                                        self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-forward-distance"):
                                        self.route_forward_distance = value
                                        self.route_forward_distance.value_namespace = name_space
                                        self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-rib-version"):
                                        self.route_rib_version = value
                                        self.route_rib_version.value_namespace = name_space
                                        self.route_rib_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-source"):
                                        self.route_source = value
                                        self.route_source.value_namespace = name_space
                                        self.route_source.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-spf-priority"):
                                        self.route_spf_priority = value
                                        self.route_spf_priority.value_namespace = name_space
                                        self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-spf-version"):
                                        self.route_spf_version = value
                                        self.route_spf_version.value_namespace = name_space
                                        self.route_spf_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-srte-nbr-registered"):
                                        self.route_srte_nbr_registered = value
                                        self.route_srte_nbr_registered.value_namespace = name_space
                                        self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-srte-prefix-registered"):
                                        self.route_srte_prefix_registered = value
                                        self.route_srte_prefix_registered.value_namespace = name_space
                                        self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-te-metric"):
                                        self.route_te_metric = value
                                        self.route_te_metric.value_namespace = name_space
                                        self.route_te_metric.value_namespace_prefix = name_space_prefix


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: lsa_type
                                
                                	LSA type, see RFC2328 etc
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_backup_path
                                
                                	Backup Path Info
                                	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath>`
                                
                                .. attribute:: route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: route_lsaid
                                
                                	LSA ID, see RFC2328
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_id
                                
                                	Path ID of path
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_path_is_mcast_intact
                                
                                	Multicast\-intact path
                                	**type**\:  bool
                                
                                .. attribute:: route_path_is_ucmp_path
                                
                                	UCMP path
                                	**type**\:  bool
                                
                                .. attribute:: route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_path
                                
                                	SR Microloop avoidance Path Info
                                	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "backup-route"

                                    self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                    self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                    self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                    self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                    self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                    self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                    self.route_source = YLeaf(YType.str, "route-source")

                                    self.route_backup_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath()
                                    self.route_backup_path.parent = self
                                    self._children_name_map["route_backup_path"] = "route-backup-path"
                                    self._children_yang_names.add("route-backup-path")

                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath()
                                    self.sr_microloop_avoidance_path.parent = self
                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                    self._children_yang_names.add("sr-microloop-avoidance-path")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("lsa_type",
                                                    "route_interface_name",
                                                    "route_lsaid",
                                                    "route_metric",
                                                    "route_next_hop_address",
                                                    "route_path_id",
                                                    "route_path_is_mcast_intact",
                                                    "route_path_is_ucmp_path",
                                                    "route_source") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath, self).__setattr__(name, value)


                                class RouteBackupPath(Entity):
                                    """
                                    Backup Path Info
                                    
                                    .. attribute:: backup_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_remote_lfa
                                    
                                    	IP address of remote LFA
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_repair
                                    
                                    	Backup Repair List
                                    	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair>`
                                    
                                    .. attribute:: backup_repair_list_size
                                    
                                    	Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: backup_route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_tunnel_interface_name
                                    
                                    	Backup Tunnel Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: downstream
                                    
                                    	Downstream
                                    	**type**\:  bool
                                    
                                    .. attribute:: line_card_disjoint
                                    
                                    	Line Card Disjoint
                                    	**type**\:  bool
                                    
                                    .. attribute:: node_protect
                                    
                                    	Node Protect
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_path
                                    
                                    	Primary Path
                                    	**type**\:  bool
                                    
                                    .. attribute:: srlg_disjoint
                                    
                                    	SRLG Disjoint
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath, self).__init__()

                                        self.yang_name = "route-backup-path"
                                        self.yang_parent_name = "route-path"

                                        self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                        self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                        self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                        self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                        self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                        self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                        self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                        self.downstream = YLeaf(YType.boolean, "downstream")

                                        self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                        self.node_protect = YLeaf(YType.boolean, "node-protect")

                                        self.primary_path = YLeaf(YType.boolean, "primary-path")

                                        self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                        self.backup_repair = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("backup_metric",
                                                        "backup_remote_lfa",
                                                        "backup_repair_list_size",
                                                        "backup_route_interface_name",
                                                        "backup_route_next_hop_address",
                                                        "backup_route_source",
                                                        "backup_tunnel_interface_name",
                                                        "downstream",
                                                        "line_card_disjoint",
                                                        "node_protect",
                                                        "primary_path",
                                                        "srlg_disjoint") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath, self).__setattr__(name, value)


                                    class BackupRepair(Entity):
                                        """
                                        Backup Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                            self.yang_name = "backup-repair"
                                            self.yang_parent_name = "route-backup-path"

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("repair_element_id",
                                                            "repair_element_type",
                                                            "repair_label") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.repair_element_id.is_set or
                                                self.repair_element_type.is_set or
                                                self.repair_label.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.repair_element_id.yfilter != YFilter.not_set or
                                                self.repair_element_type.yfilter != YFilter.not_set or
                                                self.repair_label.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup-repair" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                            if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                            if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_label.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "repair-element-id"):
                                                self.repair_element_id = value
                                                self.repair_element_id.value_namespace = name_space
                                                self.repair_element_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-element-type"):
                                                self.repair_element_type = value
                                                self.repair_element_type.value_namespace = name_space
                                                self.repair_element_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-label"):
                                                self.repair_label = value
                                                self.repair_label.value_namespace = name_space
                                                self.repair_label.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup_repair:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.backup_metric.is_set or
                                            self.backup_remote_lfa.is_set or
                                            self.backup_repair_list_size.is_set or
                                            self.backup_route_interface_name.is_set or
                                            self.backup_route_next_hop_address.is_set or
                                            self.backup_route_source.is_set or
                                            self.backup_tunnel_interface_name.is_set or
                                            self.downstream.is_set or
                                            self.line_card_disjoint.is_set or
                                            self.node_protect.is_set or
                                            self.primary_path.is_set or
                                            self.srlg_disjoint.is_set)

                                    def has_operation(self):
                                        for c in self.backup_repair:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.backup_metric.yfilter != YFilter.not_set or
                                            self.backup_remote_lfa.yfilter != YFilter.not_set or
                                            self.backup_repair_list_size.yfilter != YFilter.not_set or
                                            self.backup_route_interface_name.yfilter != YFilter.not_set or
                                            self.backup_route_next_hop_address.yfilter != YFilter.not_set or
                                            self.backup_route_source.yfilter != YFilter.not_set or
                                            self.backup_tunnel_interface_name.yfilter != YFilter.not_set or
                                            self.downstream.yfilter != YFilter.not_set or
                                            self.line_card_disjoint.yfilter != YFilter.not_set or
                                            self.node_protect.yfilter != YFilter.not_set or
                                            self.primary_path.yfilter != YFilter.not_set or
                                            self.srlg_disjoint.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-backup-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.backup_metric.is_set or self.backup_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_metric.get_name_leafdata())
                                        if (self.backup_remote_lfa.is_set or self.backup_remote_lfa.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_remote_lfa.get_name_leafdata())
                                        if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                        if (self.backup_route_interface_name.is_set or self.backup_route_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_route_interface_name.get_name_leafdata())
                                        if (self.backup_route_next_hop_address.is_set or self.backup_route_next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_route_next_hop_address.get_name_leafdata())
                                        if (self.backup_route_source.is_set or self.backup_route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_route_source.get_name_leafdata())
                                        if (self.backup_tunnel_interface_name.is_set or self.backup_tunnel_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_tunnel_interface_name.get_name_leafdata())
                                        if (self.downstream.is_set or self.downstream.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.downstream.get_name_leafdata())
                                        if (self.line_card_disjoint.is_set or self.line_card_disjoint.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.line_card_disjoint.get_name_leafdata())
                                        if (self.node_protect.is_set or self.node_protect.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.node_protect.get_name_leafdata())
                                        if (self.primary_path.is_set or self.primary_path.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.primary_path.get_name_leafdata())
                                        if (self.srlg_disjoint.is_set or self.srlg_disjoint.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.srlg_disjoint.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup-repair"):
                                            for c in self.backup_repair:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup_repair.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup-repair" or name == "backup-metric" or name == "backup-remote-lfa" or name == "backup-repair-list-size" or name == "backup-route-interface-name" or name == "backup-route-next-hop-address" or name == "backup-route-source" or name == "backup-tunnel-interface-name" or name == "downstream" or name == "line-card-disjoint" or name == "node-protect" or name == "primary-path" or name == "srlg-disjoint"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "backup-metric"):
                                            self.backup_metric = value
                                            self.backup_metric.value_namespace = name_space
                                            self.backup_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-remote-lfa"):
                                            self.backup_remote_lfa = value
                                            self.backup_remote_lfa.value_namespace = name_space
                                            self.backup_remote_lfa.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-repair-list-size"):
                                            self.backup_repair_list_size = value
                                            self.backup_repair_list_size.value_namespace = name_space
                                            self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-route-interface-name"):
                                            self.backup_route_interface_name = value
                                            self.backup_route_interface_name.value_namespace = name_space
                                            self.backup_route_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-route-next-hop-address"):
                                            self.backup_route_next_hop_address = value
                                            self.backup_route_next_hop_address.value_namespace = name_space
                                            self.backup_route_next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-route-source"):
                                            self.backup_route_source = value
                                            self.backup_route_source.value_namespace = name_space
                                            self.backup_route_source.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-tunnel-interface-name"):
                                            self.backup_tunnel_interface_name = value
                                            self.backup_tunnel_interface_name.value_namespace = name_space
                                            self.backup_tunnel_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "downstream"):
                                            self.downstream = value
                                            self.downstream.value_namespace = name_space
                                            self.downstream.value_namespace_prefix = name_space_prefix
                                        if(value_path == "line-card-disjoint"):
                                            self.line_card_disjoint = value
                                            self.line_card_disjoint.value_namespace = name_space
                                            self.line_card_disjoint.value_namespace_prefix = name_space_prefix
                                        if(value_path == "node-protect"):
                                            self.node_protect = value
                                            self.node_protect.value_namespace = name_space
                                            self.node_protect.value_namespace_prefix = name_space_prefix
                                        if(value_path == "primary-path"):
                                            self.primary_path = value
                                            self.primary_path.value_namespace = name_space
                                            self.primary_path.value_namespace_prefix = name_space_prefix
                                        if(value_path == "srlg-disjoint"):
                                            self.srlg_disjoint = value
                                            self.srlg_disjoint.value_namespace = name_space
                                            self.srlg_disjoint.value_namespace_prefix = name_space_prefix


                                class SrMicroloopAvoidancePath(Entity):
                                    """
                                    SR Microloop avoidance Path Info
                                    
                                    .. attribute:: microloop_repair
                                    
                                    	Microloop Repair List
                                    	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                    
                                    .. attribute:: microloop_repair_list_size
                                    
                                    	Microloop Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: microloop_strict_spf
                                    
                                    	Strict SPF SID
                                    	**type**\:  bool
                                    
                                    .. attribute:: microloop_tunnel_interface_name
                                    
                                    	Microloop Tunnel Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                        self.yang_name = "sr-microloop-avoidance-path"
                                        self.yang_parent_name = "route-path"

                                        self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                        self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                        self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                        self.microloop_repair = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("microloop_repair_list_size",
                                                        "microloop_strict_spf",
                                                        "microloop_tunnel_interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                    class MicroloopRepair(Entity):
                                        """
                                        Microloop Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                            self.yang_name = "microloop-repair"
                                            self.yang_parent_name = "sr-microloop-avoidance-path"

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("repair_element_id",
                                                            "repair_element_type",
                                                            "repair_label") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.repair_element_id.is_set or
                                                self.repair_element_type.is_set or
                                                self.repair_label.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.repair_element_id.yfilter != YFilter.not_set or
                                                self.repair_element_type.yfilter != YFilter.not_set or
                                                self.repair_label.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "microloop-repair" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                            if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                            if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_label.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "repair-element-id"):
                                                self.repair_element_id = value
                                                self.repair_element_id.value_namespace = name_space
                                                self.repair_element_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-element-type"):
                                                self.repair_element_type = value
                                                self.repair_element_type.value_namespace = name_space
                                                self.repair_element_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-label"):
                                                self.repair_label = value
                                                self.repair_label.value_namespace = name_space
                                                self.repair_label.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.microloop_repair:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.microloop_repair_list_size.is_set or
                                            self.microloop_strict_spf.is_set or
                                            self.microloop_tunnel_interface_name.is_set)

                                    def has_operation(self):
                                        for c in self.microloop_repair:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                            self.microloop_strict_spf.yfilter != YFilter.not_set or
                                            self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                        if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                        if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "microloop-repair"):
                                            for c in self.microloop_repair:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.microloop_repair.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "microloop-repair-list-size"):
                                            self.microloop_repair_list_size = value
                                            self.microloop_repair_list_size.value_namespace = name_space
                                            self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "microloop-strict-spf"):
                                            self.microloop_strict_spf = value
                                            self.microloop_strict_spf.value_namespace = name_space
                                            self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                        if(value_path == "microloop-tunnel-interface-name"):
                                            self.microloop_tunnel_interface_name = value
                                            self.microloop_tunnel_interface_name.value_namespace = name_space
                                            self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.lsa_type.is_set or
                                        self.route_interface_name.is_set or
                                        self.route_lsaid.is_set or
                                        self.route_metric.is_set or
                                        self.route_next_hop_address.is_set or
                                        self.route_path_id.is_set or
                                        self.route_path_is_mcast_intact.is_set or
                                        self.route_path_is_ucmp_path.is_set or
                                        self.route_source.is_set or
                                        (self.route_backup_path is not None and self.route_backup_path.has_data()) or
                                        (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.lsa_type.yfilter != YFilter.not_set or
                                        self.route_interface_name.yfilter != YFilter.not_set or
                                        self.route_lsaid.yfilter != YFilter.not_set or
                                        self.route_metric.yfilter != YFilter.not_set or
                                        self.route_next_hop_address.yfilter != YFilter.not_set or
                                        self.route_path_id.yfilter != YFilter.not_set or
                                        self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                        self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                        self.route_source.yfilter != YFilter.not_set or
                                        (self.route_backup_path is not None and self.route_backup_path.has_operation()) or
                                        (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                    if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                    if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                    if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_metric.get_name_leafdata())
                                    if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                    if (self.route_path_id.is_set or self.route_path_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_id.get_name_leafdata())
                                    if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                    if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                    if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_source.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-backup-path"):
                                        if (self.route_backup_path is None):
                                            self.route_backup_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath()
                                            self.route_backup_path.parent = self
                                            self._children_name_map["route_backup_path"] = "route-backup-path"
                                        return self.route_backup_path

                                    if (child_yang_name == "sr-microloop-avoidance-path"):
                                        if (self.sr_microloop_avoidance_path is None):
                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        return self.sr_microloop_avoidance_path

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-backup-path" or name == "sr-microloop-avoidance-path" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-id" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "lsa-type"):
                                        self.lsa_type = value
                                        self.lsa_type.value_namespace = name_space
                                        self.lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-interface-name"):
                                        self.route_interface_name = value
                                        self.route_interface_name.value_namespace = name_space
                                        self.route_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-lsaid"):
                                        self.route_lsaid = value
                                        self.route_lsaid.value_namespace = name_space
                                        self.route_lsaid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-metric"):
                                        self.route_metric = value
                                        self.route_metric.value_namespace = name_space
                                        self.route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-next-hop-address"):
                                        self.route_next_hop_address = value
                                        self.route_next_hop_address.value_namespace = name_space
                                        self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-id"):
                                        self.route_path_id = value
                                        self.route_path_id.value_namespace = name_space
                                        self.route_path_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-is-mcast-intact"):
                                        self.route_path_is_mcast_intact = value
                                        self.route_path_is_mcast_intact.value_namespace = name_space
                                        self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-is-ucmp-path"):
                                        self.route_path_is_ucmp_path = value
                                        self.route_path_is_ucmp_path.value_namespace = name_space
                                        self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-source"):
                                        self.route_source = value
                                        self.route_source.value_namespace = name_space
                                        self.route_source.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.route_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    self.route_connected.is_set or
                                    self.route_metric.is_set or
                                    self.route_prefix.is_set or
                                    self.route_prefix_length.is_set or
                                    self.route_type.is_set or
                                    (self.route_info is not None and self.route_info.has_data()))

                            def has_operation(self):
                                for c in self.route_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.route_connected.yfilter != YFilter.not_set or
                                    self.route_metric.yfilter != YFilter.not_set or
                                    self.route_prefix.yfilter != YFilter.not_set or
                                    self.route_prefix_length.yfilter != YFilter.not_set or
                                    self.route_type.yfilter != YFilter.not_set or
                                    (self.route_info is not None and self.route_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "backup-route" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_connected.get_name_leafdata())
                                if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_metric.get_name_leafdata())
                                if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "route-info"):
                                    if (self.route_info is None):
                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                    return self.route_info

                                if (child_yang_name == "route-path"):
                                    for c in self.route_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.route_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-connected"):
                                    self.route_connected = value
                                    self.route_connected.value_namespace = name_space
                                    self.route_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-metric"):
                                    self.route_metric = value
                                    self.route_metric.value_namespace = name_space
                                    self.route_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-prefix"):
                                    self.route_prefix = value
                                    self.route_prefix.value_namespace = name_space
                                    self.route_prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-prefix-length"):
                                    self.route_prefix_length = value
                                    self.route_prefix_length.value_namespace = name_space
                                    self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-type"):
                                    self.route_type = value
                                    self.route_type.value_namespace = name_space
                                    self.route_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.backup_route:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.backup_route:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "backup-routes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "backup-route"):
                                for c in self.backup_route:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.backup_route.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "backup-route"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class MulticastIntactRouteTable(Entity):
                        """
                        OSPF Route Table including multicast\-intact
                        routes
                        
                        .. attribute:: route
                        
                        	An OSPF route
                        	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable, self).__init__()

                            self.yang_name = "multicast-intact-route-table"
                            self.yang_parent_name = "route-information"

                            self.route = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable, self).__setattr__(name, value)


                        class Route(Entity):
                            """
                            An OSPF route
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: route_connected
                            
                            	If true, connected route
                            	**type**\:  bool
                            
                            .. attribute:: route_info
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo>`
                            
                            .. attribute:: route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath>`
                            
                            .. attribute:: route_prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "multicast-intact-route-table"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_connected = YLeaf(YType.boolean, "route-connected")

                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                self.route_prefix = YLeaf(YType.str, "route-prefix")

                                self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo()
                                self.route_info.parent = self
                                self._children_name_map["route_info"] = "route-info"
                                self._children_yang_names.add("route-info")

                                self.route_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length",
                                                "route_connected",
                                                "route_metric",
                                                "route_prefix",
                                                "route_prefix_length",
                                                "route_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route, self).__setattr__(name, value)


                            class RouteInfo(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_auto_excluded
                                
                                	If true, exclude from TE paths
                                	**type**\:  bool
                                
                                .. attribute:: route_fail_time
                                
                                	Last time update failed
                                	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime>`
                                
                                .. attribute:: route_forward_distance
                                
                                	Forward distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_source
                                
                                	Protocol source
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_spf_priority
                                
                                	SPF priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: route_srte_nbr_registered
                                
                                	SRTE registered neigbhor count on route
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_srte_prefix_registered
                                
                                	If true, SRTE registered prefix route
                                	**type**\:  bool
                                
                                .. attribute:: route_te_metric
                                
                                	TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_update_time
                                
                                	Last time updated
                                	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo, self).__init__()

                                    self.yang_name = "route-info"
                                    self.yang_parent_name = "route"

                                    self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                    self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                    self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                    self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                    self.route_source = YLeaf(YType.uint16, "route-source")

                                    self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                    self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                    self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                    self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                    self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime()
                                    self.route_fail_time.parent = self
                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                    self._children_yang_names.add("route-fail-time")

                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime()
                                    self.route_update_time.parent = self
                                    self._children_name_map["route_update_time"] = "route-update-time"
                                    self._children_yang_names.add("route-update-time")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("route_area_id",
                                                    "route_auto_excluded",
                                                    "route_forward_distance",
                                                    "route_rib_version",
                                                    "route_source",
                                                    "route_spf_priority",
                                                    "route_spf_version",
                                                    "route_srte_nbr_registered",
                                                    "route_srte_prefix_registered",
                                                    "route_te_metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo, self).__setattr__(name, value)


                                class RouteUpdateTime(Entity):
                                    """
                                    Last time updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime, self).__init__()

                                        self.yang_name = "route-update-time"
                                        self.yang_parent_name = "route-info"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-update-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix


                                class RouteFailTime(Entity):
                                    """
                                    Last time update failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime, self).__init__()

                                        self.yang_name = "route-fail-time"
                                        self.yang_parent_name = "route-info"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-fail-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.route_area_id.is_set or
                                        self.route_auto_excluded.is_set or
                                        self.route_forward_distance.is_set or
                                        self.route_rib_version.is_set or
                                        self.route_source.is_set or
                                        self.route_spf_priority.is_set or
                                        self.route_spf_version.is_set or
                                        self.route_srte_nbr_registered.is_set or
                                        self.route_srte_prefix_registered.is_set or
                                        self.route_te_metric.is_set or
                                        (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                        (self.route_update_time is not None and self.route_update_time.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.route_area_id.yfilter != YFilter.not_set or
                                        self.route_auto_excluded.yfilter != YFilter.not_set or
                                        self.route_forward_distance.yfilter != YFilter.not_set or
                                        self.route_rib_version.yfilter != YFilter.not_set or
                                        self.route_source.yfilter != YFilter.not_set or
                                        self.route_spf_priority.yfilter != YFilter.not_set or
                                        self.route_spf_version.yfilter != YFilter.not_set or
                                        self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                        self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                        self.route_te_metric.yfilter != YFilter.not_set or
                                        (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                        (self.route_update_time is not None and self.route_update_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                    if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                    if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                    if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                    if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_source.get_name_leafdata())
                                    if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                    if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                    if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                    if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                    if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-fail-time"):
                                        if (self.route_fail_time is None):
                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                        return self.route_fail_time

                                    if (child_yang_name == "route-update-time"):
                                        if (self.route_update_time is None):
                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                        return self.route_update_time

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "route-area-id"):
                                        self.route_area_id = value
                                        self.route_area_id.value_namespace = name_space
                                        self.route_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-auto-excluded"):
                                        self.route_auto_excluded = value
                                        self.route_auto_excluded.value_namespace = name_space
                                        self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-forward-distance"):
                                        self.route_forward_distance = value
                                        self.route_forward_distance.value_namespace = name_space
                                        self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-rib-version"):
                                        self.route_rib_version = value
                                        self.route_rib_version.value_namespace = name_space
                                        self.route_rib_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-source"):
                                        self.route_source = value
                                        self.route_source.value_namespace = name_space
                                        self.route_source.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-spf-priority"):
                                        self.route_spf_priority = value
                                        self.route_spf_priority.value_namespace = name_space
                                        self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-spf-version"):
                                        self.route_spf_version = value
                                        self.route_spf_version.value_namespace = name_space
                                        self.route_spf_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-srte-nbr-registered"):
                                        self.route_srte_nbr_registered = value
                                        self.route_srte_nbr_registered.value_namespace = name_space
                                        self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-srte-prefix-registered"):
                                        self.route_srte_prefix_registered = value
                                        self.route_srte_prefix_registered.value_namespace = name_space
                                        self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-te-metric"):
                                        self.route_te_metric = value
                                        self.route_te_metric.value_namespace = name_space
                                        self.route_te_metric.value_namespace_prefix = name_space_prefix


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: area_format
                                
                                	Area format IP or uint32
                                	**type**\:  bool
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_type
                                
                                	LSA type, see RFC2328 etc
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: route_lsaid
                                
                                	LSA ID, see RFC2328
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_is_mcast_intact
                                
                                	Multicast\-intact path
                                	**type**\:  bool
                                
                                .. attribute:: route_path_is_ucmp_path
                                
                                	UCMP path
                                	**type**\:  bool
                                
                                .. attribute:: route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_path
                                
                                	SR Microloop avoidance Path Info
                                	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "route"

                                    self.area_format = YLeaf(YType.boolean, "area-format")

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                    self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                    self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                    self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                    self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                    self.route_source = YLeaf(YType.str, "route-source")

                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath()
                                    self.sr_microloop_avoidance_path.parent = self
                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                    self._children_yang_names.add("sr-microloop-avoidance-path")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_format",
                                                    "area_id",
                                                    "lsa_type",
                                                    "route_interface_name",
                                                    "route_lsaid",
                                                    "route_metric",
                                                    "route_next_hop_address",
                                                    "route_path_is_mcast_intact",
                                                    "route_path_is_ucmp_path",
                                                    "route_source") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath, self).__setattr__(name, value)


                                class SrMicroloopAvoidancePath(Entity):
                                    """
                                    SR Microloop avoidance Path Info
                                    
                                    .. attribute:: microloop_repair
                                    
                                    	Microloop Repair List
                                    	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                    
                                    .. attribute:: microloop_repair_list_size
                                    
                                    	Microloop Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: microloop_strict_spf
                                    
                                    	Strict SPF SID
                                    	**type**\:  bool
                                    
                                    .. attribute:: microloop_tunnel_interface_name
                                    
                                    	Microloop Tunnel Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                        self.yang_name = "sr-microloop-avoidance-path"
                                        self.yang_parent_name = "route-path"

                                        self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                        self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                        self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                        self.microloop_repair = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("microloop_repair_list_size",
                                                        "microloop_strict_spf",
                                                        "microloop_tunnel_interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                    class MicroloopRepair(Entity):
                                        """
                                        Microloop Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                            self.yang_name = "microloop-repair"
                                            self.yang_parent_name = "sr-microloop-avoidance-path"

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("repair_element_id",
                                                            "repair_element_type",
                                                            "repair_label") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.repair_element_id.is_set or
                                                self.repair_element_type.is_set or
                                                self.repair_label.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.repair_element_id.yfilter != YFilter.not_set or
                                                self.repair_element_type.yfilter != YFilter.not_set or
                                                self.repair_label.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "microloop-repair" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                            if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                            if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_label.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "repair-element-id"):
                                                self.repair_element_id = value
                                                self.repair_element_id.value_namespace = name_space
                                                self.repair_element_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-element-type"):
                                                self.repair_element_type = value
                                                self.repair_element_type.value_namespace = name_space
                                                self.repair_element_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-label"):
                                                self.repair_label = value
                                                self.repair_label.value_namespace = name_space
                                                self.repair_label.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.microloop_repair:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.microloop_repair_list_size.is_set or
                                            self.microloop_strict_spf.is_set or
                                            self.microloop_tunnel_interface_name.is_set)

                                    def has_operation(self):
                                        for c in self.microloop_repair:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                            self.microloop_strict_spf.yfilter != YFilter.not_set or
                                            self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                        if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                        if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "microloop-repair"):
                                            for c in self.microloop_repair:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.microloop_repair.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "microloop-repair-list-size"):
                                            self.microloop_repair_list_size = value
                                            self.microloop_repair_list_size.value_namespace = name_space
                                            self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "microloop-strict-spf"):
                                            self.microloop_strict_spf = value
                                            self.microloop_strict_spf.value_namespace = name_space
                                            self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                        if(value_path == "microloop-tunnel-interface-name"):
                                            self.microloop_tunnel_interface_name = value
                                            self.microloop_tunnel_interface_name.value_namespace = name_space
                                            self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.area_format.is_set or
                                        self.area_id.is_set or
                                        self.lsa_type.is_set or
                                        self.route_interface_name.is_set or
                                        self.route_lsaid.is_set or
                                        self.route_metric.is_set or
                                        self.route_next_hop_address.is_set or
                                        self.route_path_is_mcast_intact.is_set or
                                        self.route_path_is_ucmp_path.is_set or
                                        self.route_source.is_set or
                                        (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_format.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.lsa_type.yfilter != YFilter.not_set or
                                        self.route_interface_name.yfilter != YFilter.not_set or
                                        self.route_lsaid.yfilter != YFilter.not_set or
                                        self.route_metric.yfilter != YFilter.not_set or
                                        self.route_next_hop_address.yfilter != YFilter.not_set or
                                        self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                        self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                        self.route_source.yfilter != YFilter.not_set or
                                        (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_format.get_name_leafdata())
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                    if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                    if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                    if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_metric.get_name_leafdata())
                                    if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                    if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                    if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                    if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_source.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sr-microloop-avoidance-path"):
                                        if (self.sr_microloop_avoidance_path is None):
                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        return self.sr_microloop_avoidance_path

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-format"):
                                        self.area_format = value
                                        self.area_format.value_namespace = name_space
                                        self.area_format.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-type"):
                                        self.lsa_type = value
                                        self.lsa_type.value_namespace = name_space
                                        self.lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-interface-name"):
                                        self.route_interface_name = value
                                        self.route_interface_name.value_namespace = name_space
                                        self.route_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-lsaid"):
                                        self.route_lsaid = value
                                        self.route_lsaid.value_namespace = name_space
                                        self.route_lsaid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-metric"):
                                        self.route_metric = value
                                        self.route_metric.value_namespace = name_space
                                        self.route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-next-hop-address"):
                                        self.route_next_hop_address = value
                                        self.route_next_hop_address.value_namespace = name_space
                                        self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-is-mcast-intact"):
                                        self.route_path_is_mcast_intact = value
                                        self.route_path_is_mcast_intact.value_namespace = name_space
                                        self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-is-ucmp-path"):
                                        self.route_path_is_ucmp_path = value
                                        self.route_path_is_ucmp_path.value_namespace = name_space
                                        self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-source"):
                                        self.route_source = value
                                        self.route_source.value_namespace = name_space
                                        self.route_source.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.route_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    self.route_connected.is_set or
                                    self.route_metric.is_set or
                                    self.route_prefix.is_set or
                                    self.route_prefix_length.is_set or
                                    self.route_type.is_set or
                                    (self.route_info is not None and self.route_info.has_data()))

                            def has_operation(self):
                                for c in self.route_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.route_connected.yfilter != YFilter.not_set or
                                    self.route_metric.yfilter != YFilter.not_set or
                                    self.route_prefix.yfilter != YFilter.not_set or
                                    self.route_prefix_length.yfilter != YFilter.not_set or
                                    self.route_type.yfilter != YFilter.not_set or
                                    (self.route_info is not None and self.route_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "route" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_connected.get_name_leafdata())
                                if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_metric.get_name_leafdata())
                                if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "route-info"):
                                    if (self.route_info is None):
                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                    return self.route_info

                                if (child_yang_name == "route-path"):
                                    for c in self.route_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.route_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-connected"):
                                    self.route_connected = value
                                    self.route_connected.value_namespace = name_space
                                    self.route_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-metric"):
                                    self.route_metric = value
                                    self.route_metric.value_namespace = name_space
                                    self.route_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-prefix"):
                                    self.route_prefix = value
                                    self.route_prefix.value_namespace = name_space
                                    self.route_prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-prefix-length"):
                                    self.route_prefix_length = value
                                    self.route_prefix_length.value_namespace = name_space
                                    self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-type"):
                                    self.route_type = value
                                    self.route_type.value_namespace = name_space
                                    self.route_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.route:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.route:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "multicast-intact-route-table" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "route"):
                                for c in self.route:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.route.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "route"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class MulticastIntactBackupRoutes(Entity):
                        """
                        OSPF Route Table Including Multicast intact
                        Backup Paths
                        
                        .. attribute:: multicast_intact_backup_route
                        
                        	OSPF route including multicast backup paths
                        	**type**\: list of    :py:class:`MulticastIntactBackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes, self).__init__()

                            self.yang_name = "multicast-intact-backup-routes"
                            self.yang_parent_name = "route-information"

                            self.multicast_intact_backup_route = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes, self).__setattr__(name, value)


                        class MulticastIntactBackupRoute(Entity):
                            """
                            OSPF route including multicast backup paths
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: route_connected
                            
                            	If true, connected route
                            	**type**\:  bool
                            
                            .. attribute:: route_info
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo>`
                            
                            .. attribute:: route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath>`
                            
                            .. attribute:: route_prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute, self).__init__()

                                self.yang_name = "multicast-intact-backup-route"
                                self.yang_parent_name = "multicast-intact-backup-routes"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_connected = YLeaf(YType.boolean, "route-connected")

                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                self.route_prefix = YLeaf(YType.str, "route-prefix")

                                self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo()
                                self.route_info.parent = self
                                self._children_name_map["route_info"] = "route-info"
                                self._children_yang_names.add("route-info")

                                self.route_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length",
                                                "route_connected",
                                                "route_metric",
                                                "route_prefix",
                                                "route_prefix_length",
                                                "route_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute, self).__setattr__(name, value)


                            class RouteInfo(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_auto_excluded
                                
                                	If true, exclude from TE paths
                                	**type**\:  bool
                                
                                .. attribute:: route_fail_time
                                
                                	Last time update failed
                                	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime>`
                                
                                .. attribute:: route_forward_distance
                                
                                	Forward distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_source
                                
                                	Protocol source
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_spf_priority
                                
                                	SPF priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: route_srte_nbr_registered
                                
                                	SRTE registered neigbhor count on route
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_srte_prefix_registered
                                
                                	If true, SRTE registered prefix route
                                	**type**\:  bool
                                
                                .. attribute:: route_te_metric
                                
                                	TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_update_time
                                
                                	Last time updated
                                	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo, self).__init__()

                                    self.yang_name = "route-info"
                                    self.yang_parent_name = "multicast-intact-backup-route"

                                    self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                    self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                    self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                    self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                    self.route_source = YLeaf(YType.uint16, "route-source")

                                    self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                    self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                    self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                    self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                    self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime()
                                    self.route_fail_time.parent = self
                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                    self._children_yang_names.add("route-fail-time")

                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime()
                                    self.route_update_time.parent = self
                                    self._children_name_map["route_update_time"] = "route-update-time"
                                    self._children_yang_names.add("route-update-time")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("route_area_id",
                                                    "route_auto_excluded",
                                                    "route_forward_distance",
                                                    "route_rib_version",
                                                    "route_source",
                                                    "route_spf_priority",
                                                    "route_spf_version",
                                                    "route_srte_nbr_registered",
                                                    "route_srte_prefix_registered",
                                                    "route_te_metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo, self).__setattr__(name, value)


                                class RouteUpdateTime(Entity):
                                    """
                                    Last time updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                        self.yang_name = "route-update-time"
                                        self.yang_parent_name = "route-info"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-update-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix


                                class RouteFailTime(Entity):
                                    """
                                    Last time update failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime, self).__init__()

                                        self.yang_name = "route-fail-time"
                                        self.yang_parent_name = "route-info"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-fail-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.route_area_id.is_set or
                                        self.route_auto_excluded.is_set or
                                        self.route_forward_distance.is_set or
                                        self.route_rib_version.is_set or
                                        self.route_source.is_set or
                                        self.route_spf_priority.is_set or
                                        self.route_spf_version.is_set or
                                        self.route_srte_nbr_registered.is_set or
                                        self.route_srte_prefix_registered.is_set or
                                        self.route_te_metric.is_set or
                                        (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                        (self.route_update_time is not None and self.route_update_time.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.route_area_id.yfilter != YFilter.not_set or
                                        self.route_auto_excluded.yfilter != YFilter.not_set or
                                        self.route_forward_distance.yfilter != YFilter.not_set or
                                        self.route_rib_version.yfilter != YFilter.not_set or
                                        self.route_source.yfilter != YFilter.not_set or
                                        self.route_spf_priority.yfilter != YFilter.not_set or
                                        self.route_spf_version.yfilter != YFilter.not_set or
                                        self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                        self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                        self.route_te_metric.yfilter != YFilter.not_set or
                                        (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                        (self.route_update_time is not None and self.route_update_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                    if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                    if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                    if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                    if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_source.get_name_leafdata())
                                    if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                    if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                    if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                    if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                    if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-fail-time"):
                                        if (self.route_fail_time is None):
                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                        return self.route_fail_time

                                    if (child_yang_name == "route-update-time"):
                                        if (self.route_update_time is None):
                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                        return self.route_update_time

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "route-area-id"):
                                        self.route_area_id = value
                                        self.route_area_id.value_namespace = name_space
                                        self.route_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-auto-excluded"):
                                        self.route_auto_excluded = value
                                        self.route_auto_excluded.value_namespace = name_space
                                        self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-forward-distance"):
                                        self.route_forward_distance = value
                                        self.route_forward_distance.value_namespace = name_space
                                        self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-rib-version"):
                                        self.route_rib_version = value
                                        self.route_rib_version.value_namespace = name_space
                                        self.route_rib_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-source"):
                                        self.route_source = value
                                        self.route_source.value_namespace = name_space
                                        self.route_source.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-spf-priority"):
                                        self.route_spf_priority = value
                                        self.route_spf_priority.value_namespace = name_space
                                        self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-spf-version"):
                                        self.route_spf_version = value
                                        self.route_spf_version.value_namespace = name_space
                                        self.route_spf_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-srte-nbr-registered"):
                                        self.route_srte_nbr_registered = value
                                        self.route_srte_nbr_registered.value_namespace = name_space
                                        self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-srte-prefix-registered"):
                                        self.route_srte_prefix_registered = value
                                        self.route_srte_prefix_registered.value_namespace = name_space
                                        self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-te-metric"):
                                        self.route_te_metric = value
                                        self.route_te_metric.value_namespace = name_space
                                        self.route_te_metric.value_namespace_prefix = name_space_prefix


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: lsa_type
                                
                                	LSA type, see RFC2328 etc
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_backup_path
                                
                                	Backup Path Info
                                	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath>`
                                
                                .. attribute:: route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: route_lsaid
                                
                                	LSA ID, see RFC2328
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_id
                                
                                	Path ID of path
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_path_is_mcast_intact
                                
                                	Multicast\-intact path
                                	**type**\:  bool
                                
                                .. attribute:: route_path_is_ucmp_path
                                
                                	UCMP path
                                	**type**\:  bool
                                
                                .. attribute:: route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_path
                                
                                	SR Microloop avoidance Path Info
                                	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "multicast-intact-backup-route"

                                    self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                    self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                    self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                    self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                    self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                    self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                    self.route_source = YLeaf(YType.str, "route-source")

                                    self.route_backup_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath()
                                    self.route_backup_path.parent = self
                                    self._children_name_map["route_backup_path"] = "route-backup-path"
                                    self._children_yang_names.add("route-backup-path")

                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath()
                                    self.sr_microloop_avoidance_path.parent = self
                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                    self._children_yang_names.add("sr-microloop-avoidance-path")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("lsa_type",
                                                    "route_interface_name",
                                                    "route_lsaid",
                                                    "route_metric",
                                                    "route_next_hop_address",
                                                    "route_path_id",
                                                    "route_path_is_mcast_intact",
                                                    "route_path_is_ucmp_path",
                                                    "route_source") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath, self).__setattr__(name, value)


                                class RouteBackupPath(Entity):
                                    """
                                    Backup Path Info
                                    
                                    .. attribute:: backup_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_remote_lfa
                                    
                                    	IP address of remote LFA
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_repair
                                    
                                    	Backup Repair List
                                    	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair>`
                                    
                                    .. attribute:: backup_repair_list_size
                                    
                                    	Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: backup_route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_tunnel_interface_name
                                    
                                    	Backup Tunnel Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: downstream
                                    
                                    	Downstream
                                    	**type**\:  bool
                                    
                                    .. attribute:: line_card_disjoint
                                    
                                    	Line Card Disjoint
                                    	**type**\:  bool
                                    
                                    .. attribute:: node_protect
                                    
                                    	Node Protect
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_path
                                    
                                    	Primary Path
                                    	**type**\:  bool
                                    
                                    .. attribute:: srlg_disjoint
                                    
                                    	SRLG Disjoint
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath, self).__init__()

                                        self.yang_name = "route-backup-path"
                                        self.yang_parent_name = "route-path"

                                        self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                        self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                        self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                        self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                        self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                        self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                        self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                        self.downstream = YLeaf(YType.boolean, "downstream")

                                        self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                        self.node_protect = YLeaf(YType.boolean, "node-protect")

                                        self.primary_path = YLeaf(YType.boolean, "primary-path")

                                        self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                        self.backup_repair = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("backup_metric",
                                                        "backup_remote_lfa",
                                                        "backup_repair_list_size",
                                                        "backup_route_interface_name",
                                                        "backup_route_next_hop_address",
                                                        "backup_route_source",
                                                        "backup_tunnel_interface_name",
                                                        "downstream",
                                                        "line_card_disjoint",
                                                        "node_protect",
                                                        "primary_path",
                                                        "srlg_disjoint") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath, self).__setattr__(name, value)


                                    class BackupRepair(Entity):
                                        """
                                        Backup Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                            self.yang_name = "backup-repair"
                                            self.yang_parent_name = "route-backup-path"

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("repair_element_id",
                                                            "repair_element_type",
                                                            "repair_label") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.repair_element_id.is_set or
                                                self.repair_element_type.is_set or
                                                self.repair_label.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.repair_element_id.yfilter != YFilter.not_set or
                                                self.repair_element_type.yfilter != YFilter.not_set or
                                                self.repair_label.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup-repair" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                            if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                            if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_label.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "repair-element-id"):
                                                self.repair_element_id = value
                                                self.repair_element_id.value_namespace = name_space
                                                self.repair_element_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-element-type"):
                                                self.repair_element_type = value
                                                self.repair_element_type.value_namespace = name_space
                                                self.repair_element_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-label"):
                                                self.repair_label = value
                                                self.repair_label.value_namespace = name_space
                                                self.repair_label.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup_repair:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.backup_metric.is_set or
                                            self.backup_remote_lfa.is_set or
                                            self.backup_repair_list_size.is_set or
                                            self.backup_route_interface_name.is_set or
                                            self.backup_route_next_hop_address.is_set or
                                            self.backup_route_source.is_set or
                                            self.backup_tunnel_interface_name.is_set or
                                            self.downstream.is_set or
                                            self.line_card_disjoint.is_set or
                                            self.node_protect.is_set or
                                            self.primary_path.is_set or
                                            self.srlg_disjoint.is_set)

                                    def has_operation(self):
                                        for c in self.backup_repair:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.backup_metric.yfilter != YFilter.not_set or
                                            self.backup_remote_lfa.yfilter != YFilter.not_set or
                                            self.backup_repair_list_size.yfilter != YFilter.not_set or
                                            self.backup_route_interface_name.yfilter != YFilter.not_set or
                                            self.backup_route_next_hop_address.yfilter != YFilter.not_set or
                                            self.backup_route_source.yfilter != YFilter.not_set or
                                            self.backup_tunnel_interface_name.yfilter != YFilter.not_set or
                                            self.downstream.yfilter != YFilter.not_set or
                                            self.line_card_disjoint.yfilter != YFilter.not_set or
                                            self.node_protect.yfilter != YFilter.not_set or
                                            self.primary_path.yfilter != YFilter.not_set or
                                            self.srlg_disjoint.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-backup-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.backup_metric.is_set or self.backup_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_metric.get_name_leafdata())
                                        if (self.backup_remote_lfa.is_set or self.backup_remote_lfa.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_remote_lfa.get_name_leafdata())
                                        if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                        if (self.backup_route_interface_name.is_set or self.backup_route_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_route_interface_name.get_name_leafdata())
                                        if (self.backup_route_next_hop_address.is_set or self.backup_route_next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_route_next_hop_address.get_name_leafdata())
                                        if (self.backup_route_source.is_set or self.backup_route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_route_source.get_name_leafdata())
                                        if (self.backup_tunnel_interface_name.is_set or self.backup_tunnel_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_tunnel_interface_name.get_name_leafdata())
                                        if (self.downstream.is_set or self.downstream.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.downstream.get_name_leafdata())
                                        if (self.line_card_disjoint.is_set or self.line_card_disjoint.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.line_card_disjoint.get_name_leafdata())
                                        if (self.node_protect.is_set or self.node_protect.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.node_protect.get_name_leafdata())
                                        if (self.primary_path.is_set or self.primary_path.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.primary_path.get_name_leafdata())
                                        if (self.srlg_disjoint.is_set or self.srlg_disjoint.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.srlg_disjoint.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup-repair"):
                                            for c in self.backup_repair:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup_repair.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup-repair" or name == "backup-metric" or name == "backup-remote-lfa" or name == "backup-repair-list-size" or name == "backup-route-interface-name" or name == "backup-route-next-hop-address" or name == "backup-route-source" or name == "backup-tunnel-interface-name" or name == "downstream" or name == "line-card-disjoint" or name == "node-protect" or name == "primary-path" or name == "srlg-disjoint"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "backup-metric"):
                                            self.backup_metric = value
                                            self.backup_metric.value_namespace = name_space
                                            self.backup_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-remote-lfa"):
                                            self.backup_remote_lfa = value
                                            self.backup_remote_lfa.value_namespace = name_space
                                            self.backup_remote_lfa.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-repair-list-size"):
                                            self.backup_repair_list_size = value
                                            self.backup_repair_list_size.value_namespace = name_space
                                            self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-route-interface-name"):
                                            self.backup_route_interface_name = value
                                            self.backup_route_interface_name.value_namespace = name_space
                                            self.backup_route_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-route-next-hop-address"):
                                            self.backup_route_next_hop_address = value
                                            self.backup_route_next_hop_address.value_namespace = name_space
                                            self.backup_route_next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-route-source"):
                                            self.backup_route_source = value
                                            self.backup_route_source.value_namespace = name_space
                                            self.backup_route_source.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-tunnel-interface-name"):
                                            self.backup_tunnel_interface_name = value
                                            self.backup_tunnel_interface_name.value_namespace = name_space
                                            self.backup_tunnel_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "downstream"):
                                            self.downstream = value
                                            self.downstream.value_namespace = name_space
                                            self.downstream.value_namespace_prefix = name_space_prefix
                                        if(value_path == "line-card-disjoint"):
                                            self.line_card_disjoint = value
                                            self.line_card_disjoint.value_namespace = name_space
                                            self.line_card_disjoint.value_namespace_prefix = name_space_prefix
                                        if(value_path == "node-protect"):
                                            self.node_protect = value
                                            self.node_protect.value_namespace = name_space
                                            self.node_protect.value_namespace_prefix = name_space_prefix
                                        if(value_path == "primary-path"):
                                            self.primary_path = value
                                            self.primary_path.value_namespace = name_space
                                            self.primary_path.value_namespace_prefix = name_space_prefix
                                        if(value_path == "srlg-disjoint"):
                                            self.srlg_disjoint = value
                                            self.srlg_disjoint.value_namespace = name_space
                                            self.srlg_disjoint.value_namespace_prefix = name_space_prefix


                                class SrMicroloopAvoidancePath(Entity):
                                    """
                                    SR Microloop avoidance Path Info
                                    
                                    .. attribute:: microloop_repair
                                    
                                    	Microloop Repair List
                                    	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                    
                                    .. attribute:: microloop_repair_list_size
                                    
                                    	Microloop Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: microloop_strict_spf
                                    
                                    	Strict SPF SID
                                    	**type**\:  bool
                                    
                                    .. attribute:: microloop_tunnel_interface_name
                                    
                                    	Microloop Tunnel Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                        self.yang_name = "sr-microloop-avoidance-path"
                                        self.yang_parent_name = "route-path"

                                        self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                        self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                        self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                        self.microloop_repair = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("microloop_repair_list_size",
                                                        "microloop_strict_spf",
                                                        "microloop_tunnel_interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                    class MicroloopRepair(Entity):
                                        """
                                        Microloop Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                            self.yang_name = "microloop-repair"
                                            self.yang_parent_name = "sr-microloop-avoidance-path"

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("repair_element_id",
                                                            "repair_element_type",
                                                            "repair_label") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.repair_element_id.is_set or
                                                self.repair_element_type.is_set or
                                                self.repair_label.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.repair_element_id.yfilter != YFilter.not_set or
                                                self.repair_element_type.yfilter != YFilter.not_set or
                                                self.repair_label.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "microloop-repair" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                            if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                            if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_label.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "repair-element-id"):
                                                self.repair_element_id = value
                                                self.repair_element_id.value_namespace = name_space
                                                self.repair_element_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-element-type"):
                                                self.repair_element_type = value
                                                self.repair_element_type.value_namespace = name_space
                                                self.repair_element_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-label"):
                                                self.repair_label = value
                                                self.repair_label.value_namespace = name_space
                                                self.repair_label.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.microloop_repair:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.microloop_repair_list_size.is_set or
                                            self.microloop_strict_spf.is_set or
                                            self.microloop_tunnel_interface_name.is_set)

                                    def has_operation(self):
                                        for c in self.microloop_repair:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                            self.microloop_strict_spf.yfilter != YFilter.not_set or
                                            self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                        if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                        if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "microloop-repair"):
                                            for c in self.microloop_repair:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.microloop_repair.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "microloop-repair-list-size"):
                                            self.microloop_repair_list_size = value
                                            self.microloop_repair_list_size.value_namespace = name_space
                                            self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "microloop-strict-spf"):
                                            self.microloop_strict_spf = value
                                            self.microloop_strict_spf.value_namespace = name_space
                                            self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                        if(value_path == "microloop-tunnel-interface-name"):
                                            self.microloop_tunnel_interface_name = value
                                            self.microloop_tunnel_interface_name.value_namespace = name_space
                                            self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.lsa_type.is_set or
                                        self.route_interface_name.is_set or
                                        self.route_lsaid.is_set or
                                        self.route_metric.is_set or
                                        self.route_next_hop_address.is_set or
                                        self.route_path_id.is_set or
                                        self.route_path_is_mcast_intact.is_set or
                                        self.route_path_is_ucmp_path.is_set or
                                        self.route_source.is_set or
                                        (self.route_backup_path is not None and self.route_backup_path.has_data()) or
                                        (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.lsa_type.yfilter != YFilter.not_set or
                                        self.route_interface_name.yfilter != YFilter.not_set or
                                        self.route_lsaid.yfilter != YFilter.not_set or
                                        self.route_metric.yfilter != YFilter.not_set or
                                        self.route_next_hop_address.yfilter != YFilter.not_set or
                                        self.route_path_id.yfilter != YFilter.not_set or
                                        self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                        self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                        self.route_source.yfilter != YFilter.not_set or
                                        (self.route_backup_path is not None and self.route_backup_path.has_operation()) or
                                        (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                    if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                    if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                    if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_metric.get_name_leafdata())
                                    if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                    if (self.route_path_id.is_set or self.route_path_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_id.get_name_leafdata())
                                    if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                    if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                    if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_source.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-backup-path"):
                                        if (self.route_backup_path is None):
                                            self.route_backup_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath()
                                            self.route_backup_path.parent = self
                                            self._children_name_map["route_backup_path"] = "route-backup-path"
                                        return self.route_backup_path

                                    if (child_yang_name == "sr-microloop-avoidance-path"):
                                        if (self.sr_microloop_avoidance_path is None):
                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        return self.sr_microloop_avoidance_path

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-backup-path" or name == "sr-microloop-avoidance-path" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-id" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "lsa-type"):
                                        self.lsa_type = value
                                        self.lsa_type.value_namespace = name_space
                                        self.lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-interface-name"):
                                        self.route_interface_name = value
                                        self.route_interface_name.value_namespace = name_space
                                        self.route_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-lsaid"):
                                        self.route_lsaid = value
                                        self.route_lsaid.value_namespace = name_space
                                        self.route_lsaid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-metric"):
                                        self.route_metric = value
                                        self.route_metric.value_namespace = name_space
                                        self.route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-next-hop-address"):
                                        self.route_next_hop_address = value
                                        self.route_next_hop_address.value_namespace = name_space
                                        self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-id"):
                                        self.route_path_id = value
                                        self.route_path_id.value_namespace = name_space
                                        self.route_path_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-is-mcast-intact"):
                                        self.route_path_is_mcast_intact = value
                                        self.route_path_is_mcast_intact.value_namespace = name_space
                                        self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-is-ucmp-path"):
                                        self.route_path_is_ucmp_path = value
                                        self.route_path_is_ucmp_path.value_namespace = name_space
                                        self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-source"):
                                        self.route_source = value
                                        self.route_source.value_namespace = name_space
                                        self.route_source.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.route_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    self.route_connected.is_set or
                                    self.route_metric.is_set or
                                    self.route_prefix.is_set or
                                    self.route_prefix_length.is_set or
                                    self.route_type.is_set or
                                    (self.route_info is not None and self.route_info.has_data()))

                            def has_operation(self):
                                for c in self.route_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.route_connected.yfilter != YFilter.not_set or
                                    self.route_metric.yfilter != YFilter.not_set or
                                    self.route_prefix.yfilter != YFilter.not_set or
                                    self.route_prefix_length.yfilter != YFilter.not_set or
                                    self.route_type.yfilter != YFilter.not_set or
                                    (self.route_info is not None and self.route_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "multicast-intact-backup-route" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_connected.get_name_leafdata())
                                if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_metric.get_name_leafdata())
                                if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "route-info"):
                                    if (self.route_info is None):
                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                    return self.route_info

                                if (child_yang_name == "route-path"):
                                    for c in self.route_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.route_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-connected"):
                                    self.route_connected = value
                                    self.route_connected.value_namespace = name_space
                                    self.route_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-metric"):
                                    self.route_metric = value
                                    self.route_metric.value_namespace = name_space
                                    self.route_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-prefix"):
                                    self.route_prefix = value
                                    self.route_prefix.value_namespace = name_space
                                    self.route_prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-prefix-length"):
                                    self.route_prefix_length = value
                                    self.route_prefix_length.value_namespace = name_space
                                    self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-type"):
                                    self.route_type = value
                                    self.route_type.value_namespace = name_space
                                    self.route_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.multicast_intact_backup_route:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.multicast_intact_backup_route:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "multicast-intact-backup-routes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "multicast-intact-backup-route"):
                                for c in self.multicast_intact_backup_route:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.multicast_intact_backup_route.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "multicast-intact-backup-route"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SummaryInformation(Entity):
                        """
                        OSPF route summary statistics
                        
                        .. attribute:: common
                        
                        	OSPF route summary Information
                        	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.Common>`
                        
                        .. attribute:: failure_address
                        
                        	Last failed address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: failure_time
                        
                        	Last time failed
                        	**type**\:   :py:class:`FailureTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.FailureTime>`
                        
                        .. attribute:: failures
                        
                        	RIB failure count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation, self).__init__()

                            self.yang_name = "summary-information"
                            self.yang_parent_name = "route-information"

                            self.failure_address = YLeaf(YType.str, "failure-address")

                            self.failures = YLeaf(YType.uint32, "failures")

                            self.common = Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.Common()
                            self.common.parent = self
                            self._children_name_map["common"] = "common"
                            self._children_yang_names.add("common")

                            self.failure_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.FailureTime()
                            self.failure_time.parent = self
                            self._children_name_map["failure_time"] = "failure-time"
                            self._children_yang_names.add("failure-time")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("failure_address",
                                            "failures") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation, self).__setattr__(name, value)


                        class FailureTime(Entity):
                            """
                            Last time failed
                            
                            .. attribute:: nanosecond
                            
                            	Nanosecond
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: second
                            
                            	Second
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.FailureTime, self).__init__()

                                self.yang_name = "failure-time"
                                self.yang_parent_name = "summary-information"

                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                self.second = YLeaf(YType.uint32, "second")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nanosecond",
                                                "second") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.FailureTime, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.FailureTime, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nanosecond.is_set or
                                    self.second.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nanosecond.yfilter != YFilter.not_set or
                                    self.second.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "failure-time" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.second.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nanosecond" or name == "second"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nanosecond"):
                                    self.nanosecond = value
                                    self.nanosecond.value_namespace = name_space
                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                if(value_path == "second"):
                                    self.second = value
                                    self.second.value_namespace = name_space
                                    self.second.value_namespace_prefix = name_space_prefix


                        class Common(Entity):
                            """
                            OSPF route summary Information
                            
                            .. attribute:: external_nssa_type1s
                            
                            	External NSSA type 1 count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_nssa_type2s
                            
                            	External NSSA type 2 count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_type1s
                            
                            	External type 1 count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_type2s
                            
                            	External type 2 count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inter_areas
                            
                            	Inter\-area count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: intra_areas
                            
                            	Intra\-area count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.Common, self).__init__()

                                self.yang_name = "common"
                                self.yang_parent_name = "summary-information"

                                self.external_nssa_type1s = YLeaf(YType.uint32, "external-nssa-type1s")

                                self.external_nssa_type2s = YLeaf(YType.uint32, "external-nssa-type2s")

                                self.external_type1s = YLeaf(YType.uint32, "external-type1s")

                                self.external_type2s = YLeaf(YType.uint32, "external-type2s")

                                self.inter_areas = YLeaf(YType.uint32, "inter-areas")

                                self.intra_areas = YLeaf(YType.uint32, "intra-areas")

                                self.total = YLeaf(YType.uint32, "total")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("external_nssa_type1s",
                                                "external_nssa_type2s",
                                                "external_type1s",
                                                "external_type2s",
                                                "inter_areas",
                                                "intra_areas",
                                                "total") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.Common, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.Common, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.external_nssa_type1s.is_set or
                                    self.external_nssa_type2s.is_set or
                                    self.external_type1s.is_set or
                                    self.external_type2s.is_set or
                                    self.inter_areas.is_set or
                                    self.intra_areas.is_set or
                                    self.total.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.external_nssa_type1s.yfilter != YFilter.not_set or
                                    self.external_nssa_type2s.yfilter != YFilter.not_set or
                                    self.external_type1s.yfilter != YFilter.not_set or
                                    self.external_type2s.yfilter != YFilter.not_set or
                                    self.inter_areas.yfilter != YFilter.not_set or
                                    self.intra_areas.yfilter != YFilter.not_set or
                                    self.total.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "common" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.external_nssa_type1s.is_set or self.external_nssa_type1s.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_nssa_type1s.get_name_leafdata())
                                if (self.external_nssa_type2s.is_set or self.external_nssa_type2s.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_nssa_type2s.get_name_leafdata())
                                if (self.external_type1s.is_set or self.external_type1s.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_type1s.get_name_leafdata())
                                if (self.external_type2s.is_set or self.external_type2s.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_type2s.get_name_leafdata())
                                if (self.inter_areas.is_set or self.inter_areas.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inter_areas.get_name_leafdata())
                                if (self.intra_areas.is_set or self.intra_areas.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.intra_areas.get_name_leafdata())
                                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "external-nssa-type1s" or name == "external-nssa-type2s" or name == "external-type1s" or name == "external-type2s" or name == "inter-areas" or name == "intra-areas" or name == "total"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "external-nssa-type1s"):
                                    self.external_nssa_type1s = value
                                    self.external_nssa_type1s.value_namespace = name_space
                                    self.external_nssa_type1s.value_namespace_prefix = name_space_prefix
                                if(value_path == "external-nssa-type2s"):
                                    self.external_nssa_type2s = value
                                    self.external_nssa_type2s.value_namespace = name_space
                                    self.external_nssa_type2s.value_namespace_prefix = name_space_prefix
                                if(value_path == "external-type1s"):
                                    self.external_type1s = value
                                    self.external_type1s.value_namespace = name_space
                                    self.external_type1s.value_namespace_prefix = name_space_prefix
                                if(value_path == "external-type2s"):
                                    self.external_type2s = value
                                    self.external_type2s.value_namespace = name_space
                                    self.external_type2s.value_namespace_prefix = name_space_prefix
                                if(value_path == "inter-areas"):
                                    self.inter_areas = value
                                    self.inter_areas.value_namespace = name_space
                                    self.inter_areas.value_namespace_prefix = name_space_prefix
                                if(value_path == "intra-areas"):
                                    self.intra_areas = value
                                    self.intra_areas.value_namespace = name_space
                                    self.intra_areas.value_namespace_prefix = name_space_prefix
                                if(value_path == "total"):
                                    self.total = value
                                    self.total.value_namespace = name_space
                                    self.total.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.failure_address.is_set or
                                self.failures.is_set or
                                (self.common is not None and self.common.has_data()) or
                                (self.failure_time is not None and self.failure_time.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.failure_address.yfilter != YFilter.not_set or
                                self.failures.yfilter != YFilter.not_set or
                                (self.common is not None and self.common.has_operation()) or
                                (self.failure_time is not None and self.failure_time.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "summary-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.failure_address.is_set or self.failure_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.failure_address.get_name_leafdata())
                            if (self.failures.is_set or self.failures.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.failures.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "common"):
                                if (self.common is None):
                                    self.common = Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.Common()
                                    self.common.parent = self
                                    self._children_name_map["common"] = "common"
                                return self.common

                            if (child_yang_name == "failure-time"):
                                if (self.failure_time is None):
                                    self.failure_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.FailureTime()
                                    self.failure_time.parent = self
                                    self._children_name_map["failure_time"] = "failure-time"
                                return self.failure_time

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "common" or name == "failure-time" or name == "failure-address" or name == "failures"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "failure-address"):
                                self.failure_address = value
                                self.failure_address.value_namespace = name_space
                                self.failure_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "failures"):
                                self.failures = value
                                self.failures.value_namespace = name_space
                                self.failures.value_namespace_prefix = name_space_prefix


                    class ConnectedRoutes(Entity):
                        """
                        OSPF Connected Route Table
                        
                        .. attribute:: connected_route
                        
                        	Connected route
                        	**type**\: list of    :py:class:`ConnectedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes, self).__init__()

                            self.yang_name = "connected-routes"
                            self.yang_parent_name = "route-information"

                            self.connected_route = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes, self).__setattr__(name, value)


                        class ConnectedRoute(Entity):
                            """
                            Connected route
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: route_connected
                            
                            	If true, connected route
                            	**type**\:  bool
                            
                            .. attribute:: route_info
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo>`
                            
                            .. attribute:: route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath>`
                            
                            .. attribute:: route_prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute, self).__init__()

                                self.yang_name = "connected-route"
                                self.yang_parent_name = "connected-routes"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_connected = YLeaf(YType.boolean, "route-connected")

                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                self.route_prefix = YLeaf(YType.str, "route-prefix")

                                self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo()
                                self.route_info.parent = self
                                self._children_name_map["route_info"] = "route-info"
                                self._children_yang_names.add("route-info")

                                self.route_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length",
                                                "route_connected",
                                                "route_metric",
                                                "route_prefix",
                                                "route_prefix_length",
                                                "route_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute, self).__setattr__(name, value)


                            class RouteInfo(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_auto_excluded
                                
                                	If true, exclude from TE paths
                                	**type**\:  bool
                                
                                .. attribute:: route_fail_time
                                
                                	Last time update failed
                                	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime>`
                                
                                .. attribute:: route_forward_distance
                                
                                	Forward distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_source
                                
                                	Protocol source
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_spf_priority
                                
                                	SPF priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: route_srte_nbr_registered
                                
                                	SRTE registered neigbhor count on route
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_srte_prefix_registered
                                
                                	If true, SRTE registered prefix route
                                	**type**\:  bool
                                
                                .. attribute:: route_te_metric
                                
                                	TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_update_time
                                
                                	Last time updated
                                	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo, self).__init__()

                                    self.yang_name = "route-info"
                                    self.yang_parent_name = "connected-route"

                                    self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                    self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                    self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                    self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                    self.route_source = YLeaf(YType.uint16, "route-source")

                                    self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                    self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                    self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                    self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                    self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime()
                                    self.route_fail_time.parent = self
                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                    self._children_yang_names.add("route-fail-time")

                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime()
                                    self.route_update_time.parent = self
                                    self._children_name_map["route_update_time"] = "route-update-time"
                                    self._children_yang_names.add("route-update-time")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("route_area_id",
                                                    "route_auto_excluded",
                                                    "route_forward_distance",
                                                    "route_rib_version",
                                                    "route_source",
                                                    "route_spf_priority",
                                                    "route_spf_version",
                                                    "route_srte_nbr_registered",
                                                    "route_srte_prefix_registered",
                                                    "route_te_metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo, self).__setattr__(name, value)


                                class RouteUpdateTime(Entity):
                                    """
                                    Last time updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                        self.yang_name = "route-update-time"
                                        self.yang_parent_name = "route-info"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-update-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix


                                class RouteFailTime(Entity):
                                    """
                                    Last time update failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime, self).__init__()

                                        self.yang_name = "route-fail-time"
                                        self.yang_parent_name = "route-info"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-fail-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.route_area_id.is_set or
                                        self.route_auto_excluded.is_set or
                                        self.route_forward_distance.is_set or
                                        self.route_rib_version.is_set or
                                        self.route_source.is_set or
                                        self.route_spf_priority.is_set or
                                        self.route_spf_version.is_set or
                                        self.route_srte_nbr_registered.is_set or
                                        self.route_srte_prefix_registered.is_set or
                                        self.route_te_metric.is_set or
                                        (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                        (self.route_update_time is not None and self.route_update_time.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.route_area_id.yfilter != YFilter.not_set or
                                        self.route_auto_excluded.yfilter != YFilter.not_set or
                                        self.route_forward_distance.yfilter != YFilter.not_set or
                                        self.route_rib_version.yfilter != YFilter.not_set or
                                        self.route_source.yfilter != YFilter.not_set or
                                        self.route_spf_priority.yfilter != YFilter.not_set or
                                        self.route_spf_version.yfilter != YFilter.not_set or
                                        self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                        self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                        self.route_te_metric.yfilter != YFilter.not_set or
                                        (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                        (self.route_update_time is not None and self.route_update_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                    if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                    if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                    if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                    if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_source.get_name_leafdata())
                                    if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                    if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                    if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                    if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                    if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-fail-time"):
                                        if (self.route_fail_time is None):
                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                        return self.route_fail_time

                                    if (child_yang_name == "route-update-time"):
                                        if (self.route_update_time is None):
                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                        return self.route_update_time

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "route-area-id"):
                                        self.route_area_id = value
                                        self.route_area_id.value_namespace = name_space
                                        self.route_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-auto-excluded"):
                                        self.route_auto_excluded = value
                                        self.route_auto_excluded.value_namespace = name_space
                                        self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-forward-distance"):
                                        self.route_forward_distance = value
                                        self.route_forward_distance.value_namespace = name_space
                                        self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-rib-version"):
                                        self.route_rib_version = value
                                        self.route_rib_version.value_namespace = name_space
                                        self.route_rib_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-source"):
                                        self.route_source = value
                                        self.route_source.value_namespace = name_space
                                        self.route_source.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-spf-priority"):
                                        self.route_spf_priority = value
                                        self.route_spf_priority.value_namespace = name_space
                                        self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-spf-version"):
                                        self.route_spf_version = value
                                        self.route_spf_version.value_namespace = name_space
                                        self.route_spf_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-srte-nbr-registered"):
                                        self.route_srte_nbr_registered = value
                                        self.route_srte_nbr_registered.value_namespace = name_space
                                        self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-srte-prefix-registered"):
                                        self.route_srte_prefix_registered = value
                                        self.route_srte_prefix_registered.value_namespace = name_space
                                        self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-te-metric"):
                                        self.route_te_metric = value
                                        self.route_te_metric.value_namespace = name_space
                                        self.route_te_metric.value_namespace_prefix = name_space_prefix


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: area_format
                                
                                	Area format IP or uint32
                                	**type**\:  bool
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_type
                                
                                	LSA type, see RFC2328 etc
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: route_lsaid
                                
                                	LSA ID, see RFC2328
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_is_mcast_intact
                                
                                	Multicast\-intact path
                                	**type**\:  bool
                                
                                .. attribute:: route_path_is_ucmp_path
                                
                                	UCMP path
                                	**type**\:  bool
                                
                                .. attribute:: route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_path
                                
                                	SR Microloop avoidance Path Info
                                	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "connected-route"

                                    self.area_format = YLeaf(YType.boolean, "area-format")

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                    self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                    self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                    self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                    self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                    self.route_source = YLeaf(YType.str, "route-source")

                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath()
                                    self.sr_microloop_avoidance_path.parent = self
                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                    self._children_yang_names.add("sr-microloop-avoidance-path")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_format",
                                                    "area_id",
                                                    "lsa_type",
                                                    "route_interface_name",
                                                    "route_lsaid",
                                                    "route_metric",
                                                    "route_next_hop_address",
                                                    "route_path_is_mcast_intact",
                                                    "route_path_is_ucmp_path",
                                                    "route_source") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath, self).__setattr__(name, value)


                                class SrMicroloopAvoidancePath(Entity):
                                    """
                                    SR Microloop avoidance Path Info
                                    
                                    .. attribute:: microloop_repair
                                    
                                    	Microloop Repair List
                                    	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                    
                                    .. attribute:: microloop_repair_list_size
                                    
                                    	Microloop Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: microloop_strict_spf
                                    
                                    	Strict SPF SID
                                    	**type**\:  bool
                                    
                                    .. attribute:: microloop_tunnel_interface_name
                                    
                                    	Microloop Tunnel Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                        self.yang_name = "sr-microloop-avoidance-path"
                                        self.yang_parent_name = "route-path"

                                        self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                        self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                        self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                        self.microloop_repair = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("microloop_repair_list_size",
                                                        "microloop_strict_spf",
                                                        "microloop_tunnel_interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                    class MicroloopRepair(Entity):
                                        """
                                        Microloop Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                            self.yang_name = "microloop-repair"
                                            self.yang_parent_name = "sr-microloop-avoidance-path"

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("repair_element_id",
                                                            "repair_element_type",
                                                            "repair_label") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.repair_element_id.is_set or
                                                self.repair_element_type.is_set or
                                                self.repair_label.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.repair_element_id.yfilter != YFilter.not_set or
                                                self.repair_element_type.yfilter != YFilter.not_set or
                                                self.repair_label.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "microloop-repair" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                            if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                            if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_label.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "repair-element-id"):
                                                self.repair_element_id = value
                                                self.repair_element_id.value_namespace = name_space
                                                self.repair_element_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-element-type"):
                                                self.repair_element_type = value
                                                self.repair_element_type.value_namespace = name_space
                                                self.repair_element_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-label"):
                                                self.repair_label = value
                                                self.repair_label.value_namespace = name_space
                                                self.repair_label.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.microloop_repair:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.microloop_repair_list_size.is_set or
                                            self.microloop_strict_spf.is_set or
                                            self.microloop_tunnel_interface_name.is_set)

                                    def has_operation(self):
                                        for c in self.microloop_repair:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                            self.microloop_strict_spf.yfilter != YFilter.not_set or
                                            self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                        if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                        if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "microloop-repair"):
                                            for c in self.microloop_repair:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.microloop_repair.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "microloop-repair-list-size"):
                                            self.microloop_repair_list_size = value
                                            self.microloop_repair_list_size.value_namespace = name_space
                                            self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "microloop-strict-spf"):
                                            self.microloop_strict_spf = value
                                            self.microloop_strict_spf.value_namespace = name_space
                                            self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                        if(value_path == "microloop-tunnel-interface-name"):
                                            self.microloop_tunnel_interface_name = value
                                            self.microloop_tunnel_interface_name.value_namespace = name_space
                                            self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.area_format.is_set or
                                        self.area_id.is_set or
                                        self.lsa_type.is_set or
                                        self.route_interface_name.is_set or
                                        self.route_lsaid.is_set or
                                        self.route_metric.is_set or
                                        self.route_next_hop_address.is_set or
                                        self.route_path_is_mcast_intact.is_set or
                                        self.route_path_is_ucmp_path.is_set or
                                        self.route_source.is_set or
                                        (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_format.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.lsa_type.yfilter != YFilter.not_set or
                                        self.route_interface_name.yfilter != YFilter.not_set or
                                        self.route_lsaid.yfilter != YFilter.not_set or
                                        self.route_metric.yfilter != YFilter.not_set or
                                        self.route_next_hop_address.yfilter != YFilter.not_set or
                                        self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                        self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                        self.route_source.yfilter != YFilter.not_set or
                                        (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_format.get_name_leafdata())
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                    if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                    if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                    if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_metric.get_name_leafdata())
                                    if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                    if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                    if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                    if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_source.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sr-microloop-avoidance-path"):
                                        if (self.sr_microloop_avoidance_path is None):
                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        return self.sr_microloop_avoidance_path

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-format"):
                                        self.area_format = value
                                        self.area_format.value_namespace = name_space
                                        self.area_format.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-type"):
                                        self.lsa_type = value
                                        self.lsa_type.value_namespace = name_space
                                        self.lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-interface-name"):
                                        self.route_interface_name = value
                                        self.route_interface_name.value_namespace = name_space
                                        self.route_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-lsaid"):
                                        self.route_lsaid = value
                                        self.route_lsaid.value_namespace = name_space
                                        self.route_lsaid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-metric"):
                                        self.route_metric = value
                                        self.route_metric.value_namespace = name_space
                                        self.route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-next-hop-address"):
                                        self.route_next_hop_address = value
                                        self.route_next_hop_address.value_namespace = name_space
                                        self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-is-mcast-intact"):
                                        self.route_path_is_mcast_intact = value
                                        self.route_path_is_mcast_intact.value_namespace = name_space
                                        self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-is-ucmp-path"):
                                        self.route_path_is_ucmp_path = value
                                        self.route_path_is_ucmp_path.value_namespace = name_space
                                        self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-source"):
                                        self.route_source = value
                                        self.route_source.value_namespace = name_space
                                        self.route_source.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.route_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    self.route_connected.is_set or
                                    self.route_metric.is_set or
                                    self.route_prefix.is_set or
                                    self.route_prefix_length.is_set or
                                    self.route_type.is_set or
                                    (self.route_info is not None and self.route_info.has_data()))

                            def has_operation(self):
                                for c in self.route_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.route_connected.yfilter != YFilter.not_set or
                                    self.route_metric.yfilter != YFilter.not_set or
                                    self.route_prefix.yfilter != YFilter.not_set or
                                    self.route_prefix_length.yfilter != YFilter.not_set or
                                    self.route_type.yfilter != YFilter.not_set or
                                    (self.route_info is not None and self.route_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "connected-route" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_connected.get_name_leafdata())
                                if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_metric.get_name_leafdata())
                                if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "route-info"):
                                    if (self.route_info is None):
                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                    return self.route_info

                                if (child_yang_name == "route-path"):
                                    for c in self.route_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.route_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-connected"):
                                    self.route_connected = value
                                    self.route_connected.value_namespace = name_space
                                    self.route_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-metric"):
                                    self.route_metric = value
                                    self.route_metric.value_namespace = name_space
                                    self.route_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-prefix"):
                                    self.route_prefix = value
                                    self.route_prefix.value_namespace = name_space
                                    self.route_prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-prefix-length"):
                                    self.route_prefix_length = value
                                    self.route_prefix_length.value_namespace = name_space
                                    self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-type"):
                                    self.route_type = value
                                    self.route_type.value_namespace = name_space
                                    self.route_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.connected_route:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.connected_route:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "connected-routes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "connected-route"):
                                for c in self.connected_route:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.connected_route.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "connected-route"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class LocalRoutes(Entity):
                        """
                        OSPF Local Route Table
                        
                        .. attribute:: local_route
                        
                        	Local route
                        	**type**\: list of    :py:class:`LocalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes, self).__init__()

                            self.yang_name = "local-routes"
                            self.yang_parent_name = "route-information"

                            self.local_route = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes, self).__setattr__(name, value)


                        class LocalRoute(Entity):
                            """
                            Local route
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: route_connected
                            
                            	If true, connected route
                            	**type**\:  bool
                            
                            .. attribute:: route_info
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo>`
                            
                            .. attribute:: route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath>`
                            
                            .. attribute:: route_prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute, self).__init__()

                                self.yang_name = "local-route"
                                self.yang_parent_name = "local-routes"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_connected = YLeaf(YType.boolean, "route-connected")

                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                self.route_prefix = YLeaf(YType.str, "route-prefix")

                                self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo()
                                self.route_info.parent = self
                                self._children_name_map["route_info"] = "route-info"
                                self._children_yang_names.add("route-info")

                                self.route_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length",
                                                "route_connected",
                                                "route_metric",
                                                "route_prefix",
                                                "route_prefix_length",
                                                "route_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute, self).__setattr__(name, value)


                            class RouteInfo(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_auto_excluded
                                
                                	If true, exclude from TE paths
                                	**type**\:  bool
                                
                                .. attribute:: route_fail_time
                                
                                	Last time update failed
                                	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime>`
                                
                                .. attribute:: route_forward_distance
                                
                                	Forward distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_source
                                
                                	Protocol source
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_spf_priority
                                
                                	SPF priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: route_srte_nbr_registered
                                
                                	SRTE registered neigbhor count on route
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_srte_prefix_registered
                                
                                	If true, SRTE registered prefix route
                                	**type**\:  bool
                                
                                .. attribute:: route_te_metric
                                
                                	TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_update_time
                                
                                	Last time updated
                                	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo, self).__init__()

                                    self.yang_name = "route-info"
                                    self.yang_parent_name = "local-route"

                                    self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                    self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                    self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                    self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                    self.route_source = YLeaf(YType.uint16, "route-source")

                                    self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                    self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                    self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                    self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                    self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime()
                                    self.route_fail_time.parent = self
                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                    self._children_yang_names.add("route-fail-time")

                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime()
                                    self.route_update_time.parent = self
                                    self._children_name_map["route_update_time"] = "route-update-time"
                                    self._children_yang_names.add("route-update-time")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("route_area_id",
                                                    "route_auto_excluded",
                                                    "route_forward_distance",
                                                    "route_rib_version",
                                                    "route_source",
                                                    "route_spf_priority",
                                                    "route_spf_version",
                                                    "route_srte_nbr_registered",
                                                    "route_srte_prefix_registered",
                                                    "route_te_metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo, self).__setattr__(name, value)


                                class RouteUpdateTime(Entity):
                                    """
                                    Last time updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                        self.yang_name = "route-update-time"
                                        self.yang_parent_name = "route-info"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-update-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix


                                class RouteFailTime(Entity):
                                    """
                                    Last time update failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime, self).__init__()

                                        self.yang_name = "route-fail-time"
                                        self.yang_parent_name = "route-info"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-fail-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.route_area_id.is_set or
                                        self.route_auto_excluded.is_set or
                                        self.route_forward_distance.is_set or
                                        self.route_rib_version.is_set or
                                        self.route_source.is_set or
                                        self.route_spf_priority.is_set or
                                        self.route_spf_version.is_set or
                                        self.route_srte_nbr_registered.is_set or
                                        self.route_srte_prefix_registered.is_set or
                                        self.route_te_metric.is_set or
                                        (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                        (self.route_update_time is not None and self.route_update_time.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.route_area_id.yfilter != YFilter.not_set or
                                        self.route_auto_excluded.yfilter != YFilter.not_set or
                                        self.route_forward_distance.yfilter != YFilter.not_set or
                                        self.route_rib_version.yfilter != YFilter.not_set or
                                        self.route_source.yfilter != YFilter.not_set or
                                        self.route_spf_priority.yfilter != YFilter.not_set or
                                        self.route_spf_version.yfilter != YFilter.not_set or
                                        self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                        self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                        self.route_te_metric.yfilter != YFilter.not_set or
                                        (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                        (self.route_update_time is not None and self.route_update_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                    if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                    if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                    if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                    if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_source.get_name_leafdata())
                                    if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                    if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                    if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                    if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                    if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-fail-time"):
                                        if (self.route_fail_time is None):
                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                        return self.route_fail_time

                                    if (child_yang_name == "route-update-time"):
                                        if (self.route_update_time is None):
                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                        return self.route_update_time

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "route-area-id"):
                                        self.route_area_id = value
                                        self.route_area_id.value_namespace = name_space
                                        self.route_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-auto-excluded"):
                                        self.route_auto_excluded = value
                                        self.route_auto_excluded.value_namespace = name_space
                                        self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-forward-distance"):
                                        self.route_forward_distance = value
                                        self.route_forward_distance.value_namespace = name_space
                                        self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-rib-version"):
                                        self.route_rib_version = value
                                        self.route_rib_version.value_namespace = name_space
                                        self.route_rib_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-source"):
                                        self.route_source = value
                                        self.route_source.value_namespace = name_space
                                        self.route_source.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-spf-priority"):
                                        self.route_spf_priority = value
                                        self.route_spf_priority.value_namespace = name_space
                                        self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-spf-version"):
                                        self.route_spf_version = value
                                        self.route_spf_version.value_namespace = name_space
                                        self.route_spf_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-srte-nbr-registered"):
                                        self.route_srte_nbr_registered = value
                                        self.route_srte_nbr_registered.value_namespace = name_space
                                        self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-srte-prefix-registered"):
                                        self.route_srte_prefix_registered = value
                                        self.route_srte_prefix_registered.value_namespace = name_space
                                        self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-te-metric"):
                                        self.route_te_metric = value
                                        self.route_te_metric.value_namespace = name_space
                                        self.route_te_metric.value_namespace_prefix = name_space_prefix


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: area_format
                                
                                	Area format IP or uint32
                                	**type**\:  bool
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_type
                                
                                	LSA type, see RFC2328 etc
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: route_lsaid
                                
                                	LSA ID, see RFC2328
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_is_mcast_intact
                                
                                	Multicast\-intact path
                                	**type**\:  bool
                                
                                .. attribute:: route_path_is_ucmp_path
                                
                                	UCMP path
                                	**type**\:  bool
                                
                                .. attribute:: route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_path
                                
                                	SR Microloop avoidance Path Info
                                	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "local-route"

                                    self.area_format = YLeaf(YType.boolean, "area-format")

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                    self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                    self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                    self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                    self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                    self.route_source = YLeaf(YType.str, "route-source")

                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath()
                                    self.sr_microloop_avoidance_path.parent = self
                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                    self._children_yang_names.add("sr-microloop-avoidance-path")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_format",
                                                    "area_id",
                                                    "lsa_type",
                                                    "route_interface_name",
                                                    "route_lsaid",
                                                    "route_metric",
                                                    "route_next_hop_address",
                                                    "route_path_is_mcast_intact",
                                                    "route_path_is_ucmp_path",
                                                    "route_source") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath, self).__setattr__(name, value)


                                class SrMicroloopAvoidancePath(Entity):
                                    """
                                    SR Microloop avoidance Path Info
                                    
                                    .. attribute:: microloop_repair
                                    
                                    	Microloop Repair List
                                    	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                    
                                    .. attribute:: microloop_repair_list_size
                                    
                                    	Microloop Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: microloop_strict_spf
                                    
                                    	Strict SPF SID
                                    	**type**\:  bool
                                    
                                    .. attribute:: microloop_tunnel_interface_name
                                    
                                    	Microloop Tunnel Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                        self.yang_name = "sr-microloop-avoidance-path"
                                        self.yang_parent_name = "route-path"

                                        self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                        self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                        self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                        self.microloop_repair = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("microloop_repair_list_size",
                                                        "microloop_strict_spf",
                                                        "microloop_tunnel_interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                    class MicroloopRepair(Entity):
                                        """
                                        Microloop Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                            self.yang_name = "microloop-repair"
                                            self.yang_parent_name = "sr-microloop-avoidance-path"

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("repair_element_id",
                                                            "repair_element_type",
                                                            "repair_label") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.repair_element_id.is_set or
                                                self.repair_element_type.is_set or
                                                self.repair_label.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.repair_element_id.yfilter != YFilter.not_set or
                                                self.repair_element_type.yfilter != YFilter.not_set or
                                                self.repair_label.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "microloop-repair" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                            if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                            if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_label.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "repair-element-id"):
                                                self.repair_element_id = value
                                                self.repair_element_id.value_namespace = name_space
                                                self.repair_element_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-element-type"):
                                                self.repair_element_type = value
                                                self.repair_element_type.value_namespace = name_space
                                                self.repair_element_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-label"):
                                                self.repair_label = value
                                                self.repair_label.value_namespace = name_space
                                                self.repair_label.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.microloop_repair:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.microloop_repair_list_size.is_set or
                                            self.microloop_strict_spf.is_set or
                                            self.microloop_tunnel_interface_name.is_set)

                                    def has_operation(self):
                                        for c in self.microloop_repair:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                            self.microloop_strict_spf.yfilter != YFilter.not_set or
                                            self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                        if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                        if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "microloop-repair"):
                                            for c in self.microloop_repair:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.microloop_repair.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "microloop-repair-list-size"):
                                            self.microloop_repair_list_size = value
                                            self.microloop_repair_list_size.value_namespace = name_space
                                            self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "microloop-strict-spf"):
                                            self.microloop_strict_spf = value
                                            self.microloop_strict_spf.value_namespace = name_space
                                            self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                        if(value_path == "microloop-tunnel-interface-name"):
                                            self.microloop_tunnel_interface_name = value
                                            self.microloop_tunnel_interface_name.value_namespace = name_space
                                            self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.area_format.is_set or
                                        self.area_id.is_set or
                                        self.lsa_type.is_set or
                                        self.route_interface_name.is_set or
                                        self.route_lsaid.is_set or
                                        self.route_metric.is_set or
                                        self.route_next_hop_address.is_set or
                                        self.route_path_is_mcast_intact.is_set or
                                        self.route_path_is_ucmp_path.is_set or
                                        self.route_source.is_set or
                                        (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_format.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.lsa_type.yfilter != YFilter.not_set or
                                        self.route_interface_name.yfilter != YFilter.not_set or
                                        self.route_lsaid.yfilter != YFilter.not_set or
                                        self.route_metric.yfilter != YFilter.not_set or
                                        self.route_next_hop_address.yfilter != YFilter.not_set or
                                        self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                        self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                        self.route_source.yfilter != YFilter.not_set or
                                        (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_format.get_name_leafdata())
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                    if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                    if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                    if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_metric.get_name_leafdata())
                                    if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                    if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                    if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                    if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_source.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sr-microloop-avoidance-path"):
                                        if (self.sr_microloop_avoidance_path is None):
                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        return self.sr_microloop_avoidance_path

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-format"):
                                        self.area_format = value
                                        self.area_format.value_namespace = name_space
                                        self.area_format.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-type"):
                                        self.lsa_type = value
                                        self.lsa_type.value_namespace = name_space
                                        self.lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-interface-name"):
                                        self.route_interface_name = value
                                        self.route_interface_name.value_namespace = name_space
                                        self.route_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-lsaid"):
                                        self.route_lsaid = value
                                        self.route_lsaid.value_namespace = name_space
                                        self.route_lsaid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-metric"):
                                        self.route_metric = value
                                        self.route_metric.value_namespace = name_space
                                        self.route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-next-hop-address"):
                                        self.route_next_hop_address = value
                                        self.route_next_hop_address.value_namespace = name_space
                                        self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-is-mcast-intact"):
                                        self.route_path_is_mcast_intact = value
                                        self.route_path_is_mcast_intact.value_namespace = name_space
                                        self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-is-ucmp-path"):
                                        self.route_path_is_ucmp_path = value
                                        self.route_path_is_ucmp_path.value_namespace = name_space
                                        self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-source"):
                                        self.route_source = value
                                        self.route_source.value_namespace = name_space
                                        self.route_source.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.route_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    self.route_connected.is_set or
                                    self.route_metric.is_set or
                                    self.route_prefix.is_set or
                                    self.route_prefix_length.is_set or
                                    self.route_type.is_set or
                                    (self.route_info is not None and self.route_info.has_data()))

                            def has_operation(self):
                                for c in self.route_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.route_connected.yfilter != YFilter.not_set or
                                    self.route_metric.yfilter != YFilter.not_set or
                                    self.route_prefix.yfilter != YFilter.not_set or
                                    self.route_prefix_length.yfilter != YFilter.not_set or
                                    self.route_type.yfilter != YFilter.not_set or
                                    (self.route_info is not None and self.route_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-route" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_connected.get_name_leafdata())
                                if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_metric.get_name_leafdata())
                                if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "route-info"):
                                    if (self.route_info is None):
                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                    return self.route_info

                                if (child_yang_name == "route-path"):
                                    for c in self.route_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.route_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-connected"):
                                    self.route_connected = value
                                    self.route_connected.value_namespace = name_space
                                    self.route_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-metric"):
                                    self.route_metric = value
                                    self.route_metric.value_namespace = name_space
                                    self.route_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-prefix"):
                                    self.route_prefix = value
                                    self.route_prefix.value_namespace = name_space
                                    self.route_prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-prefix-length"):
                                    self.route_prefix_length = value
                                    self.route_prefix_length.value_namespace = name_space
                                    self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-type"):
                                    self.route_type = value
                                    self.route_type.value_namespace = name_space
                                    self.route_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.local_route:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.local_route:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "local-routes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "local-route"):
                                for c in self.local_route:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.local_route.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "local-route"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class RouteAreas(Entity):
                        """
                        OSPF Area Route Table
                        
                        .. attribute:: route_area
                        
                        	OSPF Area Route
                        	**type**\: list of    :py:class:`RouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas, self).__init__()

                            self.yang_name = "route-areas"
                            self.yang_parent_name = "route-information"

                            self.route_area = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas, self).__setattr__(name, value)


                        class RouteArea(Entity):
                            """
                            OSPF Area Route
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: backup_route_areas
                            
                            	OSPF Route Table Including Backup Paths in an area
                            	**type**\:   :py:class:`BackupRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas>`
                            
                            .. attribute:: connected_route_areas
                            
                            	OSPF Connected Route Table in an area
                            	**type**\:   :py:class:`ConnectedRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas>`
                            
                            .. attribute:: local_route_areas
                            
                            	OSPF Local Route Table
                            	**type**\:   :py:class:`LocalRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas>`
                            
                            .. attribute:: multicast_intact_backup_route_areas
                            
                            	OSPF Route Table Including Multicast Intace Backup Paths in an area
                            	**type**\:   :py:class:`MulticastIntactBackupRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas>`
                            
                            .. attribute:: multicast_intact_route_areas
                            
                            	OSPF Area multicast\-intact included route entry
                            	**type**\:   :py:class:`MulticastIntactRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas>`
                            
                            .. attribute:: route_area_informations
                            
                            	OSPF Area Route Entry
                            	**type**\:   :py:class:`RouteAreaInformations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations>`
                            
                            .. attribute:: summary_area_information
                            
                            	OSPF route summary statistics
                            	**type**\:   :py:class:`SummaryAreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea, self).__init__()

                                self.yang_name = "route-area"
                                self.yang_parent_name = "route-areas"

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.backup_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas()
                                self.backup_route_areas.parent = self
                                self._children_name_map["backup_route_areas"] = "backup-route-areas"
                                self._children_yang_names.add("backup-route-areas")

                                self.connected_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas()
                                self.connected_route_areas.parent = self
                                self._children_name_map["connected_route_areas"] = "connected-route-areas"
                                self._children_yang_names.add("connected-route-areas")

                                self.local_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas()
                                self.local_route_areas.parent = self
                                self._children_name_map["local_route_areas"] = "local-route-areas"
                                self._children_yang_names.add("local-route-areas")

                                self.multicast_intact_backup_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas()
                                self.multicast_intact_backup_route_areas.parent = self
                                self._children_name_map["multicast_intact_backup_route_areas"] = "multicast-intact-backup-route-areas"
                                self._children_yang_names.add("multicast-intact-backup-route-areas")

                                self.multicast_intact_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas()
                                self.multicast_intact_route_areas.parent = self
                                self._children_name_map["multicast_intact_route_areas"] = "multicast-intact-route-areas"
                                self._children_yang_names.add("multicast-intact-route-areas")

                                self.route_area_informations = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations()
                                self.route_area_informations.parent = self
                                self._children_name_map["route_area_informations"] = "route-area-informations"
                                self._children_yang_names.add("route-area-informations")

                                self.summary_area_information = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation()
                                self.summary_area_information.parent = self
                                self._children_name_map["summary_area_information"] = "summary-area-information"
                                self._children_yang_names.add("summary-area-information")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("area_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea, self).__setattr__(name, value)


                            class MulticastIntactBackupRouteAreas(Entity):
                                """
                                OSPF Route Table Including Multicast Intace
                                Backup Paths in an area
                                
                                .. attribute:: multicast_intact_backup_route_area
                                
                                	OSPF route including Multicast intact backup paths
                                	**type**\: list of    :py:class:`MulticastIntactBackupRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas, self).__init__()

                                    self.yang_name = "multicast-intact-backup-route-areas"
                                    self.yang_parent_name = "route-area"

                                    self.multicast_intact_backup_route_area = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas, self).__setattr__(name, value)


                                class MulticastIntactBackupRouteArea(Entity):
                                    """
                                    OSPF route including Multicast intact backup
                                    paths
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..32
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea, self).__init__()

                                        self.yang_name = "multicast-intact-backup-route-area"
                                        self.yang_parent_name = "multicast-intact-backup-route-areas"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length",
                                                        "route_connected",
                                                        "route_metric",
                                                        "route_prefix",
                                                        "route_prefix_length",
                                                        "route_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea, self).__setattr__(name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "multicast-intact-backup-route-area"

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("route_area_id",
                                                            "route_auto_excluded",
                                                            "route_forward_distance",
                                                            "route_rib_version",
                                                            "route_source",
                                                            "route_spf_priority",
                                                            "route_spf_version",
                                                            "route_srte_nbr_registered",
                                                            "route_srte_prefix_registered",
                                                            "route_te_metric") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo, self).__setattr__(name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-update-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-fail-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.route_area_id.is_set or
                                                self.route_auto_excluded.is_set or
                                                self.route_forward_distance.is_set or
                                                self.route_rib_version.is_set or
                                                self.route_source.is_set or
                                                self.route_spf_priority.is_set or
                                                self.route_spf_version.is_set or
                                                self.route_srte_nbr_registered.is_set or
                                                self.route_srte_prefix_registered.is_set or
                                                self.route_te_metric.is_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                                (self.route_update_time is not None and self.route_update_time.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.route_area_id.yfilter != YFilter.not_set or
                                                self.route_auto_excluded.yfilter != YFilter.not_set or
                                                self.route_forward_distance.yfilter != YFilter.not_set or
                                                self.route_rib_version.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                self.route_spf_priority.yfilter != YFilter.not_set or
                                                self.route_spf_version.yfilter != YFilter.not_set or
                                                self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                                self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                                self.route_te_metric.yfilter != YFilter.not_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                                (self.route_update_time is not None and self.route_update_time.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-info" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                            if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                            if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                            if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())
                                            if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                            if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                            if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                            if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                            if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-fail-time"):
                                                if (self.route_fail_time is None):
                                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime()
                                                    self.route_fail_time.parent = self
                                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                                return self.route_fail_time

                                            if (child_yang_name == "route-update-time"):
                                                if (self.route_update_time is None):
                                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime()
                                                    self.route_update_time.parent = self
                                                    self._children_name_map["route_update_time"] = "route-update-time"
                                                return self.route_update_time

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "route-area-id"):
                                                self.route_area_id = value
                                                self.route_area_id.value_namespace = name_space
                                                self.route_area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-auto-excluded"):
                                                self.route_auto_excluded = value
                                                self.route_auto_excluded.value_namespace = name_space
                                                self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-forward-distance"):
                                                self.route_forward_distance = value
                                                self.route_forward_distance.value_namespace = name_space
                                                self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-rib-version"):
                                                self.route_rib_version = value
                                                self.route_rib_version.value_namespace = name_space
                                                self.route_rib_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-priority"):
                                                self.route_spf_priority = value
                                                self.route_spf_priority.value_namespace = name_space
                                                self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-version"):
                                                self.route_spf_version = value
                                                self.route_spf_version.value_namespace = name_space
                                                self.route_spf_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-nbr-registered"):
                                                self.route_srte_nbr_registered = value
                                                self.route_srte_nbr_registered.value_namespace = name_space
                                                self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-prefix-registered"):
                                                self.route_srte_prefix_registered = value
                                                self.route_srte_prefix_registered.value_namespace = name_space
                                                self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-te-metric"):
                                                self.route_te_metric = value
                                                self.route_te_metric.value_namespace = name_space
                                                self.route_te_metric.value_namespace_prefix = name_space_prefix


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_backup_path
                                        
                                        	Backup Path Info
                                        	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath>`
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_id
                                        
                                        	Path ID of path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "multicast-intact-backup-route-area"

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.route_backup_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath()
                                            self.route_backup_path.parent = self
                                            self._children_name_map["route_backup_path"] = "route-backup-path"
                                            self._children_yang_names.add("route-backup-path")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lsa_type",
                                                            "route_interface_name",
                                                            "route_lsaid",
                                                            "route_metric",
                                                            "route_next_hop_address",
                                                            "route_path_id",
                                                            "route_path_is_mcast_intact",
                                                            "route_path_is_ucmp_path",
                                                            "route_source") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath, self).__setattr__(name, value)


                                        class RouteBackupPath(Entity):
                                            """
                                            Backup Path Info
                                            
                                            .. attribute:: backup_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: backup_remote_lfa
                                            
                                            	IP address of remote LFA
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_repair
                                            
                                            	Backup Repair List
                                            	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair>`
                                            
                                            .. attribute:: backup_repair_list_size
                                            
                                            	Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: backup_route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: backup_route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_tunnel_interface_name
                                            
                                            	Backup Tunnel Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: downstream
                                            
                                            	Downstream
                                            	**type**\:  bool
                                            
                                            .. attribute:: line_card_disjoint
                                            
                                            	Line Card Disjoint
                                            	**type**\:  bool
                                            
                                            .. attribute:: node_protect
                                            
                                            	Node Protect
                                            	**type**\:  bool
                                            
                                            .. attribute:: primary_path
                                            
                                            	Primary Path
                                            	**type**\:  bool
                                            
                                            .. attribute:: srlg_disjoint
                                            
                                            	SRLG Disjoint
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath, self).__init__()

                                                self.yang_name = "route-backup-path"
                                                self.yang_parent_name = "route-path"

                                                self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                                self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                                self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                                self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                                self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                                self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                                self.downstream = YLeaf(YType.boolean, "downstream")

                                                self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                                self.node_protect = YLeaf(YType.boolean, "node-protect")

                                                self.primary_path = YLeaf(YType.boolean, "primary-path")

                                                self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                                self.backup_repair = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("backup_metric",
                                                                "backup_remote_lfa",
                                                                "backup_repair_list_size",
                                                                "backup_route_interface_name",
                                                                "backup_route_next_hop_address",
                                                                "backup_route_source",
                                                                "backup_tunnel_interface_name",
                                                                "downstream",
                                                                "line_card_disjoint",
                                                                "node_protect",
                                                                "primary_path",
                                                                "srlg_disjoint") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath, self).__setattr__(name, value)


                                            class BackupRepair(Entity):
                                                """
                                                Backup Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                                    self.yang_name = "backup-repair"
                                                    self.yang_parent_name = "route-backup-path"

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_id",
                                                                    "repair_element_type",
                                                                    "repair_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "backup-repair" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-id"):
                                                        self.repair_element_id = value
                                                        self.repair_element_id.value_namespace = name_space
                                                        self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.backup_repair:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.backup_metric.is_set or
                                                    self.backup_remote_lfa.is_set or
                                                    self.backup_repair_list_size.is_set or
                                                    self.backup_route_interface_name.is_set or
                                                    self.backup_route_next_hop_address.is_set or
                                                    self.backup_route_source.is_set or
                                                    self.backup_tunnel_interface_name.is_set or
                                                    self.downstream.is_set or
                                                    self.line_card_disjoint.is_set or
                                                    self.node_protect.is_set or
                                                    self.primary_path.is_set or
                                                    self.srlg_disjoint.is_set)

                                            def has_operation(self):
                                                for c in self.backup_repair:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.backup_metric.yfilter != YFilter.not_set or
                                                    self.backup_remote_lfa.yfilter != YFilter.not_set or
                                                    self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                    self.backup_route_interface_name.yfilter != YFilter.not_set or
                                                    self.backup_route_next_hop_address.yfilter != YFilter.not_set or
                                                    self.backup_route_source.yfilter != YFilter.not_set or
                                                    self.backup_tunnel_interface_name.yfilter != YFilter.not_set or
                                                    self.downstream.yfilter != YFilter.not_set or
                                                    self.line_card_disjoint.yfilter != YFilter.not_set or
                                                    self.node_protect.yfilter != YFilter.not_set or
                                                    self.primary_path.yfilter != YFilter.not_set or
                                                    self.srlg_disjoint.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-backup-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.backup_metric.is_set or self.backup_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_metric.get_name_leafdata())
                                                if (self.backup_remote_lfa.is_set or self.backup_remote_lfa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_remote_lfa.get_name_leafdata())
                                                if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                if (self.backup_route_interface_name.is_set or self.backup_route_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_route_interface_name.get_name_leafdata())
                                                if (self.backup_route_next_hop_address.is_set or self.backup_route_next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_route_next_hop_address.get_name_leafdata())
                                                if (self.backup_route_source.is_set or self.backup_route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_route_source.get_name_leafdata())
                                                if (self.backup_tunnel_interface_name.is_set or self.backup_tunnel_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_tunnel_interface_name.get_name_leafdata())
                                                if (self.downstream.is_set or self.downstream.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.downstream.get_name_leafdata())
                                                if (self.line_card_disjoint.is_set or self.line_card_disjoint.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.line_card_disjoint.get_name_leafdata())
                                                if (self.node_protect.is_set or self.node_protect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.node_protect.get_name_leafdata())
                                                if (self.primary_path.is_set or self.primary_path.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.primary_path.get_name_leafdata())
                                                if (self.srlg_disjoint.is_set or self.srlg_disjoint.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.srlg_disjoint.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "backup-repair"):
                                                    for c in self.backup_repair:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.backup_repair.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "backup-repair" or name == "backup-metric" or name == "backup-remote-lfa" or name == "backup-repair-list-size" or name == "backup-route-interface-name" or name == "backup-route-next-hop-address" or name == "backup-route-source" or name == "backup-tunnel-interface-name" or name == "downstream" or name == "line-card-disjoint" or name == "node-protect" or name == "primary-path" or name == "srlg-disjoint"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "backup-metric"):
                                                    self.backup_metric = value
                                                    self.backup_metric.value_namespace = name_space
                                                    self.backup_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-remote-lfa"):
                                                    self.backup_remote_lfa = value
                                                    self.backup_remote_lfa.value_namespace = name_space
                                                    self.backup_remote_lfa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-repair-list-size"):
                                                    self.backup_repair_list_size = value
                                                    self.backup_repair_list_size.value_namespace = name_space
                                                    self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-route-interface-name"):
                                                    self.backup_route_interface_name = value
                                                    self.backup_route_interface_name.value_namespace = name_space
                                                    self.backup_route_interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-route-next-hop-address"):
                                                    self.backup_route_next_hop_address = value
                                                    self.backup_route_next_hop_address.value_namespace = name_space
                                                    self.backup_route_next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-route-source"):
                                                    self.backup_route_source = value
                                                    self.backup_route_source.value_namespace = name_space
                                                    self.backup_route_source.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-tunnel-interface-name"):
                                                    self.backup_tunnel_interface_name = value
                                                    self.backup_tunnel_interface_name.value_namespace = name_space
                                                    self.backup_tunnel_interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "downstream"):
                                                    self.downstream = value
                                                    self.downstream.value_namespace = name_space
                                                    self.downstream.value_namespace_prefix = name_space_prefix
                                                if(value_path == "line-card-disjoint"):
                                                    self.line_card_disjoint = value
                                                    self.line_card_disjoint.value_namespace = name_space
                                                    self.line_card_disjoint.value_namespace_prefix = name_space_prefix
                                                if(value_path == "node-protect"):
                                                    self.node_protect = value
                                                    self.node_protect.value_namespace = name_space
                                                    self.node_protect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "primary-path"):
                                                    self.primary_path = value
                                                    self.primary_path.value_namespace = name_space
                                                    self.primary_path.value_namespace_prefix = name_space_prefix
                                                if(value_path == "srlg-disjoint"):
                                                    self.srlg_disjoint = value
                                                    self.srlg_disjoint.value_namespace = name_space
                                                    self.srlg_disjoint.value_namespace_prefix = name_space_prefix


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("microloop_repair_list_size",
                                                                "microloop_strict_spf",
                                                                "microloop_tunnel_interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_id",
                                                                    "repair_element_type",
                                                                    "repair_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "microloop-repair" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-id"):
                                                        self.repair_element_id = value
                                                        self.repair_element_id.value_namespace = name_space
                                                        self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.microloop_repair_list_size.is_set or
                                                    self.microloop_strict_spf.is_set or
                                                    self.microloop_tunnel_interface_name.is_set)

                                            def has_operation(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                    self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                    self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                                if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                                if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "microloop-repair"):
                                                    for c in self.microloop_repair:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.microloop_repair.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "microloop-repair-list-size"):
                                                    self.microloop_repair_list_size = value
                                                    self.microloop_repair_list_size.value_namespace = name_space
                                                    self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-strict-spf"):
                                                    self.microloop_strict_spf = value
                                                    self.microloop_strict_spf.value_namespace = name_space
                                                    self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-tunnel-interface-name"):
                                                    self.microloop_tunnel_interface_name = value
                                                    self.microloop_tunnel_interface_name.value_namespace = name_space
                                                    self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.lsa_type.is_set or
                                                self.route_interface_name.is_set or
                                                self.route_lsaid.is_set or
                                                self.route_metric.is_set or
                                                self.route_next_hop_address.is_set or
                                                self.route_path_id.is_set or
                                                self.route_path_is_mcast_intact.is_set or
                                                self.route_path_is_ucmp_path.is_set or
                                                self.route_source.is_set or
                                                (self.route_backup_path is not None and self.route_backup_path.has_data()) or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lsa_type.yfilter != YFilter.not_set or
                                                self.route_interface_name.yfilter != YFilter.not_set or
                                                self.route_lsaid.yfilter != YFilter.not_set or
                                                self.route_metric.yfilter != YFilter.not_set or
                                                self.route_next_hop_address.yfilter != YFilter.not_set or
                                                self.route_path_id.yfilter != YFilter.not_set or
                                                self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                                self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                (self.route_backup_path is not None and self.route_backup_path.has_operation()) or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                            if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                            if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                            if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_metric.get_name_leafdata())
                                            if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                            if (self.route_path_id.is_set or self.route_path_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_id.get_name_leafdata())
                                            if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                            if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-backup-path"):
                                                if (self.route_backup_path is None):
                                                    self.route_backup_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath()
                                                    self.route_backup_path.parent = self
                                                    self._children_name_map["route_backup_path"] = "route-backup-path"
                                                return self.route_backup_path

                                            if (child_yang_name == "sr-microloop-avoidance-path"):
                                                if (self.sr_microloop_avoidance_path is None):
                                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                    self.sr_microloop_avoidance_path.parent = self
                                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                return self.sr_microloop_avoidance_path

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-backup-path" or name == "sr-microloop-avoidance-path" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-id" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lsa-type"):
                                                self.lsa_type = value
                                                self.lsa_type.value_namespace = name_space
                                                self.lsa_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-interface-name"):
                                                self.route_interface_name = value
                                                self.route_interface_name.value_namespace = name_space
                                                self.route_interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-lsaid"):
                                                self.route_lsaid = value
                                                self.route_lsaid.value_namespace = name_space
                                                self.route_lsaid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-metric"):
                                                self.route_metric = value
                                                self.route_metric.value_namespace = name_space
                                                self.route_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-next-hop-address"):
                                                self.route_next_hop_address = value
                                                self.route_next_hop_address.value_namespace = name_space
                                                self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-id"):
                                                self.route_path_id = value
                                                self.route_path_id.value_namespace = name_space
                                                self.route_path_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-mcast-intact"):
                                                self.route_path_is_mcast_intact = value
                                                self.route_path_is_mcast_intact.value_namespace = name_space
                                                self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-ucmp-path"):
                                                self.route_path_is_ucmp_path = value
                                                self.route_path_is_ucmp_path.value_namespace = name_space
                                                self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.route_path:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            self.route_connected.is_set or
                                            self.route_metric.is_set or
                                            self.route_prefix.is_set or
                                            self.route_prefix_length.is_set or
                                            self.route_type.is_set or
                                            (self.route_info is not None and self.route_info.has_data()))

                                    def has_operation(self):
                                        for c in self.route_path:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            self.route_connected.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_prefix.yfilter != YFilter.not_set or
                                            self.route_prefix_length.yfilter != YFilter.not_set or
                                            self.route_type.yfilter != YFilter.not_set or
                                            (self.route_info is not None and self.route_info.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-intact-backup-route-area" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                        if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_connected.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                        if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                        if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-info"):
                                            if (self.route_info is None):
                                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo()
                                                self.route_info.parent = self
                                                self._children_name_map["route_info"] = "route-info"
                                            return self.route_info

                                        if (child_yang_name == "route-path"):
                                            for c in self.route_path:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.route_path.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-connected"):
                                            self.route_connected = value
                                            self.route_connected.value_namespace = name_space
                                            self.route_connected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix"):
                                            self.route_prefix = value
                                            self.route_prefix.value_namespace = name_space
                                            self.route_prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix-length"):
                                            self.route_prefix_length = value
                                            self.route_prefix_length.value_namespace = name_space
                                            self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-type"):
                                            self.route_type = value
                                            self.route_type.value_namespace = name_space
                                            self.route_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.multicast_intact_backup_route_area:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.multicast_intact_backup_route_area:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast-intact-backup-route-areas" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "multicast-intact-backup-route-area"):
                                        for c in self.multicast_intact_backup_route_area:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.multicast_intact_backup_route_area.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "multicast-intact-backup-route-area"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class ConnectedRouteAreas(Entity):
                                """
                                OSPF Connected Route Table in an area
                                
                                .. attribute:: connected_route_area
                                
                                	Connected route
                                	**type**\: list of    :py:class:`ConnectedRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas, self).__init__()

                                    self.yang_name = "connected-route-areas"
                                    self.yang_parent_name = "route-area"

                                    self.connected_route_area = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas, self).__setattr__(name, value)


                                class ConnectedRouteArea(Entity):
                                    """
                                    Connected route
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..32
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea, self).__init__()

                                        self.yang_name = "connected-route-area"
                                        self.yang_parent_name = "connected-route-areas"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length",
                                                        "route_connected",
                                                        "route_metric",
                                                        "route_prefix",
                                                        "route_prefix_length",
                                                        "route_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea, self).__setattr__(name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "connected-route-area"

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("route_area_id",
                                                            "route_auto_excluded",
                                                            "route_forward_distance",
                                                            "route_rib_version",
                                                            "route_source",
                                                            "route_spf_priority",
                                                            "route_spf_version",
                                                            "route_srte_nbr_registered",
                                                            "route_srte_prefix_registered",
                                                            "route_te_metric") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo, self).__setattr__(name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-update-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-fail-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.route_area_id.is_set or
                                                self.route_auto_excluded.is_set or
                                                self.route_forward_distance.is_set or
                                                self.route_rib_version.is_set or
                                                self.route_source.is_set or
                                                self.route_spf_priority.is_set or
                                                self.route_spf_version.is_set or
                                                self.route_srte_nbr_registered.is_set or
                                                self.route_srte_prefix_registered.is_set or
                                                self.route_te_metric.is_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                                (self.route_update_time is not None and self.route_update_time.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.route_area_id.yfilter != YFilter.not_set or
                                                self.route_auto_excluded.yfilter != YFilter.not_set or
                                                self.route_forward_distance.yfilter != YFilter.not_set or
                                                self.route_rib_version.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                self.route_spf_priority.yfilter != YFilter.not_set or
                                                self.route_spf_version.yfilter != YFilter.not_set or
                                                self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                                self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                                self.route_te_metric.yfilter != YFilter.not_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                                (self.route_update_time is not None and self.route_update_time.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-info" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                            if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                            if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                            if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())
                                            if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                            if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                            if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                            if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                            if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-fail-time"):
                                                if (self.route_fail_time is None):
                                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime()
                                                    self.route_fail_time.parent = self
                                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                                return self.route_fail_time

                                            if (child_yang_name == "route-update-time"):
                                                if (self.route_update_time is None):
                                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime()
                                                    self.route_update_time.parent = self
                                                    self._children_name_map["route_update_time"] = "route-update-time"
                                                return self.route_update_time

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "route-area-id"):
                                                self.route_area_id = value
                                                self.route_area_id.value_namespace = name_space
                                                self.route_area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-auto-excluded"):
                                                self.route_auto_excluded = value
                                                self.route_auto_excluded.value_namespace = name_space
                                                self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-forward-distance"):
                                                self.route_forward_distance = value
                                                self.route_forward_distance.value_namespace = name_space
                                                self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-rib-version"):
                                                self.route_rib_version = value
                                                self.route_rib_version.value_namespace = name_space
                                                self.route_rib_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-priority"):
                                                self.route_spf_priority = value
                                                self.route_spf_priority.value_namespace = name_space
                                                self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-version"):
                                                self.route_spf_version = value
                                                self.route_spf_version.value_namespace = name_space
                                                self.route_spf_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-nbr-registered"):
                                                self.route_srte_nbr_registered = value
                                                self.route_srte_nbr_registered.value_namespace = name_space
                                                self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-prefix-registered"):
                                                self.route_srte_prefix_registered = value
                                                self.route_srte_prefix_registered.value_namespace = name_space
                                                self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-te-metric"):
                                                self.route_te_metric = value
                                                self.route_te_metric.value_namespace = name_space
                                                self.route_te_metric.value_namespace_prefix = name_space_prefix


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: area_format
                                        
                                        	Area format IP or uint32
                                        	**type**\:  bool
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "connected-route-area"

                                            self.area_format = YLeaf(YType.boolean, "area-format")

                                            self.area_id = YLeaf(YType.uint32, "area-id")

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("area_format",
                                                            "area_id",
                                                            "lsa_type",
                                                            "route_interface_name",
                                                            "route_lsaid",
                                                            "route_metric",
                                                            "route_next_hop_address",
                                                            "route_path_is_mcast_intact",
                                                            "route_path_is_ucmp_path",
                                                            "route_source") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath, self).__setattr__(name, value)


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("microloop_repair_list_size",
                                                                "microloop_strict_spf",
                                                                "microloop_tunnel_interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_id",
                                                                    "repair_element_type",
                                                                    "repair_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "microloop-repair" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-id"):
                                                        self.repair_element_id = value
                                                        self.repair_element_id.value_namespace = name_space
                                                        self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.microloop_repair_list_size.is_set or
                                                    self.microloop_strict_spf.is_set or
                                                    self.microloop_tunnel_interface_name.is_set)

                                            def has_operation(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                    self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                    self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                                if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                                if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "microloop-repair"):
                                                    for c in self.microloop_repair:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.microloop_repair.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "microloop-repair-list-size"):
                                                    self.microloop_repair_list_size = value
                                                    self.microloop_repair_list_size.value_namespace = name_space
                                                    self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-strict-spf"):
                                                    self.microloop_strict_spf = value
                                                    self.microloop_strict_spf.value_namespace = name_space
                                                    self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-tunnel-interface-name"):
                                                    self.microloop_tunnel_interface_name = value
                                                    self.microloop_tunnel_interface_name.value_namespace = name_space
                                                    self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.area_format.is_set or
                                                self.area_id.is_set or
                                                self.lsa_type.is_set or
                                                self.route_interface_name.is_set or
                                                self.route_lsaid.is_set or
                                                self.route_metric.is_set or
                                                self.route_next_hop_address.is_set or
                                                self.route_path_is_mcast_intact.is_set or
                                                self.route_path_is_ucmp_path.is_set or
                                                self.route_source.is_set or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.area_format.yfilter != YFilter.not_set or
                                                self.area_id.yfilter != YFilter.not_set or
                                                self.lsa_type.yfilter != YFilter.not_set or
                                                self.route_interface_name.yfilter != YFilter.not_set or
                                                self.route_lsaid.yfilter != YFilter.not_set or
                                                self.route_metric.yfilter != YFilter.not_set or
                                                self.route_next_hop_address.yfilter != YFilter.not_set or
                                                self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                                self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_format.get_name_leafdata())
                                            if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_id.get_name_leafdata())
                                            if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                            if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                            if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                            if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_metric.get_name_leafdata())
                                            if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                            if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                            if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "sr-microloop-avoidance-path"):
                                                if (self.sr_microloop_avoidance_path is None):
                                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                    self.sr_microloop_avoidance_path.parent = self
                                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                return self.sr_microloop_avoidance_path

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "area-format"):
                                                self.area_format = value
                                                self.area_format.value_namespace = name_space
                                                self.area_format.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-id"):
                                                self.area_id = value
                                                self.area_id.value_namespace = name_space
                                                self.area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-type"):
                                                self.lsa_type = value
                                                self.lsa_type.value_namespace = name_space
                                                self.lsa_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-interface-name"):
                                                self.route_interface_name = value
                                                self.route_interface_name.value_namespace = name_space
                                                self.route_interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-lsaid"):
                                                self.route_lsaid = value
                                                self.route_lsaid.value_namespace = name_space
                                                self.route_lsaid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-metric"):
                                                self.route_metric = value
                                                self.route_metric.value_namespace = name_space
                                                self.route_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-next-hop-address"):
                                                self.route_next_hop_address = value
                                                self.route_next_hop_address.value_namespace = name_space
                                                self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-mcast-intact"):
                                                self.route_path_is_mcast_intact = value
                                                self.route_path_is_mcast_intact.value_namespace = name_space
                                                self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-ucmp-path"):
                                                self.route_path_is_ucmp_path = value
                                                self.route_path_is_ucmp_path.value_namespace = name_space
                                                self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.route_path:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            self.route_connected.is_set or
                                            self.route_metric.is_set or
                                            self.route_prefix.is_set or
                                            self.route_prefix_length.is_set or
                                            self.route_type.is_set or
                                            (self.route_info is not None and self.route_info.has_data()))

                                    def has_operation(self):
                                        for c in self.route_path:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            self.route_connected.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_prefix.yfilter != YFilter.not_set or
                                            self.route_prefix_length.yfilter != YFilter.not_set or
                                            self.route_type.yfilter != YFilter.not_set or
                                            (self.route_info is not None and self.route_info.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "connected-route-area" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                        if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_connected.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                        if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                        if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-info"):
                                            if (self.route_info is None):
                                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo()
                                                self.route_info.parent = self
                                                self._children_name_map["route_info"] = "route-info"
                                            return self.route_info

                                        if (child_yang_name == "route-path"):
                                            for c in self.route_path:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.route_path.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-connected"):
                                            self.route_connected = value
                                            self.route_connected.value_namespace = name_space
                                            self.route_connected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix"):
                                            self.route_prefix = value
                                            self.route_prefix.value_namespace = name_space
                                            self.route_prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix-length"):
                                            self.route_prefix_length = value
                                            self.route_prefix_length.value_namespace = name_space
                                            self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-type"):
                                            self.route_type = value
                                            self.route_type.value_namespace = name_space
                                            self.route_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.connected_route_area:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.connected_route_area:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "connected-route-areas" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "connected-route-area"):
                                        for c in self.connected_route_area:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.connected_route_area.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "connected-route-area"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class BackupRouteAreas(Entity):
                                """
                                OSPF Route Table Including Backup Paths in an
                                area
                                
                                .. attribute:: backup_route_area
                                
                                	OSPF route including backup paths
                                	**type**\: list of    :py:class:`BackupRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas, self).__init__()

                                    self.yang_name = "backup-route-areas"
                                    self.yang_parent_name = "route-area"

                                    self.backup_route_area = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas, self).__setattr__(name, value)


                                class BackupRouteArea(Entity):
                                    """
                                    OSPF route including backup paths
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..32
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea, self).__init__()

                                        self.yang_name = "backup-route-area"
                                        self.yang_parent_name = "backup-route-areas"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length",
                                                        "route_connected",
                                                        "route_metric",
                                                        "route_prefix",
                                                        "route_prefix_length",
                                                        "route_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea, self).__setattr__(name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "backup-route-area"

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("route_area_id",
                                                            "route_auto_excluded",
                                                            "route_forward_distance",
                                                            "route_rib_version",
                                                            "route_source",
                                                            "route_spf_priority",
                                                            "route_spf_version",
                                                            "route_srte_nbr_registered",
                                                            "route_srte_prefix_registered",
                                                            "route_te_metric") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo, self).__setattr__(name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-update-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-fail-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.route_area_id.is_set or
                                                self.route_auto_excluded.is_set or
                                                self.route_forward_distance.is_set or
                                                self.route_rib_version.is_set or
                                                self.route_source.is_set or
                                                self.route_spf_priority.is_set or
                                                self.route_spf_version.is_set or
                                                self.route_srte_nbr_registered.is_set or
                                                self.route_srte_prefix_registered.is_set or
                                                self.route_te_metric.is_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                                (self.route_update_time is not None and self.route_update_time.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.route_area_id.yfilter != YFilter.not_set or
                                                self.route_auto_excluded.yfilter != YFilter.not_set or
                                                self.route_forward_distance.yfilter != YFilter.not_set or
                                                self.route_rib_version.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                self.route_spf_priority.yfilter != YFilter.not_set or
                                                self.route_spf_version.yfilter != YFilter.not_set or
                                                self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                                self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                                self.route_te_metric.yfilter != YFilter.not_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                                (self.route_update_time is not None and self.route_update_time.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-info" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                            if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                            if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                            if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())
                                            if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                            if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                            if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                            if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                            if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-fail-time"):
                                                if (self.route_fail_time is None):
                                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime()
                                                    self.route_fail_time.parent = self
                                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                                return self.route_fail_time

                                            if (child_yang_name == "route-update-time"):
                                                if (self.route_update_time is None):
                                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime()
                                                    self.route_update_time.parent = self
                                                    self._children_name_map["route_update_time"] = "route-update-time"
                                                return self.route_update_time

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "route-area-id"):
                                                self.route_area_id = value
                                                self.route_area_id.value_namespace = name_space
                                                self.route_area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-auto-excluded"):
                                                self.route_auto_excluded = value
                                                self.route_auto_excluded.value_namespace = name_space
                                                self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-forward-distance"):
                                                self.route_forward_distance = value
                                                self.route_forward_distance.value_namespace = name_space
                                                self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-rib-version"):
                                                self.route_rib_version = value
                                                self.route_rib_version.value_namespace = name_space
                                                self.route_rib_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-priority"):
                                                self.route_spf_priority = value
                                                self.route_spf_priority.value_namespace = name_space
                                                self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-version"):
                                                self.route_spf_version = value
                                                self.route_spf_version.value_namespace = name_space
                                                self.route_spf_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-nbr-registered"):
                                                self.route_srte_nbr_registered = value
                                                self.route_srte_nbr_registered.value_namespace = name_space
                                                self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-prefix-registered"):
                                                self.route_srte_prefix_registered = value
                                                self.route_srte_prefix_registered.value_namespace = name_space
                                                self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-te-metric"):
                                                self.route_te_metric = value
                                                self.route_te_metric.value_namespace = name_space
                                                self.route_te_metric.value_namespace_prefix = name_space_prefix


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_backup_path
                                        
                                        	Backup Path Info
                                        	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath>`
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_id
                                        
                                        	Path ID of path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "backup-route-area"

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.route_backup_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath()
                                            self.route_backup_path.parent = self
                                            self._children_name_map["route_backup_path"] = "route-backup-path"
                                            self._children_yang_names.add("route-backup-path")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lsa_type",
                                                            "route_interface_name",
                                                            "route_lsaid",
                                                            "route_metric",
                                                            "route_next_hop_address",
                                                            "route_path_id",
                                                            "route_path_is_mcast_intact",
                                                            "route_path_is_ucmp_path",
                                                            "route_source") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath, self).__setattr__(name, value)


                                        class RouteBackupPath(Entity):
                                            """
                                            Backup Path Info
                                            
                                            .. attribute:: backup_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: backup_remote_lfa
                                            
                                            	IP address of remote LFA
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_repair
                                            
                                            	Backup Repair List
                                            	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair>`
                                            
                                            .. attribute:: backup_repair_list_size
                                            
                                            	Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: backup_route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: backup_route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_tunnel_interface_name
                                            
                                            	Backup Tunnel Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: downstream
                                            
                                            	Downstream
                                            	**type**\:  bool
                                            
                                            .. attribute:: line_card_disjoint
                                            
                                            	Line Card Disjoint
                                            	**type**\:  bool
                                            
                                            .. attribute:: node_protect
                                            
                                            	Node Protect
                                            	**type**\:  bool
                                            
                                            .. attribute:: primary_path
                                            
                                            	Primary Path
                                            	**type**\:  bool
                                            
                                            .. attribute:: srlg_disjoint
                                            
                                            	SRLG Disjoint
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath, self).__init__()

                                                self.yang_name = "route-backup-path"
                                                self.yang_parent_name = "route-path"

                                                self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                                self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                                self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                                self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                                self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                                self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                                self.downstream = YLeaf(YType.boolean, "downstream")

                                                self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                                self.node_protect = YLeaf(YType.boolean, "node-protect")

                                                self.primary_path = YLeaf(YType.boolean, "primary-path")

                                                self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                                self.backup_repair = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("backup_metric",
                                                                "backup_remote_lfa",
                                                                "backup_repair_list_size",
                                                                "backup_route_interface_name",
                                                                "backup_route_next_hop_address",
                                                                "backup_route_source",
                                                                "backup_tunnel_interface_name",
                                                                "downstream",
                                                                "line_card_disjoint",
                                                                "node_protect",
                                                                "primary_path",
                                                                "srlg_disjoint") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath, self).__setattr__(name, value)


                                            class BackupRepair(Entity):
                                                """
                                                Backup Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                                    self.yang_name = "backup-repair"
                                                    self.yang_parent_name = "route-backup-path"

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_id",
                                                                    "repair_element_type",
                                                                    "repair_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "backup-repair" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-id"):
                                                        self.repair_element_id = value
                                                        self.repair_element_id.value_namespace = name_space
                                                        self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.backup_repair:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.backup_metric.is_set or
                                                    self.backup_remote_lfa.is_set or
                                                    self.backup_repair_list_size.is_set or
                                                    self.backup_route_interface_name.is_set or
                                                    self.backup_route_next_hop_address.is_set or
                                                    self.backup_route_source.is_set or
                                                    self.backup_tunnel_interface_name.is_set or
                                                    self.downstream.is_set or
                                                    self.line_card_disjoint.is_set or
                                                    self.node_protect.is_set or
                                                    self.primary_path.is_set or
                                                    self.srlg_disjoint.is_set)

                                            def has_operation(self):
                                                for c in self.backup_repair:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.backup_metric.yfilter != YFilter.not_set or
                                                    self.backup_remote_lfa.yfilter != YFilter.not_set or
                                                    self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                    self.backup_route_interface_name.yfilter != YFilter.not_set or
                                                    self.backup_route_next_hop_address.yfilter != YFilter.not_set or
                                                    self.backup_route_source.yfilter != YFilter.not_set or
                                                    self.backup_tunnel_interface_name.yfilter != YFilter.not_set or
                                                    self.downstream.yfilter != YFilter.not_set or
                                                    self.line_card_disjoint.yfilter != YFilter.not_set or
                                                    self.node_protect.yfilter != YFilter.not_set or
                                                    self.primary_path.yfilter != YFilter.not_set or
                                                    self.srlg_disjoint.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-backup-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.backup_metric.is_set or self.backup_metric.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_metric.get_name_leafdata())
                                                if (self.backup_remote_lfa.is_set or self.backup_remote_lfa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_remote_lfa.get_name_leafdata())
                                                if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                if (self.backup_route_interface_name.is_set or self.backup_route_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_route_interface_name.get_name_leafdata())
                                                if (self.backup_route_next_hop_address.is_set or self.backup_route_next_hop_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_route_next_hop_address.get_name_leafdata())
                                                if (self.backup_route_source.is_set or self.backup_route_source.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_route_source.get_name_leafdata())
                                                if (self.backup_tunnel_interface_name.is_set or self.backup_tunnel_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_tunnel_interface_name.get_name_leafdata())
                                                if (self.downstream.is_set or self.downstream.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.downstream.get_name_leafdata())
                                                if (self.line_card_disjoint.is_set or self.line_card_disjoint.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.line_card_disjoint.get_name_leafdata())
                                                if (self.node_protect.is_set or self.node_protect.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.node_protect.get_name_leafdata())
                                                if (self.primary_path.is_set or self.primary_path.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.primary_path.get_name_leafdata())
                                                if (self.srlg_disjoint.is_set or self.srlg_disjoint.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.srlg_disjoint.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "backup-repair"):
                                                    for c in self.backup_repair:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.backup_repair.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "backup-repair" or name == "backup-metric" or name == "backup-remote-lfa" or name == "backup-repair-list-size" or name == "backup-route-interface-name" or name == "backup-route-next-hop-address" or name == "backup-route-source" or name == "backup-tunnel-interface-name" or name == "downstream" or name == "line-card-disjoint" or name == "node-protect" or name == "primary-path" or name == "srlg-disjoint"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "backup-metric"):
                                                    self.backup_metric = value
                                                    self.backup_metric.value_namespace = name_space
                                                    self.backup_metric.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-remote-lfa"):
                                                    self.backup_remote_lfa = value
                                                    self.backup_remote_lfa.value_namespace = name_space
                                                    self.backup_remote_lfa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-repair-list-size"):
                                                    self.backup_repair_list_size = value
                                                    self.backup_repair_list_size.value_namespace = name_space
                                                    self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-route-interface-name"):
                                                    self.backup_route_interface_name = value
                                                    self.backup_route_interface_name.value_namespace = name_space
                                                    self.backup_route_interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-route-next-hop-address"):
                                                    self.backup_route_next_hop_address = value
                                                    self.backup_route_next_hop_address.value_namespace = name_space
                                                    self.backup_route_next_hop_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-route-source"):
                                                    self.backup_route_source = value
                                                    self.backup_route_source.value_namespace = name_space
                                                    self.backup_route_source.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-tunnel-interface-name"):
                                                    self.backup_tunnel_interface_name = value
                                                    self.backup_tunnel_interface_name.value_namespace = name_space
                                                    self.backup_tunnel_interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "downstream"):
                                                    self.downstream = value
                                                    self.downstream.value_namespace = name_space
                                                    self.downstream.value_namespace_prefix = name_space_prefix
                                                if(value_path == "line-card-disjoint"):
                                                    self.line_card_disjoint = value
                                                    self.line_card_disjoint.value_namespace = name_space
                                                    self.line_card_disjoint.value_namespace_prefix = name_space_prefix
                                                if(value_path == "node-protect"):
                                                    self.node_protect = value
                                                    self.node_protect.value_namespace = name_space
                                                    self.node_protect.value_namespace_prefix = name_space_prefix
                                                if(value_path == "primary-path"):
                                                    self.primary_path = value
                                                    self.primary_path.value_namespace = name_space
                                                    self.primary_path.value_namespace_prefix = name_space_prefix
                                                if(value_path == "srlg-disjoint"):
                                                    self.srlg_disjoint = value
                                                    self.srlg_disjoint.value_namespace = name_space
                                                    self.srlg_disjoint.value_namespace_prefix = name_space_prefix


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("microloop_repair_list_size",
                                                                "microloop_strict_spf",
                                                                "microloop_tunnel_interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_id",
                                                                    "repair_element_type",
                                                                    "repair_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "microloop-repair" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-id"):
                                                        self.repair_element_id = value
                                                        self.repair_element_id.value_namespace = name_space
                                                        self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.microloop_repair_list_size.is_set or
                                                    self.microloop_strict_spf.is_set or
                                                    self.microloop_tunnel_interface_name.is_set)

                                            def has_operation(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                    self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                    self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                                if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                                if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "microloop-repair"):
                                                    for c in self.microloop_repair:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.microloop_repair.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "microloop-repair-list-size"):
                                                    self.microloop_repair_list_size = value
                                                    self.microloop_repair_list_size.value_namespace = name_space
                                                    self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-strict-spf"):
                                                    self.microloop_strict_spf = value
                                                    self.microloop_strict_spf.value_namespace = name_space
                                                    self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-tunnel-interface-name"):
                                                    self.microloop_tunnel_interface_name = value
                                                    self.microloop_tunnel_interface_name.value_namespace = name_space
                                                    self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.lsa_type.is_set or
                                                self.route_interface_name.is_set or
                                                self.route_lsaid.is_set or
                                                self.route_metric.is_set or
                                                self.route_next_hop_address.is_set or
                                                self.route_path_id.is_set or
                                                self.route_path_is_mcast_intact.is_set or
                                                self.route_path_is_ucmp_path.is_set or
                                                self.route_source.is_set or
                                                (self.route_backup_path is not None and self.route_backup_path.has_data()) or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lsa_type.yfilter != YFilter.not_set or
                                                self.route_interface_name.yfilter != YFilter.not_set or
                                                self.route_lsaid.yfilter != YFilter.not_set or
                                                self.route_metric.yfilter != YFilter.not_set or
                                                self.route_next_hop_address.yfilter != YFilter.not_set or
                                                self.route_path_id.yfilter != YFilter.not_set or
                                                self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                                self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                (self.route_backup_path is not None and self.route_backup_path.has_operation()) or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                            if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                            if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                            if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_metric.get_name_leafdata())
                                            if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                            if (self.route_path_id.is_set or self.route_path_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_id.get_name_leafdata())
                                            if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                            if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-backup-path"):
                                                if (self.route_backup_path is None):
                                                    self.route_backup_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath()
                                                    self.route_backup_path.parent = self
                                                    self._children_name_map["route_backup_path"] = "route-backup-path"
                                                return self.route_backup_path

                                            if (child_yang_name == "sr-microloop-avoidance-path"):
                                                if (self.sr_microloop_avoidance_path is None):
                                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                    self.sr_microloop_avoidance_path.parent = self
                                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                return self.sr_microloop_avoidance_path

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-backup-path" or name == "sr-microloop-avoidance-path" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-id" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lsa-type"):
                                                self.lsa_type = value
                                                self.lsa_type.value_namespace = name_space
                                                self.lsa_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-interface-name"):
                                                self.route_interface_name = value
                                                self.route_interface_name.value_namespace = name_space
                                                self.route_interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-lsaid"):
                                                self.route_lsaid = value
                                                self.route_lsaid.value_namespace = name_space
                                                self.route_lsaid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-metric"):
                                                self.route_metric = value
                                                self.route_metric.value_namespace = name_space
                                                self.route_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-next-hop-address"):
                                                self.route_next_hop_address = value
                                                self.route_next_hop_address.value_namespace = name_space
                                                self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-id"):
                                                self.route_path_id = value
                                                self.route_path_id.value_namespace = name_space
                                                self.route_path_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-mcast-intact"):
                                                self.route_path_is_mcast_intact = value
                                                self.route_path_is_mcast_intact.value_namespace = name_space
                                                self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-ucmp-path"):
                                                self.route_path_is_ucmp_path = value
                                                self.route_path_is_ucmp_path.value_namespace = name_space
                                                self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.route_path:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            self.route_connected.is_set or
                                            self.route_metric.is_set or
                                            self.route_prefix.is_set or
                                            self.route_prefix_length.is_set or
                                            self.route_type.is_set or
                                            (self.route_info is not None and self.route_info.has_data()))

                                    def has_operation(self):
                                        for c in self.route_path:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            self.route_connected.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_prefix.yfilter != YFilter.not_set or
                                            self.route_prefix_length.yfilter != YFilter.not_set or
                                            self.route_type.yfilter != YFilter.not_set or
                                            (self.route_info is not None and self.route_info.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "backup-route-area" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                        if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_connected.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                        if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                        if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-info"):
                                            if (self.route_info is None):
                                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo()
                                                self.route_info.parent = self
                                                self._children_name_map["route_info"] = "route-info"
                                            return self.route_info

                                        if (child_yang_name == "route-path"):
                                            for c in self.route_path:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.route_path.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-connected"):
                                            self.route_connected = value
                                            self.route_connected.value_namespace = name_space
                                            self.route_connected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix"):
                                            self.route_prefix = value
                                            self.route_prefix.value_namespace = name_space
                                            self.route_prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix-length"):
                                            self.route_prefix_length = value
                                            self.route_prefix_length.value_namespace = name_space
                                            self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-type"):
                                            self.route_type = value
                                            self.route_type.value_namespace = name_space
                                            self.route_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.backup_route_area:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.backup_route_area:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "backup-route-areas" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "backup-route-area"):
                                        for c in self.backup_route_area:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.backup_route_area.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "backup-route-area"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class RouteAreaInformations(Entity):
                                """
                                OSPF Area Route Entry
                                
                                .. attribute:: route_area_information
                                
                                	An OSPF route
                                	**type**\: list of    :py:class:`RouteAreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations, self).__init__()

                                    self.yang_name = "route-area-informations"
                                    self.yang_parent_name = "route-area"

                                    self.route_area_information = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations, self).__setattr__(name, value)


                                class RouteAreaInformation(Entity):
                                    """
                                    An OSPF route
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..32
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation, self).__init__()

                                        self.yang_name = "route-area-information"
                                        self.yang_parent_name = "route-area-informations"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length",
                                                        "route_connected",
                                                        "route_metric",
                                                        "route_prefix",
                                                        "route_prefix_length",
                                                        "route_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation, self).__setattr__(name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "route-area-information"

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("route_area_id",
                                                            "route_auto_excluded",
                                                            "route_forward_distance",
                                                            "route_rib_version",
                                                            "route_source",
                                                            "route_spf_priority",
                                                            "route_spf_version",
                                                            "route_srte_nbr_registered",
                                                            "route_srte_prefix_registered",
                                                            "route_te_metric") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo, self).__setattr__(name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-update-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-fail-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.route_area_id.is_set or
                                                self.route_auto_excluded.is_set or
                                                self.route_forward_distance.is_set or
                                                self.route_rib_version.is_set or
                                                self.route_source.is_set or
                                                self.route_spf_priority.is_set or
                                                self.route_spf_version.is_set or
                                                self.route_srte_nbr_registered.is_set or
                                                self.route_srte_prefix_registered.is_set or
                                                self.route_te_metric.is_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                                (self.route_update_time is not None and self.route_update_time.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.route_area_id.yfilter != YFilter.not_set or
                                                self.route_auto_excluded.yfilter != YFilter.not_set or
                                                self.route_forward_distance.yfilter != YFilter.not_set or
                                                self.route_rib_version.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                self.route_spf_priority.yfilter != YFilter.not_set or
                                                self.route_spf_version.yfilter != YFilter.not_set or
                                                self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                                self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                                self.route_te_metric.yfilter != YFilter.not_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                                (self.route_update_time is not None and self.route_update_time.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-info" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                            if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                            if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                            if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())
                                            if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                            if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                            if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                            if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                            if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-fail-time"):
                                                if (self.route_fail_time is None):
                                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime()
                                                    self.route_fail_time.parent = self
                                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                                return self.route_fail_time

                                            if (child_yang_name == "route-update-time"):
                                                if (self.route_update_time is None):
                                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime()
                                                    self.route_update_time.parent = self
                                                    self._children_name_map["route_update_time"] = "route-update-time"
                                                return self.route_update_time

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "route-area-id"):
                                                self.route_area_id = value
                                                self.route_area_id.value_namespace = name_space
                                                self.route_area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-auto-excluded"):
                                                self.route_auto_excluded = value
                                                self.route_auto_excluded.value_namespace = name_space
                                                self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-forward-distance"):
                                                self.route_forward_distance = value
                                                self.route_forward_distance.value_namespace = name_space
                                                self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-rib-version"):
                                                self.route_rib_version = value
                                                self.route_rib_version.value_namespace = name_space
                                                self.route_rib_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-priority"):
                                                self.route_spf_priority = value
                                                self.route_spf_priority.value_namespace = name_space
                                                self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-version"):
                                                self.route_spf_version = value
                                                self.route_spf_version.value_namespace = name_space
                                                self.route_spf_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-nbr-registered"):
                                                self.route_srte_nbr_registered = value
                                                self.route_srte_nbr_registered.value_namespace = name_space
                                                self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-prefix-registered"):
                                                self.route_srte_prefix_registered = value
                                                self.route_srte_prefix_registered.value_namespace = name_space
                                                self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-te-metric"):
                                                self.route_te_metric = value
                                                self.route_te_metric.value_namespace = name_space
                                                self.route_te_metric.value_namespace_prefix = name_space_prefix


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: area_format
                                        
                                        	Area format IP or uint32
                                        	**type**\:  bool
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "route-area-information"

                                            self.area_format = YLeaf(YType.boolean, "area-format")

                                            self.area_id = YLeaf(YType.uint32, "area-id")

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("area_format",
                                                            "area_id",
                                                            "lsa_type",
                                                            "route_interface_name",
                                                            "route_lsaid",
                                                            "route_metric",
                                                            "route_next_hop_address",
                                                            "route_path_is_mcast_intact",
                                                            "route_path_is_ucmp_path",
                                                            "route_source") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath, self).__setattr__(name, value)


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("microloop_repair_list_size",
                                                                "microloop_strict_spf",
                                                                "microloop_tunnel_interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_id",
                                                                    "repair_element_type",
                                                                    "repair_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "microloop-repair" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-id"):
                                                        self.repair_element_id = value
                                                        self.repair_element_id.value_namespace = name_space
                                                        self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.microloop_repair_list_size.is_set or
                                                    self.microloop_strict_spf.is_set or
                                                    self.microloop_tunnel_interface_name.is_set)

                                            def has_operation(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                    self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                    self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                                if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                                if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "microloop-repair"):
                                                    for c in self.microloop_repair:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.microloop_repair.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "microloop-repair-list-size"):
                                                    self.microloop_repair_list_size = value
                                                    self.microloop_repair_list_size.value_namespace = name_space
                                                    self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-strict-spf"):
                                                    self.microloop_strict_spf = value
                                                    self.microloop_strict_spf.value_namespace = name_space
                                                    self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-tunnel-interface-name"):
                                                    self.microloop_tunnel_interface_name = value
                                                    self.microloop_tunnel_interface_name.value_namespace = name_space
                                                    self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.area_format.is_set or
                                                self.area_id.is_set or
                                                self.lsa_type.is_set or
                                                self.route_interface_name.is_set or
                                                self.route_lsaid.is_set or
                                                self.route_metric.is_set or
                                                self.route_next_hop_address.is_set or
                                                self.route_path_is_mcast_intact.is_set or
                                                self.route_path_is_ucmp_path.is_set or
                                                self.route_source.is_set or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.area_format.yfilter != YFilter.not_set or
                                                self.area_id.yfilter != YFilter.not_set or
                                                self.lsa_type.yfilter != YFilter.not_set or
                                                self.route_interface_name.yfilter != YFilter.not_set or
                                                self.route_lsaid.yfilter != YFilter.not_set or
                                                self.route_metric.yfilter != YFilter.not_set or
                                                self.route_next_hop_address.yfilter != YFilter.not_set or
                                                self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                                self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_format.get_name_leafdata())
                                            if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_id.get_name_leafdata())
                                            if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                            if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                            if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                            if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_metric.get_name_leafdata())
                                            if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                            if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                            if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "sr-microloop-avoidance-path"):
                                                if (self.sr_microloop_avoidance_path is None):
                                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath()
                                                    self.sr_microloop_avoidance_path.parent = self
                                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                return self.sr_microloop_avoidance_path

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "area-format"):
                                                self.area_format = value
                                                self.area_format.value_namespace = name_space
                                                self.area_format.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-id"):
                                                self.area_id = value
                                                self.area_id.value_namespace = name_space
                                                self.area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-type"):
                                                self.lsa_type = value
                                                self.lsa_type.value_namespace = name_space
                                                self.lsa_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-interface-name"):
                                                self.route_interface_name = value
                                                self.route_interface_name.value_namespace = name_space
                                                self.route_interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-lsaid"):
                                                self.route_lsaid = value
                                                self.route_lsaid.value_namespace = name_space
                                                self.route_lsaid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-metric"):
                                                self.route_metric = value
                                                self.route_metric.value_namespace = name_space
                                                self.route_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-next-hop-address"):
                                                self.route_next_hop_address = value
                                                self.route_next_hop_address.value_namespace = name_space
                                                self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-mcast-intact"):
                                                self.route_path_is_mcast_intact = value
                                                self.route_path_is_mcast_intact.value_namespace = name_space
                                                self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-ucmp-path"):
                                                self.route_path_is_ucmp_path = value
                                                self.route_path_is_ucmp_path.value_namespace = name_space
                                                self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.route_path:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            self.route_connected.is_set or
                                            self.route_metric.is_set or
                                            self.route_prefix.is_set or
                                            self.route_prefix_length.is_set or
                                            self.route_type.is_set or
                                            (self.route_info is not None and self.route_info.has_data()))

                                    def has_operation(self):
                                        for c in self.route_path:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            self.route_connected.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_prefix.yfilter != YFilter.not_set or
                                            self.route_prefix_length.yfilter != YFilter.not_set or
                                            self.route_type.yfilter != YFilter.not_set or
                                            (self.route_info is not None and self.route_info.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-area-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                        if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_connected.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                        if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                        if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-info"):
                                            if (self.route_info is None):
                                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo()
                                                self.route_info.parent = self
                                                self._children_name_map["route_info"] = "route-info"
                                            return self.route_info

                                        if (child_yang_name == "route-path"):
                                            for c in self.route_path:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.route_path.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-connected"):
                                            self.route_connected = value
                                            self.route_connected.value_namespace = name_space
                                            self.route_connected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix"):
                                            self.route_prefix = value
                                            self.route_prefix.value_namespace = name_space
                                            self.route_prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix-length"):
                                            self.route_prefix_length = value
                                            self.route_prefix_length.value_namespace = name_space
                                            self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-type"):
                                            self.route_type = value
                                            self.route_type.value_namespace = name_space
                                            self.route_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.route_area_information:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.route_area_information:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-area-informations" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-area-information"):
                                        for c in self.route_area_information:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.route_area_information.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-area-information"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class MulticastIntactRouteAreas(Entity):
                                """
                                OSPF Area multicast\-intact included route
                                entry
                                
                                .. attribute:: multicast_intact_route_area
                                
                                	A Muliticast OSPF route in an area
                                	**type**\: list of    :py:class:`MulticastIntactRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas, self).__init__()

                                    self.yang_name = "multicast-intact-route-areas"
                                    self.yang_parent_name = "route-area"

                                    self.multicast_intact_route_area = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas, self).__setattr__(name, value)


                                class MulticastIntactRouteArea(Entity):
                                    """
                                    A Muliticast OSPF route in an area
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..32
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea, self).__init__()

                                        self.yang_name = "multicast-intact-route-area"
                                        self.yang_parent_name = "multicast-intact-route-areas"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length",
                                                        "route_connected",
                                                        "route_metric",
                                                        "route_prefix",
                                                        "route_prefix_length",
                                                        "route_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea, self).__setattr__(name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "multicast-intact-route-area"

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("route_area_id",
                                                            "route_auto_excluded",
                                                            "route_forward_distance",
                                                            "route_rib_version",
                                                            "route_source",
                                                            "route_spf_priority",
                                                            "route_spf_version",
                                                            "route_srte_nbr_registered",
                                                            "route_srte_prefix_registered",
                                                            "route_te_metric") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo, self).__setattr__(name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-update-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-fail-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.route_area_id.is_set or
                                                self.route_auto_excluded.is_set or
                                                self.route_forward_distance.is_set or
                                                self.route_rib_version.is_set or
                                                self.route_source.is_set or
                                                self.route_spf_priority.is_set or
                                                self.route_spf_version.is_set or
                                                self.route_srte_nbr_registered.is_set or
                                                self.route_srte_prefix_registered.is_set or
                                                self.route_te_metric.is_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                                (self.route_update_time is not None and self.route_update_time.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.route_area_id.yfilter != YFilter.not_set or
                                                self.route_auto_excluded.yfilter != YFilter.not_set or
                                                self.route_forward_distance.yfilter != YFilter.not_set or
                                                self.route_rib_version.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                self.route_spf_priority.yfilter != YFilter.not_set or
                                                self.route_spf_version.yfilter != YFilter.not_set or
                                                self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                                self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                                self.route_te_metric.yfilter != YFilter.not_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                                (self.route_update_time is not None and self.route_update_time.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-info" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                            if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                            if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                            if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())
                                            if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                            if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                            if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                            if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                            if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-fail-time"):
                                                if (self.route_fail_time is None):
                                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime()
                                                    self.route_fail_time.parent = self
                                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                                return self.route_fail_time

                                            if (child_yang_name == "route-update-time"):
                                                if (self.route_update_time is None):
                                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime()
                                                    self.route_update_time.parent = self
                                                    self._children_name_map["route_update_time"] = "route-update-time"
                                                return self.route_update_time

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "route-area-id"):
                                                self.route_area_id = value
                                                self.route_area_id.value_namespace = name_space
                                                self.route_area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-auto-excluded"):
                                                self.route_auto_excluded = value
                                                self.route_auto_excluded.value_namespace = name_space
                                                self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-forward-distance"):
                                                self.route_forward_distance = value
                                                self.route_forward_distance.value_namespace = name_space
                                                self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-rib-version"):
                                                self.route_rib_version = value
                                                self.route_rib_version.value_namespace = name_space
                                                self.route_rib_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-priority"):
                                                self.route_spf_priority = value
                                                self.route_spf_priority.value_namespace = name_space
                                                self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-version"):
                                                self.route_spf_version = value
                                                self.route_spf_version.value_namespace = name_space
                                                self.route_spf_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-nbr-registered"):
                                                self.route_srte_nbr_registered = value
                                                self.route_srte_nbr_registered.value_namespace = name_space
                                                self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-prefix-registered"):
                                                self.route_srte_prefix_registered = value
                                                self.route_srte_prefix_registered.value_namespace = name_space
                                                self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-te-metric"):
                                                self.route_te_metric = value
                                                self.route_te_metric.value_namespace = name_space
                                                self.route_te_metric.value_namespace_prefix = name_space_prefix


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: area_format
                                        
                                        	Area format IP or uint32
                                        	**type**\:  bool
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "multicast-intact-route-area"

                                            self.area_format = YLeaf(YType.boolean, "area-format")

                                            self.area_id = YLeaf(YType.uint32, "area-id")

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("area_format",
                                                            "area_id",
                                                            "lsa_type",
                                                            "route_interface_name",
                                                            "route_lsaid",
                                                            "route_metric",
                                                            "route_next_hop_address",
                                                            "route_path_is_mcast_intact",
                                                            "route_path_is_ucmp_path",
                                                            "route_source") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath, self).__setattr__(name, value)


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("microloop_repair_list_size",
                                                                "microloop_strict_spf",
                                                                "microloop_tunnel_interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_id",
                                                                    "repair_element_type",
                                                                    "repair_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "microloop-repair" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-id"):
                                                        self.repair_element_id = value
                                                        self.repair_element_id.value_namespace = name_space
                                                        self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.microloop_repair_list_size.is_set or
                                                    self.microloop_strict_spf.is_set or
                                                    self.microloop_tunnel_interface_name.is_set)

                                            def has_operation(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                    self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                    self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                                if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                                if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "microloop-repair"):
                                                    for c in self.microloop_repair:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.microloop_repair.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "microloop-repair-list-size"):
                                                    self.microloop_repair_list_size = value
                                                    self.microloop_repair_list_size.value_namespace = name_space
                                                    self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-strict-spf"):
                                                    self.microloop_strict_spf = value
                                                    self.microloop_strict_spf.value_namespace = name_space
                                                    self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-tunnel-interface-name"):
                                                    self.microloop_tunnel_interface_name = value
                                                    self.microloop_tunnel_interface_name.value_namespace = name_space
                                                    self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.area_format.is_set or
                                                self.area_id.is_set or
                                                self.lsa_type.is_set or
                                                self.route_interface_name.is_set or
                                                self.route_lsaid.is_set or
                                                self.route_metric.is_set or
                                                self.route_next_hop_address.is_set or
                                                self.route_path_is_mcast_intact.is_set or
                                                self.route_path_is_ucmp_path.is_set or
                                                self.route_source.is_set or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.area_format.yfilter != YFilter.not_set or
                                                self.area_id.yfilter != YFilter.not_set or
                                                self.lsa_type.yfilter != YFilter.not_set or
                                                self.route_interface_name.yfilter != YFilter.not_set or
                                                self.route_lsaid.yfilter != YFilter.not_set or
                                                self.route_metric.yfilter != YFilter.not_set or
                                                self.route_next_hop_address.yfilter != YFilter.not_set or
                                                self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                                self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_format.get_name_leafdata())
                                            if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_id.get_name_leafdata())
                                            if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                            if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                            if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                            if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_metric.get_name_leafdata())
                                            if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                            if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                            if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "sr-microloop-avoidance-path"):
                                                if (self.sr_microloop_avoidance_path is None):
                                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                    self.sr_microloop_avoidance_path.parent = self
                                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                return self.sr_microloop_avoidance_path

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "area-format"):
                                                self.area_format = value
                                                self.area_format.value_namespace = name_space
                                                self.area_format.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-id"):
                                                self.area_id = value
                                                self.area_id.value_namespace = name_space
                                                self.area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-type"):
                                                self.lsa_type = value
                                                self.lsa_type.value_namespace = name_space
                                                self.lsa_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-interface-name"):
                                                self.route_interface_name = value
                                                self.route_interface_name.value_namespace = name_space
                                                self.route_interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-lsaid"):
                                                self.route_lsaid = value
                                                self.route_lsaid.value_namespace = name_space
                                                self.route_lsaid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-metric"):
                                                self.route_metric = value
                                                self.route_metric.value_namespace = name_space
                                                self.route_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-next-hop-address"):
                                                self.route_next_hop_address = value
                                                self.route_next_hop_address.value_namespace = name_space
                                                self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-mcast-intact"):
                                                self.route_path_is_mcast_intact = value
                                                self.route_path_is_mcast_intact.value_namespace = name_space
                                                self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-ucmp-path"):
                                                self.route_path_is_ucmp_path = value
                                                self.route_path_is_ucmp_path.value_namespace = name_space
                                                self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.route_path:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            self.route_connected.is_set or
                                            self.route_metric.is_set or
                                            self.route_prefix.is_set or
                                            self.route_prefix_length.is_set or
                                            self.route_type.is_set or
                                            (self.route_info is not None and self.route_info.has_data()))

                                    def has_operation(self):
                                        for c in self.route_path:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            self.route_connected.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_prefix.yfilter != YFilter.not_set or
                                            self.route_prefix_length.yfilter != YFilter.not_set or
                                            self.route_type.yfilter != YFilter.not_set or
                                            (self.route_info is not None and self.route_info.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-intact-route-area" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                        if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_connected.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                        if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                        if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-info"):
                                            if (self.route_info is None):
                                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo()
                                                self.route_info.parent = self
                                                self._children_name_map["route_info"] = "route-info"
                                            return self.route_info

                                        if (child_yang_name == "route-path"):
                                            for c in self.route_path:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.route_path.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-connected"):
                                            self.route_connected = value
                                            self.route_connected.value_namespace = name_space
                                            self.route_connected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix"):
                                            self.route_prefix = value
                                            self.route_prefix.value_namespace = name_space
                                            self.route_prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix-length"):
                                            self.route_prefix_length = value
                                            self.route_prefix_length.value_namespace = name_space
                                            self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-type"):
                                            self.route_type = value
                                            self.route_type.value_namespace = name_space
                                            self.route_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.multicast_intact_route_area:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.multicast_intact_route_area:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast-intact-route-areas" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "multicast-intact-route-area"):
                                        for c in self.multicast_intact_route_area:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.multicast_intact_route_area.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "multicast-intact-route-area"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SummaryAreaInformation(Entity):
                                """
                                OSPF route summary statistics
                                
                                .. attribute:: common
                                
                                	OSPF route summary Information
                                	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common>`
                                
                                .. attribute:: failure_address
                                
                                	Last failed address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: failure_time
                                
                                	Last time failed
                                	**type**\:   :py:class:`FailureTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime>`
                                
                                .. attribute:: failures
                                
                                	RIB failure count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation, self).__init__()

                                    self.yang_name = "summary-area-information"
                                    self.yang_parent_name = "route-area"

                                    self.failure_address = YLeaf(YType.str, "failure-address")

                                    self.failures = YLeaf(YType.uint32, "failures")

                                    self.common = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common()
                                    self.common.parent = self
                                    self._children_name_map["common"] = "common"
                                    self._children_yang_names.add("common")

                                    self.failure_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime()
                                    self.failure_time.parent = self
                                    self._children_name_map["failure_time"] = "failure-time"
                                    self._children_yang_names.add("failure-time")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("failure_address",
                                                    "failures") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation, self).__setattr__(name, value)


                                class FailureTime(Entity):
                                    """
                                    Last time failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime, self).__init__()

                                        self.yang_name = "failure-time"
                                        self.yang_parent_name = "summary-area-information"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "failure-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix


                                class Common(Entity):
                                    """
                                    OSPF route summary Information
                                    
                                    .. attribute:: external_nssa_type1s
                                    
                                    	External NSSA type 1 count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_nssa_type2s
                                    
                                    	External NSSA type 2 count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_type1s
                                    
                                    	External type 1 count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_type2s
                                    
                                    	External type 2 count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_areas
                                    
                                    	Inter\-area count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_areas
                                    
                                    	Intra\-area count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total
                                    
                                    	Total count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common, self).__init__()

                                        self.yang_name = "common"
                                        self.yang_parent_name = "summary-area-information"

                                        self.external_nssa_type1s = YLeaf(YType.uint32, "external-nssa-type1s")

                                        self.external_nssa_type2s = YLeaf(YType.uint32, "external-nssa-type2s")

                                        self.external_type1s = YLeaf(YType.uint32, "external-type1s")

                                        self.external_type2s = YLeaf(YType.uint32, "external-type2s")

                                        self.inter_areas = YLeaf(YType.uint32, "inter-areas")

                                        self.intra_areas = YLeaf(YType.uint32, "intra-areas")

                                        self.total = YLeaf(YType.uint32, "total")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("external_nssa_type1s",
                                                        "external_nssa_type2s",
                                                        "external_type1s",
                                                        "external_type2s",
                                                        "inter_areas",
                                                        "intra_areas",
                                                        "total") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.external_nssa_type1s.is_set or
                                            self.external_nssa_type2s.is_set or
                                            self.external_type1s.is_set or
                                            self.external_type2s.is_set or
                                            self.inter_areas.is_set or
                                            self.intra_areas.is_set or
                                            self.total.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.external_nssa_type1s.yfilter != YFilter.not_set or
                                            self.external_nssa_type2s.yfilter != YFilter.not_set or
                                            self.external_type1s.yfilter != YFilter.not_set or
                                            self.external_type2s.yfilter != YFilter.not_set or
                                            self.inter_areas.yfilter != YFilter.not_set or
                                            self.intra_areas.yfilter != YFilter.not_set or
                                            self.total.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "common" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.external_nssa_type1s.is_set or self.external_nssa_type1s.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.external_nssa_type1s.get_name_leafdata())
                                        if (self.external_nssa_type2s.is_set or self.external_nssa_type2s.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.external_nssa_type2s.get_name_leafdata())
                                        if (self.external_type1s.is_set or self.external_type1s.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.external_type1s.get_name_leafdata())
                                        if (self.external_type2s.is_set or self.external_type2s.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.external_type2s.get_name_leafdata())
                                        if (self.inter_areas.is_set or self.inter_areas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.inter_areas.get_name_leafdata())
                                        if (self.intra_areas.is_set or self.intra_areas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.intra_areas.get_name_leafdata())
                                        if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.total.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "external-nssa-type1s" or name == "external-nssa-type2s" or name == "external-type1s" or name == "external-type2s" or name == "inter-areas" or name == "intra-areas" or name == "total"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "external-nssa-type1s"):
                                            self.external_nssa_type1s = value
                                            self.external_nssa_type1s.value_namespace = name_space
                                            self.external_nssa_type1s.value_namespace_prefix = name_space_prefix
                                        if(value_path == "external-nssa-type2s"):
                                            self.external_nssa_type2s = value
                                            self.external_nssa_type2s.value_namespace = name_space
                                            self.external_nssa_type2s.value_namespace_prefix = name_space_prefix
                                        if(value_path == "external-type1s"):
                                            self.external_type1s = value
                                            self.external_type1s.value_namespace = name_space
                                            self.external_type1s.value_namespace_prefix = name_space_prefix
                                        if(value_path == "external-type2s"):
                                            self.external_type2s = value
                                            self.external_type2s.value_namespace = name_space
                                            self.external_type2s.value_namespace_prefix = name_space_prefix
                                        if(value_path == "inter-areas"):
                                            self.inter_areas = value
                                            self.inter_areas.value_namespace = name_space
                                            self.inter_areas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "intra-areas"):
                                            self.intra_areas = value
                                            self.intra_areas.value_namespace = name_space
                                            self.intra_areas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "total"):
                                            self.total = value
                                            self.total.value_namespace = name_space
                                            self.total.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.failure_address.is_set or
                                        self.failures.is_set or
                                        (self.common is not None and self.common.has_data()) or
                                        (self.failure_time is not None and self.failure_time.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.failure_address.yfilter != YFilter.not_set or
                                        self.failures.yfilter != YFilter.not_set or
                                        (self.common is not None and self.common.has_operation()) or
                                        (self.failure_time is not None and self.failure_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "summary-area-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.failure_address.is_set or self.failure_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.failure_address.get_name_leafdata())
                                    if (self.failures.is_set or self.failures.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.failures.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "common"):
                                        if (self.common is None):
                                            self.common = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common()
                                            self.common.parent = self
                                            self._children_name_map["common"] = "common"
                                        return self.common

                                    if (child_yang_name == "failure-time"):
                                        if (self.failure_time is None):
                                            self.failure_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime()
                                            self.failure_time.parent = self
                                            self._children_name_map["failure_time"] = "failure-time"
                                        return self.failure_time

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "common" or name == "failure-time" or name == "failure-address" or name == "failures"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "failure-address"):
                                        self.failure_address = value
                                        self.failure_address.value_namespace = name_space
                                        self.failure_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "failures"):
                                        self.failures = value
                                        self.failures.value_namespace = name_space
                                        self.failures.value_namespace_prefix = name_space_prefix


                            class LocalRouteAreas(Entity):
                                """
                                OSPF Local Route Table
                                
                                .. attribute:: local_route_area
                                
                                	Local route
                                	**type**\: list of    :py:class:`LocalRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas, self).__init__()

                                    self.yang_name = "local-route-areas"
                                    self.yang_parent_name = "route-area"

                                    self.local_route_area = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas, self).__setattr__(name, value)


                                class LocalRouteArea(Entity):
                                    """
                                    Local route
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..32
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea, self).__init__()

                                        self.yang_name = "local-route-area"
                                        self.yang_parent_name = "local-route-areas"

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("prefix",
                                                        "prefix_length",
                                                        "route_connected",
                                                        "route_metric",
                                                        "route_prefix",
                                                        "route_prefix_length",
                                                        "route_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea, self).__setattr__(name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "local-route-area"

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("route_area_id",
                                                            "route_auto_excluded",
                                                            "route_forward_distance",
                                                            "route_rib_version",
                                                            "route_source",
                                                            "route_spf_priority",
                                                            "route_spf_version",
                                                            "route_srte_nbr_registered",
                                                            "route_srte_prefix_registered",
                                                            "route_te_metric") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo, self).__setattr__(name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-update-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-fail-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.route_area_id.is_set or
                                                self.route_auto_excluded.is_set or
                                                self.route_forward_distance.is_set or
                                                self.route_rib_version.is_set or
                                                self.route_source.is_set or
                                                self.route_spf_priority.is_set or
                                                self.route_spf_version.is_set or
                                                self.route_srte_nbr_registered.is_set or
                                                self.route_srte_prefix_registered.is_set or
                                                self.route_te_metric.is_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                                (self.route_update_time is not None and self.route_update_time.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.route_area_id.yfilter != YFilter.not_set or
                                                self.route_auto_excluded.yfilter != YFilter.not_set or
                                                self.route_forward_distance.yfilter != YFilter.not_set or
                                                self.route_rib_version.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                self.route_spf_priority.yfilter != YFilter.not_set or
                                                self.route_spf_version.yfilter != YFilter.not_set or
                                                self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                                self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                                self.route_te_metric.yfilter != YFilter.not_set or
                                                (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                                (self.route_update_time is not None and self.route_update_time.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-info" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                            if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                            if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                            if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())
                                            if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                            if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                            if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                            if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                            if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "route-fail-time"):
                                                if (self.route_fail_time is None):
                                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime()
                                                    self.route_fail_time.parent = self
                                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                                return self.route_fail_time

                                            if (child_yang_name == "route-update-time"):
                                                if (self.route_update_time is None):
                                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime()
                                                    self.route_update_time.parent = self
                                                    self._children_name_map["route_update_time"] = "route-update-time"
                                                return self.route_update_time

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "route-area-id"):
                                                self.route_area_id = value
                                                self.route_area_id.value_namespace = name_space
                                                self.route_area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-auto-excluded"):
                                                self.route_auto_excluded = value
                                                self.route_auto_excluded.value_namespace = name_space
                                                self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-forward-distance"):
                                                self.route_forward_distance = value
                                                self.route_forward_distance.value_namespace = name_space
                                                self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-rib-version"):
                                                self.route_rib_version = value
                                                self.route_rib_version.value_namespace = name_space
                                                self.route_rib_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-priority"):
                                                self.route_spf_priority = value
                                                self.route_spf_priority.value_namespace = name_space
                                                self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-spf-version"):
                                                self.route_spf_version = value
                                                self.route_spf_version.value_namespace = name_space
                                                self.route_spf_version.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-nbr-registered"):
                                                self.route_srte_nbr_registered = value
                                                self.route_srte_nbr_registered.value_namespace = name_space
                                                self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-srte-prefix-registered"):
                                                self.route_srte_prefix_registered = value
                                                self.route_srte_prefix_registered.value_namespace = name_space
                                                self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-te-metric"):
                                                self.route_te_metric = value
                                                self.route_te_metric.value_namespace = name_space
                                                self.route_te_metric.value_namespace_prefix = name_space_prefix


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: area_format
                                        
                                        	Area format IP or uint32
                                        	**type**\:  bool
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "local-route-area"

                                            self.area_format = YLeaf(YType.boolean, "area-format")

                                            self.area_id = YLeaf(YType.uint32, "area-id")

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("area_format",
                                                            "area_id",
                                                            "lsa_type",
                                                            "route_interface_name",
                                                            "route_lsaid",
                                                            "route_metric",
                                                            "route_next_hop_address",
                                                            "route_path_is_mcast_intact",
                                                            "route_path_is_ucmp_path",
                                                            "route_source") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath, self).__setattr__(name, value)


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("microloop_repair_list_size",
                                                                "microloop_strict_spf",
                                                                "microloop_tunnel_interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_id",
                                                                    "repair_element_type",
                                                                    "repair_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "microloop-repair" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-id"):
                                                        self.repair_element_id = value
                                                        self.repair_element_id.value_namespace = name_space
                                                        self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.microloop_repair_list_size.is_set or
                                                    self.microloop_strict_spf.is_set or
                                                    self.microloop_tunnel_interface_name.is_set)

                                            def has_operation(self):
                                                for c in self.microloop_repair:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                    self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                    self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                                if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                                if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "microloop-repair"):
                                                    for c in self.microloop_repair:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.microloop_repair.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "microloop-repair-list-size"):
                                                    self.microloop_repair_list_size = value
                                                    self.microloop_repair_list_size.value_namespace = name_space
                                                    self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-strict-spf"):
                                                    self.microloop_strict_spf = value
                                                    self.microloop_strict_spf.value_namespace = name_space
                                                    self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                                if(value_path == "microloop-tunnel-interface-name"):
                                                    self.microloop_tunnel_interface_name = value
                                                    self.microloop_tunnel_interface_name.value_namespace = name_space
                                                    self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.area_format.is_set or
                                                self.area_id.is_set or
                                                self.lsa_type.is_set or
                                                self.route_interface_name.is_set or
                                                self.route_lsaid.is_set or
                                                self.route_metric.is_set or
                                                self.route_next_hop_address.is_set or
                                                self.route_path_is_mcast_intact.is_set or
                                                self.route_path_is_ucmp_path.is_set or
                                                self.route_source.is_set or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.area_format.yfilter != YFilter.not_set or
                                                self.area_id.yfilter != YFilter.not_set or
                                                self.lsa_type.yfilter != YFilter.not_set or
                                                self.route_interface_name.yfilter != YFilter.not_set or
                                                self.route_lsaid.yfilter != YFilter.not_set or
                                                self.route_metric.yfilter != YFilter.not_set or
                                                self.route_next_hop_address.yfilter != YFilter.not_set or
                                                self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                                self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                                self.route_source.yfilter != YFilter.not_set or
                                                (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_format.get_name_leafdata())
                                            if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_id.get_name_leafdata())
                                            if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                            if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                            if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                            if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_metric.get_name_leafdata())
                                            if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                            if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                            if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                            if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_source.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "sr-microloop-avoidance-path"):
                                                if (self.sr_microloop_avoidance_path is None):
                                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                    self.sr_microloop_avoidance_path.parent = self
                                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                return self.sr_microloop_avoidance_path

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "area-format"):
                                                self.area_format = value
                                                self.area_format.value_namespace = name_space
                                                self.area_format.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-id"):
                                                self.area_id = value
                                                self.area_id.value_namespace = name_space
                                                self.area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-type"):
                                                self.lsa_type = value
                                                self.lsa_type.value_namespace = name_space
                                                self.lsa_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-interface-name"):
                                                self.route_interface_name = value
                                                self.route_interface_name.value_namespace = name_space
                                                self.route_interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-lsaid"):
                                                self.route_lsaid = value
                                                self.route_lsaid.value_namespace = name_space
                                                self.route_lsaid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-metric"):
                                                self.route_metric = value
                                                self.route_metric.value_namespace = name_space
                                                self.route_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-next-hop-address"):
                                                self.route_next_hop_address = value
                                                self.route_next_hop_address.value_namespace = name_space
                                                self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-mcast-intact"):
                                                self.route_path_is_mcast_intact = value
                                                self.route_path_is_mcast_intact.value_namespace = name_space
                                                self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-path-is-ucmp-path"):
                                                self.route_path_is_ucmp_path = value
                                                self.route_path_is_ucmp_path.value_namespace = name_space
                                                self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-source"):
                                                self.route_source = value
                                                self.route_source.value_namespace = name_space
                                                self.route_source.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.route_path:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.prefix.is_set or
                                            self.prefix_length.is_set or
                                            self.route_connected.is_set or
                                            self.route_metric.is_set or
                                            self.route_prefix.is_set or
                                            self.route_prefix_length.is_set or
                                            self.route_type.is_set or
                                            (self.route_info is not None and self.route_info.has_data()))

                                    def has_operation(self):
                                        for c in self.route_path:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.prefix.yfilter != YFilter.not_set or
                                            self.prefix_length.yfilter != YFilter.not_set or
                                            self.route_connected.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_prefix.yfilter != YFilter.not_set or
                                            self.route_prefix_length.yfilter != YFilter.not_set or
                                            self.route_type.yfilter != YFilter.not_set or
                                            (self.route_info is not None and self.route_info.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-route-area" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix.get_name_leafdata())
                                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                        if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_connected.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                        if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                        if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-info"):
                                            if (self.route_info is None):
                                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo()
                                                self.route_info.parent = self
                                                self._children_name_map["route_info"] = "route-info"
                                            return self.route_info

                                        if (child_yang_name == "route-path"):
                                            for c in self.route_path:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.route_path.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "prefix"):
                                            self.prefix = value
                                            self.prefix.value_namespace = name_space
                                            self.prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-length"):
                                            self.prefix_length = value
                                            self.prefix_length.value_namespace = name_space
                                            self.prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-connected"):
                                            self.route_connected = value
                                            self.route_connected.value_namespace = name_space
                                            self.route_connected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix"):
                                            self.route_prefix = value
                                            self.route_prefix.value_namespace = name_space
                                            self.route_prefix.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-prefix-length"):
                                            self.route_prefix_length = value
                                            self.route_prefix_length.value_namespace = name_space
                                            self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-type"):
                                            self.route_type = value
                                            self.route_type.value_namespace = name_space
                                            self.route_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.local_route_area:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.local_route_area:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-route-areas" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-route-area"):
                                        for c in self.local_route_area:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.local_route_area.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-route-area"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.area_id.is_set or
                                    (self.backup_route_areas is not None and self.backup_route_areas.has_data()) or
                                    (self.connected_route_areas is not None and self.connected_route_areas.has_data()) or
                                    (self.local_route_areas is not None and self.local_route_areas.has_data()) or
                                    (self.multicast_intact_backup_route_areas is not None and self.multicast_intact_backup_route_areas.has_data()) or
                                    (self.multicast_intact_route_areas is not None and self.multicast_intact_route_areas.has_data()) or
                                    (self.route_area_informations is not None and self.route_area_informations.has_data()) or
                                    (self.summary_area_information is not None and self.summary_area_information.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.area_id.yfilter != YFilter.not_set or
                                    (self.backup_route_areas is not None and self.backup_route_areas.has_operation()) or
                                    (self.connected_route_areas is not None and self.connected_route_areas.has_operation()) or
                                    (self.local_route_areas is not None and self.local_route_areas.has_operation()) or
                                    (self.multicast_intact_backup_route_areas is not None and self.multicast_intact_backup_route_areas.has_operation()) or
                                    (self.multicast_intact_route_areas is not None and self.multicast_intact_route_areas.has_operation()) or
                                    (self.route_area_informations is not None and self.route_area_informations.has_operation()) or
                                    (self.summary_area_information is not None and self.summary_area_information.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "route-area" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "backup-route-areas"):
                                    if (self.backup_route_areas is None):
                                        self.backup_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas()
                                        self.backup_route_areas.parent = self
                                        self._children_name_map["backup_route_areas"] = "backup-route-areas"
                                    return self.backup_route_areas

                                if (child_yang_name == "connected-route-areas"):
                                    if (self.connected_route_areas is None):
                                        self.connected_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas()
                                        self.connected_route_areas.parent = self
                                        self._children_name_map["connected_route_areas"] = "connected-route-areas"
                                    return self.connected_route_areas

                                if (child_yang_name == "local-route-areas"):
                                    if (self.local_route_areas is None):
                                        self.local_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas()
                                        self.local_route_areas.parent = self
                                        self._children_name_map["local_route_areas"] = "local-route-areas"
                                    return self.local_route_areas

                                if (child_yang_name == "multicast-intact-backup-route-areas"):
                                    if (self.multicast_intact_backup_route_areas is None):
                                        self.multicast_intact_backup_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas()
                                        self.multicast_intact_backup_route_areas.parent = self
                                        self._children_name_map["multicast_intact_backup_route_areas"] = "multicast-intact-backup-route-areas"
                                    return self.multicast_intact_backup_route_areas

                                if (child_yang_name == "multicast-intact-route-areas"):
                                    if (self.multicast_intact_route_areas is None):
                                        self.multicast_intact_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas()
                                        self.multicast_intact_route_areas.parent = self
                                        self._children_name_map["multicast_intact_route_areas"] = "multicast-intact-route-areas"
                                    return self.multicast_intact_route_areas

                                if (child_yang_name == "route-area-informations"):
                                    if (self.route_area_informations is None):
                                        self.route_area_informations = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations()
                                        self.route_area_informations.parent = self
                                        self._children_name_map["route_area_informations"] = "route-area-informations"
                                    return self.route_area_informations

                                if (child_yang_name == "summary-area-information"):
                                    if (self.summary_area_information is None):
                                        self.summary_area_information = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation()
                                        self.summary_area_information.parent = self
                                        self._children_name_map["summary_area_information"] = "summary-area-information"
                                    return self.summary_area_information

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "backup-route-areas" or name == "connected-route-areas" or name == "local-route-areas" or name == "multicast-intact-backup-route-areas" or name == "multicast-intact-route-areas" or name == "route-area-informations" or name == "summary-area-information" or name == "area-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "area-id"):
                                    self.area_id = value
                                    self.area_id.value_namespace = name_space
                                    self.area_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.route_area:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.route_area:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-areas" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "route-area"):
                                for c in self.route_area:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.route_area.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "route-area"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class RouteTable(Entity):
                        """
                        OSPF Route Table
                        
                        .. attribute:: route
                        
                        	An OSPF route
                        	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable, self).__init__()

                            self.yang_name = "route-table"
                            self.yang_parent_name = "route-information"

                            self.route = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable, self).__setattr__(name, value)


                        class Route(Entity):
                            """
                            An OSPF route
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: route_connected
                            
                            	If true, connected route
                            	**type**\:  bool
                            
                            .. attribute:: route_info
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo>`
                            
                            .. attribute:: route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath>`
                            
                            .. attribute:: route_prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "route-table"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_connected = YLeaf(YType.boolean, "route-connected")

                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                self.route_prefix = YLeaf(YType.str, "route-prefix")

                                self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo()
                                self.route_info.parent = self
                                self._children_name_map["route_info"] = "route-info"
                                self._children_yang_names.add("route-info")

                                self.route_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length",
                                                "route_connected",
                                                "route_metric",
                                                "route_prefix",
                                                "route_prefix_length",
                                                "route_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route, self).__setattr__(name, value)


                            class RouteInfo(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_auto_excluded
                                
                                	If true, exclude from TE paths
                                	**type**\:  bool
                                
                                .. attribute:: route_fail_time
                                
                                	Last time update failed
                                	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime>`
                                
                                .. attribute:: route_forward_distance
                                
                                	Forward distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_source
                                
                                	Protocol source
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_spf_priority
                                
                                	SPF priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: route_srte_nbr_registered
                                
                                	SRTE registered neigbhor count on route
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_srte_prefix_registered
                                
                                	If true, SRTE registered prefix route
                                	**type**\:  bool
                                
                                .. attribute:: route_te_metric
                                
                                	TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_update_time
                                
                                	Last time updated
                                	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo, self).__init__()

                                    self.yang_name = "route-info"
                                    self.yang_parent_name = "route"

                                    self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                    self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                    self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                    self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                    self.route_source = YLeaf(YType.uint16, "route-source")

                                    self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                    self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                    self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                    self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                    self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime()
                                    self.route_fail_time.parent = self
                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                    self._children_yang_names.add("route-fail-time")

                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime()
                                    self.route_update_time.parent = self
                                    self._children_name_map["route_update_time"] = "route-update-time"
                                    self._children_yang_names.add("route-update-time")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("route_area_id",
                                                    "route_auto_excluded",
                                                    "route_forward_distance",
                                                    "route_rib_version",
                                                    "route_source",
                                                    "route_spf_priority",
                                                    "route_spf_version",
                                                    "route_srte_nbr_registered",
                                                    "route_srte_prefix_registered",
                                                    "route_te_metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo, self).__setattr__(name, value)


                                class RouteUpdateTime(Entity):
                                    """
                                    Last time updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime, self).__init__()

                                        self.yang_name = "route-update-time"
                                        self.yang_parent_name = "route-info"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-update-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix


                                class RouteFailTime(Entity):
                                    """
                                    Last time update failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime, self).__init__()

                                        self.yang_name = "route-fail-time"
                                        self.yang_parent_name = "route-info"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-fail-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.route_area_id.is_set or
                                        self.route_auto_excluded.is_set or
                                        self.route_forward_distance.is_set or
                                        self.route_rib_version.is_set or
                                        self.route_source.is_set or
                                        self.route_spf_priority.is_set or
                                        self.route_spf_version.is_set or
                                        self.route_srte_nbr_registered.is_set or
                                        self.route_srte_prefix_registered.is_set or
                                        self.route_te_metric.is_set or
                                        (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                        (self.route_update_time is not None and self.route_update_time.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.route_area_id.yfilter != YFilter.not_set or
                                        self.route_auto_excluded.yfilter != YFilter.not_set or
                                        self.route_forward_distance.yfilter != YFilter.not_set or
                                        self.route_rib_version.yfilter != YFilter.not_set or
                                        self.route_source.yfilter != YFilter.not_set or
                                        self.route_spf_priority.yfilter != YFilter.not_set or
                                        self.route_spf_version.yfilter != YFilter.not_set or
                                        self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                        self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                        self.route_te_metric.yfilter != YFilter.not_set or
                                        (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                        (self.route_update_time is not None and self.route_update_time.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                    if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                    if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                    if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                    if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_source.get_name_leafdata())
                                    if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                    if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                    if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                    if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                    if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-fail-time"):
                                        if (self.route_fail_time is None):
                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                        return self.route_fail_time

                                    if (child_yang_name == "route-update-time"):
                                        if (self.route_update_time is None):
                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                        return self.route_update_time

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "route-area-id"):
                                        self.route_area_id = value
                                        self.route_area_id.value_namespace = name_space
                                        self.route_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-auto-excluded"):
                                        self.route_auto_excluded = value
                                        self.route_auto_excluded.value_namespace = name_space
                                        self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-forward-distance"):
                                        self.route_forward_distance = value
                                        self.route_forward_distance.value_namespace = name_space
                                        self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-rib-version"):
                                        self.route_rib_version = value
                                        self.route_rib_version.value_namespace = name_space
                                        self.route_rib_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-source"):
                                        self.route_source = value
                                        self.route_source.value_namespace = name_space
                                        self.route_source.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-spf-priority"):
                                        self.route_spf_priority = value
                                        self.route_spf_priority.value_namespace = name_space
                                        self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-spf-version"):
                                        self.route_spf_version = value
                                        self.route_spf_version.value_namespace = name_space
                                        self.route_spf_version.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-srte-nbr-registered"):
                                        self.route_srte_nbr_registered = value
                                        self.route_srte_nbr_registered.value_namespace = name_space
                                        self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-srte-prefix-registered"):
                                        self.route_srte_prefix_registered = value
                                        self.route_srte_prefix_registered.value_namespace = name_space
                                        self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-te-metric"):
                                        self.route_te_metric = value
                                        self.route_te_metric.value_namespace = name_space
                                        self.route_te_metric.value_namespace_prefix = name_space_prefix


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: area_format
                                
                                	Area format IP or uint32
                                	**type**\:  bool
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_type
                                
                                	LSA type, see RFC2328 etc
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: route_lsaid
                                
                                	LSA ID, see RFC2328
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_is_mcast_intact
                                
                                	Multicast\-intact path
                                	**type**\:  bool
                                
                                .. attribute:: route_path_is_ucmp_path
                                
                                	UCMP path
                                	**type**\:  bool
                                
                                .. attribute:: route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_path
                                
                                	SR Microloop avoidance Path Info
                                	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "route"

                                    self.area_format = YLeaf(YType.boolean, "area-format")

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                    self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                    self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                    self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                    self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                    self.route_source = YLeaf(YType.str, "route-source")

                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath()
                                    self.sr_microloop_avoidance_path.parent = self
                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                    self._children_yang_names.add("sr-microloop-avoidance-path")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_format",
                                                    "area_id",
                                                    "lsa_type",
                                                    "route_interface_name",
                                                    "route_lsaid",
                                                    "route_metric",
                                                    "route_next_hop_address",
                                                    "route_path_is_mcast_intact",
                                                    "route_path_is_ucmp_path",
                                                    "route_source") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath, self).__setattr__(name, value)


                                class SrMicroloopAvoidancePath(Entity):
                                    """
                                    SR Microloop avoidance Path Info
                                    
                                    .. attribute:: microloop_repair
                                    
                                    	Microloop Repair List
                                    	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                    
                                    .. attribute:: microloop_repair_list_size
                                    
                                    	Microloop Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: microloop_strict_spf
                                    
                                    	Strict SPF SID
                                    	**type**\:  bool
                                    
                                    .. attribute:: microloop_tunnel_interface_name
                                    
                                    	Microloop Tunnel Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                        self.yang_name = "sr-microloop-avoidance-path"
                                        self.yang_parent_name = "route-path"

                                        self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                        self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                        self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                        self.microloop_repair = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("microloop_repair_list_size",
                                                        "microloop_strict_spf",
                                                        "microloop_tunnel_interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                    class MicroloopRepair(Entity):
                                        """
                                        Microloop Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                            self.yang_name = "microloop-repair"
                                            self.yang_parent_name = "sr-microloop-avoidance-path"

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("repair_element_id",
                                                            "repair_element_type",
                                                            "repair_label") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.repair_element_id.is_set or
                                                self.repair_element_type.is_set or
                                                self.repair_label.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.repair_element_id.yfilter != YFilter.not_set or
                                                self.repair_element_type.yfilter != YFilter.not_set or
                                                self.repair_label.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "microloop-repair" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                            if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                            if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.repair_label.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "repair-element-id"):
                                                self.repair_element_id = value
                                                self.repair_element_id.value_namespace = name_space
                                                self.repair_element_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-element-type"):
                                                self.repair_element_type = value
                                                self.repair_element_type.value_namespace = name_space
                                                self.repair_element_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "repair-label"):
                                                self.repair_label = value
                                                self.repair_label.value_namespace = name_space
                                                self.repair_label.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.microloop_repair:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.microloop_repair_list_size.is_set or
                                            self.microloop_strict_spf.is_set or
                                            self.microloop_tunnel_interface_name.is_set)

                                    def has_operation(self):
                                        for c in self.microloop_repair:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                            self.microloop_strict_spf.yfilter != YFilter.not_set or
                                            self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                        if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                        if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "microloop-repair"):
                                            for c in self.microloop_repair:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.microloop_repair.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "microloop-repair-list-size"):
                                            self.microloop_repair_list_size = value
                                            self.microloop_repair_list_size.value_namespace = name_space
                                            self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "microloop-strict-spf"):
                                            self.microloop_strict_spf = value
                                            self.microloop_strict_spf.value_namespace = name_space
                                            self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                        if(value_path == "microloop-tunnel-interface-name"):
                                            self.microloop_tunnel_interface_name = value
                                            self.microloop_tunnel_interface_name.value_namespace = name_space
                                            self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.area_format.is_set or
                                        self.area_id.is_set or
                                        self.lsa_type.is_set or
                                        self.route_interface_name.is_set or
                                        self.route_lsaid.is_set or
                                        self.route_metric.is_set or
                                        self.route_next_hop_address.is_set or
                                        self.route_path_is_mcast_intact.is_set or
                                        self.route_path_is_ucmp_path.is_set or
                                        self.route_source.is_set or
                                        (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_format.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.lsa_type.yfilter != YFilter.not_set or
                                        self.route_interface_name.yfilter != YFilter.not_set or
                                        self.route_lsaid.yfilter != YFilter.not_set or
                                        self.route_metric.yfilter != YFilter.not_set or
                                        self.route_next_hop_address.yfilter != YFilter.not_set or
                                        self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                        self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                        self.route_source.yfilter != YFilter.not_set or
                                        (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_format.get_name_leafdata())
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                    if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                    if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                    if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_metric.get_name_leafdata())
                                    if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                    if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                    if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                    if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_source.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sr-microloop-avoidance-path"):
                                        if (self.sr_microloop_avoidance_path is None):
                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        return self.sr_microloop_avoidance_path

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-format"):
                                        self.area_format = value
                                        self.area_format.value_namespace = name_space
                                        self.area_format.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-type"):
                                        self.lsa_type = value
                                        self.lsa_type.value_namespace = name_space
                                        self.lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-interface-name"):
                                        self.route_interface_name = value
                                        self.route_interface_name.value_namespace = name_space
                                        self.route_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-lsaid"):
                                        self.route_lsaid = value
                                        self.route_lsaid.value_namespace = name_space
                                        self.route_lsaid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-metric"):
                                        self.route_metric = value
                                        self.route_metric.value_namespace = name_space
                                        self.route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-next-hop-address"):
                                        self.route_next_hop_address = value
                                        self.route_next_hop_address.value_namespace = name_space
                                        self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-is-mcast-intact"):
                                        self.route_path_is_mcast_intact = value
                                        self.route_path_is_mcast_intact.value_namespace = name_space
                                        self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-path-is-ucmp-path"):
                                        self.route_path_is_ucmp_path = value
                                        self.route_path_is_ucmp_path.value_namespace = name_space
                                        self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-source"):
                                        self.route_source = value
                                        self.route_source.value_namespace = name_space
                                        self.route_source.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.route_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    self.route_connected.is_set or
                                    self.route_metric.is_set or
                                    self.route_prefix.is_set or
                                    self.route_prefix_length.is_set or
                                    self.route_type.is_set or
                                    (self.route_info is not None and self.route_info.has_data()))

                            def has_operation(self):
                                for c in self.route_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.route_connected.yfilter != YFilter.not_set or
                                    self.route_metric.yfilter != YFilter.not_set or
                                    self.route_prefix.yfilter != YFilter.not_set or
                                    self.route_prefix_length.yfilter != YFilter.not_set or
                                    self.route_type.yfilter != YFilter.not_set or
                                    (self.route_info is not None and self.route_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "route" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_connected.get_name_leafdata())
                                if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_metric.get_name_leafdata())
                                if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "route-info"):
                                    if (self.route_info is None):
                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                    return self.route_info

                                if (child_yang_name == "route-path"):
                                    for c in self.route_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.route_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "route-info" or name == "route-path" or name == "prefix" or name == "prefix-length" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-connected"):
                                    self.route_connected = value
                                    self.route_connected.value_namespace = name_space
                                    self.route_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-metric"):
                                    self.route_metric = value
                                    self.route_metric.value_namespace = name_space
                                    self.route_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-prefix"):
                                    self.route_prefix = value
                                    self.route_prefix.value_namespace = name_space
                                    self.route_prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-prefix-length"):
                                    self.route_prefix_length = value
                                    self.route_prefix_length.value_namespace = name_space
                                    self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-type"):
                                    self.route_type = value
                                    self.route_type.value_namespace = name_space
                                    self.route_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.route:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.route:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-table" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "route"):
                                for c in self.route:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.route.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "route"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class ExternalRoutes(Entity):
                        """
                        OSPF External Route Table
                        
                        .. attribute:: external_route
                        
                        	OSPF external route
                        	**type**\: list of    :py:class:`ExternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes, self).__init__()

                            self.yang_name = "external-routes"
                            self.yang_parent_name = "route-information"

                            self.external_route = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes, self).__setattr__(name, value)


                        class ExternalRoute(Entity):
                            """
                            OSPF external route
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: protocol_name
                            
                            	Name of protocol from which the external route was redistributed
                            	**type**\:   :py:class:`ProtocolName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName>`
                            
                            .. attribute:: route_extended_community
                            
                            	Extended communities in the route
                            	**type**\:   :py:class:`RouteExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity>`
                            
                            .. attribute:: route_information
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute, self).__init__()

                                self.yang_name = "external-route"
                                self.yang_parent_name = "external-routes"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.protocol_name = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName()
                                self.protocol_name.parent = self
                                self._children_name_map["protocol_name"] = "protocol-name"
                                self._children_yang_names.add("protocol-name")

                                self.route_extended_community = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity()
                                self.route_extended_community.parent = self
                                self._children_name_map["route_extended_community"] = "route-extended-community"
                                self._children_yang_names.add("route-extended-community")

                                self.route_information = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation()
                                self.route_information.parent = self
                                self._children_name_map["route_information"] = "route-information"
                                self._children_yang_names.add("route-information")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute, self).__setattr__(name, value)


                            class RouteInformation(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation, self).__init__()

                                    self.yang_name = "route-information"
                                    self.yang_parent_name = "external-route"

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("route_connected",
                                                    "route_metric",
                                                    "route_prefix",
                                                    "route_prefix_length",
                                                    "route_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation, self).__setattr__(name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "route-information"

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("route_area_id",
                                                        "route_auto_excluded",
                                                        "route_forward_distance",
                                                        "route_rib_version",
                                                        "route_source",
                                                        "route_spf_priority",
                                                        "route_spf_version",
                                                        "route_srte_nbr_registered",
                                                        "route_srte_prefix_registered",
                                                        "route_te_metric") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo, self).__setattr__(name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-update-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("nanosecond",
                                                            "second") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.nanosecond.is_set or
                                                self.second.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.nanosecond.yfilter != YFilter.not_set or
                                                self.second.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-fail-time" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                            if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.second.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "nanosecond" or name == "second"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "nanosecond"):
                                                self.nanosecond = value
                                                self.nanosecond.value_namespace = name_space
                                                self.nanosecond.value_namespace_prefix = name_space_prefix
                                            if(value_path == "second"):
                                                self.second = value
                                                self.second.value_namespace = name_space
                                                self.second.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.route_area_id.is_set or
                                            self.route_auto_excluded.is_set or
                                            self.route_forward_distance.is_set or
                                            self.route_rib_version.is_set or
                                            self.route_source.is_set or
                                            self.route_spf_priority.is_set or
                                            self.route_spf_version.is_set or
                                            self.route_srte_nbr_registered.is_set or
                                            self.route_srte_prefix_registered.is_set or
                                            self.route_te_metric.is_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_data()) or
                                            (self.route_update_time is not None and self.route_update_time.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.route_area_id.yfilter != YFilter.not_set or
                                            self.route_auto_excluded.yfilter != YFilter.not_set or
                                            self.route_forward_distance.yfilter != YFilter.not_set or
                                            self.route_rib_version.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            self.route_spf_priority.yfilter != YFilter.not_set or
                                            self.route_spf_version.yfilter != YFilter.not_set or
                                            self.route_srte_nbr_registered.yfilter != YFilter.not_set or
                                            self.route_srte_prefix_registered.yfilter != YFilter.not_set or
                                            self.route_te_metric.yfilter != YFilter.not_set or
                                            (self.route_fail_time is not None and self.route_fail_time.has_operation()) or
                                            (self.route_update_time is not None and self.route_update_time.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.route_area_id.is_set or self.route_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_area_id.get_name_leafdata())
                                        if (self.route_auto_excluded.is_set or self.route_auto_excluded.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_auto_excluded.get_name_leafdata())
                                        if (self.route_forward_distance.is_set or self.route_forward_distance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_forward_distance.get_name_leafdata())
                                        if (self.route_rib_version.is_set or self.route_rib_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_rib_version.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())
                                        if (self.route_spf_priority.is_set or self.route_spf_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_priority.get_name_leafdata())
                                        if (self.route_spf_version.is_set or self.route_spf_version.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_spf_version.get_name_leafdata())
                                        if (self.route_srte_nbr_registered.is_set or self.route_srte_nbr_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_nbr_registered.get_name_leafdata())
                                        if (self.route_srte_prefix_registered.is_set or self.route_srte_prefix_registered.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_srte_prefix_registered.get_name_leafdata())
                                        if (self.route_te_metric.is_set or self.route_te_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_te_metric.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "route-fail-time"):
                                            if (self.route_fail_time is None):
                                                self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                            return self.route_fail_time

                                        if (child_yang_name == "route-update-time"):
                                            if (self.route_update_time is None):
                                                self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                            return self.route_update_time

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "route-fail-time" or name == "route-update-time" or name == "route-area-id" or name == "route-auto-excluded" or name == "route-forward-distance" or name == "route-rib-version" or name == "route-source" or name == "route-spf-priority" or name == "route-spf-version" or name == "route-srte-nbr-registered" or name == "route-srte-prefix-registered" or name == "route-te-metric"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "route-area-id"):
                                            self.route_area_id = value
                                            self.route_area_id.value_namespace = name_space
                                            self.route_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-auto-excluded"):
                                            self.route_auto_excluded = value
                                            self.route_auto_excluded.value_namespace = name_space
                                            self.route_auto_excluded.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-forward-distance"):
                                            self.route_forward_distance = value
                                            self.route_forward_distance.value_namespace = name_space
                                            self.route_forward_distance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-rib-version"):
                                            self.route_rib_version = value
                                            self.route_rib_version.value_namespace = name_space
                                            self.route_rib_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-priority"):
                                            self.route_spf_priority = value
                                            self.route_spf_priority.value_namespace = name_space
                                            self.route_spf_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-spf-version"):
                                            self.route_spf_version = value
                                            self.route_spf_version.value_namespace = name_space
                                            self.route_spf_version.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-nbr-registered"):
                                            self.route_srte_nbr_registered = value
                                            self.route_srte_nbr_registered.value_namespace = name_space
                                            self.route_srte_nbr_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-srte-prefix-registered"):
                                            self.route_srte_prefix_registered = value
                                            self.route_srte_prefix_registered.value_namespace = name_space
                                            self.route_srte_prefix_registered.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-te-metric"):
                                            self.route_te_metric = value
                                            self.route_te_metric.value_namespace = name_space
                                            self.route_te_metric.value_namespace_prefix = name_space_prefix


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: area_format
                                    
                                    	Area format IP or uint32
                                    	**type**\:  bool
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "route-information"

                                        self.area_format = YLeaf(YType.boolean, "area-format")

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("area_format",
                                                        "area_id",
                                                        "lsa_type",
                                                        "route_interface_name",
                                                        "route_lsaid",
                                                        "route_metric",
                                                        "route_next_hop_address",
                                                        "route_path_is_mcast_intact",
                                                        "route_path_is_ucmp_path",
                                                        "route_source") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath, self).__setattr__(name, value)


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("microloop_repair_list_size",
                                                            "microloop_strict_spf",
                                                            "microloop_tunnel_interface_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath, self).__setattr__(name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("repair_element_id",
                                                                "repair_element_type",
                                                                "repair_label") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.repair_element_id.is_set or
                                                    self.repair_element_type.is_set or
                                                    self.repair_label.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.repair_element_id.yfilter != YFilter.not_set or
                                                    self.repair_element_type.yfilter != YFilter.not_set or
                                                    self.repair_label.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "microloop-repair" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.repair_element_id.is_set or self.repair_element_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_id.get_name_leafdata())
                                                if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.repair_label.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "repair-element-id" or name == "repair-element-type" or name == "repair-label"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "repair-element-id"):
                                                    self.repair_element_id = value
                                                    self.repair_element_id.value_namespace = name_space
                                                    self.repair_element_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-element-type"):
                                                    self.repair_element_type = value
                                                    self.repair_element_type.value_namespace = name_space
                                                    self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "repair-label"):
                                                    self.repair_label = value
                                                    self.repair_label.value_namespace = name_space
                                                    self.repair_label.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.microloop_repair:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.microloop_repair_list_size.is_set or
                                                self.microloop_strict_spf.is_set or
                                                self.microloop_tunnel_interface_name.is_set)

                                        def has_operation(self):
                                            for c in self.microloop_repair:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.microloop_repair_list_size.yfilter != YFilter.not_set or
                                                self.microloop_strict_spf.yfilter != YFilter.not_set or
                                                self.microloop_tunnel_interface_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sr-microloop-avoidance-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.microloop_repair_list_size.is_set or self.microloop_repair_list_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_repair_list_size.get_name_leafdata())
                                            if (self.microloop_strict_spf.is_set or self.microloop_strict_spf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_strict_spf.get_name_leafdata())
                                            if (self.microloop_tunnel_interface_name.is_set or self.microloop_tunnel_interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.microloop_tunnel_interface_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "microloop-repair"):
                                                for c in self.microloop_repair:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.microloop_repair.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "microloop-repair" or name == "microloop-repair-list-size" or name == "microloop-strict-spf" or name == "microloop-tunnel-interface-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "microloop-repair-list-size"):
                                                self.microloop_repair_list_size = value
                                                self.microloop_repair_list_size.value_namespace = name_space
                                                self.microloop_repair_list_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-strict-spf"):
                                                self.microloop_strict_spf = value
                                                self.microloop_strict_spf.value_namespace = name_space
                                                self.microloop_strict_spf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "microloop-tunnel-interface-name"):
                                                self.microloop_tunnel_interface_name = value
                                                self.microloop_tunnel_interface_name.value_namespace = name_space
                                                self.microloop_tunnel_interface_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.area_format.is_set or
                                            self.area_id.is_set or
                                            self.lsa_type.is_set or
                                            self.route_interface_name.is_set or
                                            self.route_lsaid.is_set or
                                            self.route_metric.is_set or
                                            self.route_next_hop_address.is_set or
                                            self.route_path_is_mcast_intact.is_set or
                                            self.route_path_is_ucmp_path.is_set or
                                            self.route_source.is_set or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.area_format.yfilter != YFilter.not_set or
                                            self.area_id.yfilter != YFilter.not_set or
                                            self.lsa_type.yfilter != YFilter.not_set or
                                            self.route_interface_name.yfilter != YFilter.not_set or
                                            self.route_lsaid.yfilter != YFilter.not_set or
                                            self.route_metric.yfilter != YFilter.not_set or
                                            self.route_next_hop_address.yfilter != YFilter.not_set or
                                            self.route_path_is_mcast_intact.yfilter != YFilter.not_set or
                                            self.route_path_is_ucmp_path.yfilter != YFilter.not_set or
                                            self.route_source.yfilter != YFilter.not_set or
                                            (self.sr_microloop_avoidance_path is not None and self.sr_microloop_avoidance_path.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.area_format.is_set or self.area_format.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_format.get_name_leafdata())
                                        if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id.get_name_leafdata())
                                        if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_type.get_name_leafdata())
                                        if (self.route_interface_name.is_set or self.route_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_interface_name.get_name_leafdata())
                                        if (self.route_lsaid.is_set or self.route_lsaid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_lsaid.get_name_leafdata())
                                        if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_metric.get_name_leafdata())
                                        if (self.route_next_hop_address.is_set or self.route_next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_next_hop_address.get_name_leafdata())
                                        if (self.route_path_is_mcast_intact.is_set or self.route_path_is_mcast_intact.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_mcast_intact.get_name_leafdata())
                                        if (self.route_path_is_ucmp_path.is_set or self.route_path_is_ucmp_path.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_path_is_ucmp_path.get_name_leafdata())
                                        if (self.route_source.is_set or self.route_source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_source.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "sr-microloop-avoidance-path"):
                                            if (self.sr_microloop_avoidance_path is None):
                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            return self.sr_microloop_avoidance_path

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "sr-microloop-avoidance-path" or name == "area-format" or name == "area-id" or name == "lsa-type" or name == "route-interface-name" or name == "route-lsaid" or name == "route-metric" or name == "route-next-hop-address" or name == "route-path-is-mcast-intact" or name == "route-path-is-ucmp-path" or name == "route-source"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "area-format"):
                                            self.area_format = value
                                            self.area_format.value_namespace = name_space
                                            self.area_format.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-id"):
                                            self.area_id = value
                                            self.area_id.value_namespace = name_space
                                            self.area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-type"):
                                            self.lsa_type = value
                                            self.lsa_type.value_namespace = name_space
                                            self.lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-interface-name"):
                                            self.route_interface_name = value
                                            self.route_interface_name.value_namespace = name_space
                                            self.route_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-lsaid"):
                                            self.route_lsaid = value
                                            self.route_lsaid.value_namespace = name_space
                                            self.route_lsaid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-metric"):
                                            self.route_metric = value
                                            self.route_metric.value_namespace = name_space
                                            self.route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-next-hop-address"):
                                            self.route_next_hop_address = value
                                            self.route_next_hop_address.value_namespace = name_space
                                            self.route_next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-mcast-intact"):
                                            self.route_path_is_mcast_intact = value
                                            self.route_path_is_mcast_intact.value_namespace = name_space
                                            self.route_path_is_mcast_intact.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-path-is-ucmp-path"):
                                            self.route_path_is_ucmp_path = value
                                            self.route_path_is_ucmp_path.value_namespace = name_space
                                            self.route_path_is_ucmp_path.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-source"):
                                            self.route_source = value
                                            self.route_source.value_namespace = name_space
                                            self.route_source.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.route_path:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.route_connected.is_set or
                                        self.route_metric.is_set or
                                        self.route_prefix.is_set or
                                        self.route_prefix_length.is_set or
                                        self.route_type.is_set or
                                        (self.route_info is not None and self.route_info.has_data()))

                                def has_operation(self):
                                    for c in self.route_path:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.route_connected.yfilter != YFilter.not_set or
                                        self.route_metric.yfilter != YFilter.not_set or
                                        self.route_prefix.yfilter != YFilter.not_set or
                                        self.route_prefix_length.yfilter != YFilter.not_set or
                                        self.route_type.yfilter != YFilter.not_set or
                                        (self.route_info is not None and self.route_info.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.route_connected.is_set or self.route_connected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_connected.get_name_leafdata())
                                    if (self.route_metric.is_set or self.route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_metric.get_name_leafdata())
                                    if (self.route_prefix.is_set or self.route_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix.get_name_leafdata())
                                    if (self.route_prefix_length.is_set or self.route_prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_prefix_length.get_name_leafdata())
                                    if (self.route_type.is_set or self.route_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "route-info"):
                                        if (self.route_info is None):
                                            self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                        return self.route_info

                                    if (child_yang_name == "route-path"):
                                        for c in self.route_path:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.route_path.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "route-info" or name == "route-path" or name == "route-connected" or name == "route-metric" or name == "route-prefix" or name == "route-prefix-length" or name == "route-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "route-connected"):
                                        self.route_connected = value
                                        self.route_connected.value_namespace = name_space
                                        self.route_connected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-metric"):
                                        self.route_metric = value
                                        self.route_metric.value_namespace = name_space
                                        self.route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix"):
                                        self.route_prefix = value
                                        self.route_prefix.value_namespace = name_space
                                        self.route_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-prefix-length"):
                                        self.route_prefix_length = value
                                        self.route_prefix_length.value_namespace = name_space
                                        self.route_prefix_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-type"):
                                        self.route_type = value
                                        self.route_type.value_namespace = name_space
                                        self.route_type.value_namespace_prefix = name_space_prefix


                            class ProtocolName(Entity):
                                """
                                Name of protocol from which the external route
                                was redistributed
                                
                                .. attribute:: bgp_as_number
                                
                                	BGP Autonomous System Number
                                	**type**\:  str
                                
                                .. attribute:: connected_instance
                                
                                	Connected instance name
                                	**type**\:  str
                                
                                .. attribute:: eigrp_as_number
                                
                                	Autonomous System Number
                                	**type**\:  str
                                
                                .. attribute:: isis_instance_id
                                
                                	ISIS instance identifier
                                	**type**\:  str
                                
                                .. attribute:: ospf_process_id
                                
                                	OSPF process identifier
                                	**type**\:  str
                                
                                .. attribute:: protocol_type
                                
                                	ProtocolType
                                	**type**\:   :py:class:`RedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.RedistProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName, self).__init__()

                                    self.yang_name = "protocol-name"
                                    self.yang_parent_name = "external-route"

                                    self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                    self.connected_instance = YLeaf(YType.str, "connected-instance")

                                    self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                    self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                    self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                    self.protocol_type = YLeaf(YType.enumeration, "protocol-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bgp_as_number",
                                                    "connected_instance",
                                                    "eigrp_as_number",
                                                    "isis_instance_id",
                                                    "ospf_process_id",
                                                    "protocol_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bgp_as_number.is_set or
                                        self.connected_instance.is_set or
                                        self.eigrp_as_number.is_set or
                                        self.isis_instance_id.is_set or
                                        self.ospf_process_id.is_set or
                                        self.protocol_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bgp_as_number.yfilter != YFilter.not_set or
                                        self.connected_instance.yfilter != YFilter.not_set or
                                        self.eigrp_as_number.yfilter != YFilter.not_set or
                                        self.isis_instance_id.yfilter != YFilter.not_set or
                                        self.ospf_process_id.yfilter != YFilter.not_set or
                                        self.protocol_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "protocol-name" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bgp_as_number.is_set or self.bgp_as_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_as_number.get_name_leafdata())
                                    if (self.connected_instance.is_set or self.connected_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.connected_instance.get_name_leafdata())
                                    if (self.eigrp_as_number.is_set or self.eigrp_as_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.eigrp_as_number.get_name_leafdata())
                                    if (self.isis_instance_id.is_set or self.isis_instance_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.isis_instance_id.get_name_leafdata())
                                    if (self.ospf_process_id.is_set or self.ospf_process_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_process_id.get_name_leafdata())
                                    if (self.protocol_type.is_set or self.protocol_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bgp-as-number" or name == "connected-instance" or name == "eigrp-as-number" or name == "isis-instance-id" or name == "ospf-process-id" or name == "protocol-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bgp-as-number"):
                                        self.bgp_as_number = value
                                        self.bgp_as_number.value_namespace = name_space
                                        self.bgp_as_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "connected-instance"):
                                        self.connected_instance = value
                                        self.connected_instance.value_namespace = name_space
                                        self.connected_instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "eigrp-as-number"):
                                        self.eigrp_as_number = value
                                        self.eigrp_as_number.value_namespace = name_space
                                        self.eigrp_as_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "isis-instance-id"):
                                        self.isis_instance_id = value
                                        self.isis_instance_id.value_namespace = name_space
                                        self.isis_instance_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-process-id"):
                                        self.ospf_process_id = value
                                        self.ospf_process_id.value_namespace = name_space
                                        self.ospf_process_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol-type"):
                                        self.protocol_type = value
                                        self.protocol_type.value_namespace = name_space
                                        self.protocol_type.value_namespace_prefix = name_space_prefix


                            class RouteExtendedCommunity(Entity):
                                """
                                Extended communities in the route
                                
                                .. attribute:: extended_community_area_id
                                
                                	Area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_domain_id_value
                                
                                	Domain ID value
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extended_community_options
                                
                                	Route Options
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: extended_community_route_type
                                
                                	Route type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: extended_community_router_id
                                
                                	Router id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: extended_communityl_domain_id_type
                                
                                	Domain ID type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, self).__init__()

                                    self.yang_name = "route-extended-community"
                                    self.yang_parent_name = "external-route"

                                    self.extended_community_area_id = YLeaf(YType.uint32, "extended-community-area-id")

                                    self.extended_community_domain_id_value = YLeaf(YType.str, "extended-community-domain-id-value")

                                    self.extended_community_options = YLeaf(YType.uint8, "extended-community-options")

                                    self.extended_community_route_type = YLeaf(YType.uint8, "extended-community-route-type")

                                    self.extended_community_router_id = YLeaf(YType.str, "extended-community-router-id")

                                    self.extended_communityl_domain_id_type = YLeaf(YType.uint16, "extended-communityl-domain-id-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("extended_community_area_id",
                                                    "extended_community_domain_id_value",
                                                    "extended_community_options",
                                                    "extended_community_route_type",
                                                    "extended_community_router_id",
                                                    "extended_communityl_domain_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.extended_community_area_id.is_set or
                                        self.extended_community_domain_id_value.is_set or
                                        self.extended_community_options.is_set or
                                        self.extended_community_route_type.is_set or
                                        self.extended_community_router_id.is_set or
                                        self.extended_communityl_domain_id_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.extended_community_area_id.yfilter != YFilter.not_set or
                                        self.extended_community_domain_id_value.yfilter != YFilter.not_set or
                                        self.extended_community_options.yfilter != YFilter.not_set or
                                        self.extended_community_route_type.yfilter != YFilter.not_set or
                                        self.extended_community_router_id.yfilter != YFilter.not_set or
                                        self.extended_communityl_domain_id_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "route-extended-community" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.extended_community_area_id.is_set or self.extended_community_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extended_community_area_id.get_name_leafdata())
                                    if (self.extended_community_domain_id_value.is_set or self.extended_community_domain_id_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extended_community_domain_id_value.get_name_leafdata())
                                    if (self.extended_community_options.is_set or self.extended_community_options.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extended_community_options.get_name_leafdata())
                                    if (self.extended_community_route_type.is_set or self.extended_community_route_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extended_community_route_type.get_name_leafdata())
                                    if (self.extended_community_router_id.is_set or self.extended_community_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extended_community_router_id.get_name_leafdata())
                                    if (self.extended_communityl_domain_id_type.is_set or self.extended_communityl_domain_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extended_communityl_domain_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "extended-community-area-id" or name == "extended-community-domain-id-value" or name == "extended-community-options" or name == "extended-community-route-type" or name == "extended-community-router-id" or name == "extended-communityl-domain-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "extended-community-area-id"):
                                        self.extended_community_area_id = value
                                        self.extended_community_area_id.value_namespace = name_space
                                        self.extended_community_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "extended-community-domain-id-value"):
                                        self.extended_community_domain_id_value = value
                                        self.extended_community_domain_id_value.value_namespace = name_space
                                        self.extended_community_domain_id_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "extended-community-options"):
                                        self.extended_community_options = value
                                        self.extended_community_options.value_namespace = name_space
                                        self.extended_community_options.value_namespace_prefix = name_space_prefix
                                    if(value_path == "extended-community-route-type"):
                                        self.extended_community_route_type = value
                                        self.extended_community_route_type.value_namespace = name_space
                                        self.extended_community_route_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "extended-community-router-id"):
                                        self.extended_community_router_id = value
                                        self.extended_community_router_id.value_namespace = name_space
                                        self.extended_community_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "extended-communityl-domain-id-type"):
                                        self.extended_communityl_domain_id_type = value
                                        self.extended_communityl_domain_id_type.value_namespace = name_space
                                        self.extended_communityl_domain_id_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    (self.protocol_name is not None and self.protocol_name.has_data()) or
                                    (self.route_extended_community is not None and self.route_extended_community.has_data()) or
                                    (self.route_information is not None and self.route_information.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    (self.protocol_name is not None and self.protocol_name.has_operation()) or
                                    (self.route_extended_community is not None and self.route_extended_community.has_operation()) or
                                    (self.route_information is not None and self.route_information.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "external-route" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "protocol-name"):
                                    if (self.protocol_name is None):
                                        self.protocol_name = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName()
                                        self.protocol_name.parent = self
                                        self._children_name_map["protocol_name"] = "protocol-name"
                                    return self.protocol_name

                                if (child_yang_name == "route-extended-community"):
                                    if (self.route_extended_community is None):
                                        self.route_extended_community = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity()
                                        self.route_extended_community.parent = self
                                        self._children_name_map["route_extended_community"] = "route-extended-community"
                                    return self.route_extended_community

                                if (child_yang_name == "route-information"):
                                    if (self.route_information is None):
                                        self.route_information = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation()
                                        self.route_information.parent = self
                                        self._children_name_map["route_information"] = "route-information"
                                    return self.route_information

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "protocol-name" or name == "route-extended-community" or name == "route-information" or name == "prefix" or name == "prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.external_route:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.external_route:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "external-routes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "external-route"):
                                for c in self.external_route:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.external_route.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "external-route"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.backup_routes is not None and self.backup_routes.has_data()) or
                            (self.connected_routes is not None and self.connected_routes.has_data()) or
                            (self.external_routes is not None and self.external_routes.has_data()) or
                            (self.local_routes is not None and self.local_routes.has_data()) or
                            (self.multicast_intact_backup_routes is not None and self.multicast_intact_backup_routes.has_data()) or
                            (self.multicast_intact_route_table is not None and self.multicast_intact_route_table.has_data()) or
                            (self.route_areas is not None and self.route_areas.has_data()) or
                            (self.route_table is not None and self.route_table.has_data()) or
                            (self.summary_information is not None and self.summary_information.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.backup_routes is not None and self.backup_routes.has_operation()) or
                            (self.connected_routes is not None and self.connected_routes.has_operation()) or
                            (self.external_routes is not None and self.external_routes.has_operation()) or
                            (self.local_routes is not None and self.local_routes.has_operation()) or
                            (self.multicast_intact_backup_routes is not None and self.multicast_intact_backup_routes.has_operation()) or
                            (self.multicast_intact_route_table is not None and self.multicast_intact_route_table.has_operation()) or
                            (self.route_areas is not None and self.route_areas.has_operation()) or
                            (self.route_table is not None and self.route_table.has_operation()) or
                            (self.summary_information is not None and self.summary_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "route-information" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "backup-routes"):
                            if (self.backup_routes is None):
                                self.backup_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes()
                                self.backup_routes.parent = self
                                self._children_name_map["backup_routes"] = "backup-routes"
                            return self.backup_routes

                        if (child_yang_name == "connected-routes"):
                            if (self.connected_routes is None):
                                self.connected_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes()
                                self.connected_routes.parent = self
                                self._children_name_map["connected_routes"] = "connected-routes"
                            return self.connected_routes

                        if (child_yang_name == "external-routes"):
                            if (self.external_routes is None):
                                self.external_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes()
                                self.external_routes.parent = self
                                self._children_name_map["external_routes"] = "external-routes"
                            return self.external_routes

                        if (child_yang_name == "local-routes"):
                            if (self.local_routes is None):
                                self.local_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes()
                                self.local_routes.parent = self
                                self._children_name_map["local_routes"] = "local-routes"
                            return self.local_routes

                        if (child_yang_name == "multicast-intact-backup-routes"):
                            if (self.multicast_intact_backup_routes is None):
                                self.multicast_intact_backup_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes()
                                self.multicast_intact_backup_routes.parent = self
                                self._children_name_map["multicast_intact_backup_routes"] = "multicast-intact-backup-routes"
                            return self.multicast_intact_backup_routes

                        if (child_yang_name == "multicast-intact-route-table"):
                            if (self.multicast_intact_route_table is None):
                                self.multicast_intact_route_table = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable()
                                self.multicast_intact_route_table.parent = self
                                self._children_name_map["multicast_intact_route_table"] = "multicast-intact-route-table"
                            return self.multicast_intact_route_table

                        if (child_yang_name == "route-areas"):
                            if (self.route_areas is None):
                                self.route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas()
                                self.route_areas.parent = self
                                self._children_name_map["route_areas"] = "route-areas"
                            return self.route_areas

                        if (child_yang_name == "route-table"):
                            if (self.route_table is None):
                                self.route_table = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable()
                                self.route_table.parent = self
                                self._children_name_map["route_table"] = "route-table"
                            return self.route_table

                        if (child_yang_name == "summary-information"):
                            if (self.summary_information is None):
                                self.summary_information = Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation()
                                self.summary_information.parent = self
                                self._children_name_map["summary_information"] = "summary-information"
                            return self.summary_information

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "backup-routes" or name == "connected-routes" or name == "external-routes" or name == "local-routes" or name == "multicast-intact-backup-routes" or name == "multicast-intact-route-table" or name == "route-areas" or name == "route-table" or name == "summary-information"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceInformation(Entity):
                    """
                    Container for OSPF Interfaces/links
                    
                    .. attribute:: interface_briefs
                    
                    	OSPF Interface Brief Table
                    	**type**\:   :py:class:`InterfaceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs>`
                    
                    .. attribute:: interfaces
                    
                    	OSPF Interface Table
                    	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces>`
                    
                    .. attribute:: virtual_links
                    
                    	Virtual Link table
                    	**type**\:   :py:class:`VirtualLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation, self).__init__()

                        self.yang_name = "interface-information"
                        self.yang_parent_name = "default-vrf"

                        self.interface_briefs = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs()
                        self.interface_briefs.parent = self
                        self._children_name_map["interface_briefs"] = "interface-briefs"
                        self._children_yang_names.add("interface-briefs")

                        self.interfaces = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                        self._children_yang_names.add("interfaces")

                        self.virtual_links = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks()
                        self.virtual_links.parent = self
                        self._children_name_map["virtual_links"] = "virtual-links"
                        self._children_yang_names.add("virtual-links")


                    class VirtualLinks(Entity):
                        """
                        Virtual Link table
                        
                        .. attribute:: virtual_link
                        
                        	Information for one Virtual link
                        	**type**\: list of    :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks, self).__init__()

                            self.yang_name = "virtual-links"
                            self.yang_parent_name = "interface-information"

                            self.virtual_link = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks, self).__setattr__(name, value)


                        class VirtualLink(Entity):
                            """
                            Information for one Virtual link
                            
                            .. attribute:: virtual_link_name  <key>
                            
                            	Virtual link
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: transit_area
                            
                            	Transit area id
                            	**type**\:  str
                            
                            .. attribute:: virtaul_link_retransmission_interval
                            
                            	Retransmission interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_authentication_type
                            
                            	Authentication type
                            	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                            
                            .. attribute:: virtual_link_cost
                            
                            	Cost of the virtual link
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtual_link_dc_bitless_lsa
                            
                            	Number of LSA's with demand circuit bit not set
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_dead_interval
                            
                            	Dead interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_demand_circuit
                            
                            	If true, the link runs as demand circuit
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_hello_interval
                            
                            	Hello interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_hello_interval_ms
                            
                            	Hello interval (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_interface_name
                            
                            	Interface on which this virtual link is formed
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: virtual_link_keychain_id
                            
                            	Virtual Link Keychain ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: virtual_link_last_nsf
                            
                            	Time in seconds since last NSF
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: virtual_link_md_key
                            
                            	List of old MD keys (if any)
                            	**type**\: list of    :py:class:`VirtualLinkMdKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey>`
                            
                            .. attribute:: virtual_link_name_xr
                            
                            	Virtual link name
                            	**type**\:  str
                            
                            .. attribute:: virtual_link_neighbor
                            
                            	Neighbor information
                            	**type**\:   :py:class:`VirtualLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor>`
                            
                            .. attribute:: virtual_link_neighbor_id
                            
                            	Neighbor on other end of this virtual link
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: virtual_link_next_hello
                            
                            	Time until next hello (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_next_hello_ms
                            
                            	Time until next hello (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_nsf
                            
                            	If true, NSF restart in progress on the virtual link
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_nsf_enabled
                            
                            	If true, NSF enabled
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_old_md_key_count
                            
                            	Number of neighbors still using the old key (rollover in progress)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_passive
                            
                            	If true, interface is passive
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_state
                            
                            	OSPF interface state for the virtual link
                            	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                            
                            .. attribute:: virtual_link_wait_interval
                            
                            	Wait interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_youngest_md_key
                            
                            	If true, MD key configured
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_youngest_md_key_id
                            
                            	Youngest MD key ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virual_link_transmission_delay
                            
                            	Transmission delay in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink, self).__init__()

                                self.yang_name = "virtual-link"
                                self.yang_parent_name = "virtual-links"

                                self.virtual_link_name = YLeaf(YType.str, "virtual-link-name")

                                self.transit_area = YLeaf(YType.str, "transit-area")

                                self.virtaul_link_retransmission_interval = YLeaf(YType.uint32, "virtaul-link-retransmission-interval")

                                self.virtual_link_authentication_type = YLeaf(YType.enumeration, "virtual-link-authentication-type")

                                self.virtual_link_cost = YLeaf(YType.uint16, "virtual-link-cost")

                                self.virtual_link_dc_bitless_lsa = YLeaf(YType.uint32, "virtual-link-dc-bitless-lsa")

                                self.virtual_link_dead_interval = YLeaf(YType.uint32, "virtual-link-dead-interval")

                                self.virtual_link_demand_circuit = YLeaf(YType.boolean, "virtual-link-demand-circuit")

                                self.virtual_link_hello_interval = YLeaf(YType.uint32, "virtual-link-hello-interval")

                                self.virtual_link_hello_interval_ms = YLeaf(YType.uint32, "virtual-link-hello-interval-ms")

                                self.virtual_link_interface_name = YLeaf(YType.str, "virtual-link-interface-name")

                                self.virtual_link_keychain_id = YLeaf(YType.uint64, "virtual-link-keychain-id")

                                self.virtual_link_last_nsf = YLeaf(YType.uint32, "virtual-link-last-nsf")

                                self.virtual_link_name_xr = YLeaf(YType.str, "virtual-link-name-xr")

                                self.virtual_link_neighbor_id = YLeaf(YType.str, "virtual-link-neighbor-id")

                                self.virtual_link_next_hello = YLeaf(YType.uint32, "virtual-link-next-hello")

                                self.virtual_link_next_hello_ms = YLeaf(YType.uint32, "virtual-link-next-hello-ms")

                                self.virtual_link_nsf = YLeaf(YType.boolean, "virtual-link-nsf")

                                self.virtual_link_nsf_enabled = YLeaf(YType.boolean, "virtual-link-nsf-enabled")

                                self.virtual_link_old_md_key_count = YLeaf(YType.uint32, "virtual-link-old-md-key-count")

                                self.virtual_link_passive = YLeaf(YType.boolean, "virtual-link-passive")

                                self.virtual_link_state = YLeaf(YType.enumeration, "virtual-link-state")

                                self.virtual_link_wait_interval = YLeaf(YType.uint32, "virtual-link-wait-interval")

                                self.virtual_link_youngest_md_key = YLeaf(YType.boolean, "virtual-link-youngest-md-key")

                                self.virtual_link_youngest_md_key_id = YLeaf(YType.uint16, "virtual-link-youngest-md-key-id")

                                self.virual_link_transmission_delay = YLeaf(YType.uint16, "virual-link-transmission-delay")

                                self.virtual_link_neighbor = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor()
                                self.virtual_link_neighbor.parent = self
                                self._children_name_map["virtual_link_neighbor"] = "virtual-link-neighbor"
                                self._children_yang_names.add("virtual-link-neighbor")

                                self.virtual_link_md_key = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("virtual_link_name",
                                                "transit_area",
                                                "virtaul_link_retransmission_interval",
                                                "virtual_link_authentication_type",
                                                "virtual_link_cost",
                                                "virtual_link_dc_bitless_lsa",
                                                "virtual_link_dead_interval",
                                                "virtual_link_demand_circuit",
                                                "virtual_link_hello_interval",
                                                "virtual_link_hello_interval_ms",
                                                "virtual_link_interface_name",
                                                "virtual_link_keychain_id",
                                                "virtual_link_last_nsf",
                                                "virtual_link_name_xr",
                                                "virtual_link_neighbor_id",
                                                "virtual_link_next_hello",
                                                "virtual_link_next_hello_ms",
                                                "virtual_link_nsf",
                                                "virtual_link_nsf_enabled",
                                                "virtual_link_old_md_key_count",
                                                "virtual_link_passive",
                                                "virtual_link_state",
                                                "virtual_link_wait_interval",
                                                "virtual_link_youngest_md_key",
                                                "virtual_link_youngest_md_key_id",
                                                "virual_link_transmission_delay") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink, self).__setattr__(name, value)


                            class VirtualLinkNeighbor(Entity):
                                """
                                Neighbor information
                                
                                .. attribute:: virtual_link_retransmissoin
                                
                                	Neighbor retransmission info
                                	**type**\:   :py:class:`VirtualLinkRetransmissoin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin>`
                                
                                .. attribute:: virtual_link_state
                                
                                	Adjacency state
                                	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                
                                .. attribute:: virtual_link_suppress_hello
                                
                                	If true Hellos suppressed
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor, self).__init__()

                                    self.yang_name = "virtual-link-neighbor"
                                    self.yang_parent_name = "virtual-link"

                                    self.virtual_link_state = YLeaf(YType.enumeration, "virtual-link-state")

                                    self.virtual_link_suppress_hello = YLeaf(YType.boolean, "virtual-link-suppress-hello")

                                    self.virtual_link_retransmissoin = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin()
                                    self.virtual_link_retransmissoin.parent = self
                                    self._children_name_map["virtual_link_retransmissoin"] = "virtual-link-retransmissoin"
                                    self._children_yang_names.add("virtual-link-retransmissoin")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("virtual_link_state",
                                                    "virtual_link_suppress_hello") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor, self).__setattr__(name, value)


                                class VirtualLinkRetransmissoin(Entity):
                                    """
                                    Neighbor retransmission info
                                    
                                    .. attribute:: area_first_flood_information
                                    
                                    	First flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood_information_index
                                    
                                    	Index of the first flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_flooding_index
                                    
                                    	Area scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_information
                                    
                                    	Next flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_information_index
                                    
                                    	Index of next flood item for Area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_information
                                    
                                    	First flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_information_index
                                    
                                    	Index for first flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_flood_index
                                    
                                    	AS scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_information
                                    
                                    	Next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_information_index
                                    
                                    	Index of next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dbd_retransmission_count
                                    
                                    	Number of DBD retransmissions during last exchange
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dbd_retransmission_total_count
                                    
                                    	Total number of DBD retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_length
                                    
                                    	Number of LSAs sent in last retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_time
                                    
                                    	Last retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_retransmission_timer
                                    
                                    	Time until next LSA retransmission (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_length
                                    
                                    	Maximum number of LSAs sent in a retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_time
                                    
                                    	Maximum retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmission_count
                                    
                                    	Retransmission queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_retransmissions
                                    
                                    	Number of retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin, self).__init__()

                                        self.yang_name = "virtual-link-retransmissoin"
                                        self.yang_parent_name = "virtual-link-neighbor"

                                        self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                        self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                        self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                        self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                        self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                        self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                        self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                        self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                        self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                        self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                        self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                        self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                        self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                        self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                        self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                        self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                        self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                        self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                        self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("area_first_flood_information",
                                                        "area_first_flood_information_index",
                                                        "area_flooding_index",
                                                        "area_next_flood_information",
                                                        "area_next_flood_information_index",
                                                        "as_first_flood_information",
                                                        "as_first_flood_information_index",
                                                        "as_flood_index",
                                                        "as_next_flood_information",
                                                        "as_next_flood_information_index",
                                                        "dbd_retransmission_count",
                                                        "dbd_retransmission_total_count",
                                                        "last_retransmission_length",
                                                        "last_retransmission_time",
                                                        "lsa_retransmission_timer",
                                                        "maximum_retransmission_length",
                                                        "maximum_retransmission_time",
                                                        "neighbor_retransmission_count",
                                                        "number_of_retransmissions") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.area_first_flood_information.is_set or
                                            self.area_first_flood_information_index.is_set or
                                            self.area_flooding_index.is_set or
                                            self.area_next_flood_information.is_set or
                                            self.area_next_flood_information_index.is_set or
                                            self.as_first_flood_information.is_set or
                                            self.as_first_flood_information_index.is_set or
                                            self.as_flood_index.is_set or
                                            self.as_next_flood_information.is_set or
                                            self.as_next_flood_information_index.is_set or
                                            self.dbd_retransmission_count.is_set or
                                            self.dbd_retransmission_total_count.is_set or
                                            self.last_retransmission_length.is_set or
                                            self.last_retransmission_time.is_set or
                                            self.lsa_retransmission_timer.is_set or
                                            self.maximum_retransmission_length.is_set or
                                            self.maximum_retransmission_time.is_set or
                                            self.neighbor_retransmission_count.is_set or
                                            self.number_of_retransmissions.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.area_first_flood_information.yfilter != YFilter.not_set or
                                            self.area_first_flood_information_index.yfilter != YFilter.not_set or
                                            self.area_flooding_index.yfilter != YFilter.not_set or
                                            self.area_next_flood_information.yfilter != YFilter.not_set or
                                            self.area_next_flood_information_index.yfilter != YFilter.not_set or
                                            self.as_first_flood_information.yfilter != YFilter.not_set or
                                            self.as_first_flood_information_index.yfilter != YFilter.not_set or
                                            self.as_flood_index.yfilter != YFilter.not_set or
                                            self.as_next_flood_information.yfilter != YFilter.not_set or
                                            self.as_next_flood_information_index.yfilter != YFilter.not_set or
                                            self.dbd_retransmission_count.yfilter != YFilter.not_set or
                                            self.dbd_retransmission_total_count.yfilter != YFilter.not_set or
                                            self.last_retransmission_length.yfilter != YFilter.not_set or
                                            self.last_retransmission_time.yfilter != YFilter.not_set or
                                            self.lsa_retransmission_timer.yfilter != YFilter.not_set or
                                            self.maximum_retransmission_length.yfilter != YFilter.not_set or
                                            self.maximum_retransmission_time.yfilter != YFilter.not_set or
                                            self.neighbor_retransmission_count.yfilter != YFilter.not_set or
                                            self.number_of_retransmissions.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "virtual-link-retransmissoin" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.area_first_flood_information.is_set or self.area_first_flood_information.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_first_flood_information.get_name_leafdata())
                                        if (self.area_first_flood_information_index.is_set or self.area_first_flood_information_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_first_flood_information_index.get_name_leafdata())
                                        if (self.area_flooding_index.is_set or self.area_flooding_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_flooding_index.get_name_leafdata())
                                        if (self.area_next_flood_information.is_set or self.area_next_flood_information.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_next_flood_information.get_name_leafdata())
                                        if (self.area_next_flood_information_index.is_set or self.area_next_flood_information_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_next_flood_information_index.get_name_leafdata())
                                        if (self.as_first_flood_information.is_set or self.as_first_flood_information.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_first_flood_information.get_name_leafdata())
                                        if (self.as_first_flood_information_index.is_set or self.as_first_flood_information_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_first_flood_information_index.get_name_leafdata())
                                        if (self.as_flood_index.is_set or self.as_flood_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_flood_index.get_name_leafdata())
                                        if (self.as_next_flood_information.is_set or self.as_next_flood_information.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_next_flood_information.get_name_leafdata())
                                        if (self.as_next_flood_information_index.is_set or self.as_next_flood_information_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_next_flood_information_index.get_name_leafdata())
                                        if (self.dbd_retransmission_count.is_set or self.dbd_retransmission_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dbd_retransmission_count.get_name_leafdata())
                                        if (self.dbd_retransmission_total_count.is_set or self.dbd_retransmission_total_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dbd_retransmission_total_count.get_name_leafdata())
                                        if (self.last_retransmission_length.is_set or self.last_retransmission_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_retransmission_length.get_name_leafdata())
                                        if (self.last_retransmission_time.is_set or self.last_retransmission_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_retransmission_time.get_name_leafdata())
                                        if (self.lsa_retransmission_timer.is_set or self.lsa_retransmission_timer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_retransmission_timer.get_name_leafdata())
                                        if (self.maximum_retransmission_length.is_set or self.maximum_retransmission_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_retransmission_length.get_name_leafdata())
                                        if (self.maximum_retransmission_time.is_set or self.maximum_retransmission_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_retransmission_time.get_name_leafdata())
                                        if (self.neighbor_retransmission_count.is_set or self.neighbor_retransmission_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_retransmission_count.get_name_leafdata())
                                        if (self.number_of_retransmissions.is_set or self.number_of_retransmissions.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number_of_retransmissions.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "area-first-flood-information" or name == "area-first-flood-information-index" or name == "area-flooding-index" or name == "area-next-flood-information" or name == "area-next-flood-information-index" or name == "as-first-flood-information" or name == "as-first-flood-information-index" or name == "as-flood-index" or name == "as-next-flood-information" or name == "as-next-flood-information-index" or name == "dbd-retransmission-count" or name == "dbd-retransmission-total-count" or name == "last-retransmission-length" or name == "last-retransmission-time" or name == "lsa-retransmission-timer" or name == "maximum-retransmission-length" or name == "maximum-retransmission-time" or name == "neighbor-retransmission-count" or name == "number-of-retransmissions"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "area-first-flood-information"):
                                            self.area_first_flood_information = value
                                            self.area_first_flood_information.value_namespace = name_space
                                            self.area_first_flood_information.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-first-flood-information-index"):
                                            self.area_first_flood_information_index = value
                                            self.area_first_flood_information_index.value_namespace = name_space
                                            self.area_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-flooding-index"):
                                            self.area_flooding_index = value
                                            self.area_flooding_index.value_namespace = name_space
                                            self.area_flooding_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-next-flood-information"):
                                            self.area_next_flood_information = value
                                            self.area_next_flood_information.value_namespace = name_space
                                            self.area_next_flood_information.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-next-flood-information-index"):
                                            self.area_next_flood_information_index = value
                                            self.area_next_flood_information_index.value_namespace = name_space
                                            self.area_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-first-flood-information"):
                                            self.as_first_flood_information = value
                                            self.as_first_flood_information.value_namespace = name_space
                                            self.as_first_flood_information.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-first-flood-information-index"):
                                            self.as_first_flood_information_index = value
                                            self.as_first_flood_information_index.value_namespace = name_space
                                            self.as_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-flood-index"):
                                            self.as_flood_index = value
                                            self.as_flood_index.value_namespace = name_space
                                            self.as_flood_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-next-flood-information"):
                                            self.as_next_flood_information = value
                                            self.as_next_flood_information.value_namespace = name_space
                                            self.as_next_flood_information.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-next-flood-information-index"):
                                            self.as_next_flood_information_index = value
                                            self.as_next_flood_information_index.value_namespace = name_space
                                            self.as_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dbd-retransmission-count"):
                                            self.dbd_retransmission_count = value
                                            self.dbd_retransmission_count.value_namespace = name_space
                                            self.dbd_retransmission_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dbd-retransmission-total-count"):
                                            self.dbd_retransmission_total_count = value
                                            self.dbd_retransmission_total_count.value_namespace = name_space
                                            self.dbd_retransmission_total_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-retransmission-length"):
                                            self.last_retransmission_length = value
                                            self.last_retransmission_length.value_namespace = name_space
                                            self.last_retransmission_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-retransmission-time"):
                                            self.last_retransmission_time = value
                                            self.last_retransmission_time.value_namespace = name_space
                                            self.last_retransmission_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-retransmission-timer"):
                                            self.lsa_retransmission_timer = value
                                            self.lsa_retransmission_timer.value_namespace = name_space
                                            self.lsa_retransmission_timer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-retransmission-length"):
                                            self.maximum_retransmission_length = value
                                            self.maximum_retransmission_length.value_namespace = name_space
                                            self.maximum_retransmission_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-retransmission-time"):
                                            self.maximum_retransmission_time = value
                                            self.maximum_retransmission_time.value_namespace = name_space
                                            self.maximum_retransmission_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-retransmission-count"):
                                            self.neighbor_retransmission_count = value
                                            self.neighbor_retransmission_count.value_namespace = name_space
                                            self.neighbor_retransmission_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "number-of-retransmissions"):
                                            self.number_of_retransmissions = value
                                            self.number_of_retransmissions.value_namespace = name_space
                                            self.number_of_retransmissions.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.virtual_link_state.is_set or
                                        self.virtual_link_suppress_hello.is_set or
                                        (self.virtual_link_retransmissoin is not None and self.virtual_link_retransmissoin.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.virtual_link_state.yfilter != YFilter.not_set or
                                        self.virtual_link_suppress_hello.yfilter != YFilter.not_set or
                                        (self.virtual_link_retransmissoin is not None and self.virtual_link_retransmissoin.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "virtual-link-neighbor" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.virtual_link_state.is_set or self.virtual_link_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_state.get_name_leafdata())
                                    if (self.virtual_link_suppress_hello.is_set or self.virtual_link_suppress_hello.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_link_suppress_hello.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "virtual-link-retransmissoin"):
                                        if (self.virtual_link_retransmissoin is None):
                                            self.virtual_link_retransmissoin = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin()
                                            self.virtual_link_retransmissoin.parent = self
                                            self._children_name_map["virtual_link_retransmissoin"] = "virtual-link-retransmissoin"
                                        return self.virtual_link_retransmissoin

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "virtual-link-retransmissoin" or name == "virtual-link-state" or name == "virtual-link-suppress-hello"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "virtual-link-state"):
                                        self.virtual_link_state = value
                                        self.virtual_link_state.value_namespace = name_space
                                        self.virtual_link_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-link-suppress-hello"):
                                        self.virtual_link_suppress_hello = value
                                        self.virtual_link_suppress_hello.value_namespace = name_space
                                        self.virtual_link_suppress_hello.value_namespace_prefix = name_space_prefix


                            class VirtualLinkMdKey(Entity):
                                """
                                List of old MD keys (if any)
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey, self).__init__()

                                    self.yang_name = "virtual-link-md-key"
                                    self.yang_parent_name = "virtual-link"

                                    self.entry = YLeaf(YType.uint16, "entry")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("entry") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.entry.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.entry.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "virtual-link-md-key" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "entry"):
                                        self.entry = value
                                        self.entry.value_namespace = name_space
                                        self.entry.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.virtual_link_md_key:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.virtual_link_name.is_set or
                                    self.transit_area.is_set or
                                    self.virtaul_link_retransmission_interval.is_set or
                                    self.virtual_link_authentication_type.is_set or
                                    self.virtual_link_cost.is_set or
                                    self.virtual_link_dc_bitless_lsa.is_set or
                                    self.virtual_link_dead_interval.is_set or
                                    self.virtual_link_demand_circuit.is_set or
                                    self.virtual_link_hello_interval.is_set or
                                    self.virtual_link_hello_interval_ms.is_set or
                                    self.virtual_link_interface_name.is_set or
                                    self.virtual_link_keychain_id.is_set or
                                    self.virtual_link_last_nsf.is_set or
                                    self.virtual_link_name_xr.is_set or
                                    self.virtual_link_neighbor_id.is_set or
                                    self.virtual_link_next_hello.is_set or
                                    self.virtual_link_next_hello_ms.is_set or
                                    self.virtual_link_nsf.is_set or
                                    self.virtual_link_nsf_enabled.is_set or
                                    self.virtual_link_old_md_key_count.is_set or
                                    self.virtual_link_passive.is_set or
                                    self.virtual_link_state.is_set or
                                    self.virtual_link_wait_interval.is_set or
                                    self.virtual_link_youngest_md_key.is_set or
                                    self.virtual_link_youngest_md_key_id.is_set or
                                    self.virual_link_transmission_delay.is_set or
                                    (self.virtual_link_neighbor is not None and self.virtual_link_neighbor.has_data()))

                            def has_operation(self):
                                for c in self.virtual_link_md_key:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.virtual_link_name.yfilter != YFilter.not_set or
                                    self.transit_area.yfilter != YFilter.not_set or
                                    self.virtaul_link_retransmission_interval.yfilter != YFilter.not_set or
                                    self.virtual_link_authentication_type.yfilter != YFilter.not_set or
                                    self.virtual_link_cost.yfilter != YFilter.not_set or
                                    self.virtual_link_dc_bitless_lsa.yfilter != YFilter.not_set or
                                    self.virtual_link_dead_interval.yfilter != YFilter.not_set or
                                    self.virtual_link_demand_circuit.yfilter != YFilter.not_set or
                                    self.virtual_link_hello_interval.yfilter != YFilter.not_set or
                                    self.virtual_link_hello_interval_ms.yfilter != YFilter.not_set or
                                    self.virtual_link_interface_name.yfilter != YFilter.not_set or
                                    self.virtual_link_keychain_id.yfilter != YFilter.not_set or
                                    self.virtual_link_last_nsf.yfilter != YFilter.not_set or
                                    self.virtual_link_name_xr.yfilter != YFilter.not_set or
                                    self.virtual_link_neighbor_id.yfilter != YFilter.not_set or
                                    self.virtual_link_next_hello.yfilter != YFilter.not_set or
                                    self.virtual_link_next_hello_ms.yfilter != YFilter.not_set or
                                    self.virtual_link_nsf.yfilter != YFilter.not_set or
                                    self.virtual_link_nsf_enabled.yfilter != YFilter.not_set or
                                    self.virtual_link_old_md_key_count.yfilter != YFilter.not_set or
                                    self.virtual_link_passive.yfilter != YFilter.not_set or
                                    self.virtual_link_state.yfilter != YFilter.not_set or
                                    self.virtual_link_wait_interval.yfilter != YFilter.not_set or
                                    self.virtual_link_youngest_md_key.yfilter != YFilter.not_set or
                                    self.virtual_link_youngest_md_key_id.yfilter != YFilter.not_set or
                                    self.virual_link_transmission_delay.yfilter != YFilter.not_set or
                                    (self.virtual_link_neighbor is not None and self.virtual_link_neighbor.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "virtual-link" + "[virtual-link-name='" + self.virtual_link_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.virtual_link_name.is_set or self.virtual_link_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_name.get_name_leafdata())
                                if (self.transit_area.is_set or self.transit_area.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transit_area.get_name_leafdata())
                                if (self.virtaul_link_retransmission_interval.is_set or self.virtaul_link_retransmission_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtaul_link_retransmission_interval.get_name_leafdata())
                                if (self.virtual_link_authentication_type.is_set or self.virtual_link_authentication_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_authentication_type.get_name_leafdata())
                                if (self.virtual_link_cost.is_set or self.virtual_link_cost.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_cost.get_name_leafdata())
                                if (self.virtual_link_dc_bitless_lsa.is_set or self.virtual_link_dc_bitless_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_dc_bitless_lsa.get_name_leafdata())
                                if (self.virtual_link_dead_interval.is_set or self.virtual_link_dead_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_dead_interval.get_name_leafdata())
                                if (self.virtual_link_demand_circuit.is_set or self.virtual_link_demand_circuit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_demand_circuit.get_name_leafdata())
                                if (self.virtual_link_hello_interval.is_set or self.virtual_link_hello_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_hello_interval.get_name_leafdata())
                                if (self.virtual_link_hello_interval_ms.is_set or self.virtual_link_hello_interval_ms.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_hello_interval_ms.get_name_leafdata())
                                if (self.virtual_link_interface_name.is_set or self.virtual_link_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_interface_name.get_name_leafdata())
                                if (self.virtual_link_keychain_id.is_set or self.virtual_link_keychain_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_keychain_id.get_name_leafdata())
                                if (self.virtual_link_last_nsf.is_set or self.virtual_link_last_nsf.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_last_nsf.get_name_leafdata())
                                if (self.virtual_link_name_xr.is_set or self.virtual_link_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_name_xr.get_name_leafdata())
                                if (self.virtual_link_neighbor_id.is_set or self.virtual_link_neighbor_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_neighbor_id.get_name_leafdata())
                                if (self.virtual_link_next_hello.is_set or self.virtual_link_next_hello.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_next_hello.get_name_leafdata())
                                if (self.virtual_link_next_hello_ms.is_set or self.virtual_link_next_hello_ms.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_next_hello_ms.get_name_leafdata())
                                if (self.virtual_link_nsf.is_set or self.virtual_link_nsf.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_nsf.get_name_leafdata())
                                if (self.virtual_link_nsf_enabled.is_set or self.virtual_link_nsf_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_nsf_enabled.get_name_leafdata())
                                if (self.virtual_link_old_md_key_count.is_set or self.virtual_link_old_md_key_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_old_md_key_count.get_name_leafdata())
                                if (self.virtual_link_passive.is_set or self.virtual_link_passive.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_passive.get_name_leafdata())
                                if (self.virtual_link_state.is_set or self.virtual_link_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_state.get_name_leafdata())
                                if (self.virtual_link_wait_interval.is_set or self.virtual_link_wait_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_wait_interval.get_name_leafdata())
                                if (self.virtual_link_youngest_md_key.is_set or self.virtual_link_youngest_md_key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_youngest_md_key.get_name_leafdata())
                                if (self.virtual_link_youngest_md_key_id.is_set or self.virtual_link_youngest_md_key_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virtual_link_youngest_md_key_id.get_name_leafdata())
                                if (self.virual_link_transmission_delay.is_set or self.virual_link_transmission_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.virual_link_transmission_delay.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "virtual-link-md-key"):
                                    for c in self.virtual_link_md_key:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.virtual_link_md_key.append(c)
                                    return c

                                if (child_yang_name == "virtual-link-neighbor"):
                                    if (self.virtual_link_neighbor is None):
                                        self.virtual_link_neighbor = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor()
                                        self.virtual_link_neighbor.parent = self
                                        self._children_name_map["virtual_link_neighbor"] = "virtual-link-neighbor"
                                    return self.virtual_link_neighbor

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "virtual-link-md-key" or name == "virtual-link-neighbor" or name == "virtual-link-name" or name == "transit-area" or name == "virtaul-link-retransmission-interval" or name == "virtual-link-authentication-type" or name == "virtual-link-cost" or name == "virtual-link-dc-bitless-lsa" or name == "virtual-link-dead-interval" or name == "virtual-link-demand-circuit" or name == "virtual-link-hello-interval" or name == "virtual-link-hello-interval-ms" or name == "virtual-link-interface-name" or name == "virtual-link-keychain-id" or name == "virtual-link-last-nsf" or name == "virtual-link-name-xr" or name == "virtual-link-neighbor-id" or name == "virtual-link-next-hello" or name == "virtual-link-next-hello-ms" or name == "virtual-link-nsf" or name == "virtual-link-nsf-enabled" or name == "virtual-link-old-md-key-count" or name == "virtual-link-passive" or name == "virtual-link-state" or name == "virtual-link-wait-interval" or name == "virtual-link-youngest-md-key" or name == "virtual-link-youngest-md-key-id" or name == "virual-link-transmission-delay"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "virtual-link-name"):
                                    self.virtual_link_name = value
                                    self.virtual_link_name.value_namespace = name_space
                                    self.virtual_link_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "transit-area"):
                                    self.transit_area = value
                                    self.transit_area.value_namespace = name_space
                                    self.transit_area.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtaul-link-retransmission-interval"):
                                    self.virtaul_link_retransmission_interval = value
                                    self.virtaul_link_retransmission_interval.value_namespace = name_space
                                    self.virtaul_link_retransmission_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-authentication-type"):
                                    self.virtual_link_authentication_type = value
                                    self.virtual_link_authentication_type.value_namespace = name_space
                                    self.virtual_link_authentication_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-cost"):
                                    self.virtual_link_cost = value
                                    self.virtual_link_cost.value_namespace = name_space
                                    self.virtual_link_cost.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-dc-bitless-lsa"):
                                    self.virtual_link_dc_bitless_lsa = value
                                    self.virtual_link_dc_bitless_lsa.value_namespace = name_space
                                    self.virtual_link_dc_bitless_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-dead-interval"):
                                    self.virtual_link_dead_interval = value
                                    self.virtual_link_dead_interval.value_namespace = name_space
                                    self.virtual_link_dead_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-demand-circuit"):
                                    self.virtual_link_demand_circuit = value
                                    self.virtual_link_demand_circuit.value_namespace = name_space
                                    self.virtual_link_demand_circuit.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-hello-interval"):
                                    self.virtual_link_hello_interval = value
                                    self.virtual_link_hello_interval.value_namespace = name_space
                                    self.virtual_link_hello_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-hello-interval-ms"):
                                    self.virtual_link_hello_interval_ms = value
                                    self.virtual_link_hello_interval_ms.value_namespace = name_space
                                    self.virtual_link_hello_interval_ms.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-interface-name"):
                                    self.virtual_link_interface_name = value
                                    self.virtual_link_interface_name.value_namespace = name_space
                                    self.virtual_link_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-keychain-id"):
                                    self.virtual_link_keychain_id = value
                                    self.virtual_link_keychain_id.value_namespace = name_space
                                    self.virtual_link_keychain_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-last-nsf"):
                                    self.virtual_link_last_nsf = value
                                    self.virtual_link_last_nsf.value_namespace = name_space
                                    self.virtual_link_last_nsf.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-name-xr"):
                                    self.virtual_link_name_xr = value
                                    self.virtual_link_name_xr.value_namespace = name_space
                                    self.virtual_link_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-neighbor-id"):
                                    self.virtual_link_neighbor_id = value
                                    self.virtual_link_neighbor_id.value_namespace = name_space
                                    self.virtual_link_neighbor_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-next-hello"):
                                    self.virtual_link_next_hello = value
                                    self.virtual_link_next_hello.value_namespace = name_space
                                    self.virtual_link_next_hello.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-next-hello-ms"):
                                    self.virtual_link_next_hello_ms = value
                                    self.virtual_link_next_hello_ms.value_namespace = name_space
                                    self.virtual_link_next_hello_ms.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-nsf"):
                                    self.virtual_link_nsf = value
                                    self.virtual_link_nsf.value_namespace = name_space
                                    self.virtual_link_nsf.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-nsf-enabled"):
                                    self.virtual_link_nsf_enabled = value
                                    self.virtual_link_nsf_enabled.value_namespace = name_space
                                    self.virtual_link_nsf_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-old-md-key-count"):
                                    self.virtual_link_old_md_key_count = value
                                    self.virtual_link_old_md_key_count.value_namespace = name_space
                                    self.virtual_link_old_md_key_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-passive"):
                                    self.virtual_link_passive = value
                                    self.virtual_link_passive.value_namespace = name_space
                                    self.virtual_link_passive.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-state"):
                                    self.virtual_link_state = value
                                    self.virtual_link_state.value_namespace = name_space
                                    self.virtual_link_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-wait-interval"):
                                    self.virtual_link_wait_interval = value
                                    self.virtual_link_wait_interval.value_namespace = name_space
                                    self.virtual_link_wait_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-youngest-md-key"):
                                    self.virtual_link_youngest_md_key = value
                                    self.virtual_link_youngest_md_key.value_namespace = name_space
                                    self.virtual_link_youngest_md_key.value_namespace_prefix = name_space_prefix
                                if(value_path == "virtual-link-youngest-md-key-id"):
                                    self.virtual_link_youngest_md_key_id = value
                                    self.virtual_link_youngest_md_key_id.value_namespace = name_space
                                    self.virtual_link_youngest_md_key_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "virual-link-transmission-delay"):
                                    self.virual_link_transmission_delay = value
                                    self.virual_link_transmission_delay.value_namespace = name_space
                                    self.virual_link_transmission_delay.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.virtual_link:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.virtual_link:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "virtual-links" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "virtual-link"):
                                for c in self.virtual_link:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.virtual_link.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "virtual-link"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class InterfaceBriefs(Entity):
                        """
                        OSPF Interface Brief Table
                        
                        .. attribute:: interface_brief
                        
                        	OSPF interface brief information
                        	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs, self).__init__()

                            self.yang_name = "interface-briefs"
                            self.yang_parent_name = "interface-information"

                            self.interface_brief = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs, self).__setattr__(name, value)


                        class InterfaceBrief(Entity):
                            """
                            OSPF interface brief information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: interface_address
                            
                            	Interface IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_adj_neighbor_count
                            
                            	Total number of Adjacent Neighbors
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_area
                            
                            	Area ID string in decimal or dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: interface_fast_detect_hold_down
                            
                            	Interface in fast detect hold down state
                            	**type**\:  bool
                            
                            .. attribute:: interface_link_cost
                            
                            	Interface link cost
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_madj
                            
                            	Information for multi\-area on the interface
                            	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj>`
                            
                            .. attribute:: interface_madj_count
                            
                            	Total number of multi\-area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_mask
                            
                            	Interface IP Mask
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: interface_neighbor_count
                            
                            	Total number of Neighbors
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interfaceis_madj
                            
                            	If true, interface is multi\-area
                            	**type**\:  bool
                            
                            .. attribute:: ospf_interface_state
                            
                            	Interface OSPF state
                            	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief, self).__init__()

                                self.yang_name = "interface-brief"
                                self.yang_parent_name = "interface-briefs"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.interface_address = YLeaf(YType.str, "interface-address")

                                self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                self.interface_area = YLeaf(YType.str, "interface-area")

                                self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                self.interface_madj = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "interface_address",
                                                "interface_adj_neighbor_count",
                                                "interface_area",
                                                "interface_fast_detect_hold_down",
                                                "interface_link_cost",
                                                "interface_madj_count",
                                                "interface_mask",
                                                "interface_name_xr",
                                                "interface_neighbor_count",
                                                "interfaceis_madj",
                                                "ospf_interface_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief, self).__setattr__(name, value)


                            class InterfaceMadj(Entity):
                                """
                                Information for multi\-area on the interface
                                
                                .. attribute:: interface_adj_neighbor_count
                                
                                	Total number of Adjacent Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_area
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_neighbor_count
                                
                                	Number of Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: madj_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__init__()

                                    self.yang_name = "interface-madj"
                                    self.yang_parent_name = "interface-brief"

                                    self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                    self.interface_area = YLeaf(YType.str, "interface-area")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                    self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_adj_neighbor_count",
                                                    "interface_area",
                                                    "interface_link_cost",
                                                    "interface_neighbor_count",
                                                    "madj_area_id",
                                                    "ospf_interface_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.interface_adj_neighbor_count.is_set or
                                        self.interface_area.is_set or
                                        self.interface_link_cost.is_set or
                                        self.interface_neighbor_count.is_set or
                                        self.madj_area_id.is_set or
                                        self.ospf_interface_state.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_adj_neighbor_count.yfilter != YFilter.not_set or
                                        self.interface_area.yfilter != YFilter.not_set or
                                        self.interface_link_cost.yfilter != YFilter.not_set or
                                        self.interface_neighbor_count.yfilter != YFilter.not_set or
                                        self.madj_area_id.yfilter != YFilter.not_set or
                                        self.ospf_interface_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface-madj" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_adj_neighbor_count.is_set or self.interface_adj_neighbor_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_adj_neighbor_count.get_name_leafdata())
                                    if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_area.get_name_leafdata())
                                    if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                    if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                    if (self.madj_area_id.is_set or self.madj_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.madj_area_id.get_name_leafdata())
                                    if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-adj-neighbor-count" or name == "interface-area" or name == "interface-link-cost" or name == "interface-neighbor-count" or name == "madj-area-id" or name == "ospf-interface-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-adj-neighbor-count"):
                                        self.interface_adj_neighbor_count = value
                                        self.interface_adj_neighbor_count.value_namespace = name_space
                                        self.interface_adj_neighbor_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-area"):
                                        self.interface_area = value
                                        self.interface_area.value_namespace = name_space
                                        self.interface_area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-link-cost"):
                                        self.interface_link_cost = value
                                        self.interface_link_cost.value_namespace = name_space
                                        self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-neighbor-count"):
                                        self.interface_neighbor_count = value
                                        self.interface_neighbor_count.value_namespace = name_space
                                        self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "madj-area-id"):
                                        self.madj_area_id = value
                                        self.madj_area_id.value_namespace = name_space
                                        self.madj_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-interface-state"):
                                        self.ospf_interface_state = value
                                        self.ospf_interface_state.value_namespace = name_space
                                        self.ospf_interface_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface_madj:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.interface_name.is_set or
                                    self.interface_address.is_set or
                                    self.interface_adj_neighbor_count.is_set or
                                    self.interface_area.is_set or
                                    self.interface_fast_detect_hold_down.is_set or
                                    self.interface_link_cost.is_set or
                                    self.interface_madj_count.is_set or
                                    self.interface_mask.is_set or
                                    self.interface_name_xr.is_set or
                                    self.interface_neighbor_count.is_set or
                                    self.interfaceis_madj.is_set or
                                    self.ospf_interface_state.is_set)

                            def has_operation(self):
                                for c in self.interface_madj:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.interface_address.yfilter != YFilter.not_set or
                                    self.interface_adj_neighbor_count.yfilter != YFilter.not_set or
                                    self.interface_area.yfilter != YFilter.not_set or
                                    self.interface_fast_detect_hold_down.yfilter != YFilter.not_set or
                                    self.interface_link_cost.yfilter != YFilter.not_set or
                                    self.interface_madj_count.yfilter != YFilter.not_set or
                                    self.interface_mask.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.interface_neighbor_count.yfilter != YFilter.not_set or
                                    self.interfaceis_madj.yfilter != YFilter.not_set or
                                    self.ospf_interface_state.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-brief" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.interface_address.is_set or self.interface_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_address.get_name_leafdata())
                                if (self.interface_adj_neighbor_count.is_set or self.interface_adj_neighbor_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_adj_neighbor_count.get_name_leafdata())
                                if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_area.get_name_leafdata())
                                if (self.interface_fast_detect_hold_down.is_set or self.interface_fast_detect_hold_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_fast_detect_hold_down.get_name_leafdata())
                                if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                if (self.interface_madj_count.is_set or self.interface_madj_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_madj_count.get_name_leafdata())
                                if (self.interface_mask.is_set or self.interface_mask.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_mask.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                if (self.interfaceis_madj.is_set or self.interfaceis_madj.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interfaceis_madj.get_name_leafdata())
                                if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface-madj"):
                                    for c in self.interface_madj:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface_madj.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-madj" or name == "interface-name" or name == "interface-address" or name == "interface-adj-neighbor-count" or name == "interface-area" or name == "interface-fast-detect-hold-down" or name == "interface-link-cost" or name == "interface-madj-count" or name == "interface-mask" or name == "interface-name-xr" or name == "interface-neighbor-count" or name == "interfaceis-madj" or name == "ospf-interface-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-address"):
                                    self.interface_address = value
                                    self.interface_address.value_namespace = name_space
                                    self.interface_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-adj-neighbor-count"):
                                    self.interface_adj_neighbor_count = value
                                    self.interface_adj_neighbor_count.value_namespace = name_space
                                    self.interface_adj_neighbor_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-area"):
                                    self.interface_area = value
                                    self.interface_area.value_namespace = name_space
                                    self.interface_area.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-fast-detect-hold-down"):
                                    self.interface_fast_detect_hold_down = value
                                    self.interface_fast_detect_hold_down.value_namespace = name_space
                                    self.interface_fast_detect_hold_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-link-cost"):
                                    self.interface_link_cost = value
                                    self.interface_link_cost.value_namespace = name_space
                                    self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-madj-count"):
                                    self.interface_madj_count = value
                                    self.interface_madj_count.value_namespace = name_space
                                    self.interface_madj_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-mask"):
                                    self.interface_mask = value
                                    self.interface_mask.value_namespace = name_space
                                    self.interface_mask.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-neighbor-count"):
                                    self.interface_neighbor_count = value
                                    self.interface_neighbor_count.value_namespace = name_space
                                    self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "interfaceis-madj"):
                                    self.interfaceis_madj = value
                                    self.interfaceis_madj.value_namespace = name_space
                                    self.interfaceis_madj.value_namespace_prefix = name_space_prefix
                                if(value_path == "ospf-interface-state"):
                                    self.ospf_interface_state = value
                                    self.ospf_interface_state.value_namespace = name_space
                                    self.ospf_interface_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_brief:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.interface_brief:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-briefs" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface-brief"):
                                for c in self.interface_brief:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_brief.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-brief"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Interfaces(Entity):
                        """
                        OSPF Interface Table
                        
                        .. attribute:: interface
                        
                        	OSPF interface information
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces, self).__init__()

                            self.yang_name = "interfaces"
                            self.yang_parent_name = "interface-information"

                            self.interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces, self).__setattr__(name, value)


                        class Interface(Entity):
                            """
                            OSPF interface information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: active_interface
                            
                            	Active interface details
                            	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface>`
                            
                            .. attribute:: backup_designated_router
                            
                            	If true, backup designated router
                            	**type**\:  bool
                            
                            .. attribute:: backup_designated_router_address
                            
                            	Backup designated router interface address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: backup_designated_router_id
                            
                            	Backup designated router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cfg_cost_fallback
                            
                            	If true, cost fallback is configured
                            	**type**\:  bool
                            
                            .. attribute:: configured_demand_circuit
                            
                            	If true, configured as demand circuit
                            	**type**\:  bool
                            
                            .. attribute:: configured_ldp_sync
                            
                            	If true, configured as LDP sync
                            	**type**\:  bool
                            
                            .. attribute:: configured_ldp_sync_igp_shortcuts
                            
                            	If true, sync igp shortcuts
                            	**type**\:  bool
                            
                            .. attribute:: cost_fallback_active
                            
                            	If true, cost fallback is active
                            	**type**\:  bool
                            
                            .. attribute:: dead_interval
                            
                            	Configured dead interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: designated_router
                            
                            	If true, designated router
                            	**type**\:  bool
                            
                            .. attribute:: designated_router_address
                            
                            	Designated router interface address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: designated_router_id
                            
                            	Designated router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: fast_detect_hold_down_time
                            
                            	Hold\-down time in ms for fast\-detect event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fast_detect_hold_down_time_remaining
                            
                            	Remaining hold down time in ms
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fast_reroute_topology_independent_lfa
                            
                            	Topology Independent LFA
                            	**type**\:  bool
                            
                            .. attribute:: fast_reroute_type
                            
                            	IP Fast Reroute Type
                            	**type**\:   :py:class:`Ipfrr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ipfrr>`
                            
                            .. attribute:: hello_interval
                            
                            	Configured hello interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: hello_interval_ms
                            
                            	Configured hello interval (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_ack_list_count
                            
                            	Ack List Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_ack_list_high_watermark
                            
                            	Ack List High Watermark
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_address
                            
                            	Interface IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_area
                            
                            	Area ID string in decimal or dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: interface_bandwidth
                            
                            	Interface bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_bfd_information
                            
                            	BFD information
                            	**type**\:   :py:class:`InterfaceBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation>`
                            
                            .. attribute:: interface_cost_fallback
                            
                            	Interface fallback cost
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_dc_bitless_lsa_count
                            
                            	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_demand_circuit
                            
                            	If true, interface running as demand circuit
                            	**type**\:  bool
                            
                            .. attribute:: interface_fast_detect_hold_down
                            
                            	Link in hold\-down state due to fast detect event
                            	**type**\:  bool
                            
                            .. attribute:: interface_last_nsf
                            
                            	Time since last NSF restart (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_ldp_sync
                            
                            	If true, interface LDP sync is achieved
                            	**type**\:  bool
                            
                            .. attribute:: interface_line_state
                            
                            	If true, line protocol is up
                            	**type**\:  bool
                            
                            .. attribute:: interface_link_cost
                            
                            	Interface link cost
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_lsa_filter
                            
                            	Filter is configured for out going LSAs
                            	**type**\:  bool
                            
                            .. attribute:: interface_madj
                            
                            	Information for multi\-area on the interface
                            	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj>`
                            
                            .. attribute:: interface_madj_count
                            
                            	Total number of multi\-area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_mask
                            
                            	Interface IP Mask
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: interface_neighbor
                            
                            	Information for neighbors on the interface
                            	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor>`
                            
                            .. attribute:: interface_nsf
                            
                            	If true, NSF restart in progress on this interface
                            	**type**\:  bool
                            
                            .. attribute:: interface_nsf_enabled
                            
                            	If true, NSF is enabled
                            	**type**\:  bool
                            
                            .. attribute:: interface_priority
                            
                            	Interface priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_retransmission_interrval
                            
                            	Configured retransmit interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_router_id
                            
                            	Interface Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_sid
                            
                            	Interface SID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_sid_n_flag_clear
                            
                            	SID N\-Flag Clear
                            	**type**\:  bool
                            
                            .. attribute:: interface_sid_php_off
                            
                            	SID PHP Off
                            	**type**\:  bool
                            
                            .. attribute:: interface_state
                            
                            	Interface state
                            	**type**\:   :py:class:`InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.InterfaceState>`
                            
                            .. attribute:: interface_strict_spf_sid
                            
                            	Interface Strict\-SPF SID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_strict_spf_sid_n_flag_clear
                            
                            	Strict\-SPF SID N\-Flag Clear
                            	**type**\:  bool
                            
                            .. attribute:: interface_strict_spf_sid_php_off
                            
                            	Strict\-SPF SID PHP Off
                            	**type**\:  bool
                            
                            .. attribute:: interface_tunnel_flags
                            
                            	Interface tunnel flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interfaceis_madj
                            
                            	If true, interface is multi\-area
                            	**type**\:  bool
                            
                            .. attribute:: ip_mtu
                            
                            	IP MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ipfrr_tiebreakers
                            
                            	IPFRR\-Tiebreakers list
                            	**type**\: list of    :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers>`
                            
                            .. attribute:: is_loopback_stub_network
                            
                            	If true, loopback interface is advertised as a stub network
                            	**type**\:  bool
                            
                            .. attribute:: maximum_packet_size
                            
                            	Maximum Packet Size
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: network_lsa_flush_timer
                            
                            	The amount of time in seconds before flush timer for old network LSA expires
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: network_type
                            
                            	Network type
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                            
                            .. attribute:: next_hello_time
                            
                            	Time until next Hello (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hello_time_ms
                            
                            	Time until next Hello (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ospf_interface_state
                            
                            	Interface OSPF state
                            	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                            
                            .. attribute:: passive_interface
                            
                            	If true, passive interface
                            	**type**\:  bool
                            
                            .. attribute:: prefix_suppress_primary_addresses
                            
                            	Prefix Suppression for primary addresses
                            	**type**\:  bool
                            
                            .. attribute:: prefix_suppress_secondary_addresses
                            
                            	Prefix Suppression for secondary addresses
                            	**type**\:  bool
                            
                            .. attribute:: registered_for_link_down_fast_detection
                            
                            	Registered for Link Down Fast Detection
                            	**type**\:  bool
                            
                            .. attribute:: srlg
                            
                            	SRLG Values
                            	**type**\: list of    :py:class:`Srlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.Srlg>`
                            
                            .. attribute:: transmission_delay
                            
                            	Interface Transmission delay
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL security enabled on the interface
                            	**type**\:  bool
                            
                            .. attribute:: ttl_security_hop_count
                            
                            	TTL security hop counts
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wait_interval
                            
                            	Configured wait interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "interfaces"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.backup_designated_router = YLeaf(YType.boolean, "backup-designated-router")

                                self.backup_designated_router_address = YLeaf(YType.str, "backup-designated-router-address")

                                self.backup_designated_router_id = YLeaf(YType.str, "backup-designated-router-id")

                                self.cfg_cost_fallback = YLeaf(YType.boolean, "cfg-cost-fallback")

                                self.configured_demand_circuit = YLeaf(YType.boolean, "configured-demand-circuit")

                                self.configured_ldp_sync = YLeaf(YType.boolean, "configured-ldp-sync")

                                self.configured_ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "configured-ldp-sync-igp-shortcuts")

                                self.cost_fallback_active = YLeaf(YType.boolean, "cost-fallback-active")

                                self.dead_interval = YLeaf(YType.uint32, "dead-interval")

                                self.designated_router = YLeaf(YType.boolean, "designated-router")

                                self.designated_router_address = YLeaf(YType.str, "designated-router-address")

                                self.designated_router_id = YLeaf(YType.str, "designated-router-id")

                                self.fast_detect_hold_down_time = YLeaf(YType.uint32, "fast-detect-hold-down-time")

                                self.fast_detect_hold_down_time_remaining = YLeaf(YType.uint32, "fast-detect-hold-down-time-remaining")

                                self.fast_reroute_topology_independent_lfa = YLeaf(YType.boolean, "fast-reroute-topology-independent-lfa")

                                self.fast_reroute_type = YLeaf(YType.enumeration, "fast-reroute-type")

                                self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                self.hello_interval_ms = YLeaf(YType.uint32, "hello-interval-ms")

                                self.interface_ack_list_count = YLeaf(YType.uint32, "interface-ack-list-count")

                                self.interface_ack_list_high_watermark = YLeaf(YType.uint32, "interface-ack-list-high-watermark")

                                self.interface_address = YLeaf(YType.str, "interface-address")

                                self.interface_area = YLeaf(YType.str, "interface-area")

                                self.interface_bandwidth = YLeaf(YType.uint32, "interface-bandwidth")

                                self.interface_cost_fallback = YLeaf(YType.uint16, "interface-cost-fallback")

                                self.interface_dc_bitless_lsa_count = YLeaf(YType.uint32, "interface-dc-bitless-lsa-count")

                                self.interface_demand_circuit = YLeaf(YType.boolean, "interface-demand-circuit")

                                self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                self.interface_last_nsf = YLeaf(YType.uint32, "interface-last-nsf")

                                self.interface_ldp_sync = YLeaf(YType.boolean, "interface-ldp-sync")

                                self.interface_line_state = YLeaf(YType.boolean, "interface-line-state")

                                self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                self.interface_lsa_filter = YLeaf(YType.boolean, "interface-lsa-filter")

                                self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.interface_nsf = YLeaf(YType.boolean, "interface-nsf")

                                self.interface_nsf_enabled = YLeaf(YType.boolean, "interface-nsf-enabled")

                                self.interface_priority = YLeaf(YType.uint8, "interface-priority")

                                self.interface_retransmission_interrval = YLeaf(YType.uint32, "interface-retransmission-interrval")

                                self.interface_router_id = YLeaf(YType.str, "interface-router-id")

                                self.interface_sid = YLeaf(YType.uint32, "interface-sid")

                                self.interface_sid_n_flag_clear = YLeaf(YType.boolean, "interface-sid-n-flag-clear")

                                self.interface_sid_php_off = YLeaf(YType.boolean, "interface-sid-php-off")

                                self.interface_state = YLeaf(YType.enumeration, "interface-state")

                                self.interface_strict_spf_sid = YLeaf(YType.uint32, "interface-strict-spf-sid")

                                self.interface_strict_spf_sid_n_flag_clear = YLeaf(YType.boolean, "interface-strict-spf-sid-n-flag-clear")

                                self.interface_strict_spf_sid_php_off = YLeaf(YType.boolean, "interface-strict-spf-sid-php-off")

                                self.interface_tunnel_flags = YLeaf(YType.uint32, "interface-tunnel-flags")

                                self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                self.ip_mtu = YLeaf(YType.uint16, "ip-mtu")

                                self.is_loopback_stub_network = YLeaf(YType.boolean, "is-loopback-stub-network")

                                self.maximum_packet_size = YLeaf(YType.uint16, "maximum-packet-size")

                                self.network_lsa_flush_timer = YLeaf(YType.uint32, "network-lsa-flush-timer")

                                self.network_type = YLeaf(YType.enumeration, "network-type")

                                self.next_hello_time = YLeaf(YType.uint32, "next-hello-time")

                                self.next_hello_time_ms = YLeaf(YType.uint32, "next-hello-time-ms")

                                self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                                self.prefix_suppress_primary_addresses = YLeaf(YType.boolean, "prefix-suppress-primary-addresses")

                                self.prefix_suppress_secondary_addresses = YLeaf(YType.boolean, "prefix-suppress-secondary-addresses")

                                self.registered_for_link_down_fast_detection = YLeaf(YType.boolean, "registered-for-link-down-fast-detection")

                                self.transmission_delay = YLeaf(YType.uint16, "transmission-delay")

                                self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                self.ttl_security_hop_count = YLeaf(YType.uint32, "ttl-security-hop-count")

                                self.wait_interval = YLeaf(YType.uint32, "wait-interval")

                                self.active_interface = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface()
                                self.active_interface.parent = self
                                self._children_name_map["active_interface"] = "active-interface"
                                self._children_yang_names.add("active-interface")

                                self.interface_bfd_information = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation()
                                self.interface_bfd_information.parent = self
                                self._children_name_map["interface_bfd_information"] = "interface-bfd-information"
                                self._children_yang_names.add("interface-bfd-information")

                                self.interface_madj = YList(self)
                                self.interface_neighbor = YList(self)
                                self.ipfrr_tiebreakers = YList(self)
                                self.srlg = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "backup_designated_router",
                                                "backup_designated_router_address",
                                                "backup_designated_router_id",
                                                "cfg_cost_fallback",
                                                "configured_demand_circuit",
                                                "configured_ldp_sync",
                                                "configured_ldp_sync_igp_shortcuts",
                                                "cost_fallback_active",
                                                "dead_interval",
                                                "designated_router",
                                                "designated_router_address",
                                                "designated_router_id",
                                                "fast_detect_hold_down_time",
                                                "fast_detect_hold_down_time_remaining",
                                                "fast_reroute_topology_independent_lfa",
                                                "fast_reroute_type",
                                                "hello_interval",
                                                "hello_interval_ms",
                                                "interface_ack_list_count",
                                                "interface_ack_list_high_watermark",
                                                "interface_address",
                                                "interface_area",
                                                "interface_bandwidth",
                                                "interface_cost_fallback",
                                                "interface_dc_bitless_lsa_count",
                                                "interface_demand_circuit",
                                                "interface_fast_detect_hold_down",
                                                "interface_last_nsf",
                                                "interface_ldp_sync",
                                                "interface_line_state",
                                                "interface_link_cost",
                                                "interface_lsa_filter",
                                                "interface_madj_count",
                                                "interface_mask",
                                                "interface_name_xr",
                                                "interface_nsf",
                                                "interface_nsf_enabled",
                                                "interface_priority",
                                                "interface_retransmission_interrval",
                                                "interface_router_id",
                                                "interface_sid",
                                                "interface_sid_n_flag_clear",
                                                "interface_sid_php_off",
                                                "interface_state",
                                                "interface_strict_spf_sid",
                                                "interface_strict_spf_sid_n_flag_clear",
                                                "interface_strict_spf_sid_php_off",
                                                "interface_tunnel_flags",
                                                "interfaceis_madj",
                                                "ip_mtu",
                                                "is_loopback_stub_network",
                                                "maximum_packet_size",
                                                "network_lsa_flush_timer",
                                                "network_type",
                                                "next_hello_time",
                                                "next_hello_time_ms",
                                                "ospf_interface_state",
                                                "passive_interface",
                                                "prefix_suppress_primary_addresses",
                                                "prefix_suppress_secondary_addresses",
                                                "registered_for_link_down_fast_detection",
                                                "transmission_delay",
                                                "ttl_security_enabled",
                                                "ttl_security_hop_count",
                                                "wait_interval") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface, self).__setattr__(name, value)


                            class InterfaceBfdInformation(Entity):
                                """
                                BFD information
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD enable mode \- Default/Strict
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: detection_multiplier
                                
                                	BFD detection multiplier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interval
                                
                                	BFD interval (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation, self).__init__()

                                    self.yang_name = "interface-bfd-information"
                                    self.yang_parent_name = "interface"

                                    self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                    self.interval = YLeaf(YType.uint32, "interval")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bfd_intf_enable_mode",
                                                    "detection_multiplier",
                                                    "interval") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bfd_intf_enable_mode.is_set or
                                        self.detection_multiplier.is_set or
                                        self.interval.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                        self.detection_multiplier.yfilter != YFilter.not_set or
                                        self.interval.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface-bfd-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                    if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                    if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interval.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bfd-intf-enable-mode" or name == "detection-multiplier" or name == "interval"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bfd-intf-enable-mode"):
                                        self.bfd_intf_enable_mode = value
                                        self.bfd_intf_enable_mode.value_namespace = name_space
                                        self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "detection-multiplier"):
                                        self.detection_multiplier = value
                                        self.detection_multiplier.value_namespace = name_space
                                        self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interval"):
                                        self.interval = value
                                        self.interval.value_namespace = name_space
                                        self.interval.value_namespace_prefix = name_space_prefix


                            class ActiveInterface(Entity):
                                """
                                Active interface details
                                
                                .. attribute:: flood_scan_length
                                
                                	Last flood scan length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_flood_index
                                
                                	Area scope LSAs flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_next_flood
                                
                                	Next LSA to flood (Area scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_next_flood_index
                                
                                	Index of next LSA to flood (Area scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_flood_index
                                
                                	AS scope LSAs flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_next_flood
                                
                                	Next LSA to flood (AS scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_next_flood_index
                                
                                	Index of next LSA to flood (AS scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_authentication_type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                
                                .. attribute:: interface_flood_length
                                
                                	Flood queue length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_flood_pacing_timer
                                
                                	Time until next flood pacing timer (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_neighbor_count
                                
                                	Total number of Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: keychain_id
                                
                                	Keychain ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: last_flood_time
                                
                                	Last flood scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_flood_length
                                
                                	Maximum flood length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_flood_time
                                
                                	Maximum flood time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: md_keys
                                
                                	List of old MD keys
                                	**type**\: list of    :py:class:`MdKeys <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys>`
                                
                                .. attribute:: old_md5_key_neighbor_count
                                
                                	Number of neighbors using the old key (if rollover in progress)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: suppress_hello_count
                                
                                	Number of neighbors for which hellos are suppressed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: wait_time
                                
                                	Wait time for DR/BDR selection (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: youngest_md_key
                                
                                	If true, MD key is configured
                                	**type**\:  bool
                                
                                .. attribute:: youngest_md_key_id
                                
                                	Youngest MD key ID
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface, self).__init__()

                                    self.yang_name = "active-interface"
                                    self.yang_parent_name = "interface"

                                    self.flood_scan_length = YLeaf(YType.uint32, "flood-scan-length")

                                    self.interface_area_flood_index = YLeaf(YType.uint32, "interface-area-flood-index")

                                    self.interface_area_next_flood = YLeaf(YType.uint32, "interface-area-next-flood")

                                    self.interface_area_next_flood_index = YLeaf(YType.uint32, "interface-area-next-flood-index")

                                    self.interface_as_flood_index = YLeaf(YType.uint32, "interface-as-flood-index")

                                    self.interface_as_next_flood = YLeaf(YType.uint32, "interface-as-next-flood")

                                    self.interface_as_next_flood_index = YLeaf(YType.uint32, "interface-as-next-flood-index")

                                    self.interface_authentication_type = YLeaf(YType.enumeration, "interface-authentication-type")

                                    self.interface_flood_length = YLeaf(YType.uint32, "interface-flood-length")

                                    self.interface_flood_pacing_timer = YLeaf(YType.uint32, "interface-flood-pacing-timer")

                                    self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                    self.keychain_id = YLeaf(YType.uint64, "keychain-id")

                                    self.last_flood_time = YLeaf(YType.uint32, "last-flood-time")

                                    self.maximum_flood_length = YLeaf(YType.uint32, "maximum-flood-length")

                                    self.maximum_flood_time = YLeaf(YType.uint32, "maximum-flood-time")

                                    self.old_md5_key_neighbor_count = YLeaf(YType.uint32, "old-md5-key-neighbor-count")

                                    self.suppress_hello_count = YLeaf(YType.uint16, "suppress-hello-count")

                                    self.wait_time = YLeaf(YType.uint32, "wait-time")

                                    self.youngest_md_key = YLeaf(YType.boolean, "youngest-md-key")

                                    self.youngest_md_key_id = YLeaf(YType.uint16, "youngest-md-key-id")

                                    self.md_keys = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("flood_scan_length",
                                                    "interface_area_flood_index",
                                                    "interface_area_next_flood",
                                                    "interface_area_next_flood_index",
                                                    "interface_as_flood_index",
                                                    "interface_as_next_flood",
                                                    "interface_as_next_flood_index",
                                                    "interface_authentication_type",
                                                    "interface_flood_length",
                                                    "interface_flood_pacing_timer",
                                                    "interface_neighbor_count",
                                                    "keychain_id",
                                                    "last_flood_time",
                                                    "maximum_flood_length",
                                                    "maximum_flood_time",
                                                    "old_md5_key_neighbor_count",
                                                    "suppress_hello_count",
                                                    "wait_time",
                                                    "youngest_md_key",
                                                    "youngest_md_key_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface, self).__setattr__(name, value)


                                class MdKeys(Entity):
                                    """
                                    List of old MD keys
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys, self).__init__()

                                        self.yang_name = "md-keys"
                                        self.yang_parent_name = "active-interface"

                                        self.entry = YLeaf(YType.uint16, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "md-keys" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.md_keys:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.flood_scan_length.is_set or
                                        self.interface_area_flood_index.is_set or
                                        self.interface_area_next_flood.is_set or
                                        self.interface_area_next_flood_index.is_set or
                                        self.interface_as_flood_index.is_set or
                                        self.interface_as_next_flood.is_set or
                                        self.interface_as_next_flood_index.is_set or
                                        self.interface_authentication_type.is_set or
                                        self.interface_flood_length.is_set or
                                        self.interface_flood_pacing_timer.is_set or
                                        self.interface_neighbor_count.is_set or
                                        self.keychain_id.is_set or
                                        self.last_flood_time.is_set or
                                        self.maximum_flood_length.is_set or
                                        self.maximum_flood_time.is_set or
                                        self.old_md5_key_neighbor_count.is_set or
                                        self.suppress_hello_count.is_set or
                                        self.wait_time.is_set or
                                        self.youngest_md_key.is_set or
                                        self.youngest_md_key_id.is_set)

                                def has_operation(self):
                                    for c in self.md_keys:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.flood_scan_length.yfilter != YFilter.not_set or
                                        self.interface_area_flood_index.yfilter != YFilter.not_set or
                                        self.interface_area_next_flood.yfilter != YFilter.not_set or
                                        self.interface_area_next_flood_index.yfilter != YFilter.not_set or
                                        self.interface_as_flood_index.yfilter != YFilter.not_set or
                                        self.interface_as_next_flood.yfilter != YFilter.not_set or
                                        self.interface_as_next_flood_index.yfilter != YFilter.not_set or
                                        self.interface_authentication_type.yfilter != YFilter.not_set or
                                        self.interface_flood_length.yfilter != YFilter.not_set or
                                        self.interface_flood_pacing_timer.yfilter != YFilter.not_set or
                                        self.interface_neighbor_count.yfilter != YFilter.not_set or
                                        self.keychain_id.yfilter != YFilter.not_set or
                                        self.last_flood_time.yfilter != YFilter.not_set or
                                        self.maximum_flood_length.yfilter != YFilter.not_set or
                                        self.maximum_flood_time.yfilter != YFilter.not_set or
                                        self.old_md5_key_neighbor_count.yfilter != YFilter.not_set or
                                        self.suppress_hello_count.yfilter != YFilter.not_set or
                                        self.wait_time.yfilter != YFilter.not_set or
                                        self.youngest_md_key.yfilter != YFilter.not_set or
                                        self.youngest_md_key_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "active-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.flood_scan_length.is_set or self.flood_scan_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_scan_length.get_name_leafdata())
                                    if (self.interface_area_flood_index.is_set or self.interface_area_flood_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_area_flood_index.get_name_leafdata())
                                    if (self.interface_area_next_flood.is_set or self.interface_area_next_flood.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_area_next_flood.get_name_leafdata())
                                    if (self.interface_area_next_flood_index.is_set or self.interface_area_next_flood_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_area_next_flood_index.get_name_leafdata())
                                    if (self.interface_as_flood_index.is_set or self.interface_as_flood_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_as_flood_index.get_name_leafdata())
                                    if (self.interface_as_next_flood.is_set or self.interface_as_next_flood.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_as_next_flood.get_name_leafdata())
                                    if (self.interface_as_next_flood_index.is_set or self.interface_as_next_flood_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_as_next_flood_index.get_name_leafdata())
                                    if (self.interface_authentication_type.is_set or self.interface_authentication_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_authentication_type.get_name_leafdata())
                                    if (self.interface_flood_length.is_set or self.interface_flood_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_flood_length.get_name_leafdata())
                                    if (self.interface_flood_pacing_timer.is_set or self.interface_flood_pacing_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_flood_pacing_timer.get_name_leafdata())
                                    if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                    if (self.keychain_id.is_set or self.keychain_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.keychain_id.get_name_leafdata())
                                    if (self.last_flood_time.is_set or self.last_flood_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_flood_time.get_name_leafdata())
                                    if (self.maximum_flood_length.is_set or self.maximum_flood_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_flood_length.get_name_leafdata())
                                    if (self.maximum_flood_time.is_set or self.maximum_flood_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_flood_time.get_name_leafdata())
                                    if (self.old_md5_key_neighbor_count.is_set or self.old_md5_key_neighbor_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.old_md5_key_neighbor_count.get_name_leafdata())
                                    if (self.suppress_hello_count.is_set or self.suppress_hello_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_hello_count.get_name_leafdata())
                                    if (self.wait_time.is_set or self.wait_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wait_time.get_name_leafdata())
                                    if (self.youngest_md_key.is_set or self.youngest_md_key.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.youngest_md_key.get_name_leafdata())
                                    if (self.youngest_md_key_id.is_set or self.youngest_md_key_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.youngest_md_key_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "md-keys"):
                                        for c in self.md_keys:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.md_keys.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "md-keys" or name == "flood-scan-length" or name == "interface-area-flood-index" or name == "interface-area-next-flood" or name == "interface-area-next-flood-index" or name == "interface-as-flood-index" or name == "interface-as-next-flood" or name == "interface-as-next-flood-index" or name == "interface-authentication-type" or name == "interface-flood-length" or name == "interface-flood-pacing-timer" or name == "interface-neighbor-count" or name == "keychain-id" or name == "last-flood-time" or name == "maximum-flood-length" or name == "maximum-flood-time" or name == "old-md5-key-neighbor-count" or name == "suppress-hello-count" or name == "wait-time" or name == "youngest-md-key" or name == "youngest-md-key-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "flood-scan-length"):
                                        self.flood_scan_length = value
                                        self.flood_scan_length.value_namespace = name_space
                                        self.flood_scan_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-area-flood-index"):
                                        self.interface_area_flood_index = value
                                        self.interface_area_flood_index.value_namespace = name_space
                                        self.interface_area_flood_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-area-next-flood"):
                                        self.interface_area_next_flood = value
                                        self.interface_area_next_flood.value_namespace = name_space
                                        self.interface_area_next_flood.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-area-next-flood-index"):
                                        self.interface_area_next_flood_index = value
                                        self.interface_area_next_flood_index.value_namespace = name_space
                                        self.interface_area_next_flood_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-as-flood-index"):
                                        self.interface_as_flood_index = value
                                        self.interface_as_flood_index.value_namespace = name_space
                                        self.interface_as_flood_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-as-next-flood"):
                                        self.interface_as_next_flood = value
                                        self.interface_as_next_flood.value_namespace = name_space
                                        self.interface_as_next_flood.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-as-next-flood-index"):
                                        self.interface_as_next_flood_index = value
                                        self.interface_as_next_flood_index.value_namespace = name_space
                                        self.interface_as_next_flood_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-authentication-type"):
                                        self.interface_authentication_type = value
                                        self.interface_authentication_type.value_namespace = name_space
                                        self.interface_authentication_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-flood-length"):
                                        self.interface_flood_length = value
                                        self.interface_flood_length.value_namespace = name_space
                                        self.interface_flood_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-flood-pacing-timer"):
                                        self.interface_flood_pacing_timer = value
                                        self.interface_flood_pacing_timer.value_namespace = name_space
                                        self.interface_flood_pacing_timer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-neighbor-count"):
                                        self.interface_neighbor_count = value
                                        self.interface_neighbor_count.value_namespace = name_space
                                        self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "keychain-id"):
                                        self.keychain_id = value
                                        self.keychain_id.value_namespace = name_space
                                        self.keychain_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-flood-time"):
                                        self.last_flood_time = value
                                        self.last_flood_time.value_namespace = name_space
                                        self.last_flood_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-flood-length"):
                                        self.maximum_flood_length = value
                                        self.maximum_flood_length.value_namespace = name_space
                                        self.maximum_flood_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-flood-time"):
                                        self.maximum_flood_time = value
                                        self.maximum_flood_time.value_namespace = name_space
                                        self.maximum_flood_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "old-md5-key-neighbor-count"):
                                        self.old_md5_key_neighbor_count = value
                                        self.old_md5_key_neighbor_count.value_namespace = name_space
                                        self.old_md5_key_neighbor_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-hello-count"):
                                        self.suppress_hello_count = value
                                        self.suppress_hello_count.value_namespace = name_space
                                        self.suppress_hello_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wait-time"):
                                        self.wait_time = value
                                        self.wait_time.value_namespace = name_space
                                        self.wait_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "youngest-md-key"):
                                        self.youngest_md_key = value
                                        self.youngest_md_key.value_namespace = name_space
                                        self.youngest_md_key.value_namespace_prefix = name_space_prefix
                                    if(value_path == "youngest-md-key-id"):
                                        self.youngest_md_key_id = value
                                        self.youngest_md_key_id.value_namespace = name_space
                                        self.youngest_md_key_id.value_namespace_prefix = name_space_prefix


                            class Srlg(Entity):
                                """
                                SRLG Values
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.Srlg, self).__init__()

                                    self.yang_name = "srlg"
                                    self.yang_parent_name = "interface"

                                    self.entry = YLeaf(YType.uint32, "entry")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("entry") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.Srlg, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.Srlg, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.entry.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.entry.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "srlg" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "entry"):
                                        self.entry = value
                                        self.entry.value_namespace = name_space
                                        self.entry.value_namespace_prefix = name_space_prefix


                            class InterfaceNeighbor(Entity):
                                """
                                Information for neighbors on the interface
                                
                                .. attribute:: interface_neighbor_cost
                                
                                	Cost of link to neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_neighbor_id
                                
                                	Neighbor Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bdr
                                
                                	If true, Backup designated router
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_dr
                                
                                	If true, Designated router
                                	**type**\:  bool
                                
                                .. attribute:: suppress_hello
                                
                                	If true, hellos suppressed
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor, self).__init__()

                                    self.yang_name = "interface-neighbor"
                                    self.yang_parent_name = "interface"

                                    self.interface_neighbor_cost = YLeaf(YType.uint32, "interface-neighbor-cost")

                                    self.interface_neighbor_id = YLeaf(YType.str, "interface-neighbor-id")

                                    self.neighbor_bdr = YLeaf(YType.boolean, "neighbor-bdr")

                                    self.neighbor_dr = YLeaf(YType.boolean, "neighbor-dr")

                                    self.suppress_hello = YLeaf(YType.boolean, "suppress-hello")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_neighbor_cost",
                                                    "interface_neighbor_id",
                                                    "neighbor_bdr",
                                                    "neighbor_dr",
                                                    "suppress_hello") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.interface_neighbor_cost.is_set or
                                        self.interface_neighbor_id.is_set or
                                        self.neighbor_bdr.is_set or
                                        self.neighbor_dr.is_set or
                                        self.suppress_hello.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_neighbor_cost.yfilter != YFilter.not_set or
                                        self.interface_neighbor_id.yfilter != YFilter.not_set or
                                        self.neighbor_bdr.yfilter != YFilter.not_set or
                                        self.neighbor_dr.yfilter != YFilter.not_set or
                                        self.suppress_hello.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface-neighbor" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_neighbor_cost.is_set or self.interface_neighbor_cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_neighbor_cost.get_name_leafdata())
                                    if (self.interface_neighbor_id.is_set or self.interface_neighbor_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_neighbor_id.get_name_leafdata())
                                    if (self.neighbor_bdr.is_set or self.neighbor_bdr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_bdr.get_name_leafdata())
                                    if (self.neighbor_dr.is_set or self.neighbor_dr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_dr.get_name_leafdata())
                                    if (self.suppress_hello.is_set or self.suppress_hello.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.suppress_hello.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-neighbor-cost" or name == "interface-neighbor-id" or name == "neighbor-bdr" or name == "neighbor-dr" or name == "suppress-hello"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-neighbor-cost"):
                                        self.interface_neighbor_cost = value
                                        self.interface_neighbor_cost.value_namespace = name_space
                                        self.interface_neighbor_cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-neighbor-id"):
                                        self.interface_neighbor_id = value
                                        self.interface_neighbor_id.value_namespace = name_space
                                        self.interface_neighbor_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-bdr"):
                                        self.neighbor_bdr = value
                                        self.neighbor_bdr.value_namespace = name_space
                                        self.neighbor_bdr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-dr"):
                                        self.neighbor_dr = value
                                        self.neighbor_dr.value_namespace = name_space
                                        self.neighbor_dr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "suppress-hello"):
                                        self.suppress_hello = value
                                        self.suppress_hello.value_namespace = name_space
                                        self.suppress_hello.value_namespace_prefix = name_space_prefix


                            class InterfaceMadj(Entity):
                                """
                                Information for multi\-area on the interface
                                
                                .. attribute:: interface_adj_neighbor_count
                                
                                	Total number of Adjacent Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_area
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_neighbor_count
                                
                                	Number of Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: madj_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj, self).__init__()

                                    self.yang_name = "interface-madj"
                                    self.yang_parent_name = "interface"

                                    self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                    self.interface_area = YLeaf(YType.str, "interface-area")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                    self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_adj_neighbor_count",
                                                    "interface_area",
                                                    "interface_link_cost",
                                                    "interface_neighbor_count",
                                                    "madj_area_id",
                                                    "ospf_interface_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.interface_adj_neighbor_count.is_set or
                                        self.interface_area.is_set or
                                        self.interface_link_cost.is_set or
                                        self.interface_neighbor_count.is_set or
                                        self.madj_area_id.is_set or
                                        self.ospf_interface_state.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_adj_neighbor_count.yfilter != YFilter.not_set or
                                        self.interface_area.yfilter != YFilter.not_set or
                                        self.interface_link_cost.yfilter != YFilter.not_set or
                                        self.interface_neighbor_count.yfilter != YFilter.not_set or
                                        self.madj_area_id.yfilter != YFilter.not_set or
                                        self.ospf_interface_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface-madj" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_adj_neighbor_count.is_set or self.interface_adj_neighbor_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_adj_neighbor_count.get_name_leafdata())
                                    if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_area.get_name_leafdata())
                                    if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                    if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                    if (self.madj_area_id.is_set or self.madj_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.madj_area_id.get_name_leafdata())
                                    if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-adj-neighbor-count" or name == "interface-area" or name == "interface-link-cost" or name == "interface-neighbor-count" or name == "madj-area-id" or name == "ospf-interface-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-adj-neighbor-count"):
                                        self.interface_adj_neighbor_count = value
                                        self.interface_adj_neighbor_count.value_namespace = name_space
                                        self.interface_adj_neighbor_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-area"):
                                        self.interface_area = value
                                        self.interface_area.value_namespace = name_space
                                        self.interface_area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-link-cost"):
                                        self.interface_link_cost = value
                                        self.interface_link_cost.value_namespace = name_space
                                        self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-neighbor-count"):
                                        self.interface_neighbor_count = value
                                        self.interface_neighbor_count.value_namespace = name_space
                                        self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "madj-area-id"):
                                        self.madj_area_id = value
                                        self.madj_area_id.value_namespace = name_space
                                        self.madj_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-interface-state"):
                                        self.ospf_interface_state = value
                                        self.ospf_interface_state.value_namespace = name_space
                                        self.ospf_interface_state.value_namespace_prefix = name_space_prefix


                            class IpfrrTiebreakers(Entity):
                                """
                                IPFRR\-Tiebreakers list
                                
                                .. attribute:: tiebreaker_index
                                
                                	Tiebreaker Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tiebreaker_type
                                
                                	Tiebreaker Type
                                	**type**\:   :py:class:`IpfrrTbrkr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IpfrrTbrkr>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers, self).__init__()

                                    self.yang_name = "ipfrr-tiebreakers"
                                    self.yang_parent_name = "interface"

                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tiebreaker_index",
                                                    "tiebreaker_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.tiebreaker_index.is_set or
                                        self.tiebreaker_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tiebreaker_index.yfilter != YFilter.not_set or
                                        self.tiebreaker_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipfrr-tiebreakers" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())
                                    if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tiebreaker-index" or name == "tiebreaker-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tiebreaker-index"):
                                        self.tiebreaker_index = value
                                        self.tiebreaker_index.value_namespace = name_space
                                        self.tiebreaker_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tiebreaker-type"):
                                        self.tiebreaker_type = value
                                        self.tiebreaker_type.value_namespace = name_space
                                        self.tiebreaker_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface_madj:
                                    if (c.has_data()):
                                        return True
                                for c in self.interface_neighbor:
                                    if (c.has_data()):
                                        return True
                                for c in self.ipfrr_tiebreakers:
                                    if (c.has_data()):
                                        return True
                                for c in self.srlg:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.interface_name.is_set or
                                    self.backup_designated_router.is_set or
                                    self.backup_designated_router_address.is_set or
                                    self.backup_designated_router_id.is_set or
                                    self.cfg_cost_fallback.is_set or
                                    self.configured_demand_circuit.is_set or
                                    self.configured_ldp_sync.is_set or
                                    self.configured_ldp_sync_igp_shortcuts.is_set or
                                    self.cost_fallback_active.is_set or
                                    self.dead_interval.is_set or
                                    self.designated_router.is_set or
                                    self.designated_router_address.is_set or
                                    self.designated_router_id.is_set or
                                    self.fast_detect_hold_down_time.is_set or
                                    self.fast_detect_hold_down_time_remaining.is_set or
                                    self.fast_reroute_topology_independent_lfa.is_set or
                                    self.fast_reroute_type.is_set or
                                    self.hello_interval.is_set or
                                    self.hello_interval_ms.is_set or
                                    self.interface_ack_list_count.is_set or
                                    self.interface_ack_list_high_watermark.is_set or
                                    self.interface_address.is_set or
                                    self.interface_area.is_set or
                                    self.interface_bandwidth.is_set or
                                    self.interface_cost_fallback.is_set or
                                    self.interface_dc_bitless_lsa_count.is_set or
                                    self.interface_demand_circuit.is_set or
                                    self.interface_fast_detect_hold_down.is_set or
                                    self.interface_last_nsf.is_set or
                                    self.interface_ldp_sync.is_set or
                                    self.interface_line_state.is_set or
                                    self.interface_link_cost.is_set or
                                    self.interface_lsa_filter.is_set or
                                    self.interface_madj_count.is_set or
                                    self.interface_mask.is_set or
                                    self.interface_name_xr.is_set or
                                    self.interface_nsf.is_set or
                                    self.interface_nsf_enabled.is_set or
                                    self.interface_priority.is_set or
                                    self.interface_retransmission_interrval.is_set or
                                    self.interface_router_id.is_set or
                                    self.interface_sid.is_set or
                                    self.interface_sid_n_flag_clear.is_set or
                                    self.interface_sid_php_off.is_set or
                                    self.interface_state.is_set or
                                    self.interface_strict_spf_sid.is_set or
                                    self.interface_strict_spf_sid_n_flag_clear.is_set or
                                    self.interface_strict_spf_sid_php_off.is_set or
                                    self.interface_tunnel_flags.is_set or
                                    self.interfaceis_madj.is_set or
                                    self.ip_mtu.is_set or
                                    self.is_loopback_stub_network.is_set or
                                    self.maximum_packet_size.is_set or
                                    self.network_lsa_flush_timer.is_set or
                                    self.network_type.is_set or
                                    self.next_hello_time.is_set or
                                    self.next_hello_time_ms.is_set or
                                    self.ospf_interface_state.is_set or
                                    self.passive_interface.is_set or
                                    self.prefix_suppress_primary_addresses.is_set or
                                    self.prefix_suppress_secondary_addresses.is_set or
                                    self.registered_for_link_down_fast_detection.is_set or
                                    self.transmission_delay.is_set or
                                    self.ttl_security_enabled.is_set or
                                    self.ttl_security_hop_count.is_set or
                                    self.wait_interval.is_set or
                                    (self.active_interface is not None and self.active_interface.has_data()) or
                                    (self.interface_bfd_information is not None and self.interface_bfd_information.has_data()))

                            def has_operation(self):
                                for c in self.interface_madj:
                                    if (c.has_operation()):
                                        return True
                                for c in self.interface_neighbor:
                                    if (c.has_operation()):
                                        return True
                                for c in self.ipfrr_tiebreakers:
                                    if (c.has_operation()):
                                        return True
                                for c in self.srlg:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.backup_designated_router.yfilter != YFilter.not_set or
                                    self.backup_designated_router_address.yfilter != YFilter.not_set or
                                    self.backup_designated_router_id.yfilter != YFilter.not_set or
                                    self.cfg_cost_fallback.yfilter != YFilter.not_set or
                                    self.configured_demand_circuit.yfilter != YFilter.not_set or
                                    self.configured_ldp_sync.yfilter != YFilter.not_set or
                                    self.configured_ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                                    self.cost_fallback_active.yfilter != YFilter.not_set or
                                    self.dead_interval.yfilter != YFilter.not_set or
                                    self.designated_router.yfilter != YFilter.not_set or
                                    self.designated_router_address.yfilter != YFilter.not_set or
                                    self.designated_router_id.yfilter != YFilter.not_set or
                                    self.fast_detect_hold_down_time.yfilter != YFilter.not_set or
                                    self.fast_detect_hold_down_time_remaining.yfilter != YFilter.not_set or
                                    self.fast_reroute_topology_independent_lfa.yfilter != YFilter.not_set or
                                    self.fast_reroute_type.yfilter != YFilter.not_set or
                                    self.hello_interval.yfilter != YFilter.not_set or
                                    self.hello_interval_ms.yfilter != YFilter.not_set or
                                    self.interface_ack_list_count.yfilter != YFilter.not_set or
                                    self.interface_ack_list_high_watermark.yfilter != YFilter.not_set or
                                    self.interface_address.yfilter != YFilter.not_set or
                                    self.interface_area.yfilter != YFilter.not_set or
                                    self.interface_bandwidth.yfilter != YFilter.not_set or
                                    self.interface_cost_fallback.yfilter != YFilter.not_set or
                                    self.interface_dc_bitless_lsa_count.yfilter != YFilter.not_set or
                                    self.interface_demand_circuit.yfilter != YFilter.not_set or
                                    self.interface_fast_detect_hold_down.yfilter != YFilter.not_set or
                                    self.interface_last_nsf.yfilter != YFilter.not_set or
                                    self.interface_ldp_sync.yfilter != YFilter.not_set or
                                    self.interface_line_state.yfilter != YFilter.not_set or
                                    self.interface_link_cost.yfilter != YFilter.not_set or
                                    self.interface_lsa_filter.yfilter != YFilter.not_set or
                                    self.interface_madj_count.yfilter != YFilter.not_set or
                                    self.interface_mask.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.interface_nsf.yfilter != YFilter.not_set or
                                    self.interface_nsf_enabled.yfilter != YFilter.not_set or
                                    self.interface_priority.yfilter != YFilter.not_set or
                                    self.interface_retransmission_interrval.yfilter != YFilter.not_set or
                                    self.interface_router_id.yfilter != YFilter.not_set or
                                    self.interface_sid.yfilter != YFilter.not_set or
                                    self.interface_sid_n_flag_clear.yfilter != YFilter.not_set or
                                    self.interface_sid_php_off.yfilter != YFilter.not_set or
                                    self.interface_state.yfilter != YFilter.not_set or
                                    self.interface_strict_spf_sid.yfilter != YFilter.not_set or
                                    self.interface_strict_spf_sid_n_flag_clear.yfilter != YFilter.not_set or
                                    self.interface_strict_spf_sid_php_off.yfilter != YFilter.not_set or
                                    self.interface_tunnel_flags.yfilter != YFilter.not_set or
                                    self.interfaceis_madj.yfilter != YFilter.not_set or
                                    self.ip_mtu.yfilter != YFilter.not_set or
                                    self.is_loopback_stub_network.yfilter != YFilter.not_set or
                                    self.maximum_packet_size.yfilter != YFilter.not_set or
                                    self.network_lsa_flush_timer.yfilter != YFilter.not_set or
                                    self.network_type.yfilter != YFilter.not_set or
                                    self.next_hello_time.yfilter != YFilter.not_set or
                                    self.next_hello_time_ms.yfilter != YFilter.not_set or
                                    self.ospf_interface_state.yfilter != YFilter.not_set or
                                    self.passive_interface.yfilter != YFilter.not_set or
                                    self.prefix_suppress_primary_addresses.yfilter != YFilter.not_set or
                                    self.prefix_suppress_secondary_addresses.yfilter != YFilter.not_set or
                                    self.registered_for_link_down_fast_detection.yfilter != YFilter.not_set or
                                    self.transmission_delay.yfilter != YFilter.not_set or
                                    self.ttl_security_enabled.yfilter != YFilter.not_set or
                                    self.ttl_security_hop_count.yfilter != YFilter.not_set or
                                    self.wait_interval.yfilter != YFilter.not_set or
                                    (self.active_interface is not None and self.active_interface.has_operation()) or
                                    (self.interface_bfd_information is not None and self.interface_bfd_information.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.backup_designated_router.is_set or self.backup_designated_router.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_designated_router.get_name_leafdata())
                                if (self.backup_designated_router_address.is_set or self.backup_designated_router_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_designated_router_address.get_name_leafdata())
                                if (self.backup_designated_router_id.is_set or self.backup_designated_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_designated_router_id.get_name_leafdata())
                                if (self.cfg_cost_fallback.is_set or self.cfg_cost_fallback.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cfg_cost_fallback.get_name_leafdata())
                                if (self.configured_demand_circuit.is_set or self.configured_demand_circuit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_demand_circuit.get_name_leafdata())
                                if (self.configured_ldp_sync.is_set or self.configured_ldp_sync.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_ldp_sync.get_name_leafdata())
                                if (self.configured_ldp_sync_igp_shortcuts.is_set or self.configured_ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_ldp_sync_igp_shortcuts.get_name_leafdata())
                                if (self.cost_fallback_active.is_set or self.cost_fallback_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cost_fallback_active.get_name_leafdata())
                                if (self.dead_interval.is_set or self.dead_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dead_interval.get_name_leafdata())
                                if (self.designated_router.is_set or self.designated_router.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.designated_router.get_name_leafdata())
                                if (self.designated_router_address.is_set or self.designated_router_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.designated_router_address.get_name_leafdata())
                                if (self.designated_router_id.is_set or self.designated_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.designated_router_id.get_name_leafdata())
                                if (self.fast_detect_hold_down_time.is_set or self.fast_detect_hold_down_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fast_detect_hold_down_time.get_name_leafdata())
                                if (self.fast_detect_hold_down_time_remaining.is_set or self.fast_detect_hold_down_time_remaining.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fast_detect_hold_down_time_remaining.get_name_leafdata())
                                if (self.fast_reroute_topology_independent_lfa.is_set or self.fast_reroute_topology_independent_lfa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fast_reroute_topology_independent_lfa.get_name_leafdata())
                                if (self.fast_reroute_type.is_set or self.fast_reroute_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fast_reroute_type.get_name_leafdata())
                                if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                if (self.hello_interval_ms.is_set or self.hello_interval_ms.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.hello_interval_ms.get_name_leafdata())
                                if (self.interface_ack_list_count.is_set or self.interface_ack_list_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_ack_list_count.get_name_leafdata())
                                if (self.interface_ack_list_high_watermark.is_set or self.interface_ack_list_high_watermark.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_ack_list_high_watermark.get_name_leafdata())
                                if (self.interface_address.is_set or self.interface_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_address.get_name_leafdata())
                                if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_area.get_name_leafdata())
                                if (self.interface_bandwidth.is_set or self.interface_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_bandwidth.get_name_leafdata())
                                if (self.interface_cost_fallback.is_set or self.interface_cost_fallback.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_cost_fallback.get_name_leafdata())
                                if (self.interface_dc_bitless_lsa_count.is_set or self.interface_dc_bitless_lsa_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_dc_bitless_lsa_count.get_name_leafdata())
                                if (self.interface_demand_circuit.is_set or self.interface_demand_circuit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_demand_circuit.get_name_leafdata())
                                if (self.interface_fast_detect_hold_down.is_set or self.interface_fast_detect_hold_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_fast_detect_hold_down.get_name_leafdata())
                                if (self.interface_last_nsf.is_set or self.interface_last_nsf.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_last_nsf.get_name_leafdata())
                                if (self.interface_ldp_sync.is_set or self.interface_ldp_sync.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_ldp_sync.get_name_leafdata())
                                if (self.interface_line_state.is_set or self.interface_line_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_line_state.get_name_leafdata())
                                if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                if (self.interface_lsa_filter.is_set or self.interface_lsa_filter.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_lsa_filter.get_name_leafdata())
                                if (self.interface_madj_count.is_set or self.interface_madj_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_madj_count.get_name_leafdata())
                                if (self.interface_mask.is_set or self.interface_mask.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_mask.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.interface_nsf.is_set or self.interface_nsf.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_nsf.get_name_leafdata())
                                if (self.interface_nsf_enabled.is_set or self.interface_nsf_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_nsf_enabled.get_name_leafdata())
                                if (self.interface_priority.is_set or self.interface_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_priority.get_name_leafdata())
                                if (self.interface_retransmission_interrval.is_set or self.interface_retransmission_interrval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_retransmission_interrval.get_name_leafdata())
                                if (self.interface_router_id.is_set or self.interface_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_router_id.get_name_leafdata())
                                if (self.interface_sid.is_set or self.interface_sid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_sid.get_name_leafdata())
                                if (self.interface_sid_n_flag_clear.is_set or self.interface_sid_n_flag_clear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_sid_n_flag_clear.get_name_leafdata())
                                if (self.interface_sid_php_off.is_set or self.interface_sid_php_off.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_sid_php_off.get_name_leafdata())
                                if (self.interface_state.is_set or self.interface_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_state.get_name_leafdata())
                                if (self.interface_strict_spf_sid.is_set or self.interface_strict_spf_sid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_strict_spf_sid.get_name_leafdata())
                                if (self.interface_strict_spf_sid_n_flag_clear.is_set or self.interface_strict_spf_sid_n_flag_clear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_strict_spf_sid_n_flag_clear.get_name_leafdata())
                                if (self.interface_strict_spf_sid_php_off.is_set or self.interface_strict_spf_sid_php_off.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_strict_spf_sid_php_off.get_name_leafdata())
                                if (self.interface_tunnel_flags.is_set or self.interface_tunnel_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_tunnel_flags.get_name_leafdata())
                                if (self.interfaceis_madj.is_set or self.interfaceis_madj.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interfaceis_madj.get_name_leafdata())
                                if (self.ip_mtu.is_set or self.ip_mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_mtu.get_name_leafdata())
                                if (self.is_loopback_stub_network.is_set or self.is_loopback_stub_network.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_loopback_stub_network.get_name_leafdata())
                                if (self.maximum_packet_size.is_set or self.maximum_packet_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_packet_size.get_name_leafdata())
                                if (self.network_lsa_flush_timer.is_set or self.network_lsa_flush_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.network_lsa_flush_timer.get_name_leafdata())
                                if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.network_type.get_name_leafdata())
                                if (self.next_hello_time.is_set or self.next_hello_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hello_time.get_name_leafdata())
                                if (self.next_hello_time_ms.is_set or self.next_hello_time_ms.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hello_time_ms.get_name_leafdata())
                                if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())
                                if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.passive_interface.get_name_leafdata())
                                if (self.prefix_suppress_primary_addresses.is_set or self.prefix_suppress_primary_addresses.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_suppress_primary_addresses.get_name_leafdata())
                                if (self.prefix_suppress_secondary_addresses.is_set or self.prefix_suppress_secondary_addresses.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_suppress_secondary_addresses.get_name_leafdata())
                                if (self.registered_for_link_down_fast_detection.is_set or self.registered_for_link_down_fast_detection.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.registered_for_link_down_fast_detection.get_name_leafdata())
                                if (self.transmission_delay.is_set or self.transmission_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transmission_delay.get_name_leafdata())
                                if (self.ttl_security_enabled.is_set or self.ttl_security_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ttl_security_enabled.get_name_leafdata())
                                if (self.ttl_security_hop_count.is_set or self.ttl_security_hop_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ttl_security_hop_count.get_name_leafdata())
                                if (self.wait_interval.is_set or self.wait_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wait_interval.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "active-interface"):
                                    if (self.active_interface is None):
                                        self.active_interface = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface()
                                        self.active_interface.parent = self
                                        self._children_name_map["active_interface"] = "active-interface"
                                    return self.active_interface

                                if (child_yang_name == "interface-bfd-information"):
                                    if (self.interface_bfd_information is None):
                                        self.interface_bfd_information = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation()
                                        self.interface_bfd_information.parent = self
                                        self._children_name_map["interface_bfd_information"] = "interface-bfd-information"
                                    return self.interface_bfd_information

                                if (child_yang_name == "interface-madj"):
                                    for c in self.interface_madj:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface_madj.append(c)
                                    return c

                                if (child_yang_name == "interface-neighbor"):
                                    for c in self.interface_neighbor:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface_neighbor.append(c)
                                    return c

                                if (child_yang_name == "ipfrr-tiebreakers"):
                                    for c in self.ipfrr_tiebreakers:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.ipfrr_tiebreakers.append(c)
                                    return c

                                if (child_yang_name == "srlg"):
                                    for c in self.srlg:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.Srlg()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.srlg.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "active-interface" or name == "interface-bfd-information" or name == "interface-madj" or name == "interface-neighbor" or name == "ipfrr-tiebreakers" or name == "srlg" or name == "interface-name" or name == "backup-designated-router" or name == "backup-designated-router-address" or name == "backup-designated-router-id" or name == "cfg-cost-fallback" or name == "configured-demand-circuit" or name == "configured-ldp-sync" or name == "configured-ldp-sync-igp-shortcuts" or name == "cost-fallback-active" or name == "dead-interval" or name == "designated-router" or name == "designated-router-address" or name == "designated-router-id" or name == "fast-detect-hold-down-time" or name == "fast-detect-hold-down-time-remaining" or name == "fast-reroute-topology-independent-lfa" or name == "fast-reroute-type" or name == "hello-interval" or name == "hello-interval-ms" or name == "interface-ack-list-count" or name == "interface-ack-list-high-watermark" or name == "interface-address" or name == "interface-area" or name == "interface-bandwidth" or name == "interface-cost-fallback" or name == "interface-dc-bitless-lsa-count" or name == "interface-demand-circuit" or name == "interface-fast-detect-hold-down" or name == "interface-last-nsf" or name == "interface-ldp-sync" or name == "interface-line-state" or name == "interface-link-cost" or name == "interface-lsa-filter" or name == "interface-madj-count" or name == "interface-mask" or name == "interface-name-xr" or name == "interface-nsf" or name == "interface-nsf-enabled" or name == "interface-priority" or name == "interface-retransmission-interrval" or name == "interface-router-id" or name == "interface-sid" or name == "interface-sid-n-flag-clear" or name == "interface-sid-php-off" or name == "interface-state" or name == "interface-strict-spf-sid" or name == "interface-strict-spf-sid-n-flag-clear" or name == "interface-strict-spf-sid-php-off" or name == "interface-tunnel-flags" or name == "interfaceis-madj" or name == "ip-mtu" or name == "is-loopback-stub-network" or name == "maximum-packet-size" or name == "network-lsa-flush-timer" or name == "network-type" or name == "next-hello-time" or name == "next-hello-time-ms" or name == "ospf-interface-state" or name == "passive-interface" or name == "prefix-suppress-primary-addresses" or name == "prefix-suppress-secondary-addresses" or name == "registered-for-link-down-fast-detection" or name == "transmission-delay" or name == "ttl-security-enabled" or name == "ttl-security-hop-count" or name == "wait-interval"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-designated-router"):
                                    self.backup_designated_router = value
                                    self.backup_designated_router.value_namespace = name_space
                                    self.backup_designated_router.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-designated-router-address"):
                                    self.backup_designated_router_address = value
                                    self.backup_designated_router_address.value_namespace = name_space
                                    self.backup_designated_router_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-designated-router-id"):
                                    self.backup_designated_router_id = value
                                    self.backup_designated_router_id.value_namespace = name_space
                                    self.backup_designated_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "cfg-cost-fallback"):
                                    self.cfg_cost_fallback = value
                                    self.cfg_cost_fallback.value_namespace = name_space
                                    self.cfg_cost_fallback.value_namespace_prefix = name_space_prefix
                                if(value_path == "configured-demand-circuit"):
                                    self.configured_demand_circuit = value
                                    self.configured_demand_circuit.value_namespace = name_space
                                    self.configured_demand_circuit.value_namespace_prefix = name_space_prefix
                                if(value_path == "configured-ldp-sync"):
                                    self.configured_ldp_sync = value
                                    self.configured_ldp_sync.value_namespace = name_space
                                    self.configured_ldp_sync.value_namespace_prefix = name_space_prefix
                                if(value_path == "configured-ldp-sync-igp-shortcuts"):
                                    self.configured_ldp_sync_igp_shortcuts = value
                                    self.configured_ldp_sync_igp_shortcuts.value_namespace = name_space
                                    self.configured_ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                                if(value_path == "cost-fallback-active"):
                                    self.cost_fallback_active = value
                                    self.cost_fallback_active.value_namespace = name_space
                                    self.cost_fallback_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "dead-interval"):
                                    self.dead_interval = value
                                    self.dead_interval.value_namespace = name_space
                                    self.dead_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "designated-router"):
                                    self.designated_router = value
                                    self.designated_router.value_namespace = name_space
                                    self.designated_router.value_namespace_prefix = name_space_prefix
                                if(value_path == "designated-router-address"):
                                    self.designated_router_address = value
                                    self.designated_router_address.value_namespace = name_space
                                    self.designated_router_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "designated-router-id"):
                                    self.designated_router_id = value
                                    self.designated_router_id.value_namespace = name_space
                                    self.designated_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "fast-detect-hold-down-time"):
                                    self.fast_detect_hold_down_time = value
                                    self.fast_detect_hold_down_time.value_namespace = name_space
                                    self.fast_detect_hold_down_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "fast-detect-hold-down-time-remaining"):
                                    self.fast_detect_hold_down_time_remaining = value
                                    self.fast_detect_hold_down_time_remaining.value_namespace = name_space
                                    self.fast_detect_hold_down_time_remaining.value_namespace_prefix = name_space_prefix
                                if(value_path == "fast-reroute-topology-independent-lfa"):
                                    self.fast_reroute_topology_independent_lfa = value
                                    self.fast_reroute_topology_independent_lfa.value_namespace = name_space
                                    self.fast_reroute_topology_independent_lfa.value_namespace_prefix = name_space_prefix
                                if(value_path == "fast-reroute-type"):
                                    self.fast_reroute_type = value
                                    self.fast_reroute_type.value_namespace = name_space
                                    self.fast_reroute_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "hello-interval"):
                                    self.hello_interval = value
                                    self.hello_interval.value_namespace = name_space
                                    self.hello_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "hello-interval-ms"):
                                    self.hello_interval_ms = value
                                    self.hello_interval_ms.value_namespace = name_space
                                    self.hello_interval_ms.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-ack-list-count"):
                                    self.interface_ack_list_count = value
                                    self.interface_ack_list_count.value_namespace = name_space
                                    self.interface_ack_list_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-ack-list-high-watermark"):
                                    self.interface_ack_list_high_watermark = value
                                    self.interface_ack_list_high_watermark.value_namespace = name_space
                                    self.interface_ack_list_high_watermark.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-address"):
                                    self.interface_address = value
                                    self.interface_address.value_namespace = name_space
                                    self.interface_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-area"):
                                    self.interface_area = value
                                    self.interface_area.value_namespace = name_space
                                    self.interface_area.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-bandwidth"):
                                    self.interface_bandwidth = value
                                    self.interface_bandwidth.value_namespace = name_space
                                    self.interface_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-cost-fallback"):
                                    self.interface_cost_fallback = value
                                    self.interface_cost_fallback.value_namespace = name_space
                                    self.interface_cost_fallback.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-dc-bitless-lsa-count"):
                                    self.interface_dc_bitless_lsa_count = value
                                    self.interface_dc_bitless_lsa_count.value_namespace = name_space
                                    self.interface_dc_bitless_lsa_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-demand-circuit"):
                                    self.interface_demand_circuit = value
                                    self.interface_demand_circuit.value_namespace = name_space
                                    self.interface_demand_circuit.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-fast-detect-hold-down"):
                                    self.interface_fast_detect_hold_down = value
                                    self.interface_fast_detect_hold_down.value_namespace = name_space
                                    self.interface_fast_detect_hold_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-last-nsf"):
                                    self.interface_last_nsf = value
                                    self.interface_last_nsf.value_namespace = name_space
                                    self.interface_last_nsf.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-ldp-sync"):
                                    self.interface_ldp_sync = value
                                    self.interface_ldp_sync.value_namespace = name_space
                                    self.interface_ldp_sync.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-line-state"):
                                    self.interface_line_state = value
                                    self.interface_line_state.value_namespace = name_space
                                    self.interface_line_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-link-cost"):
                                    self.interface_link_cost = value
                                    self.interface_link_cost.value_namespace = name_space
                                    self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-lsa-filter"):
                                    self.interface_lsa_filter = value
                                    self.interface_lsa_filter.value_namespace = name_space
                                    self.interface_lsa_filter.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-madj-count"):
                                    self.interface_madj_count = value
                                    self.interface_madj_count.value_namespace = name_space
                                    self.interface_madj_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-mask"):
                                    self.interface_mask = value
                                    self.interface_mask.value_namespace = name_space
                                    self.interface_mask.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-nsf"):
                                    self.interface_nsf = value
                                    self.interface_nsf.value_namespace = name_space
                                    self.interface_nsf.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-nsf-enabled"):
                                    self.interface_nsf_enabled = value
                                    self.interface_nsf_enabled.value_namespace = name_space
                                    self.interface_nsf_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-priority"):
                                    self.interface_priority = value
                                    self.interface_priority.value_namespace = name_space
                                    self.interface_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-retransmission-interrval"):
                                    self.interface_retransmission_interrval = value
                                    self.interface_retransmission_interrval.value_namespace = name_space
                                    self.interface_retransmission_interrval.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-router-id"):
                                    self.interface_router_id = value
                                    self.interface_router_id.value_namespace = name_space
                                    self.interface_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-sid"):
                                    self.interface_sid = value
                                    self.interface_sid.value_namespace = name_space
                                    self.interface_sid.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-sid-n-flag-clear"):
                                    self.interface_sid_n_flag_clear = value
                                    self.interface_sid_n_flag_clear.value_namespace = name_space
                                    self.interface_sid_n_flag_clear.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-sid-php-off"):
                                    self.interface_sid_php_off = value
                                    self.interface_sid_php_off.value_namespace = name_space
                                    self.interface_sid_php_off.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-state"):
                                    self.interface_state = value
                                    self.interface_state.value_namespace = name_space
                                    self.interface_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-strict-spf-sid"):
                                    self.interface_strict_spf_sid = value
                                    self.interface_strict_spf_sid.value_namespace = name_space
                                    self.interface_strict_spf_sid.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-strict-spf-sid-n-flag-clear"):
                                    self.interface_strict_spf_sid_n_flag_clear = value
                                    self.interface_strict_spf_sid_n_flag_clear.value_namespace = name_space
                                    self.interface_strict_spf_sid_n_flag_clear.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-strict-spf-sid-php-off"):
                                    self.interface_strict_spf_sid_php_off = value
                                    self.interface_strict_spf_sid_php_off.value_namespace = name_space
                                    self.interface_strict_spf_sid_php_off.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-tunnel-flags"):
                                    self.interface_tunnel_flags = value
                                    self.interface_tunnel_flags.value_namespace = name_space
                                    self.interface_tunnel_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "interfaceis-madj"):
                                    self.interfaceis_madj = value
                                    self.interfaceis_madj.value_namespace = name_space
                                    self.interfaceis_madj.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip-mtu"):
                                    self.ip_mtu = value
                                    self.ip_mtu.value_namespace = name_space
                                    self.ip_mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-loopback-stub-network"):
                                    self.is_loopback_stub_network = value
                                    self.is_loopback_stub_network.value_namespace = name_space
                                    self.is_loopback_stub_network.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-packet-size"):
                                    self.maximum_packet_size = value
                                    self.maximum_packet_size.value_namespace = name_space
                                    self.maximum_packet_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "network-lsa-flush-timer"):
                                    self.network_lsa_flush_timer = value
                                    self.network_lsa_flush_timer.value_namespace = name_space
                                    self.network_lsa_flush_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "network-type"):
                                    self.network_type = value
                                    self.network_type.value_namespace = name_space
                                    self.network_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hello-time"):
                                    self.next_hello_time = value
                                    self.next_hello_time.value_namespace = name_space
                                    self.next_hello_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hello-time-ms"):
                                    self.next_hello_time_ms = value
                                    self.next_hello_time_ms.value_namespace = name_space
                                    self.next_hello_time_ms.value_namespace_prefix = name_space_prefix
                                if(value_path == "ospf-interface-state"):
                                    self.ospf_interface_state = value
                                    self.ospf_interface_state.value_namespace = name_space
                                    self.ospf_interface_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "passive-interface"):
                                    self.passive_interface = value
                                    self.passive_interface.value_namespace = name_space
                                    self.passive_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-suppress-primary-addresses"):
                                    self.prefix_suppress_primary_addresses = value
                                    self.prefix_suppress_primary_addresses.value_namespace = name_space
                                    self.prefix_suppress_primary_addresses.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-suppress-secondary-addresses"):
                                    self.prefix_suppress_secondary_addresses = value
                                    self.prefix_suppress_secondary_addresses.value_namespace = name_space
                                    self.prefix_suppress_secondary_addresses.value_namespace_prefix = name_space_prefix
                                if(value_path == "registered-for-link-down-fast-detection"):
                                    self.registered_for_link_down_fast_detection = value
                                    self.registered_for_link_down_fast_detection.value_namespace = name_space
                                    self.registered_for_link_down_fast_detection.value_namespace_prefix = name_space_prefix
                                if(value_path == "transmission-delay"):
                                    self.transmission_delay = value
                                    self.transmission_delay.value_namespace = name_space
                                    self.transmission_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "ttl-security-enabled"):
                                    self.ttl_security_enabled = value
                                    self.ttl_security_enabled.value_namespace = name_space
                                    self.ttl_security_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "ttl-security-hop-count"):
                                    self.ttl_security_hop_count = value
                                    self.ttl_security_hop_count.value_namespace = name_space
                                    self.ttl_security_hop_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "wait-interval"):
                                    self.wait_interval = value
                                    self.wait_interval.value_namespace = name_space
                                    self.wait_interval.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.interface:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interfaces" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface"):
                                for c in self.interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.interface_briefs is not None and self.interface_briefs.has_data()) or
                            (self.interfaces is not None and self.interfaces.has_data()) or
                            (self.virtual_links is not None and self.virtual_links.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.interface_briefs is not None and self.interface_briefs.has_operation()) or
                            (self.interfaces is not None and self.interfaces.has_operation()) or
                            (self.virtual_links is not None and self.virtual_links.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-information" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-briefs"):
                            if (self.interface_briefs is None):
                                self.interface_briefs = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs()
                                self.interface_briefs.parent = self
                                self._children_name_map["interface_briefs"] = "interface-briefs"
                            return self.interface_briefs

                        if (child_yang_name == "interfaces"):
                            if (self.interfaces is None):
                                self.interfaces = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces()
                                self.interfaces.parent = self
                                self._children_name_map["interfaces"] = "interfaces"
                            return self.interfaces

                        if (child_yang_name == "virtual-links"):
                            if (self.virtual_links is None):
                                self.virtual_links = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks()
                                self.virtual_links.parent = self
                                self._children_name_map["virtual_links"] = "virtual-links"
                            return self.virtual_links

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-briefs" or name == "interfaces" or name == "virtual-links"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BorderRouters(Entity):
                    """
                    Border router table
                    
                    .. attribute:: border_router
                    
                    	Information for a particular border router
                    	**type**\: list of    :py:class:`BorderRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.BorderRouters, self).__init__()

                        self.yang_name = "border-routers"
                        self.yang_parent_name = "default-vrf"

                        self.border_router = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.BorderRouters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.BorderRouters, self).__setattr__(name, value)


                    class BorderRouter(Entity):
                        """
                        Information for a particular border router
                        
                        .. attribute:: border_router_id  <key>
                        
                        	Router address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: border_router_id_xr
                        
                        	Router ID of Border Router
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: border_router_path
                        
                        	List of Border Router paths
                        	**type**\: list of    :py:class:`BorderRouterPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter, self).__init__()

                            self.yang_name = "border-router"
                            self.yang_parent_name = "border-routers"

                            self.border_router_id = YLeaf(YType.str, "border-router-id")

                            self.border_router_id_xr = YLeaf(YType.str, "border-router-id-xr")

                            self.border_router_path = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("border_router_id",
                                            "border_router_id_xr") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter, self).__setattr__(name, value)


                        class BorderRouterPath(Entity):
                            """
                            List of Border Router paths
                            
                            .. attribute:: border_router_area_id
                            
                            	Area string in decimal or dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: border_router_next_hop
                            
                            	Next hop address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: border_router_next_hop_interface_name
                            
                            	Next hop Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: border_router_route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: border_router_route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            .. attribute:: border_router_type
                            
                            	Border router type
                            	**type**\:   :py:class:`OspfBr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfBr>`
                            
                            .. attribute:: spf_version
                            
                            	SPF run instance count
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath, self).__init__()

                                self.yang_name = "border-router-path"
                                self.yang_parent_name = "border-router"

                                self.border_router_area_id = YLeaf(YType.str, "border-router-area-id")

                                self.border_router_next_hop = YLeaf(YType.str, "border-router-next-hop")

                                self.border_router_next_hop_interface_name = YLeaf(YType.str, "border-router-next-hop-interface-name")

                                self.border_router_route_metric = YLeaf(YType.uint32, "border-router-route-metric")

                                self.border_router_route_type = YLeaf(YType.enumeration, "border-router-route-type")

                                self.border_router_type = YLeaf(YType.enumeration, "border-router-type")

                                self.spf_version = YLeaf(YType.uint64, "spf-version")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("border_router_area_id",
                                                "border_router_next_hop",
                                                "border_router_next_hop_interface_name",
                                                "border_router_route_metric",
                                                "border_router_route_type",
                                                "border_router_type",
                                                "spf_version") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.border_router_area_id.is_set or
                                    self.border_router_next_hop.is_set or
                                    self.border_router_next_hop_interface_name.is_set or
                                    self.border_router_route_metric.is_set or
                                    self.border_router_route_type.is_set or
                                    self.border_router_type.is_set or
                                    self.spf_version.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.border_router_area_id.yfilter != YFilter.not_set or
                                    self.border_router_next_hop.yfilter != YFilter.not_set or
                                    self.border_router_next_hop_interface_name.yfilter != YFilter.not_set or
                                    self.border_router_route_metric.yfilter != YFilter.not_set or
                                    self.border_router_route_type.yfilter != YFilter.not_set or
                                    self.border_router_type.yfilter != YFilter.not_set or
                                    self.spf_version.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "border-router-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.border_router_area_id.is_set or self.border_router_area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.border_router_area_id.get_name_leafdata())
                                if (self.border_router_next_hop.is_set or self.border_router_next_hop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.border_router_next_hop.get_name_leafdata())
                                if (self.border_router_next_hop_interface_name.is_set or self.border_router_next_hop_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.border_router_next_hop_interface_name.get_name_leafdata())
                                if (self.border_router_route_metric.is_set or self.border_router_route_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.border_router_route_metric.get_name_leafdata())
                                if (self.border_router_route_type.is_set or self.border_router_route_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.border_router_route_type.get_name_leafdata())
                                if (self.border_router_type.is_set or self.border_router_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.border_router_type.get_name_leafdata())
                                if (self.spf_version.is_set or self.spf_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spf_version.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "border-router-area-id" or name == "border-router-next-hop" or name == "border-router-next-hop-interface-name" or name == "border-router-route-metric" or name == "border-router-route-type" or name == "border-router-type" or name == "spf-version"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "border-router-area-id"):
                                    self.border_router_area_id = value
                                    self.border_router_area_id.value_namespace = name_space
                                    self.border_router_area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "border-router-next-hop"):
                                    self.border_router_next_hop = value
                                    self.border_router_next_hop.value_namespace = name_space
                                    self.border_router_next_hop.value_namespace_prefix = name_space_prefix
                                if(value_path == "border-router-next-hop-interface-name"):
                                    self.border_router_next_hop_interface_name = value
                                    self.border_router_next_hop_interface_name.value_namespace = name_space
                                    self.border_router_next_hop_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "border-router-route-metric"):
                                    self.border_router_route_metric = value
                                    self.border_router_route_metric.value_namespace = name_space
                                    self.border_router_route_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "border-router-route-type"):
                                    self.border_router_route_type = value
                                    self.border_router_route_type.value_namespace = name_space
                                    self.border_router_route_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "border-router-type"):
                                    self.border_router_type = value
                                    self.border_router_type.value_namespace = name_space
                                    self.border_router_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "spf-version"):
                                    self.spf_version = value
                                    self.spf_version.value_namespace = name_space
                                    self.spf_version.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.border_router_path:
                                if (c.has_data()):
                                    return True
                            return (
                                self.border_router_id.is_set or
                                self.border_router_id_xr.is_set)

                        def has_operation(self):
                            for c in self.border_router_path:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.border_router_id.yfilter != YFilter.not_set or
                                self.border_router_id_xr.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "border-router" + "[border-router-id='" + self.border_router_id.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.border_router_id.is_set or self.border_router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.border_router_id.get_name_leafdata())
                            if (self.border_router_id_xr.is_set or self.border_router_id_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.border_router_id_xr.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "border-router-path"):
                                for c in self.border_router_path:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.border_router_path.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "border-router-path" or name == "border-router-id" or name == "border-router-id-xr"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "border-router-id"):
                                self.border_router_id = value
                                self.border_router_id.value_namespace = name_space
                                self.border_router_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "border-router-id-xr"):
                                self.border_router_id_xr = value
                                self.border_router_id_xr.value_namespace = name_space
                                self.border_router_id_xr.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.border_router:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.border_router:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "border-routers" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "border-router"):
                            for c in self.border_router:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.border_router.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "border-router"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class ProcessInformation(Entity):
                    """
                    Container for OSPF Process information
                    
                    .. attribute:: process_areas
                    
                    	Process Area table
                    	**type**\:   :py:class:`ProcessAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas>`
                    
                    .. attribute:: process_summary
                    
                    	Basic OSPF summary information
                    	**type**\:   :py:class:`ProcessSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary>`
                    
                    .. attribute:: protocol_areas
                    
                    	Protocol Area table
                    	**type**\:   :py:class:`ProtocolAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas>`
                    
                    .. attribute:: protocol_summary
                    
                    	Basic OSPF protocol information
                    	**type**\:   :py:class:`ProtocolSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolSummary>`
                    
                    .. attribute:: redistributions
                    
                    	Redistribution information table
                    	**type**\:   :py:class:`Redistributions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.ProcessInformation, self).__init__()

                        self.yang_name = "process-information"
                        self.yang_parent_name = "default-vrf"

                        self.process_areas = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas()
                        self.process_areas.parent = self
                        self._children_name_map["process_areas"] = "process-areas"
                        self._children_yang_names.add("process-areas")

                        self.process_summary = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary()
                        self.process_summary.parent = self
                        self._children_name_map["process_summary"] = "process-summary"
                        self._children_yang_names.add("process-summary")

                        self.protocol_areas = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas()
                        self.protocol_areas.parent = self
                        self._children_name_map["protocol_areas"] = "protocol-areas"
                        self._children_yang_names.add("protocol-areas")

                        self.protocol_summary = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolSummary()
                        self.protocol_summary.parent = self
                        self._children_name_map["protocol_summary"] = "protocol-summary"
                        self._children_yang_names.add("protocol-summary")

                        self.redistributions = Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions()
                        self.redistributions.parent = self
                        self._children_name_map["redistributions"] = "redistributions"
                        self._children_yang_names.add("redistributions")


                    class ProtocolAreas(Entity):
                        """
                        Protocol Area table
                        
                        .. attribute:: protocol_area
                        
                        	Area information
                        	**type**\: list of    :py:class:`ProtocolArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas, self).__init__()

                            self.yang_name = "protocol-areas"
                            self.yang_parent_name = "process-information"

                            self.protocol_area = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas, self).__setattr__(name, value)


                        class ProtocolArea(Entity):
                            """
                            Area information
                            
                            .. attribute:: address
                            
                            	Area ID if in IP address format
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_id
                            
                            	Area ID if in integer format
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: protcol_area
                            
                            	Area ID string in decimal and dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: protocol_area_dist_list_in
                            
                            	Distribute List In
                            	**type**\:  str
                            
                            .. attribute:: protocol_interface
                            
                            	Interface list
                            	**type**\: list of    :py:class:`ProtocolInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface>`
                            
                            .. attribute:: protocol_mpls
                            
                            	MPLS\-TE enabled
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea, self).__init__()

                                self.yang_name = "protocol-area"
                                self.yang_parent_name = "protocol-areas"

                                self.address = YLeaf(YType.str, "address")

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.protcol_area = YLeaf(YType.str, "protcol-area")

                                self.protocol_area_dist_list_in = YLeaf(YType.str, "protocol-area-dist-list-in")

                                self.protocol_mpls = YLeaf(YType.boolean, "protocol-mpls")

                                self.protocol_interface = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "area_id",
                                                "protcol_area",
                                                "protocol_area_dist_list_in",
                                                "protocol_mpls") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea, self).__setattr__(name, value)


                            class ProtocolInterface(Entity):
                                """
                                Interface list
                                
                                .. attribute:: protocol_authentication_type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                
                                .. attribute:: protocol_interface_dist_list_in
                                
                                	Distribute List In
                                	**type**\:  str
                                
                                .. attribute:: protocol_interface_name
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface, self).__init__()

                                    self.yang_name = "protocol-interface"
                                    self.yang_parent_name = "protocol-area"

                                    self.protocol_authentication_type = YLeaf(YType.enumeration, "protocol-authentication-type")

                                    self.protocol_interface_dist_list_in = YLeaf(YType.str, "protocol-interface-dist-list-in")

                                    self.protocol_interface_name = YLeaf(YType.str, "protocol-interface-name")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("protocol_authentication_type",
                                                    "protocol_interface_dist_list_in",
                                                    "protocol_interface_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.protocol_authentication_type.is_set or
                                        self.protocol_interface_dist_list_in.is_set or
                                        self.protocol_interface_name.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.protocol_authentication_type.yfilter != YFilter.not_set or
                                        self.protocol_interface_dist_list_in.yfilter != YFilter.not_set or
                                        self.protocol_interface_name.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "protocol-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.protocol_authentication_type.is_set or self.protocol_authentication_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol_authentication_type.get_name_leafdata())
                                    if (self.protocol_interface_dist_list_in.is_set or self.protocol_interface_dist_list_in.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol_interface_dist_list_in.get_name_leafdata())
                                    if (self.protocol_interface_name.is_set or self.protocol_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol_interface_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "protocol-authentication-type" or name == "protocol-interface-dist-list-in" or name == "protocol-interface-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "protocol-authentication-type"):
                                        self.protocol_authentication_type = value
                                        self.protocol_authentication_type.value_namespace = name_space
                                        self.protocol_authentication_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol-interface-dist-list-in"):
                                        self.protocol_interface_dist_list_in = value
                                        self.protocol_interface_dist_list_in.value_namespace = name_space
                                        self.protocol_interface_dist_list_in.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol-interface-name"):
                                        self.protocol_interface_name = value
                                        self.protocol_interface_name.value_namespace = name_space
                                        self.protocol_interface_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.protocol_interface:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.address.is_set or
                                    self.area_id.is_set or
                                    self.protcol_area.is_set or
                                    self.protocol_area_dist_list_in.is_set or
                                    self.protocol_mpls.is_set)

                            def has_operation(self):
                                for c in self.protocol_interface:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.area_id.yfilter != YFilter.not_set or
                                    self.protcol_area.yfilter != YFilter.not_set or
                                    self.protocol_area_dist_list_in.yfilter != YFilter.not_set or
                                    self.protocol_mpls.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "protocol-area" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                if (self.protcol_area.is_set or self.protcol_area.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protcol_area.get_name_leafdata())
                                if (self.protocol_area_dist_list_in.is_set or self.protocol_area_dist_list_in.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol_area_dist_list_in.get_name_leafdata())
                                if (self.protocol_mpls.is_set or self.protocol_mpls.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol_mpls.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "protocol-interface"):
                                    for c in self.protocol_interface:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.protocol_interface.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "protocol-interface" or name == "address" or name == "area-id" or name == "protcol-area" or name == "protocol-area-dist-list-in" or name == "protocol-mpls"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-id"):
                                    self.area_id = value
                                    self.area_id.value_namespace = name_space
                                    self.area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "protcol-area"):
                                    self.protcol_area = value
                                    self.protcol_area.value_namespace = name_space
                                    self.protcol_area.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol-area-dist-list-in"):
                                    self.protocol_area_dist_list_in = value
                                    self.protocol_area_dist_list_in.value_namespace = name_space
                                    self.protocol_area_dist_list_in.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol-mpls"):
                                    self.protocol_mpls = value
                                    self.protocol_mpls.value_namespace = name_space
                                    self.protocol_mpls.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.protocol_area:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.protocol_area:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "protocol-areas" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "protocol-area"):
                                for c in self.protocol_area:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.protocol_area.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "protocol-area"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class ProtocolSummary(Entity):
                        """
                        Basic OSPF protocol information
                        
                        .. attribute:: administrative_distance_external
                        
                        	Administrative Distance for External routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: administrative_distance_inter_area
                        
                        	Administrative Distance for Inter Area routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: dist_list_in
                        
                        	Distribute List In
                        	**type**\:  str
                        
                        .. attribute:: protocol_distance
                        
                        	Administrative distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol_nsf
                        
                        	True if NSF enabled
                        	**type**\:  bool
                        
                        .. attribute:: protocol_router_id
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolSummary, self).__init__()

                            self.yang_name = "protocol-summary"
                            self.yang_parent_name = "process-information"

                            self.administrative_distance_external = YLeaf(YType.uint32, "administrative-distance-external")

                            self.administrative_distance_inter_area = YLeaf(YType.uint32, "administrative-distance-inter-area")

                            self.dist_list_in = YLeaf(YType.str, "dist-list-in")

                            self.protocol_distance = YLeaf(YType.uint32, "protocol-distance")

                            self.protocol_nsf = YLeaf(YType.boolean, "protocol-nsf")

                            self.protocol_router_id = YLeaf(YType.str, "protocol-router-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("administrative_distance_external",
                                            "administrative_distance_inter_area",
                                            "dist_list_in",
                                            "protocol_distance",
                                            "protocol_nsf",
                                            "protocol_router_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolSummary, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolSummary, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.administrative_distance_external.is_set or
                                self.administrative_distance_inter_area.is_set or
                                self.dist_list_in.is_set or
                                self.protocol_distance.is_set or
                                self.protocol_nsf.is_set or
                                self.protocol_router_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.administrative_distance_external.yfilter != YFilter.not_set or
                                self.administrative_distance_inter_area.yfilter != YFilter.not_set or
                                self.dist_list_in.yfilter != YFilter.not_set or
                                self.protocol_distance.yfilter != YFilter.not_set or
                                self.protocol_nsf.yfilter != YFilter.not_set or
                                self.protocol_router_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "protocol-summary" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.administrative_distance_external.is_set or self.administrative_distance_external.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.administrative_distance_external.get_name_leafdata())
                            if (self.administrative_distance_inter_area.is_set or self.administrative_distance_inter_area.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.administrative_distance_inter_area.get_name_leafdata())
                            if (self.dist_list_in.is_set or self.dist_list_in.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dist_list_in.get_name_leafdata())
                            if (self.protocol_distance.is_set or self.protocol_distance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol_distance.get_name_leafdata())
                            if (self.protocol_nsf.is_set or self.protocol_nsf.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol_nsf.get_name_leafdata())
                            if (self.protocol_router_id.is_set or self.protocol_router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol_router_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "administrative-distance-external" or name == "administrative-distance-inter-area" or name == "dist-list-in" or name == "protocol-distance" or name == "protocol-nsf" or name == "protocol-router-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "administrative-distance-external"):
                                self.administrative_distance_external = value
                                self.administrative_distance_external.value_namespace = name_space
                                self.administrative_distance_external.value_namespace_prefix = name_space_prefix
                            if(value_path == "administrative-distance-inter-area"):
                                self.administrative_distance_inter_area = value
                                self.administrative_distance_inter_area.value_namespace = name_space
                                self.administrative_distance_inter_area.value_namespace_prefix = name_space_prefix
                            if(value_path == "dist-list-in"):
                                self.dist_list_in = value
                                self.dist_list_in.value_namespace = name_space
                                self.dist_list_in.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol-distance"):
                                self.protocol_distance = value
                                self.protocol_distance.value_namespace = name_space
                                self.protocol_distance.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol-nsf"):
                                self.protocol_nsf = value
                                self.protocol_nsf.value_namespace = name_space
                                self.protocol_nsf.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol-router-id"):
                                self.protocol_router_id = value
                                self.protocol_router_id.value_namespace = name_space
                                self.protocol_router_id.value_namespace_prefix = name_space_prefix


                    class Redistributions(Entity):
                        """
                        Redistribution information table
                        
                        .. attribute:: redistribution
                        
                        	Redistribution information
                        	**type**\: list of    :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions, self).__init__()

                            self.yang_name = "redistributions"
                            self.yang_parent_name = "process-information"

                            self.redistribution = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions, self).__setattr__(name, value)


                        class Redistribution(Entity):
                            """
                            Redistribution information
                            
                            .. attribute:: classless
                            
                            	Whether to use CIDR
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Route metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_flag
                            
                            	If true, Metric configured
                            	**type**\:  bool
                            
                            .. attribute:: nssa_only
                            
                            	To NSSA areas only
                            	**type**\:  bool
                            
                            .. attribute:: process_name
                            
                            	Process name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: protocol_name
                            
                            	Protocol name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: redistribution_protocol
                            
                            	Protocol Information
                            	**type**\:   :py:class:`RedistributionProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution, self).__init__()

                                self.yang_name = "redistribution"
                                self.yang_parent_name = "redistributions"

                                self.classless = YLeaf(YType.boolean, "classless")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_flag = YLeaf(YType.boolean, "metric-flag")

                                self.nssa_only = YLeaf(YType.boolean, "nssa-only")

                                self.process_name = YLeaf(YType.str, "process-name")

                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                self.redistribution_protocol = Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol()
                                self.redistribution_protocol.parent = self
                                self._children_name_map["redistribution_protocol"] = "redistribution-protocol"
                                self._children_yang_names.add("redistribution-protocol")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("classless",
                                                "metric",
                                                "metric_flag",
                                                "nssa_only",
                                                "process_name",
                                                "protocol_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution, self).__setattr__(name, value)


                            class RedistributionProtocol(Entity):
                                """
                                Protocol Information
                                
                                .. attribute:: bgp_as_number
                                
                                	BGP Autonomous System Number
                                	**type**\:  str
                                
                                .. attribute:: connected_instance
                                
                                	Connected instance name
                                	**type**\:  str
                                
                                .. attribute:: eigrp_as_number
                                
                                	Autonomous System Number
                                	**type**\:  str
                                
                                .. attribute:: isis_instance_id
                                
                                	ISIS instance identifier
                                	**type**\:  str
                                
                                .. attribute:: ospf_process_id
                                
                                	OSPF process identifier
                                	**type**\:  str
                                
                                .. attribute:: protocol_type
                                
                                	ProtocolType
                                	**type**\:   :py:class:`RedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.RedistProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol, self).__init__()

                                    self.yang_name = "redistribution-protocol"
                                    self.yang_parent_name = "redistribution"

                                    self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                    self.connected_instance = YLeaf(YType.str, "connected-instance")

                                    self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                    self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                    self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                    self.protocol_type = YLeaf(YType.enumeration, "protocol-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bgp_as_number",
                                                    "connected_instance",
                                                    "eigrp_as_number",
                                                    "isis_instance_id",
                                                    "ospf_process_id",
                                                    "protocol_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bgp_as_number.is_set or
                                        self.connected_instance.is_set or
                                        self.eigrp_as_number.is_set or
                                        self.isis_instance_id.is_set or
                                        self.ospf_process_id.is_set or
                                        self.protocol_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bgp_as_number.yfilter != YFilter.not_set or
                                        self.connected_instance.yfilter != YFilter.not_set or
                                        self.eigrp_as_number.yfilter != YFilter.not_set or
                                        self.isis_instance_id.yfilter != YFilter.not_set or
                                        self.ospf_process_id.yfilter != YFilter.not_set or
                                        self.protocol_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "redistribution-protocol" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bgp_as_number.is_set or self.bgp_as_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_as_number.get_name_leafdata())
                                    if (self.connected_instance.is_set or self.connected_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.connected_instance.get_name_leafdata())
                                    if (self.eigrp_as_number.is_set or self.eigrp_as_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.eigrp_as_number.get_name_leafdata())
                                    if (self.isis_instance_id.is_set or self.isis_instance_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.isis_instance_id.get_name_leafdata())
                                    if (self.ospf_process_id.is_set or self.ospf_process_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_process_id.get_name_leafdata())
                                    if (self.protocol_type.is_set or self.protocol_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bgp-as-number" or name == "connected-instance" or name == "eigrp-as-number" or name == "isis-instance-id" or name == "ospf-process-id" or name == "protocol-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bgp-as-number"):
                                        self.bgp_as_number = value
                                        self.bgp_as_number.value_namespace = name_space
                                        self.bgp_as_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "connected-instance"):
                                        self.connected_instance = value
                                        self.connected_instance.value_namespace = name_space
                                        self.connected_instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "eigrp-as-number"):
                                        self.eigrp_as_number = value
                                        self.eigrp_as_number.value_namespace = name_space
                                        self.eigrp_as_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "isis-instance-id"):
                                        self.isis_instance_id = value
                                        self.isis_instance_id.value_namespace = name_space
                                        self.isis_instance_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-process-id"):
                                        self.ospf_process_id = value
                                        self.ospf_process_id.value_namespace = name_space
                                        self.ospf_process_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol-type"):
                                        self.protocol_type = value
                                        self.protocol_type.value_namespace = name_space
                                        self.protocol_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.classless.is_set or
                                    self.metric.is_set or
                                    self.metric_flag.is_set or
                                    self.nssa_only.is_set or
                                    self.process_name.is_set or
                                    self.protocol_name.is_set or
                                    (self.redistribution_protocol is not None and self.redistribution_protocol.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.classless.yfilter != YFilter.not_set or
                                    self.metric.yfilter != YFilter.not_set or
                                    self.metric_flag.yfilter != YFilter.not_set or
                                    self.nssa_only.yfilter != YFilter.not_set or
                                    self.process_name.yfilter != YFilter.not_set or
                                    self.protocol_name.yfilter != YFilter.not_set or
                                    (self.redistribution_protocol is not None and self.redistribution_protocol.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "redistribution" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.classless.is_set or self.classless.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.classless.get_name_leafdata())
                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                if (self.metric_flag.is_set or self.metric_flag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric_flag.get_name_leafdata())
                                if (self.nssa_only.is_set or self.nssa_only.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nssa_only.get_name_leafdata())
                                if (self.process_name.is_set or self.process_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.process_name.get_name_leafdata())
                                if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "redistribution-protocol"):
                                    if (self.redistribution_protocol is None):
                                        self.redistribution_protocol = Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol()
                                        self.redistribution_protocol.parent = self
                                        self._children_name_map["redistribution_protocol"] = "redistribution-protocol"
                                    return self.redistribution_protocol

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "redistribution-protocol" or name == "classless" or name == "metric" or name == "metric-flag" or name == "nssa-only" or name == "process-name" or name == "protocol-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "classless"):
                                    self.classless = value
                                    self.classless.value_namespace = name_space
                                    self.classless.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric"):
                                    self.metric = value
                                    self.metric.value_namespace = name_space
                                    self.metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric-flag"):
                                    self.metric_flag = value
                                    self.metric_flag.value_namespace = name_space
                                    self.metric_flag.value_namespace_prefix = name_space_prefix
                                if(value_path == "nssa-only"):
                                    self.nssa_only = value
                                    self.nssa_only.value_namespace = name_space
                                    self.nssa_only.value_namespace_prefix = name_space_prefix
                                if(value_path == "process-name"):
                                    self.process_name = value
                                    self.process_name.value_namespace = name_space
                                    self.process_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol-name"):
                                    self.protocol_name = value
                                    self.protocol_name.value_namespace = name_space
                                    self.protocol_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.redistribution:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.redistribution:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "redistributions" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "redistribution"):
                                for c in self.redistribution:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.redistribution.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "redistribution"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class ProcessAreas(Entity):
                        """
                        Process Area table
                        
                        .. attribute:: process_area
                        
                        	Detailed information for a particular area
                        	**type**\: list of    :py:class:`ProcessArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas, self).__init__()

                            self.yang_name = "process-areas"
                            self.yang_parent_name = "process-information"

                            self.process_area = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas, self).__setattr__(name, value)


                        class ProcessArea(Entity):
                            """
                            Detailed information for a particular area
                            
                            .. attribute:: address
                            
                            	Area ID if in IP address format
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_adj_stag_num_nbr_forming
                            
                            	Num of nbrs currently forming
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: area_dc_bitless_lsa_count
                            
                            	Number of LSA with demand circuit bit not set
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_id
                            
                            	Area ID if in integer format
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: area_id_string
                            
                            	Area ID string
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: area_interface_count
                            
                            	Number of interfaces in the area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: area_lfa_interface_count
                            
                            	Number of LFA enabled interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_lfa_revision
                            
                            	Area LFA revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_lsa_checksum
                            
                            	Sum of all area LSAs checksum
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_lsa_count
                            
                            	Number of LSAs in the Area
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_nssa
                            
                            	If true, area is a NSSA
                            	**type**\:  bool
                            
                            .. attribute:: area_num_nbr_full
                            
                            	Num of full nbrs in area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: area_opaque_lsa_checksum
                            
                            	Sum of opaque LSA checksums
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_opaque_lsa_count
                            
                            	Number of Opaque LSAs in the Area
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_per_prefix_lfa_interface_count
                            
                            	Number of Per Prefix LFA enabled interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_policy_in
                            
                            	If true, inbound policy is configured
                            	**type**\:  bool
                            
                            .. attribute:: area_policy_in_name
                            
                            	Inbound summary lsa filtering policy
                            	**type**\:  str
                            
                            .. attribute:: area_policy_out
                            
                            	If true, outbound policy is configured
                            	**type**\:  bool
                            
                            .. attribute:: area_policy_out_name
                            
                            	Outbound summary lsa filtering policy
                            	**type**\:  str
                            
                            .. attribute:: area_range
                            
                            	List of ranges to summarize
                            	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange>`
                            
                            .. attribute:: area_stub
                            
                            	If true, stub area
                            	**type**\:  bool
                            
                            .. attribute:: area_total_stub
                            
                            	If true, totally stubby area
                            	**type**\:  bool
                            
                            .. attribute:: authentication_type
                            
                            	Authentication type
                            	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                            
                            .. attribute:: backbone_area_active
                            
                            	If true, Backbone area is active
                            	**type**\:  bool
                            
                            .. attribute:: dna_lsa_count
                            
                            	Number of DoNotAge LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_out
                            
                            	If true, advertise intra\-area prefixes as external
                            	**type**\:  bool
                            
                            .. attribute:: flood_list_length
                            
                            	Number of LSAs which need to be flooded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: indication_lsa_count
                            
                            	Number of indication LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nssa_default
                            
                            	If true, generate NSSA default route
                            	**type**\:  bool
                            
                            .. attribute:: nssa_no_redistribution
                            
                            	If true, No redistribution into this NSSA area
                            	**type**\:  bool
                            
                            .. attribute:: nssa_translate
                            
                            	If true, perform 7/5 translation
                            	**type**\:  bool
                            
                            .. attribute:: segment_routing
                            
                            	If true, Segment Routing enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_count
                            
                            	Number of SPF calculations run
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sr_microloop_avoidance_active
                            
                            	If true, Segment routing Uloop avoidance         is currently active in this area
                            	**type**\:  bool
                            
                            .. attribute:: sr_microloop_avoidance_event_type
                            
                            	Event for which SR uloop is triggered            Link Up/Link Down
                            	**type**\:   :py:class:`SrUloopEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrUloopEvent>`
                            
                            .. attribute:: sr_microloop_avoidance_far_end_id
                            
                            	Link State ID of the far end                     of the topology change
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: sr_microloop_avoidance_near_end_id
                            
                            	Link State ID of the near end                    of the topology change
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: sr_microloop_avoidance_pseudonode_id
                            
                            	Link State ID of the pseudo node,                if the change is on a broadcast link
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: sr_strict_spf_cap
                            
                            	If true, All routers in Area are SR Strict\-SPF Capable
                            	**type**\:  bool
                            
                            .. attribute:: sr_strict_spfsids_available
                            
                            	If true, All routers in Area have SR Strict\-SPF SIDs
                            	**type**\:  bool
                            
                            .. attribute:: stub_default_cost
                            
                            	Default cost for Stub or NSSA area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: summary_in
                            
                            	If true, advertise redistributedprefixes as summary
                            	**type**\:  bool
                            
                            .. attribute:: te_enabled
                            
                            	If true, MPLS\-TE enabled
                            	**type**\:  bool
                            
                            .. attribute:: te_topology_version
                            
                            	TE area topology version number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea, self).__init__()

                                self.yang_name = "process-area"
                                self.yang_parent_name = "process-areas"

                                self.address = YLeaf(YType.str, "address")

                                self.area_adj_stag_num_nbr_forming = YLeaf(YType.uint16, "area-adj-stag-num-nbr-forming")

                                self.area_dc_bitless_lsa_count = YLeaf(YType.uint32, "area-dc-bitless-lsa-count")

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.area_id_string = YLeaf(YType.str, "area-id-string")

                                self.area_interface_count = YLeaf(YType.uint16, "area-interface-count")

                                self.area_lfa_interface_count = YLeaf(YType.uint32, "area-lfa-interface-count")

                                self.area_lfa_revision = YLeaf(YType.uint32, "area-lfa-revision")

                                self.area_lsa_checksum = YLeaf(YType.uint32, "area-lsa-checksum")

                                self.area_lsa_count = YLeaf(YType.uint32, "area-lsa-count")

                                self.area_nssa = YLeaf(YType.boolean, "area-nssa")

                                self.area_num_nbr_full = YLeaf(YType.uint16, "area-num-nbr-full")

                                self.area_opaque_lsa_checksum = YLeaf(YType.uint32, "area-opaque-lsa-checksum")

                                self.area_opaque_lsa_count = YLeaf(YType.uint32, "area-opaque-lsa-count")

                                self.area_per_prefix_lfa_interface_count = YLeaf(YType.uint32, "area-per-prefix-lfa-interface-count")

                                self.area_policy_in = YLeaf(YType.boolean, "area-policy-in")

                                self.area_policy_in_name = YLeaf(YType.str, "area-policy-in-name")

                                self.area_policy_out = YLeaf(YType.boolean, "area-policy-out")

                                self.area_policy_out_name = YLeaf(YType.str, "area-policy-out-name")

                                self.area_stub = YLeaf(YType.boolean, "area-stub")

                                self.area_total_stub = YLeaf(YType.boolean, "area-total-stub")

                                self.authentication_type = YLeaf(YType.enumeration, "authentication-type")

                                self.backbone_area_active = YLeaf(YType.boolean, "backbone-area-active")

                                self.dna_lsa_count = YLeaf(YType.uint32, "dna-lsa-count")

                                self.external_out = YLeaf(YType.boolean, "external-out")

                                self.flood_list_length = YLeaf(YType.uint32, "flood-list-length")

                                self.indication_lsa_count = YLeaf(YType.uint32, "indication-lsa-count")

                                self.nssa_default = YLeaf(YType.boolean, "nssa-default")

                                self.nssa_no_redistribution = YLeaf(YType.boolean, "nssa-no-redistribution")

                                self.nssa_translate = YLeaf(YType.boolean, "nssa-translate")

                                self.segment_routing = YLeaf(YType.uint32, "segment-routing")

                                self.spf_count = YLeaf(YType.uint32, "spf-count")

                                self.sr_microloop_avoidance_active = YLeaf(YType.boolean, "sr-microloop-avoidance-active")

                                self.sr_microloop_avoidance_event_type = YLeaf(YType.enumeration, "sr-microloop-avoidance-event-type")

                                self.sr_microloop_avoidance_far_end_id = YLeaf(YType.str, "sr-microloop-avoidance-far-end-id")

                                self.sr_microloop_avoidance_near_end_id = YLeaf(YType.str, "sr-microloop-avoidance-near-end-id")

                                self.sr_microloop_avoidance_pseudonode_id = YLeaf(YType.str, "sr-microloop-avoidance-pseudonode-id")

                                self.sr_strict_spf_cap = YLeaf(YType.boolean, "sr-strict-spf-cap")

                                self.sr_strict_spfsids_available = YLeaf(YType.boolean, "sr-strict-spfsids-available")

                                self.stub_default_cost = YLeaf(YType.uint16, "stub-default-cost")

                                self.summary_in = YLeaf(YType.boolean, "summary-in")

                                self.te_enabled = YLeaf(YType.boolean, "te-enabled")

                                self.te_topology_version = YLeaf(YType.uint32, "te-topology-version")

                                self.area_range = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "area_adj_stag_num_nbr_forming",
                                                "area_dc_bitless_lsa_count",
                                                "area_id",
                                                "area_id_string",
                                                "area_interface_count",
                                                "area_lfa_interface_count",
                                                "area_lfa_revision",
                                                "area_lsa_checksum",
                                                "area_lsa_count",
                                                "area_nssa",
                                                "area_num_nbr_full",
                                                "area_opaque_lsa_checksum",
                                                "area_opaque_lsa_count",
                                                "area_per_prefix_lfa_interface_count",
                                                "area_policy_in",
                                                "area_policy_in_name",
                                                "area_policy_out",
                                                "area_policy_out_name",
                                                "area_stub",
                                                "area_total_stub",
                                                "authentication_type",
                                                "backbone_area_active",
                                                "dna_lsa_count",
                                                "external_out",
                                                "flood_list_length",
                                                "indication_lsa_count",
                                                "nssa_default",
                                                "nssa_no_redistribution",
                                                "nssa_translate",
                                                "segment_routing",
                                                "spf_count",
                                                "sr_microloop_avoidance_active",
                                                "sr_microloop_avoidance_event_type",
                                                "sr_microloop_avoidance_far_end_id",
                                                "sr_microloop_avoidance_near_end_id",
                                                "sr_microloop_avoidance_pseudonode_id",
                                                "sr_strict_spf_cap",
                                                "sr_strict_spfsids_available",
                                                "stub_default_cost",
                                                "summary_in",
                                                "te_enabled",
                                                "te_topology_version") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea, self).__setattr__(name, value)


                            class AreaRange(Entity):
                                """
                                List of ranges to summarize
                                
                                .. attribute:: advertise_flag
                                
                                	Whether to advertise Summary LSAs for this range
                                	**type**\:  bool
                                
                                .. attribute:: cost
                                
                                	Cost
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_mask
                                
                                	Network mask
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: range_prefix
                                
                                	IP prefix for summarization
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange, self).__init__()

                                    self.yang_name = "area-range"
                                    self.yang_parent_name = "process-area"

                                    self.advertise_flag = YLeaf(YType.boolean, "advertise-flag")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.range_mask = YLeaf(YType.str, "range-mask")

                                    self.range_prefix = YLeaf(YType.str, "range-prefix")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("advertise_flag",
                                                    "cost",
                                                    "range_mask",
                                                    "range_prefix") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.advertise_flag.is_set or
                                        self.cost.is_set or
                                        self.range_mask.is_set or
                                        self.range_prefix.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.advertise_flag.yfilter != YFilter.not_set or
                                        self.cost.yfilter != YFilter.not_set or
                                        self.range_mask.yfilter != YFilter.not_set or
                                        self.range_prefix.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "area-range" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.advertise_flag.is_set or self.advertise_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.advertise_flag.get_name_leafdata())
                                    if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cost.get_name_leafdata())
                                    if (self.range_mask.is_set or self.range_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.range_mask.get_name_leafdata())
                                    if (self.range_prefix.is_set or self.range_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.range_prefix.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "advertise-flag" or name == "cost" or name == "range-mask" or name == "range-prefix"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "advertise-flag"):
                                        self.advertise_flag = value
                                        self.advertise_flag.value_namespace = name_space
                                        self.advertise_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cost"):
                                        self.cost = value
                                        self.cost.value_namespace = name_space
                                        self.cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "range-mask"):
                                        self.range_mask = value
                                        self.range_mask.value_namespace = name_space
                                        self.range_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "range-prefix"):
                                        self.range_prefix = value
                                        self.range_prefix.value_namespace = name_space
                                        self.range_prefix.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.area_range:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.address.is_set or
                                    self.area_adj_stag_num_nbr_forming.is_set or
                                    self.area_dc_bitless_lsa_count.is_set or
                                    self.area_id.is_set or
                                    self.area_id_string.is_set or
                                    self.area_interface_count.is_set or
                                    self.area_lfa_interface_count.is_set or
                                    self.area_lfa_revision.is_set or
                                    self.area_lsa_checksum.is_set or
                                    self.area_lsa_count.is_set or
                                    self.area_nssa.is_set or
                                    self.area_num_nbr_full.is_set or
                                    self.area_opaque_lsa_checksum.is_set or
                                    self.area_opaque_lsa_count.is_set or
                                    self.area_per_prefix_lfa_interface_count.is_set or
                                    self.area_policy_in.is_set or
                                    self.area_policy_in_name.is_set or
                                    self.area_policy_out.is_set or
                                    self.area_policy_out_name.is_set or
                                    self.area_stub.is_set or
                                    self.area_total_stub.is_set or
                                    self.authentication_type.is_set or
                                    self.backbone_area_active.is_set or
                                    self.dna_lsa_count.is_set or
                                    self.external_out.is_set or
                                    self.flood_list_length.is_set or
                                    self.indication_lsa_count.is_set or
                                    self.nssa_default.is_set or
                                    self.nssa_no_redistribution.is_set or
                                    self.nssa_translate.is_set or
                                    self.segment_routing.is_set or
                                    self.spf_count.is_set or
                                    self.sr_microloop_avoidance_active.is_set or
                                    self.sr_microloop_avoidance_event_type.is_set or
                                    self.sr_microloop_avoidance_far_end_id.is_set or
                                    self.sr_microloop_avoidance_near_end_id.is_set or
                                    self.sr_microloop_avoidance_pseudonode_id.is_set or
                                    self.sr_strict_spf_cap.is_set or
                                    self.sr_strict_spfsids_available.is_set or
                                    self.stub_default_cost.is_set or
                                    self.summary_in.is_set or
                                    self.te_enabled.is_set or
                                    self.te_topology_version.is_set)

                            def has_operation(self):
                                for c in self.area_range:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.area_adj_stag_num_nbr_forming.yfilter != YFilter.not_set or
                                    self.area_dc_bitless_lsa_count.yfilter != YFilter.not_set or
                                    self.area_id.yfilter != YFilter.not_set or
                                    self.area_id_string.yfilter != YFilter.not_set or
                                    self.area_interface_count.yfilter != YFilter.not_set or
                                    self.area_lfa_interface_count.yfilter != YFilter.not_set or
                                    self.area_lfa_revision.yfilter != YFilter.not_set or
                                    self.area_lsa_checksum.yfilter != YFilter.not_set or
                                    self.area_lsa_count.yfilter != YFilter.not_set or
                                    self.area_nssa.yfilter != YFilter.not_set or
                                    self.area_num_nbr_full.yfilter != YFilter.not_set or
                                    self.area_opaque_lsa_checksum.yfilter != YFilter.not_set or
                                    self.area_opaque_lsa_count.yfilter != YFilter.not_set or
                                    self.area_per_prefix_lfa_interface_count.yfilter != YFilter.not_set or
                                    self.area_policy_in.yfilter != YFilter.not_set or
                                    self.area_policy_in_name.yfilter != YFilter.not_set or
                                    self.area_policy_out.yfilter != YFilter.not_set or
                                    self.area_policy_out_name.yfilter != YFilter.not_set or
                                    self.area_stub.yfilter != YFilter.not_set or
                                    self.area_total_stub.yfilter != YFilter.not_set or
                                    self.authentication_type.yfilter != YFilter.not_set or
                                    self.backbone_area_active.yfilter != YFilter.not_set or
                                    self.dna_lsa_count.yfilter != YFilter.not_set or
                                    self.external_out.yfilter != YFilter.not_set or
                                    self.flood_list_length.yfilter != YFilter.not_set or
                                    self.indication_lsa_count.yfilter != YFilter.not_set or
                                    self.nssa_default.yfilter != YFilter.not_set or
                                    self.nssa_no_redistribution.yfilter != YFilter.not_set or
                                    self.nssa_translate.yfilter != YFilter.not_set or
                                    self.segment_routing.yfilter != YFilter.not_set or
                                    self.spf_count.yfilter != YFilter.not_set or
                                    self.sr_microloop_avoidance_active.yfilter != YFilter.not_set or
                                    self.sr_microloop_avoidance_event_type.yfilter != YFilter.not_set or
                                    self.sr_microloop_avoidance_far_end_id.yfilter != YFilter.not_set or
                                    self.sr_microloop_avoidance_near_end_id.yfilter != YFilter.not_set or
                                    self.sr_microloop_avoidance_pseudonode_id.yfilter != YFilter.not_set or
                                    self.sr_strict_spf_cap.yfilter != YFilter.not_set or
                                    self.sr_strict_spfsids_available.yfilter != YFilter.not_set or
                                    self.stub_default_cost.yfilter != YFilter.not_set or
                                    self.summary_in.yfilter != YFilter.not_set or
                                    self.te_enabled.yfilter != YFilter.not_set or
                                    self.te_topology_version.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "process-area" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.area_adj_stag_num_nbr_forming.is_set or self.area_adj_stag_num_nbr_forming.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_adj_stag_num_nbr_forming.get_name_leafdata())
                                if (self.area_dc_bitless_lsa_count.is_set or self.area_dc_bitless_lsa_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_dc_bitless_lsa_count.get_name_leafdata())
                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                if (self.area_id_string.is_set or self.area_id_string.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_id_string.get_name_leafdata())
                                if (self.area_interface_count.is_set or self.area_interface_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_interface_count.get_name_leafdata())
                                if (self.area_lfa_interface_count.is_set or self.area_lfa_interface_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_lfa_interface_count.get_name_leafdata())
                                if (self.area_lfa_revision.is_set or self.area_lfa_revision.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_lfa_revision.get_name_leafdata())
                                if (self.area_lsa_checksum.is_set or self.area_lsa_checksum.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_lsa_checksum.get_name_leafdata())
                                if (self.area_lsa_count.is_set or self.area_lsa_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_lsa_count.get_name_leafdata())
                                if (self.area_nssa.is_set or self.area_nssa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_nssa.get_name_leafdata())
                                if (self.area_num_nbr_full.is_set or self.area_num_nbr_full.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_num_nbr_full.get_name_leafdata())
                                if (self.area_opaque_lsa_checksum.is_set or self.area_opaque_lsa_checksum.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_opaque_lsa_checksum.get_name_leafdata())
                                if (self.area_opaque_lsa_count.is_set or self.area_opaque_lsa_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_opaque_lsa_count.get_name_leafdata())
                                if (self.area_per_prefix_lfa_interface_count.is_set or self.area_per_prefix_lfa_interface_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_per_prefix_lfa_interface_count.get_name_leafdata())
                                if (self.area_policy_in.is_set or self.area_policy_in.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_policy_in.get_name_leafdata())
                                if (self.area_policy_in_name.is_set or self.area_policy_in_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_policy_in_name.get_name_leafdata())
                                if (self.area_policy_out.is_set or self.area_policy_out.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_policy_out.get_name_leafdata())
                                if (self.area_policy_out_name.is_set or self.area_policy_out_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_policy_out_name.get_name_leafdata())
                                if (self.area_stub.is_set or self.area_stub.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_stub.get_name_leafdata())
                                if (self.area_total_stub.is_set or self.area_total_stub.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_total_stub.get_name_leafdata())
                                if (self.authentication_type.is_set or self.authentication_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.authentication_type.get_name_leafdata())
                                if (self.backbone_area_active.is_set or self.backbone_area_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backbone_area_active.get_name_leafdata())
                                if (self.dna_lsa_count.is_set or self.dna_lsa_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dna_lsa_count.get_name_leafdata())
                                if (self.external_out.is_set or self.external_out.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_out.get_name_leafdata())
                                if (self.flood_list_length.is_set or self.flood_list_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_list_length.get_name_leafdata())
                                if (self.indication_lsa_count.is_set or self.indication_lsa_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.indication_lsa_count.get_name_leafdata())
                                if (self.nssa_default.is_set or self.nssa_default.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nssa_default.get_name_leafdata())
                                if (self.nssa_no_redistribution.is_set or self.nssa_no_redistribution.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nssa_no_redistribution.get_name_leafdata())
                                if (self.nssa_translate.is_set or self.nssa_translate.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nssa_translate.get_name_leafdata())
                                if (self.segment_routing.is_set or self.segment_routing.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_routing.get_name_leafdata())
                                if (self.spf_count.is_set or self.spf_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spf_count.get_name_leafdata())
                                if (self.sr_microloop_avoidance_active.is_set or self.sr_microloop_avoidance_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sr_microloop_avoidance_active.get_name_leafdata())
                                if (self.sr_microloop_avoidance_event_type.is_set or self.sr_microloop_avoidance_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sr_microloop_avoidance_event_type.get_name_leafdata())
                                if (self.sr_microloop_avoidance_far_end_id.is_set or self.sr_microloop_avoidance_far_end_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sr_microloop_avoidance_far_end_id.get_name_leafdata())
                                if (self.sr_microloop_avoidance_near_end_id.is_set or self.sr_microloop_avoidance_near_end_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sr_microloop_avoidance_near_end_id.get_name_leafdata())
                                if (self.sr_microloop_avoidance_pseudonode_id.is_set or self.sr_microloop_avoidance_pseudonode_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sr_microloop_avoidance_pseudonode_id.get_name_leafdata())
                                if (self.sr_strict_spf_cap.is_set or self.sr_strict_spf_cap.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sr_strict_spf_cap.get_name_leafdata())
                                if (self.sr_strict_spfsids_available.is_set or self.sr_strict_spfsids_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sr_strict_spfsids_available.get_name_leafdata())
                                if (self.stub_default_cost.is_set or self.stub_default_cost.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.stub_default_cost.get_name_leafdata())
                                if (self.summary_in.is_set or self.summary_in.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_in.get_name_leafdata())
                                if (self.te_enabled.is_set or self.te_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_enabled.get_name_leafdata())
                                if (self.te_topology_version.is_set or self.te_topology_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_topology_version.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "area-range"):
                                    for c in self.area_range:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.area_range.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "area-range" or name == "address" or name == "area-adj-stag-num-nbr-forming" or name == "area-dc-bitless-lsa-count" or name == "area-id" or name == "area-id-string" or name == "area-interface-count" or name == "area-lfa-interface-count" or name == "area-lfa-revision" or name == "area-lsa-checksum" or name == "area-lsa-count" or name == "area-nssa" or name == "area-num-nbr-full" or name == "area-opaque-lsa-checksum" or name == "area-opaque-lsa-count" or name == "area-per-prefix-lfa-interface-count" or name == "area-policy-in" or name == "area-policy-in-name" or name == "area-policy-out" or name == "area-policy-out-name" or name == "area-stub" or name == "area-total-stub" or name == "authentication-type" or name == "backbone-area-active" or name == "dna-lsa-count" or name == "external-out" or name == "flood-list-length" or name == "indication-lsa-count" or name == "nssa-default" or name == "nssa-no-redistribution" or name == "nssa-translate" or name == "segment-routing" or name == "spf-count" or name == "sr-microloop-avoidance-active" or name == "sr-microloop-avoidance-event-type" or name == "sr-microloop-avoidance-far-end-id" or name == "sr-microloop-avoidance-near-end-id" or name == "sr-microloop-avoidance-pseudonode-id" or name == "sr-strict-spf-cap" or name == "sr-strict-spfsids-available" or name == "stub-default-cost" or name == "summary-in" or name == "te-enabled" or name == "te-topology-version"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-adj-stag-num-nbr-forming"):
                                    self.area_adj_stag_num_nbr_forming = value
                                    self.area_adj_stag_num_nbr_forming.value_namespace = name_space
                                    self.area_adj_stag_num_nbr_forming.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-dc-bitless-lsa-count"):
                                    self.area_dc_bitless_lsa_count = value
                                    self.area_dc_bitless_lsa_count.value_namespace = name_space
                                    self.area_dc_bitless_lsa_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-id"):
                                    self.area_id = value
                                    self.area_id.value_namespace = name_space
                                    self.area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-id-string"):
                                    self.area_id_string = value
                                    self.area_id_string.value_namespace = name_space
                                    self.area_id_string.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-interface-count"):
                                    self.area_interface_count = value
                                    self.area_interface_count.value_namespace = name_space
                                    self.area_interface_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-lfa-interface-count"):
                                    self.area_lfa_interface_count = value
                                    self.area_lfa_interface_count.value_namespace = name_space
                                    self.area_lfa_interface_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-lfa-revision"):
                                    self.area_lfa_revision = value
                                    self.area_lfa_revision.value_namespace = name_space
                                    self.area_lfa_revision.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-lsa-checksum"):
                                    self.area_lsa_checksum = value
                                    self.area_lsa_checksum.value_namespace = name_space
                                    self.area_lsa_checksum.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-lsa-count"):
                                    self.area_lsa_count = value
                                    self.area_lsa_count.value_namespace = name_space
                                    self.area_lsa_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-nssa"):
                                    self.area_nssa = value
                                    self.area_nssa.value_namespace = name_space
                                    self.area_nssa.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-num-nbr-full"):
                                    self.area_num_nbr_full = value
                                    self.area_num_nbr_full.value_namespace = name_space
                                    self.area_num_nbr_full.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-opaque-lsa-checksum"):
                                    self.area_opaque_lsa_checksum = value
                                    self.area_opaque_lsa_checksum.value_namespace = name_space
                                    self.area_opaque_lsa_checksum.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-opaque-lsa-count"):
                                    self.area_opaque_lsa_count = value
                                    self.area_opaque_lsa_count.value_namespace = name_space
                                    self.area_opaque_lsa_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-per-prefix-lfa-interface-count"):
                                    self.area_per_prefix_lfa_interface_count = value
                                    self.area_per_prefix_lfa_interface_count.value_namespace = name_space
                                    self.area_per_prefix_lfa_interface_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-policy-in"):
                                    self.area_policy_in = value
                                    self.area_policy_in.value_namespace = name_space
                                    self.area_policy_in.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-policy-in-name"):
                                    self.area_policy_in_name = value
                                    self.area_policy_in_name.value_namespace = name_space
                                    self.area_policy_in_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-policy-out"):
                                    self.area_policy_out = value
                                    self.area_policy_out.value_namespace = name_space
                                    self.area_policy_out.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-policy-out-name"):
                                    self.area_policy_out_name = value
                                    self.area_policy_out_name.value_namespace = name_space
                                    self.area_policy_out_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-stub"):
                                    self.area_stub = value
                                    self.area_stub.value_namespace = name_space
                                    self.area_stub.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-total-stub"):
                                    self.area_total_stub = value
                                    self.area_total_stub.value_namespace = name_space
                                    self.area_total_stub.value_namespace_prefix = name_space_prefix
                                if(value_path == "authentication-type"):
                                    self.authentication_type = value
                                    self.authentication_type.value_namespace = name_space
                                    self.authentication_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "backbone-area-active"):
                                    self.backbone_area_active = value
                                    self.backbone_area_active.value_namespace = name_space
                                    self.backbone_area_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "dna-lsa-count"):
                                    self.dna_lsa_count = value
                                    self.dna_lsa_count.value_namespace = name_space
                                    self.dna_lsa_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "external-out"):
                                    self.external_out = value
                                    self.external_out.value_namespace = name_space
                                    self.external_out.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-list-length"):
                                    self.flood_list_length = value
                                    self.flood_list_length.value_namespace = name_space
                                    self.flood_list_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "indication-lsa-count"):
                                    self.indication_lsa_count = value
                                    self.indication_lsa_count.value_namespace = name_space
                                    self.indication_lsa_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "nssa-default"):
                                    self.nssa_default = value
                                    self.nssa_default.value_namespace = name_space
                                    self.nssa_default.value_namespace_prefix = name_space_prefix
                                if(value_path == "nssa-no-redistribution"):
                                    self.nssa_no_redistribution = value
                                    self.nssa_no_redistribution.value_namespace = name_space
                                    self.nssa_no_redistribution.value_namespace_prefix = name_space_prefix
                                if(value_path == "nssa-translate"):
                                    self.nssa_translate = value
                                    self.nssa_translate.value_namespace = name_space
                                    self.nssa_translate.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-routing"):
                                    self.segment_routing = value
                                    self.segment_routing.value_namespace = name_space
                                    self.segment_routing.value_namespace_prefix = name_space_prefix
                                if(value_path == "spf-count"):
                                    self.spf_count = value
                                    self.spf_count.value_namespace = name_space
                                    self.spf_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "sr-microloop-avoidance-active"):
                                    self.sr_microloop_avoidance_active = value
                                    self.sr_microloop_avoidance_active.value_namespace = name_space
                                    self.sr_microloop_avoidance_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "sr-microloop-avoidance-event-type"):
                                    self.sr_microloop_avoidance_event_type = value
                                    self.sr_microloop_avoidance_event_type.value_namespace = name_space
                                    self.sr_microloop_avoidance_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "sr-microloop-avoidance-far-end-id"):
                                    self.sr_microloop_avoidance_far_end_id = value
                                    self.sr_microloop_avoidance_far_end_id.value_namespace = name_space
                                    self.sr_microloop_avoidance_far_end_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sr-microloop-avoidance-near-end-id"):
                                    self.sr_microloop_avoidance_near_end_id = value
                                    self.sr_microloop_avoidance_near_end_id.value_namespace = name_space
                                    self.sr_microloop_avoidance_near_end_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sr-microloop-avoidance-pseudonode-id"):
                                    self.sr_microloop_avoidance_pseudonode_id = value
                                    self.sr_microloop_avoidance_pseudonode_id.value_namespace = name_space
                                    self.sr_microloop_avoidance_pseudonode_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sr-strict-spf-cap"):
                                    self.sr_strict_spf_cap = value
                                    self.sr_strict_spf_cap.value_namespace = name_space
                                    self.sr_strict_spf_cap.value_namespace_prefix = name_space_prefix
                                if(value_path == "sr-strict-spfsids-available"):
                                    self.sr_strict_spfsids_available = value
                                    self.sr_strict_spfsids_available.value_namespace = name_space
                                    self.sr_strict_spfsids_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "stub-default-cost"):
                                    self.stub_default_cost = value
                                    self.stub_default_cost.value_namespace = name_space
                                    self.stub_default_cost.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-in"):
                                    self.summary_in = value
                                    self.summary_in.value_namespace = name_space
                                    self.summary_in.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-enabled"):
                                    self.te_enabled = value
                                    self.te_enabled.value_namespace = name_space
                                    self.te_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-topology-version"):
                                    self.te_topology_version = value
                                    self.te_topology_version.value_namespace = name_space
                                    self.te_topology_version.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.process_area:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.process_area:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "process-areas" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "process-area"):
                                for c in self.process_area:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.process_area.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "process-area"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class ProcessSummary(Entity):
                        """
                        Basic OSPF summary information
                        
                        .. attribute:: adj_stag_init_num_nbr
                        
                        	Num of nbrs brought up initially per area
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: adj_stag_max_num_nbr
                        
                        	Max num of nbrs brought up simultaneously per OSPF instance
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: adj_stag_num_nbr_forming
                        
                        	Num of nbrs currently forming for OSPF instance
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: adj_stagger_enabled
                        
                        	If true, OSPF Adjacency Staggering is configured
                        	**type**\:  bool
                        
                        .. attribute:: area_border_router
                        
                        	If true, is an Area Border Router
                        	**type**\:  bool
                        
                        .. attribute:: area_count
                        
                        	Number of areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: as_border_router
                        
                        	If true, is an AS Border Router
                        	**type**\:  bool
                        
                        .. attribute:: as_dc_bitless_lsa_count
                        
                        	Number of External and AS Opaque LSAs with demand circut bit not set
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_dna_lsa_count
                        
                        	Number of External and AS Opaque LSAs with DoNotAge set 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_lsa_checksum
                        
                        	Sum of AS scope LSA checksum
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_lsa_count
                        
                        	Number of AS scope LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_lsa_flood_list_length
                        
                        	Length of AS LSAs flood list
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: context_name
                        
                        	Context name
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        .. attribute:: domain_id
                        
                        	Domain ID information
                        	**type**\:   :py:class:`DomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId>`
                        
                        .. attribute:: graceful_shutdown_retention_time
                        
                        	Amount of time routes are retained after graceful shutdown (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: graceful_shutdown_state
                        
                        	State of graceful shutdown
                        	**type**\:   :py:class:`GsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.GsState>`
                        
                        .. attribute:: if_flood_pacing_interval
                        
                        	Flood pacing timer (ms)
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: if_retrans_pacing_interval
                        
                        	Retransmission pacing timer (ms)
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: igp_intact_on
                        
                        	If true, running in IGP\-Intact mode
                        	**type**\:  bool
                        
                        .. attribute:: last_nsf_time
                        
                        	 Length of time since the last NSF (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_hold_time
                        
                        	Second delay before generating next LSA (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_maximum_time
                        
                        	Maximum delay before generating an LSA (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_refresh_interval
                        
                        	LSA refresh interval (sec)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_start_time
                        
                        	Inital LSA throttle delay (ms)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: lsd_bound
                        
                        	True if bound to LSD
                        	**type**\:  bool
                        
                        .. attribute:: lsd_connected
                        
                        	True if connected to LSD
                        	**type**\:  bool
                        
                        .. attribute:: lsd_connection_revision
                        
                        	LSD Connection Revision
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsd_registered
                        
                        	True if registered with LSD
                        	**type**\:  bool
                        
                        .. attribute:: max_lsa_enabled
                        
                        	If true, max\-lsa protection enabled
                        	**type**\:  bool
                        
                        .. attribute:: max_lsa_ignore_count
                        
                        	How many times ignore state has been entered
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_ignore_limit
                        
                        	Max allowed number of entering ignore state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_ignore_time
                        
                        	Time ignoring new LSAs after max\-lsa reached
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_ignore_timer
                        
                        	Remaining time when ignore timer is running
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_limit
                        
                        	Maximum allowed number of non self\-generated LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_reset_time
                        
                        	Time after which LSA protection counter is reset
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_reset_timer
                        
                        	Remaining time when reset timer is running
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_treshold
                        
                        	max\-lsa protection warning threshold
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_warning_only
                        
                        	Warning only when max\-lsa reached
                        	**type**\:  bool
                        
                        .. attribute:: maximum_interfaces
                        
                        	Maximum number of interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_metric
                        
                        	Max\-metric list
                        	**type**\: list of    :py:class:`MaximumMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric>`
                        
                        .. attribute:: maximum_metric_abr_off_buffer_time
                        
                        	Buffer time in seconds since last neighbor activity, to remain in max\-metric ABR off state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: maximum_metric_abr_off_mode
                        
                        	If true, ABR duties temporarily disabled
                        	**type**\:  bool
                        
                        .. attribute:: maximum_metric_abr_off_reasons
                        
                        	Reasons for ABR duties being temporarily disabled
                        	**type**\:   :py:class:`OspfMaxMetricAbrOffReasons <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfMaxMetricAbrOffReasons>`
                        
                        .. attribute:: maximum_metric_set_reason
                        
                        	Max\-metric set reason
                        	**type**\:   :py:class:`MaxMetricSetReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MaxMetricSetReason>`
                        
                        .. attribute:: maximum_metric_start
                        
                        	If true, originate Router LSA with maximum metric
                        	**type**\:  bool
                        
                        .. attribute:: maximum_metric_start_timer
                        
                        	Time remaining for hold down timer (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: microloop_avoidance_active
                        
                        	If true, Uloop is active
                        	**type**\:  bool
                        
                        .. attribute:: microloop_avoidance_delay
                        
                        	Microloop delay time after which actual          post convergence paths are given to RIB (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: microloop_avoidance_delay_expiry
                        
                        	Remaining time for uloop delay timer             to expire (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: microloop_avoidance_type
                        
                        	Microloop avoidance type configured
                        	**type**\:   :py:class:`UloopAvoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.UloopAvoidance>`
                        
                        .. attribute:: minimum_lsa_arrival_interval
                        
                        	Minimum time between accepting LSAs (ms) Rel 4.0 .1, deprecated by MinimumLSAArrivalIntervalU32]
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: minimum_lsa_arrival_interval_u32
                        
                        	Minimum time between accepting LSAs (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_lsa_interval
                        
                        	Minimum time between LSA regeneration (ms) Rel 4 .0.1, deprecated by MinimumLSAIntervalU32]
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: minimum_lsa_interval_u32
                        
                        	Minimum time between LSA regeneration (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: non_self_lsa_count
                        
                        	Non self\-generated LSA count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: normal_area_count
                        
                        	Number of normal Areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nsf_enabled
                        
                        	If true, NSF enabled
                        	**type**\:  bool
                        
                        .. attribute:: nsf_time
                        
                        	Total time to complete NSF (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_enabled
                        
                        	If true, NSR is enabled
                        	**type**\:  bool
                        
                        .. attribute:: nsr_switchover_on_restart
                        
                        	Trigger RP Switchover on detectable process restart
                        	**type**\:  bool
                        
                        .. attribute:: nssa_area_count
                        
                        	Number of NSSA Areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: number_nbrs_full
                        
                        	Num of full nbrs
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: opaque_capable
                        
                        	Opaque LSA capable
                        	**type**\:  bool
                        
                        .. attribute:: opaque_lsa_checksum
                        
                        	Sum of opaque LSA checksum
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: opaque_lsa_count
                        
                        	Number of Opaque LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution
                        
                        	Redistribution list
                        	**type**\: list of    :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution>`
                        
                        .. attribute:: redistribution_limit
                        
                        	The number of redistributed prefixes allowed
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_limit_warn
                        
                        	If true, only a syslog message is printed when redistribution prefix limit is reached
                        	**type**\:  bool
                        
                        .. attribute:: redistribution_threshold
                        
                        	When the number of redistributed prefixes reaches this threshold, a warning message is issued
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: role
                        
                        	Role, V1/V2 Active/Standby
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: role_standby
                        
                        	If true, Role is Standby, Active otherwise
                        	**type**\:  bool
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: snmp_trap_enabled
                        
                        	If true, snmp trap is enabled
                        	**type**\:  bool
                        
                        .. attribute:: spf_hold_time
                        
                        	Minimum delay time between SPF runs (ms) This is valid if configured below 64k Deprecated by SPFHoldTimeU32]
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: spf_hold_time_u32
                        
                        	Minimum delay time between SPF runs (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: spf_maximum_time
                        
                        	Maximum delay time between SPF runs (ms) This is valid if configured below 64k Deprecated by SPFMaximumTimeU32]
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: spf_maximum_time_u32
                        
                        	Maximum delay time between SPF runs (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: spf_prefix_priority
                        
                        	If true, prefix\-priority policy is configured
                        	**type**\:  bool
                        
                        .. attribute:: spf_prefix_priority_route_policy
                        
                        	SPF Prefix\-priority route policy
                        	**type**\:  str
                        
                        .. attribute:: spf_start_time
                        
                        	Scheduling delay for SPF (ms) This is valid if configured below 64k Deprecated by SPFStartTimeU32]
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: spf_start_time_u32
                        
                        	Scheduling delay for SPF (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sr_strict_spf_cap
                        
                        	True if Segment Routing Strict\-SPF capable
                        	**type**\:  bool
                        
                        .. attribute:: srgb_configured
                        
                        	True if Segment Routing Global Block configured
                        	**type**\:  bool
                        
                        .. attribute:: srgb_end
                        
                        	Segment Routing Global Block end label value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: srgb_start
                        
                        	Segment Routing Global Block start label value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: srgb_status
                        
                        	Segment Routing Global Block allocation status
                        	**type**\:   :py:class:`OspfSrgbStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfSrgbStatus>`
                        
                        .. attribute:: stub_area_count
                        
                        	Number of Stub and Total Stub Areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: table_prefix_limit_reached
                        
                        	If true, prefix limit for table has been  reached
                        	**type**\:  bool
                        
                        .. attribute:: tos_options
                        
                        	Type of Service supported
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ucmp
                        
                        	If true, UCMP is enabled
                        	**type**\:  bool
                        
                        .. attribute:: ucmp_delay
                        
                        	Delay between end of SPF and start of UCMP calculation (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ucmp_prefix_list
                        
                        	UCMP Prefix\-list
                        	**type**\:  str
                        
                        .. attribute:: ucmp_variance
                        
                        	UCMP Variance
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: vrf_lite_enabled
                        
                        	If true, vrf lite is enabled
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary, self).__init__()

                            self.yang_name = "process-summary"
                            self.yang_parent_name = "process-information"

                            self.adj_stag_init_num_nbr = YLeaf(YType.uint16, "adj-stag-init-num-nbr")

                            self.adj_stag_max_num_nbr = YLeaf(YType.uint16, "adj-stag-max-num-nbr")

                            self.adj_stag_num_nbr_forming = YLeaf(YType.uint16, "adj-stag-num-nbr-forming")

                            self.adj_stagger_enabled = YLeaf(YType.boolean, "adj-stagger-enabled")

                            self.area_border_router = YLeaf(YType.boolean, "area-border-router")

                            self.area_count = YLeaf(YType.uint16, "area-count")

                            self.as_border_router = YLeaf(YType.boolean, "as-border-router")

                            self.as_dc_bitless_lsa_count = YLeaf(YType.uint32, "as-dc-bitless-lsa-count")

                            self.as_dna_lsa_count = YLeaf(YType.uint32, "as-dna-lsa-count")

                            self.as_lsa_checksum = YLeaf(YType.uint32, "as-lsa-checksum")

                            self.as_lsa_count = YLeaf(YType.uint32, "as-lsa-count")

                            self.as_lsa_flood_list_length = YLeaf(YType.uint32, "as-lsa-flood-list-length")

                            self.context_name = YLeaf(YType.str, "context-name")

                            self.graceful_shutdown_retention_time = YLeaf(YType.uint32, "graceful-shutdown-retention-time")

                            self.graceful_shutdown_state = YLeaf(YType.enumeration, "graceful-shutdown-state")

                            self.if_flood_pacing_interval = YLeaf(YType.uint16, "if-flood-pacing-interval")

                            self.if_retrans_pacing_interval = YLeaf(YType.uint16, "if-retrans-pacing-interval")

                            self.igp_intact_on = YLeaf(YType.boolean, "igp-intact-on")

                            self.last_nsf_time = YLeaf(YType.uint32, "last-nsf-time")

                            self.lsa_hold_time = YLeaf(YType.uint32, "lsa-hold-time")

                            self.lsa_maximum_time = YLeaf(YType.uint32, "lsa-maximum-time")

                            self.lsa_refresh_interval = YLeaf(YType.uint32, "lsa-refresh-interval")

                            self.lsa_start_time = YLeaf(YType.int32, "lsa-start-time")

                            self.lsd_bound = YLeaf(YType.boolean, "lsd-bound")

                            self.lsd_connected = YLeaf(YType.boolean, "lsd-connected")

                            self.lsd_connection_revision = YLeaf(YType.uint32, "lsd-connection-revision")

                            self.lsd_registered = YLeaf(YType.boolean, "lsd-registered")

                            self.max_lsa_enabled = YLeaf(YType.boolean, "max-lsa-enabled")

                            self.max_lsa_ignore_count = YLeaf(YType.uint32, "max-lsa-ignore-count")

                            self.max_lsa_ignore_limit = YLeaf(YType.uint32, "max-lsa-ignore-limit")

                            self.max_lsa_ignore_time = YLeaf(YType.uint32, "max-lsa-ignore-time")

                            self.max_lsa_ignore_timer = YLeaf(YType.uint32, "max-lsa-ignore-timer")

                            self.max_lsa_limit = YLeaf(YType.uint32, "max-lsa-limit")

                            self.max_lsa_reset_time = YLeaf(YType.uint32, "max-lsa-reset-time")

                            self.max_lsa_reset_timer = YLeaf(YType.uint32, "max-lsa-reset-timer")

                            self.max_lsa_treshold = YLeaf(YType.uint32, "max-lsa-treshold")

                            self.max_lsa_warning_only = YLeaf(YType.boolean, "max-lsa-warning-only")

                            self.maximum_interfaces = YLeaf(YType.uint32, "maximum-interfaces")

                            self.maximum_metric_abr_off_buffer_time = YLeaf(YType.uint32, "maximum-metric-abr-off-buffer-time")

                            self.maximum_metric_abr_off_mode = YLeaf(YType.boolean, "maximum-metric-abr-off-mode")

                            self.maximum_metric_abr_off_reasons = YLeaf(YType.enumeration, "maximum-metric-abr-off-reasons")

                            self.maximum_metric_set_reason = YLeaf(YType.enumeration, "maximum-metric-set-reason")

                            self.maximum_metric_start = YLeaf(YType.boolean, "maximum-metric-start")

                            self.maximum_metric_start_timer = YLeaf(YType.uint32, "maximum-metric-start-timer")

                            self.microloop_avoidance_active = YLeaf(YType.boolean, "microloop-avoidance-active")

                            self.microloop_avoidance_delay = YLeaf(YType.uint32, "microloop-avoidance-delay")

                            self.microloop_avoidance_delay_expiry = YLeaf(YType.uint32, "microloop-avoidance-delay-expiry")

                            self.microloop_avoidance_type = YLeaf(YType.enumeration, "microloop-avoidance-type")

                            self.minimum_lsa_arrival_interval = YLeaf(YType.uint16, "minimum-lsa-arrival-interval")

                            self.minimum_lsa_arrival_interval_u32 = YLeaf(YType.uint32, "minimum-lsa-arrival-interval-u32")

                            self.minimum_lsa_interval = YLeaf(YType.uint16, "minimum-lsa-interval")

                            self.minimum_lsa_interval_u32 = YLeaf(YType.uint32, "minimum-lsa-interval-u32")

                            self.non_self_lsa_count = YLeaf(YType.uint32, "non-self-lsa-count")

                            self.normal_area_count = YLeaf(YType.uint16, "normal-area-count")

                            self.nsf_enabled = YLeaf(YType.boolean, "nsf-enabled")

                            self.nsf_time = YLeaf(YType.uint32, "nsf-time")

                            self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                            self.nsr_switchover_on_restart = YLeaf(YType.boolean, "nsr-switchover-on-restart")

                            self.nssa_area_count = YLeaf(YType.uint16, "nssa-area-count")

                            self.number_nbrs_full = YLeaf(YType.uint16, "number-nbrs-full")

                            self.opaque_capable = YLeaf(YType.boolean, "opaque-capable")

                            self.opaque_lsa_checksum = YLeaf(YType.uint32, "opaque-lsa-checksum")

                            self.opaque_lsa_count = YLeaf(YType.uint32, "opaque-lsa-count")

                            self.redistribution_limit = YLeaf(YType.uint32, "redistribution-limit")

                            self.redistribution_limit_warn = YLeaf(YType.boolean, "redistribution-limit-warn")

                            self.redistribution_threshold = YLeaf(YType.uint32, "redistribution-threshold")

                            self.role = YLeaf(YType.uint32, "role")

                            self.role_standby = YLeaf(YType.boolean, "role-standby")

                            self.router_id = YLeaf(YType.str, "router-id")

                            self.snmp_trap_enabled = YLeaf(YType.boolean, "snmp-trap-enabled")

                            self.spf_hold_time = YLeaf(YType.uint16, "spf-hold-time")

                            self.spf_hold_time_u32 = YLeaf(YType.uint32, "spf-hold-time-u32")

                            self.spf_maximum_time = YLeaf(YType.uint16, "spf-maximum-time")

                            self.spf_maximum_time_u32 = YLeaf(YType.uint32, "spf-maximum-time-u32")

                            self.spf_prefix_priority = YLeaf(YType.boolean, "spf-prefix-priority")

                            self.spf_prefix_priority_route_policy = YLeaf(YType.str, "spf-prefix-priority-route-policy")

                            self.spf_start_time = YLeaf(YType.uint16, "spf-start-time")

                            self.spf_start_time_u32 = YLeaf(YType.uint32, "spf-start-time-u32")

                            self.sr_strict_spf_cap = YLeaf(YType.boolean, "sr-strict-spf-cap")

                            self.srgb_configured = YLeaf(YType.boolean, "srgb-configured")

                            self.srgb_end = YLeaf(YType.uint32, "srgb-end")

                            self.srgb_start = YLeaf(YType.uint32, "srgb-start")

                            self.srgb_status = YLeaf(YType.enumeration, "srgb-status")

                            self.stub_area_count = YLeaf(YType.uint16, "stub-area-count")

                            self.table_prefix_limit_reached = YLeaf(YType.boolean, "table-prefix-limit-reached")

                            self.tos_options = YLeaf(YType.uint8, "tos-options")

                            self.ucmp = YLeaf(YType.boolean, "ucmp")

                            self.ucmp_delay = YLeaf(YType.uint32, "ucmp-delay")

                            self.ucmp_prefix_list = YLeaf(YType.str, "ucmp-prefix-list")

                            self.ucmp_variance = YLeaf(YType.int32, "ucmp-variance")

                            self.vrf_lite_enabled = YLeaf(YType.boolean, "vrf-lite-enabled")

                            self.domain_id = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId()
                            self.domain_id.parent = self
                            self._children_name_map["domain_id"] = "domain-id"
                            self._children_yang_names.add("domain-id")

                            self.maximum_metric = YList(self)
                            self.redistribution = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("adj_stag_init_num_nbr",
                                            "adj_stag_max_num_nbr",
                                            "adj_stag_num_nbr_forming",
                                            "adj_stagger_enabled",
                                            "area_border_router",
                                            "area_count",
                                            "as_border_router",
                                            "as_dc_bitless_lsa_count",
                                            "as_dna_lsa_count",
                                            "as_lsa_checksum",
                                            "as_lsa_count",
                                            "as_lsa_flood_list_length",
                                            "context_name",
                                            "graceful_shutdown_retention_time",
                                            "graceful_shutdown_state",
                                            "if_flood_pacing_interval",
                                            "if_retrans_pacing_interval",
                                            "igp_intact_on",
                                            "last_nsf_time",
                                            "lsa_hold_time",
                                            "lsa_maximum_time",
                                            "lsa_refresh_interval",
                                            "lsa_start_time",
                                            "lsd_bound",
                                            "lsd_connected",
                                            "lsd_connection_revision",
                                            "lsd_registered",
                                            "max_lsa_enabled",
                                            "max_lsa_ignore_count",
                                            "max_lsa_ignore_limit",
                                            "max_lsa_ignore_time",
                                            "max_lsa_ignore_timer",
                                            "max_lsa_limit",
                                            "max_lsa_reset_time",
                                            "max_lsa_reset_timer",
                                            "max_lsa_treshold",
                                            "max_lsa_warning_only",
                                            "maximum_interfaces",
                                            "maximum_metric_abr_off_buffer_time",
                                            "maximum_metric_abr_off_mode",
                                            "maximum_metric_abr_off_reasons",
                                            "maximum_metric_set_reason",
                                            "maximum_metric_start",
                                            "maximum_metric_start_timer",
                                            "microloop_avoidance_active",
                                            "microloop_avoidance_delay",
                                            "microloop_avoidance_delay_expiry",
                                            "microloop_avoidance_type",
                                            "minimum_lsa_arrival_interval",
                                            "minimum_lsa_arrival_interval_u32",
                                            "minimum_lsa_interval",
                                            "minimum_lsa_interval_u32",
                                            "non_self_lsa_count",
                                            "normal_area_count",
                                            "nsf_enabled",
                                            "nsf_time",
                                            "nsr_enabled",
                                            "nsr_switchover_on_restart",
                                            "nssa_area_count",
                                            "number_nbrs_full",
                                            "opaque_capable",
                                            "opaque_lsa_checksum",
                                            "opaque_lsa_count",
                                            "redistribution_limit",
                                            "redistribution_limit_warn",
                                            "redistribution_threshold",
                                            "role",
                                            "role_standby",
                                            "router_id",
                                            "snmp_trap_enabled",
                                            "spf_hold_time",
                                            "spf_hold_time_u32",
                                            "spf_maximum_time",
                                            "spf_maximum_time_u32",
                                            "spf_prefix_priority",
                                            "spf_prefix_priority_route_policy",
                                            "spf_start_time",
                                            "spf_start_time_u32",
                                            "sr_strict_spf_cap",
                                            "srgb_configured",
                                            "srgb_end",
                                            "srgb_start",
                                            "srgb_status",
                                            "stub_area_count",
                                            "table_prefix_limit_reached",
                                            "tos_options",
                                            "ucmp",
                                            "ucmp_delay",
                                            "ucmp_prefix_list",
                                            "ucmp_variance",
                                            "vrf_lite_enabled") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary, self).__setattr__(name, value)


                        class DomainId(Entity):
                            """
                            Domain ID information
                            
                            .. attribute:: primary_domain_id
                            
                            	Primary Domain ID
                            	**type**\:   :py:class:`PrimaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId>`
                            
                            .. attribute:: secondary_domain_id
                            
                            	List of secondary domain IDs
                            	**type**\: list of    :py:class:`SecondaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId, self).__init__()

                                self.yang_name = "domain-id"
                                self.yang_parent_name = "process-summary"

                                self.primary_domain_id = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId()
                                self.primary_domain_id.parent = self
                                self._children_name_map["primary_domain_id"] = "primary-domain-id"
                                self._children_yang_names.add("primary-domain-id")

                                self.secondary_domain_id = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId, self).__setattr__(name, value)


                            class PrimaryDomainId(Entity):
                                """
                                Primary Domain ID
                                
                                .. attribute:: domain_id_type
                                
                                	Domain ID Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: domain_id_value
                                
                                	Domain ID value
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId, self).__init__()

                                    self.yang_name = "primary-domain-id"
                                    self.yang_parent_name = "domain-id"

                                    self.domain_id_type = YLeaf(YType.uint16, "domain-id-type")

                                    self.domain_id_value = YLeaf(YType.str, "domain-id-value")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("domain_id_type",
                                                    "domain_id_value") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.domain_id_type.is_set or
                                        self.domain_id_value.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.domain_id_type.yfilter != YFilter.not_set or
                                        self.domain_id_value.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "primary-domain-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.domain_id_type.is_set or self.domain_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.domain_id_type.get_name_leafdata())
                                    if (self.domain_id_value.is_set or self.domain_id_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.domain_id_value.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "domain-id-type" or name == "domain-id-value"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "domain-id-type"):
                                        self.domain_id_type = value
                                        self.domain_id_type.value_namespace = name_space
                                        self.domain_id_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "domain-id-value"):
                                        self.domain_id_value = value
                                        self.domain_id_value.value_namespace = name_space
                                        self.domain_id_value.value_namespace_prefix = name_space_prefix


                            class SecondaryDomainId(Entity):
                                """
                                List of secondary domain IDs
                                
                                .. attribute:: domain_id_type
                                
                                	Domain ID Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: domain_id_value
                                
                                	Domain ID value
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId, self).__init__()

                                    self.yang_name = "secondary-domain-id"
                                    self.yang_parent_name = "domain-id"

                                    self.domain_id_type = YLeaf(YType.uint16, "domain-id-type")

                                    self.domain_id_value = YLeaf(YType.str, "domain-id-value")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("domain_id_type",
                                                    "domain_id_value") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.domain_id_type.is_set or
                                        self.domain_id_value.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.domain_id_type.yfilter != YFilter.not_set or
                                        self.domain_id_value.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "secondary-domain-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.domain_id_type.is_set or self.domain_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.domain_id_type.get_name_leafdata())
                                    if (self.domain_id_value.is_set or self.domain_id_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.domain_id_value.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "domain-id-type" or name == "domain-id-value"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "domain-id-type"):
                                        self.domain_id_type = value
                                        self.domain_id_type.value_namespace = name_space
                                        self.domain_id_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "domain-id-value"):
                                        self.domain_id_value = value
                                        self.domain_id_value.value_namespace = name_space
                                        self.domain_id_value.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.secondary_domain_id:
                                    if (c.has_data()):
                                        return True
                                return (self.primary_domain_id is not None and self.primary_domain_id.has_data())

                            def has_operation(self):
                                for c in self.secondary_domain_id:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.primary_domain_id is not None and self.primary_domain_id.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "domain-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "primary-domain-id"):
                                    if (self.primary_domain_id is None):
                                        self.primary_domain_id = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId()
                                        self.primary_domain_id.parent = self
                                        self._children_name_map["primary_domain_id"] = "primary-domain-id"
                                    return self.primary_domain_id

                                if (child_yang_name == "secondary-domain-id"):
                                    for c in self.secondary_domain_id:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.secondary_domain_id.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "primary-domain-id" or name == "secondary-domain-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class MaximumMetric(Entity):
                            """
                            Max\-metric list
                            
                            .. attribute:: max_metric_enabled
                            
                            	Max\-metric enabled
                            	**type**\:  bool
                            
                            .. attribute:: max_metric_reason
                            
                            	Max\-metric reason
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: maximum_metric_external_lsa
                            
                            	If true, advertise max\-metric in external\-LSAs
                            	**type**\:  bool
                            
                            .. attribute:: maximum_metric_external_lsa_metric
                            
                            	Max\-metric value to advertise in external\-LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_metric_include_stubs
                            
                            	If true, set max\-metric in stub links
                            	**type**\:  bool
                            
                            .. attribute:: maximum_metric_originated_for
                            
                            	Time max\-metric was used for
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_metric_start_time
                            
                            	Time remaining until we will start using normal metrics (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_metric_summary_lsa
                            
                            	If true, advertise max\-metric in summary\-LSAs
                            	**type**\:  bool
                            
                            .. attribute:: maximum_metric_summary_lsa_metric
                            
                            	Max\-metric value to advertise in summary\-LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_metric_time_unset
                            
                            	Time max\-metric condition was cleared
                            	**type**\:   :py:class:`MaximumMetricTimeUnset <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset>`
                            
                            .. attribute:: maximum_metric_unset_reason
                            
                            	Max\-metric unset reason
                            	**type**\:   :py:class:`MaxMetricUnsetReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MaxMetricUnsetReason>`
                            
                            .. attribute:: saved_startup_time
                            
                            	Hold time configured (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: saved_unset_maximum_metric
                            
                            	Saved UnsetMaximumMetric
                            	**type**\:  bool
                            
                            .. attribute:: unset_maximum_metric
                            
                            	If true, BGP is up, no maximum metric Router LSA
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric, self).__init__()

                                self.yang_name = "maximum-metric"
                                self.yang_parent_name = "process-summary"

                                self.max_metric_enabled = YLeaf(YType.boolean, "max-metric-enabled")

                                self.max_metric_reason = YLeaf(YType.uint8, "max-metric-reason")

                                self.maximum_metric_external_lsa = YLeaf(YType.boolean, "maximum-metric-external-lsa")

                                self.maximum_metric_external_lsa_metric = YLeaf(YType.uint32, "maximum-metric-external-lsa-metric")

                                self.maximum_metric_include_stubs = YLeaf(YType.boolean, "maximum-metric-include-stubs")

                                self.maximum_metric_originated_for = YLeaf(YType.uint32, "maximum-metric-originated-for")

                                self.maximum_metric_start_time = YLeaf(YType.uint32, "maximum-metric-start-time")

                                self.maximum_metric_summary_lsa = YLeaf(YType.boolean, "maximum-metric-summary-lsa")

                                self.maximum_metric_summary_lsa_metric = YLeaf(YType.uint32, "maximum-metric-summary-lsa-metric")

                                self.maximum_metric_unset_reason = YLeaf(YType.enumeration, "maximum-metric-unset-reason")

                                self.saved_startup_time = YLeaf(YType.uint32, "saved-startup-time")

                                self.saved_unset_maximum_metric = YLeaf(YType.boolean, "saved-unset-maximum-metric")

                                self.unset_maximum_metric = YLeaf(YType.boolean, "unset-maximum-metric")

                                self.maximum_metric_time_unset = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset()
                                self.maximum_metric_time_unset.parent = self
                                self._children_name_map["maximum_metric_time_unset"] = "maximum-metric-time-unset"
                                self._children_yang_names.add("maximum-metric-time-unset")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("max_metric_enabled",
                                                "max_metric_reason",
                                                "maximum_metric_external_lsa",
                                                "maximum_metric_external_lsa_metric",
                                                "maximum_metric_include_stubs",
                                                "maximum_metric_originated_for",
                                                "maximum_metric_start_time",
                                                "maximum_metric_summary_lsa",
                                                "maximum_metric_summary_lsa_metric",
                                                "maximum_metric_unset_reason",
                                                "saved_startup_time",
                                                "saved_unset_maximum_metric",
                                                "unset_maximum_metric") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric, self).__setattr__(name, value)


                            class MaximumMetricTimeUnset(Entity):
                                """
                                Time max\-metric condition was cleared
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset, self).__init__()

                                    self.yang_name = "maximum-metric-time-unset"
                                    self.yang_parent_name = "maximum-metric"

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("nanosecond",
                                                    "second") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.nanosecond.is_set or
                                        self.second.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.nanosecond.yfilter != YFilter.not_set or
                                        self.second.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "maximum-metric-time-unset" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                    if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.second.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nanosecond" or name == "second"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "nanosecond"):
                                        self.nanosecond = value
                                        self.nanosecond.value_namespace = name_space
                                        self.nanosecond.value_namespace_prefix = name_space_prefix
                                    if(value_path == "second"):
                                        self.second = value
                                        self.second.value_namespace = name_space
                                        self.second.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.max_metric_enabled.is_set or
                                    self.max_metric_reason.is_set or
                                    self.maximum_metric_external_lsa.is_set or
                                    self.maximum_metric_external_lsa_metric.is_set or
                                    self.maximum_metric_include_stubs.is_set or
                                    self.maximum_metric_originated_for.is_set or
                                    self.maximum_metric_start_time.is_set or
                                    self.maximum_metric_summary_lsa.is_set or
                                    self.maximum_metric_summary_lsa_metric.is_set or
                                    self.maximum_metric_unset_reason.is_set or
                                    self.saved_startup_time.is_set or
                                    self.saved_unset_maximum_metric.is_set or
                                    self.unset_maximum_metric.is_set or
                                    (self.maximum_metric_time_unset is not None and self.maximum_metric_time_unset.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.max_metric_enabled.yfilter != YFilter.not_set or
                                    self.max_metric_reason.yfilter != YFilter.not_set or
                                    self.maximum_metric_external_lsa.yfilter != YFilter.not_set or
                                    self.maximum_metric_external_lsa_metric.yfilter != YFilter.not_set or
                                    self.maximum_metric_include_stubs.yfilter != YFilter.not_set or
                                    self.maximum_metric_originated_for.yfilter != YFilter.not_set or
                                    self.maximum_metric_start_time.yfilter != YFilter.not_set or
                                    self.maximum_metric_summary_lsa.yfilter != YFilter.not_set or
                                    self.maximum_metric_summary_lsa_metric.yfilter != YFilter.not_set or
                                    self.maximum_metric_unset_reason.yfilter != YFilter.not_set or
                                    self.saved_startup_time.yfilter != YFilter.not_set or
                                    self.saved_unset_maximum_metric.yfilter != YFilter.not_set or
                                    self.unset_maximum_metric.yfilter != YFilter.not_set or
                                    (self.maximum_metric_time_unset is not None and self.maximum_metric_time_unset.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "maximum-metric" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.max_metric_enabled.is_set or self.max_metric_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_metric_enabled.get_name_leafdata())
                                if (self.max_metric_reason.is_set or self.max_metric_reason.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_metric_reason.get_name_leafdata())
                                if (self.maximum_metric_external_lsa.is_set or self.maximum_metric_external_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_external_lsa.get_name_leafdata())
                                if (self.maximum_metric_external_lsa_metric.is_set or self.maximum_metric_external_lsa_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_external_lsa_metric.get_name_leafdata())
                                if (self.maximum_metric_include_stubs.is_set or self.maximum_metric_include_stubs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_include_stubs.get_name_leafdata())
                                if (self.maximum_metric_originated_for.is_set or self.maximum_metric_originated_for.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_originated_for.get_name_leafdata())
                                if (self.maximum_metric_start_time.is_set or self.maximum_metric_start_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_start_time.get_name_leafdata())
                                if (self.maximum_metric_summary_lsa.is_set or self.maximum_metric_summary_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_summary_lsa.get_name_leafdata())
                                if (self.maximum_metric_summary_lsa_metric.is_set or self.maximum_metric_summary_lsa_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_summary_lsa_metric.get_name_leafdata())
                                if (self.maximum_metric_unset_reason.is_set or self.maximum_metric_unset_reason.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_metric_unset_reason.get_name_leafdata())
                                if (self.saved_startup_time.is_set or self.saved_startup_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.saved_startup_time.get_name_leafdata())
                                if (self.saved_unset_maximum_metric.is_set or self.saved_unset_maximum_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.saved_unset_maximum_metric.get_name_leafdata())
                                if (self.unset_maximum_metric.is_set or self.unset_maximum_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unset_maximum_metric.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "maximum-metric-time-unset"):
                                    if (self.maximum_metric_time_unset is None):
                                        self.maximum_metric_time_unset = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset()
                                        self.maximum_metric_time_unset.parent = self
                                        self._children_name_map["maximum_metric_time_unset"] = "maximum-metric-time-unset"
                                    return self.maximum_metric_time_unset

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "maximum-metric-time-unset" or name == "max-metric-enabled" or name == "max-metric-reason" or name == "maximum-metric-external-lsa" or name == "maximum-metric-external-lsa-metric" or name == "maximum-metric-include-stubs" or name == "maximum-metric-originated-for" or name == "maximum-metric-start-time" or name == "maximum-metric-summary-lsa" or name == "maximum-metric-summary-lsa-metric" or name == "maximum-metric-unset-reason" or name == "saved-startup-time" or name == "saved-unset-maximum-metric" or name == "unset-maximum-metric"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "max-metric-enabled"):
                                    self.max_metric_enabled = value
                                    self.max_metric_enabled.value_namespace = name_space
                                    self.max_metric_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-metric-reason"):
                                    self.max_metric_reason = value
                                    self.max_metric_reason.value_namespace = name_space
                                    self.max_metric_reason.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-external-lsa"):
                                    self.maximum_metric_external_lsa = value
                                    self.maximum_metric_external_lsa.value_namespace = name_space
                                    self.maximum_metric_external_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-external-lsa-metric"):
                                    self.maximum_metric_external_lsa_metric = value
                                    self.maximum_metric_external_lsa_metric.value_namespace = name_space
                                    self.maximum_metric_external_lsa_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-include-stubs"):
                                    self.maximum_metric_include_stubs = value
                                    self.maximum_metric_include_stubs.value_namespace = name_space
                                    self.maximum_metric_include_stubs.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-originated-for"):
                                    self.maximum_metric_originated_for = value
                                    self.maximum_metric_originated_for.value_namespace = name_space
                                    self.maximum_metric_originated_for.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-start-time"):
                                    self.maximum_metric_start_time = value
                                    self.maximum_metric_start_time.value_namespace = name_space
                                    self.maximum_metric_start_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-summary-lsa"):
                                    self.maximum_metric_summary_lsa = value
                                    self.maximum_metric_summary_lsa.value_namespace = name_space
                                    self.maximum_metric_summary_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-summary-lsa-metric"):
                                    self.maximum_metric_summary_lsa_metric = value
                                    self.maximum_metric_summary_lsa_metric.value_namespace = name_space
                                    self.maximum_metric_summary_lsa_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-metric-unset-reason"):
                                    self.maximum_metric_unset_reason = value
                                    self.maximum_metric_unset_reason.value_namespace = name_space
                                    self.maximum_metric_unset_reason.value_namespace_prefix = name_space_prefix
                                if(value_path == "saved-startup-time"):
                                    self.saved_startup_time = value
                                    self.saved_startup_time.value_namespace = name_space
                                    self.saved_startup_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "saved-unset-maximum-metric"):
                                    self.saved_unset_maximum_metric = value
                                    self.saved_unset_maximum_metric.value_namespace = name_space
                                    self.saved_unset_maximum_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "unset-maximum-metric"):
                                    self.unset_maximum_metric = value
                                    self.unset_maximum_metric.value_namespace = name_space
                                    self.unset_maximum_metric.value_namespace_prefix = name_space_prefix


                        class Redistribution(Entity):
                            """
                            Redistribution list
                            
                            .. attribute:: classless
                            
                            	Whether to use CIDR
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Route metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_flag
                            
                            	If true, Metric configured
                            	**type**\:  bool
                            
                            .. attribute:: nssa_only
                            
                            	To NSSA areas only
                            	**type**\:  bool
                            
                            .. attribute:: redistribution_protocol
                            
                            	Protocol Information
                            	**type**\:   :py:class:`RedistributionProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution, self).__init__()

                                self.yang_name = "redistribution"
                                self.yang_parent_name = "process-summary"

                                self.classless = YLeaf(YType.boolean, "classless")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_flag = YLeaf(YType.boolean, "metric-flag")

                                self.nssa_only = YLeaf(YType.boolean, "nssa-only")

                                self.redistribution_protocol = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol()
                                self.redistribution_protocol.parent = self
                                self._children_name_map["redistribution_protocol"] = "redistribution-protocol"
                                self._children_yang_names.add("redistribution-protocol")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("classless",
                                                "metric",
                                                "metric_flag",
                                                "nssa_only") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution, self).__setattr__(name, value)


                            class RedistributionProtocol(Entity):
                                """
                                Protocol Information
                                
                                .. attribute:: bgp_as_number
                                
                                	BGP Autonomous System Number
                                	**type**\:  str
                                
                                .. attribute:: connected_instance
                                
                                	Connected instance name
                                	**type**\:  str
                                
                                .. attribute:: eigrp_as_number
                                
                                	Autonomous System Number
                                	**type**\:  str
                                
                                .. attribute:: isis_instance_id
                                
                                	ISIS instance identifier
                                	**type**\:  str
                                
                                .. attribute:: ospf_process_id
                                
                                	OSPF process identifier
                                	**type**\:  str
                                
                                .. attribute:: protocol_type
                                
                                	ProtocolType
                                	**type**\:   :py:class:`RedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.RedistProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol, self).__init__()

                                    self.yang_name = "redistribution-protocol"
                                    self.yang_parent_name = "redistribution"

                                    self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                    self.connected_instance = YLeaf(YType.str, "connected-instance")

                                    self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                    self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                    self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                    self.protocol_type = YLeaf(YType.enumeration, "protocol-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bgp_as_number",
                                                    "connected_instance",
                                                    "eigrp_as_number",
                                                    "isis_instance_id",
                                                    "ospf_process_id",
                                                    "protocol_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bgp_as_number.is_set or
                                        self.connected_instance.is_set or
                                        self.eigrp_as_number.is_set or
                                        self.isis_instance_id.is_set or
                                        self.ospf_process_id.is_set or
                                        self.protocol_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bgp_as_number.yfilter != YFilter.not_set or
                                        self.connected_instance.yfilter != YFilter.not_set or
                                        self.eigrp_as_number.yfilter != YFilter.not_set or
                                        self.isis_instance_id.yfilter != YFilter.not_set or
                                        self.ospf_process_id.yfilter != YFilter.not_set or
                                        self.protocol_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "redistribution-protocol" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bgp_as_number.is_set or self.bgp_as_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_as_number.get_name_leafdata())
                                    if (self.connected_instance.is_set or self.connected_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.connected_instance.get_name_leafdata())
                                    if (self.eigrp_as_number.is_set or self.eigrp_as_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.eigrp_as_number.get_name_leafdata())
                                    if (self.isis_instance_id.is_set or self.isis_instance_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.isis_instance_id.get_name_leafdata())
                                    if (self.ospf_process_id.is_set or self.ospf_process_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_process_id.get_name_leafdata())
                                    if (self.protocol_type.is_set or self.protocol_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bgp-as-number" or name == "connected-instance" or name == "eigrp-as-number" or name == "isis-instance-id" or name == "ospf-process-id" or name == "protocol-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bgp-as-number"):
                                        self.bgp_as_number = value
                                        self.bgp_as_number.value_namespace = name_space
                                        self.bgp_as_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "connected-instance"):
                                        self.connected_instance = value
                                        self.connected_instance.value_namespace = name_space
                                        self.connected_instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "eigrp-as-number"):
                                        self.eigrp_as_number = value
                                        self.eigrp_as_number.value_namespace = name_space
                                        self.eigrp_as_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "isis-instance-id"):
                                        self.isis_instance_id = value
                                        self.isis_instance_id.value_namespace = name_space
                                        self.isis_instance_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-process-id"):
                                        self.ospf_process_id = value
                                        self.ospf_process_id.value_namespace = name_space
                                        self.ospf_process_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol-type"):
                                        self.protocol_type = value
                                        self.protocol_type.value_namespace = name_space
                                        self.protocol_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.classless.is_set or
                                    self.metric.is_set or
                                    self.metric_flag.is_set or
                                    self.nssa_only.is_set or
                                    (self.redistribution_protocol is not None and self.redistribution_protocol.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.classless.yfilter != YFilter.not_set or
                                    self.metric.yfilter != YFilter.not_set or
                                    self.metric_flag.yfilter != YFilter.not_set or
                                    self.nssa_only.yfilter != YFilter.not_set or
                                    (self.redistribution_protocol is not None and self.redistribution_protocol.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "redistribution" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.classless.is_set or self.classless.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.classless.get_name_leafdata())
                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                if (self.metric_flag.is_set or self.metric_flag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric_flag.get_name_leafdata())
                                if (self.nssa_only.is_set or self.nssa_only.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nssa_only.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "redistribution-protocol"):
                                    if (self.redistribution_protocol is None):
                                        self.redistribution_protocol = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol()
                                        self.redistribution_protocol.parent = self
                                        self._children_name_map["redistribution_protocol"] = "redistribution-protocol"
                                    return self.redistribution_protocol

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "redistribution-protocol" or name == "classless" or name == "metric" or name == "metric-flag" or name == "nssa-only"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "classless"):
                                    self.classless = value
                                    self.classless.value_namespace = name_space
                                    self.classless.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric"):
                                    self.metric = value
                                    self.metric.value_namespace = name_space
                                    self.metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric-flag"):
                                    self.metric_flag = value
                                    self.metric_flag.value_namespace = name_space
                                    self.metric_flag.value_namespace_prefix = name_space_prefix
                                if(value_path == "nssa-only"):
                                    self.nssa_only = value
                                    self.nssa_only.value_namespace = name_space
                                    self.nssa_only.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.maximum_metric:
                                if (c.has_data()):
                                    return True
                            for c in self.redistribution:
                                if (c.has_data()):
                                    return True
                            return (
                                self.adj_stag_init_num_nbr.is_set or
                                self.adj_stag_max_num_nbr.is_set or
                                self.adj_stag_num_nbr_forming.is_set or
                                self.adj_stagger_enabled.is_set or
                                self.area_border_router.is_set or
                                self.area_count.is_set or
                                self.as_border_router.is_set or
                                self.as_dc_bitless_lsa_count.is_set or
                                self.as_dna_lsa_count.is_set or
                                self.as_lsa_checksum.is_set or
                                self.as_lsa_count.is_set or
                                self.as_lsa_flood_list_length.is_set or
                                self.context_name.is_set or
                                self.graceful_shutdown_retention_time.is_set or
                                self.graceful_shutdown_state.is_set or
                                self.if_flood_pacing_interval.is_set or
                                self.if_retrans_pacing_interval.is_set or
                                self.igp_intact_on.is_set or
                                self.last_nsf_time.is_set or
                                self.lsa_hold_time.is_set or
                                self.lsa_maximum_time.is_set or
                                self.lsa_refresh_interval.is_set or
                                self.lsa_start_time.is_set or
                                self.lsd_bound.is_set or
                                self.lsd_connected.is_set or
                                self.lsd_connection_revision.is_set or
                                self.lsd_registered.is_set or
                                self.max_lsa_enabled.is_set or
                                self.max_lsa_ignore_count.is_set or
                                self.max_lsa_ignore_limit.is_set or
                                self.max_lsa_ignore_time.is_set or
                                self.max_lsa_ignore_timer.is_set or
                                self.max_lsa_limit.is_set or
                                self.max_lsa_reset_time.is_set or
                                self.max_lsa_reset_timer.is_set or
                                self.max_lsa_treshold.is_set or
                                self.max_lsa_warning_only.is_set or
                                self.maximum_interfaces.is_set or
                                self.maximum_metric_abr_off_buffer_time.is_set or
                                self.maximum_metric_abr_off_mode.is_set or
                                self.maximum_metric_abr_off_reasons.is_set or
                                self.maximum_metric_set_reason.is_set or
                                self.maximum_metric_start.is_set or
                                self.maximum_metric_start_timer.is_set or
                                self.microloop_avoidance_active.is_set or
                                self.microloop_avoidance_delay.is_set or
                                self.microloop_avoidance_delay_expiry.is_set or
                                self.microloop_avoidance_type.is_set or
                                self.minimum_lsa_arrival_interval.is_set or
                                self.minimum_lsa_arrival_interval_u32.is_set or
                                self.minimum_lsa_interval.is_set or
                                self.minimum_lsa_interval_u32.is_set or
                                self.non_self_lsa_count.is_set or
                                self.normal_area_count.is_set or
                                self.nsf_enabled.is_set or
                                self.nsf_time.is_set or
                                self.nsr_enabled.is_set or
                                self.nsr_switchover_on_restart.is_set or
                                self.nssa_area_count.is_set or
                                self.number_nbrs_full.is_set or
                                self.opaque_capable.is_set or
                                self.opaque_lsa_checksum.is_set or
                                self.opaque_lsa_count.is_set or
                                self.redistribution_limit.is_set or
                                self.redistribution_limit_warn.is_set or
                                self.redistribution_threshold.is_set or
                                self.role.is_set or
                                self.role_standby.is_set or
                                self.router_id.is_set or
                                self.snmp_trap_enabled.is_set or
                                self.spf_hold_time.is_set or
                                self.spf_hold_time_u32.is_set or
                                self.spf_maximum_time.is_set or
                                self.spf_maximum_time_u32.is_set or
                                self.spf_prefix_priority.is_set or
                                self.spf_prefix_priority_route_policy.is_set or
                                self.spf_start_time.is_set or
                                self.spf_start_time_u32.is_set or
                                self.sr_strict_spf_cap.is_set or
                                self.srgb_configured.is_set or
                                self.srgb_end.is_set or
                                self.srgb_start.is_set or
                                self.srgb_status.is_set or
                                self.stub_area_count.is_set or
                                self.table_prefix_limit_reached.is_set or
                                self.tos_options.is_set or
                                self.ucmp.is_set or
                                self.ucmp_delay.is_set or
                                self.ucmp_prefix_list.is_set or
                                self.ucmp_variance.is_set or
                                self.vrf_lite_enabled.is_set or
                                (self.domain_id is not None and self.domain_id.has_data()))

                        def has_operation(self):
                            for c in self.maximum_metric:
                                if (c.has_operation()):
                                    return True
                            for c in self.redistribution:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.adj_stag_init_num_nbr.yfilter != YFilter.not_set or
                                self.adj_stag_max_num_nbr.yfilter != YFilter.not_set or
                                self.adj_stag_num_nbr_forming.yfilter != YFilter.not_set or
                                self.adj_stagger_enabled.yfilter != YFilter.not_set or
                                self.area_border_router.yfilter != YFilter.not_set or
                                self.area_count.yfilter != YFilter.not_set or
                                self.as_border_router.yfilter != YFilter.not_set or
                                self.as_dc_bitless_lsa_count.yfilter != YFilter.not_set or
                                self.as_dna_lsa_count.yfilter != YFilter.not_set or
                                self.as_lsa_checksum.yfilter != YFilter.not_set or
                                self.as_lsa_count.yfilter != YFilter.not_set or
                                self.as_lsa_flood_list_length.yfilter != YFilter.not_set or
                                self.context_name.yfilter != YFilter.not_set or
                                self.graceful_shutdown_retention_time.yfilter != YFilter.not_set or
                                self.graceful_shutdown_state.yfilter != YFilter.not_set or
                                self.if_flood_pacing_interval.yfilter != YFilter.not_set or
                                self.if_retrans_pacing_interval.yfilter != YFilter.not_set or
                                self.igp_intact_on.yfilter != YFilter.not_set or
                                self.last_nsf_time.yfilter != YFilter.not_set or
                                self.lsa_hold_time.yfilter != YFilter.not_set or
                                self.lsa_maximum_time.yfilter != YFilter.not_set or
                                self.lsa_refresh_interval.yfilter != YFilter.not_set or
                                self.lsa_start_time.yfilter != YFilter.not_set or
                                self.lsd_bound.yfilter != YFilter.not_set or
                                self.lsd_connected.yfilter != YFilter.not_set or
                                self.lsd_connection_revision.yfilter != YFilter.not_set or
                                self.lsd_registered.yfilter != YFilter.not_set or
                                self.max_lsa_enabled.yfilter != YFilter.not_set or
                                self.max_lsa_ignore_count.yfilter != YFilter.not_set or
                                self.max_lsa_ignore_limit.yfilter != YFilter.not_set or
                                self.max_lsa_ignore_time.yfilter != YFilter.not_set or
                                self.max_lsa_ignore_timer.yfilter != YFilter.not_set or
                                self.max_lsa_limit.yfilter != YFilter.not_set or
                                self.max_lsa_reset_time.yfilter != YFilter.not_set or
                                self.max_lsa_reset_timer.yfilter != YFilter.not_set or
                                self.max_lsa_treshold.yfilter != YFilter.not_set or
                                self.max_lsa_warning_only.yfilter != YFilter.not_set or
                                self.maximum_interfaces.yfilter != YFilter.not_set or
                                self.maximum_metric_abr_off_buffer_time.yfilter != YFilter.not_set or
                                self.maximum_metric_abr_off_mode.yfilter != YFilter.not_set or
                                self.maximum_metric_abr_off_reasons.yfilter != YFilter.not_set or
                                self.maximum_metric_set_reason.yfilter != YFilter.not_set or
                                self.maximum_metric_start.yfilter != YFilter.not_set or
                                self.maximum_metric_start_timer.yfilter != YFilter.not_set or
                                self.microloop_avoidance_active.yfilter != YFilter.not_set or
                                self.microloop_avoidance_delay.yfilter != YFilter.not_set or
                                self.microloop_avoidance_delay_expiry.yfilter != YFilter.not_set or
                                self.microloop_avoidance_type.yfilter != YFilter.not_set or
                                self.minimum_lsa_arrival_interval.yfilter != YFilter.not_set or
                                self.minimum_lsa_arrival_interval_u32.yfilter != YFilter.not_set or
                                self.minimum_lsa_interval.yfilter != YFilter.not_set or
                                self.minimum_lsa_interval_u32.yfilter != YFilter.not_set or
                                self.non_self_lsa_count.yfilter != YFilter.not_set or
                                self.normal_area_count.yfilter != YFilter.not_set or
                                self.nsf_enabled.yfilter != YFilter.not_set or
                                self.nsf_time.yfilter != YFilter.not_set or
                                self.nsr_enabled.yfilter != YFilter.not_set or
                                self.nsr_switchover_on_restart.yfilter != YFilter.not_set or
                                self.nssa_area_count.yfilter != YFilter.not_set or
                                self.number_nbrs_full.yfilter != YFilter.not_set or
                                self.opaque_capable.yfilter != YFilter.not_set or
                                self.opaque_lsa_checksum.yfilter != YFilter.not_set or
                                self.opaque_lsa_count.yfilter != YFilter.not_set or
                                self.redistribution_limit.yfilter != YFilter.not_set or
                                self.redistribution_limit_warn.yfilter != YFilter.not_set or
                                self.redistribution_threshold.yfilter != YFilter.not_set or
                                self.role.yfilter != YFilter.not_set or
                                self.role_standby.yfilter != YFilter.not_set or
                                self.router_id.yfilter != YFilter.not_set or
                                self.snmp_trap_enabled.yfilter != YFilter.not_set or
                                self.spf_hold_time.yfilter != YFilter.not_set or
                                self.spf_hold_time_u32.yfilter != YFilter.not_set or
                                self.spf_maximum_time.yfilter != YFilter.not_set or
                                self.spf_maximum_time_u32.yfilter != YFilter.not_set or
                                self.spf_prefix_priority.yfilter != YFilter.not_set or
                                self.spf_prefix_priority_route_policy.yfilter != YFilter.not_set or
                                self.spf_start_time.yfilter != YFilter.not_set or
                                self.spf_start_time_u32.yfilter != YFilter.not_set or
                                self.sr_strict_spf_cap.yfilter != YFilter.not_set or
                                self.srgb_configured.yfilter != YFilter.not_set or
                                self.srgb_end.yfilter != YFilter.not_set or
                                self.srgb_start.yfilter != YFilter.not_set or
                                self.srgb_status.yfilter != YFilter.not_set or
                                self.stub_area_count.yfilter != YFilter.not_set or
                                self.table_prefix_limit_reached.yfilter != YFilter.not_set or
                                self.tos_options.yfilter != YFilter.not_set or
                                self.ucmp.yfilter != YFilter.not_set or
                                self.ucmp_delay.yfilter != YFilter.not_set or
                                self.ucmp_prefix_list.yfilter != YFilter.not_set or
                                self.ucmp_variance.yfilter != YFilter.not_set or
                                self.vrf_lite_enabled.yfilter != YFilter.not_set or
                                (self.domain_id is not None and self.domain_id.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "process-summary" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.adj_stag_init_num_nbr.is_set or self.adj_stag_init_num_nbr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.adj_stag_init_num_nbr.get_name_leafdata())
                            if (self.adj_stag_max_num_nbr.is_set or self.adj_stag_max_num_nbr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.adj_stag_max_num_nbr.get_name_leafdata())
                            if (self.adj_stag_num_nbr_forming.is_set or self.adj_stag_num_nbr_forming.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.adj_stag_num_nbr_forming.get_name_leafdata())
                            if (self.adj_stagger_enabled.is_set or self.adj_stagger_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.adj_stagger_enabled.get_name_leafdata())
                            if (self.area_border_router.is_set or self.area_border_router.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.area_border_router.get_name_leafdata())
                            if (self.area_count.is_set or self.area_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.area_count.get_name_leafdata())
                            if (self.as_border_router.is_set or self.as_border_router.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.as_border_router.get_name_leafdata())
                            if (self.as_dc_bitless_lsa_count.is_set or self.as_dc_bitless_lsa_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.as_dc_bitless_lsa_count.get_name_leafdata())
                            if (self.as_dna_lsa_count.is_set or self.as_dna_lsa_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.as_dna_lsa_count.get_name_leafdata())
                            if (self.as_lsa_checksum.is_set or self.as_lsa_checksum.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.as_lsa_checksum.get_name_leafdata())
                            if (self.as_lsa_count.is_set or self.as_lsa_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.as_lsa_count.get_name_leafdata())
                            if (self.as_lsa_flood_list_length.is_set or self.as_lsa_flood_list_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.as_lsa_flood_list_length.get_name_leafdata())
                            if (self.context_name.is_set or self.context_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.context_name.get_name_leafdata())
                            if (self.graceful_shutdown_retention_time.is_set or self.graceful_shutdown_retention_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.graceful_shutdown_retention_time.get_name_leafdata())
                            if (self.graceful_shutdown_state.is_set or self.graceful_shutdown_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.graceful_shutdown_state.get_name_leafdata())
                            if (self.if_flood_pacing_interval.is_set or self.if_flood_pacing_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.if_flood_pacing_interval.get_name_leafdata())
                            if (self.if_retrans_pacing_interval.is_set or self.if_retrans_pacing_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.if_retrans_pacing_interval.get_name_leafdata())
                            if (self.igp_intact_on.is_set or self.igp_intact_on.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igp_intact_on.get_name_leafdata())
                            if (self.last_nsf_time.is_set or self.last_nsf_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_nsf_time.get_name_leafdata())
                            if (self.lsa_hold_time.is_set or self.lsa_hold_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsa_hold_time.get_name_leafdata())
                            if (self.lsa_maximum_time.is_set or self.lsa_maximum_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsa_maximum_time.get_name_leafdata())
                            if (self.lsa_refresh_interval.is_set or self.lsa_refresh_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsa_refresh_interval.get_name_leafdata())
                            if (self.lsa_start_time.is_set or self.lsa_start_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsa_start_time.get_name_leafdata())
                            if (self.lsd_bound.is_set or self.lsd_bound.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsd_bound.get_name_leafdata())
                            if (self.lsd_connected.is_set or self.lsd_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsd_connected.get_name_leafdata())
                            if (self.lsd_connection_revision.is_set or self.lsd_connection_revision.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsd_connection_revision.get_name_leafdata())
                            if (self.lsd_registered.is_set or self.lsd_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsd_registered.get_name_leafdata())
                            if (self.max_lsa_enabled.is_set or self.max_lsa_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_enabled.get_name_leafdata())
                            if (self.max_lsa_ignore_count.is_set or self.max_lsa_ignore_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_ignore_count.get_name_leafdata())
                            if (self.max_lsa_ignore_limit.is_set or self.max_lsa_ignore_limit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_ignore_limit.get_name_leafdata())
                            if (self.max_lsa_ignore_time.is_set or self.max_lsa_ignore_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_ignore_time.get_name_leafdata())
                            if (self.max_lsa_ignore_timer.is_set or self.max_lsa_ignore_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_ignore_timer.get_name_leafdata())
                            if (self.max_lsa_limit.is_set or self.max_lsa_limit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_limit.get_name_leafdata())
                            if (self.max_lsa_reset_time.is_set or self.max_lsa_reset_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_reset_time.get_name_leafdata())
                            if (self.max_lsa_reset_timer.is_set or self.max_lsa_reset_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_reset_timer.get_name_leafdata())
                            if (self.max_lsa_treshold.is_set or self.max_lsa_treshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_treshold.get_name_leafdata())
                            if (self.max_lsa_warning_only.is_set or self.max_lsa_warning_only.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_warning_only.get_name_leafdata())
                            if (self.maximum_interfaces.is_set or self.maximum_interfaces.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_interfaces.get_name_leafdata())
                            if (self.maximum_metric_abr_off_buffer_time.is_set or self.maximum_metric_abr_off_buffer_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_metric_abr_off_buffer_time.get_name_leafdata())
                            if (self.maximum_metric_abr_off_mode.is_set or self.maximum_metric_abr_off_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_metric_abr_off_mode.get_name_leafdata())
                            if (self.maximum_metric_abr_off_reasons.is_set or self.maximum_metric_abr_off_reasons.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_metric_abr_off_reasons.get_name_leafdata())
                            if (self.maximum_metric_set_reason.is_set or self.maximum_metric_set_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_metric_set_reason.get_name_leafdata())
                            if (self.maximum_metric_start.is_set or self.maximum_metric_start.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_metric_start.get_name_leafdata())
                            if (self.maximum_metric_start_timer.is_set or self.maximum_metric_start_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_metric_start_timer.get_name_leafdata())
                            if (self.microloop_avoidance_active.is_set or self.microloop_avoidance_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.microloop_avoidance_active.get_name_leafdata())
                            if (self.microloop_avoidance_delay.is_set or self.microloop_avoidance_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.microloop_avoidance_delay.get_name_leafdata())
                            if (self.microloop_avoidance_delay_expiry.is_set or self.microloop_avoidance_delay_expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.microloop_avoidance_delay_expiry.get_name_leafdata())
                            if (self.microloop_avoidance_type.is_set or self.microloop_avoidance_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.microloop_avoidance_type.get_name_leafdata())
                            if (self.minimum_lsa_arrival_interval.is_set or self.minimum_lsa_arrival_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_lsa_arrival_interval.get_name_leafdata())
                            if (self.minimum_lsa_arrival_interval_u32.is_set or self.minimum_lsa_arrival_interval_u32.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_lsa_arrival_interval_u32.get_name_leafdata())
                            if (self.minimum_lsa_interval.is_set or self.minimum_lsa_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_lsa_interval.get_name_leafdata())
                            if (self.minimum_lsa_interval_u32.is_set or self.minimum_lsa_interval_u32.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_lsa_interval_u32.get_name_leafdata())
                            if (self.non_self_lsa_count.is_set or self.non_self_lsa_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.non_self_lsa_count.get_name_leafdata())
                            if (self.normal_area_count.is_set or self.normal_area_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.normal_area_count.get_name_leafdata())
                            if (self.nsf_enabled.is_set or self.nsf_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsf_enabled.get_name_leafdata())
                            if (self.nsf_time.is_set or self.nsf_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsf_time.get_name_leafdata())
                            if (self.nsr_enabled.is_set or self.nsr_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_enabled.get_name_leafdata())
                            if (self.nsr_switchover_on_restart.is_set or self.nsr_switchover_on_restart.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_switchover_on_restart.get_name_leafdata())
                            if (self.nssa_area_count.is_set or self.nssa_area_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nssa_area_count.get_name_leafdata())
                            if (self.number_nbrs_full.is_set or self.number_nbrs_full.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_nbrs_full.get_name_leafdata())
                            if (self.opaque_capable.is_set or self.opaque_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.opaque_capable.get_name_leafdata())
                            if (self.opaque_lsa_checksum.is_set or self.opaque_lsa_checksum.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.opaque_lsa_checksum.get_name_leafdata())
                            if (self.opaque_lsa_count.is_set or self.opaque_lsa_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.opaque_lsa_count.get_name_leafdata())
                            if (self.redistribution_limit.is_set or self.redistribution_limit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redistribution_limit.get_name_leafdata())
                            if (self.redistribution_limit_warn.is_set or self.redistribution_limit_warn.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redistribution_limit_warn.get_name_leafdata())
                            if (self.redistribution_threshold.is_set or self.redistribution_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redistribution_threshold.get_name_leafdata())
                            if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.role.get_name_leafdata())
                            if (self.role_standby.is_set or self.role_standby.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.role_standby.get_name_leafdata())
                            if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_id.get_name_leafdata())
                            if (self.snmp_trap_enabled.is_set or self.snmp_trap_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.snmp_trap_enabled.get_name_leafdata())
                            if (self.spf_hold_time.is_set or self.spf_hold_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spf_hold_time.get_name_leafdata())
                            if (self.spf_hold_time_u32.is_set or self.spf_hold_time_u32.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spf_hold_time_u32.get_name_leafdata())
                            if (self.spf_maximum_time.is_set or self.spf_maximum_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spf_maximum_time.get_name_leafdata())
                            if (self.spf_maximum_time_u32.is_set or self.spf_maximum_time_u32.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spf_maximum_time_u32.get_name_leafdata())
                            if (self.spf_prefix_priority.is_set or self.spf_prefix_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spf_prefix_priority.get_name_leafdata())
                            if (self.spf_prefix_priority_route_policy.is_set or self.spf_prefix_priority_route_policy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spf_prefix_priority_route_policy.get_name_leafdata())
                            if (self.spf_start_time.is_set or self.spf_start_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spf_start_time.get_name_leafdata())
                            if (self.spf_start_time_u32.is_set or self.spf_start_time_u32.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spf_start_time_u32.get_name_leafdata())
                            if (self.sr_strict_spf_cap.is_set or self.sr_strict_spf_cap.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sr_strict_spf_cap.get_name_leafdata())
                            if (self.srgb_configured.is_set or self.srgb_configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.srgb_configured.get_name_leafdata())
                            if (self.srgb_end.is_set or self.srgb_end.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.srgb_end.get_name_leafdata())
                            if (self.srgb_start.is_set or self.srgb_start.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.srgb_start.get_name_leafdata())
                            if (self.srgb_status.is_set or self.srgb_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.srgb_status.get_name_leafdata())
                            if (self.stub_area_count.is_set or self.stub_area_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.stub_area_count.get_name_leafdata())
                            if (self.table_prefix_limit_reached.is_set or self.table_prefix_limit_reached.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_prefix_limit_reached.get_name_leafdata())
                            if (self.tos_options.is_set or self.tos_options.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tos_options.get_name_leafdata())
                            if (self.ucmp.is_set or self.ucmp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ucmp.get_name_leafdata())
                            if (self.ucmp_delay.is_set or self.ucmp_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ucmp_delay.get_name_leafdata())
                            if (self.ucmp_prefix_list.is_set or self.ucmp_prefix_list.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ucmp_prefix_list.get_name_leafdata())
                            if (self.ucmp_variance.is_set or self.ucmp_variance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ucmp_variance.get_name_leafdata())
                            if (self.vrf_lite_enabled.is_set or self.vrf_lite_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_lite_enabled.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "domain-id"):
                                if (self.domain_id is None):
                                    self.domain_id = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId()
                                    self.domain_id.parent = self
                                    self._children_name_map["domain_id"] = "domain-id"
                                return self.domain_id

                            if (child_yang_name == "maximum-metric"):
                                for c in self.maximum_metric:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.maximum_metric.append(c)
                                return c

                            if (child_yang_name == "redistribution"):
                                for c in self.redistribution:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.redistribution.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "domain-id" or name == "maximum-metric" or name == "redistribution" or name == "adj-stag-init-num-nbr" or name == "adj-stag-max-num-nbr" or name == "adj-stag-num-nbr-forming" or name == "adj-stagger-enabled" or name == "area-border-router" or name == "area-count" or name == "as-border-router" or name == "as-dc-bitless-lsa-count" or name == "as-dna-lsa-count" or name == "as-lsa-checksum" or name == "as-lsa-count" or name == "as-lsa-flood-list-length" or name == "context-name" or name == "graceful-shutdown-retention-time" or name == "graceful-shutdown-state" or name == "if-flood-pacing-interval" or name == "if-retrans-pacing-interval" or name == "igp-intact-on" or name == "last-nsf-time" or name == "lsa-hold-time" or name == "lsa-maximum-time" or name == "lsa-refresh-interval" or name == "lsa-start-time" or name == "lsd-bound" or name == "lsd-connected" or name == "lsd-connection-revision" or name == "lsd-registered" or name == "max-lsa-enabled" or name == "max-lsa-ignore-count" or name == "max-lsa-ignore-limit" or name == "max-lsa-ignore-time" or name == "max-lsa-ignore-timer" or name == "max-lsa-limit" or name == "max-lsa-reset-time" or name == "max-lsa-reset-timer" or name == "max-lsa-treshold" or name == "max-lsa-warning-only" or name == "maximum-interfaces" or name == "maximum-metric-abr-off-buffer-time" or name == "maximum-metric-abr-off-mode" or name == "maximum-metric-abr-off-reasons" or name == "maximum-metric-set-reason" or name == "maximum-metric-start" or name == "maximum-metric-start-timer" or name == "microloop-avoidance-active" or name == "microloop-avoidance-delay" or name == "microloop-avoidance-delay-expiry" or name == "microloop-avoidance-type" or name == "minimum-lsa-arrival-interval" or name == "minimum-lsa-arrival-interval-u32" or name == "minimum-lsa-interval" or name == "minimum-lsa-interval-u32" or name == "non-self-lsa-count" or name == "normal-area-count" or name == "nsf-enabled" or name == "nsf-time" or name == "nsr-enabled" or name == "nsr-switchover-on-restart" or name == "nssa-area-count" or name == "number-nbrs-full" or name == "opaque-capable" or name == "opaque-lsa-checksum" or name == "opaque-lsa-count" or name == "redistribution-limit" or name == "redistribution-limit-warn" or name == "redistribution-threshold" or name == "role" or name == "role-standby" or name == "router-id" or name == "snmp-trap-enabled" or name == "spf-hold-time" or name == "spf-hold-time-u32" or name == "spf-maximum-time" or name == "spf-maximum-time-u32" or name == "spf-prefix-priority" or name == "spf-prefix-priority-route-policy" or name == "spf-start-time" or name == "spf-start-time-u32" or name == "sr-strict-spf-cap" or name == "srgb-configured" or name == "srgb-end" or name == "srgb-start" or name == "srgb-status" or name == "stub-area-count" or name == "table-prefix-limit-reached" or name == "tos-options" or name == "ucmp" or name == "ucmp-delay" or name == "ucmp-prefix-list" or name == "ucmp-variance" or name == "vrf-lite-enabled"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "adj-stag-init-num-nbr"):
                                self.adj_stag_init_num_nbr = value
                                self.adj_stag_init_num_nbr.value_namespace = name_space
                                self.adj_stag_init_num_nbr.value_namespace_prefix = name_space_prefix
                            if(value_path == "adj-stag-max-num-nbr"):
                                self.adj_stag_max_num_nbr = value
                                self.adj_stag_max_num_nbr.value_namespace = name_space
                                self.adj_stag_max_num_nbr.value_namespace_prefix = name_space_prefix
                            if(value_path == "adj-stag-num-nbr-forming"):
                                self.adj_stag_num_nbr_forming = value
                                self.adj_stag_num_nbr_forming.value_namespace = name_space
                                self.adj_stag_num_nbr_forming.value_namespace_prefix = name_space_prefix
                            if(value_path == "adj-stagger-enabled"):
                                self.adj_stagger_enabled = value
                                self.adj_stagger_enabled.value_namespace = name_space
                                self.adj_stagger_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "area-border-router"):
                                self.area_border_router = value
                                self.area_border_router.value_namespace = name_space
                                self.area_border_router.value_namespace_prefix = name_space_prefix
                            if(value_path == "area-count"):
                                self.area_count = value
                                self.area_count.value_namespace = name_space
                                self.area_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "as-border-router"):
                                self.as_border_router = value
                                self.as_border_router.value_namespace = name_space
                                self.as_border_router.value_namespace_prefix = name_space_prefix
                            if(value_path == "as-dc-bitless-lsa-count"):
                                self.as_dc_bitless_lsa_count = value
                                self.as_dc_bitless_lsa_count.value_namespace = name_space
                                self.as_dc_bitless_lsa_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "as-dna-lsa-count"):
                                self.as_dna_lsa_count = value
                                self.as_dna_lsa_count.value_namespace = name_space
                                self.as_dna_lsa_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "as-lsa-checksum"):
                                self.as_lsa_checksum = value
                                self.as_lsa_checksum.value_namespace = name_space
                                self.as_lsa_checksum.value_namespace_prefix = name_space_prefix
                            if(value_path == "as-lsa-count"):
                                self.as_lsa_count = value
                                self.as_lsa_count.value_namespace = name_space
                                self.as_lsa_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "as-lsa-flood-list-length"):
                                self.as_lsa_flood_list_length = value
                                self.as_lsa_flood_list_length.value_namespace = name_space
                                self.as_lsa_flood_list_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "context-name"):
                                self.context_name = value
                                self.context_name.value_namespace = name_space
                                self.context_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "graceful-shutdown-retention-time"):
                                self.graceful_shutdown_retention_time = value
                                self.graceful_shutdown_retention_time.value_namespace = name_space
                                self.graceful_shutdown_retention_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "graceful-shutdown-state"):
                                self.graceful_shutdown_state = value
                                self.graceful_shutdown_state.value_namespace = name_space
                                self.graceful_shutdown_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "if-flood-pacing-interval"):
                                self.if_flood_pacing_interval = value
                                self.if_flood_pacing_interval.value_namespace = name_space
                                self.if_flood_pacing_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "if-retrans-pacing-interval"):
                                self.if_retrans_pacing_interval = value
                                self.if_retrans_pacing_interval.value_namespace = name_space
                                self.if_retrans_pacing_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "igp-intact-on"):
                                self.igp_intact_on = value
                                self.igp_intact_on.value_namespace = name_space
                                self.igp_intact_on.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-nsf-time"):
                                self.last_nsf_time = value
                                self.last_nsf_time.value_namespace = name_space
                                self.last_nsf_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsa-hold-time"):
                                self.lsa_hold_time = value
                                self.lsa_hold_time.value_namespace = name_space
                                self.lsa_hold_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsa-maximum-time"):
                                self.lsa_maximum_time = value
                                self.lsa_maximum_time.value_namespace = name_space
                                self.lsa_maximum_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsa-refresh-interval"):
                                self.lsa_refresh_interval = value
                                self.lsa_refresh_interval.value_namespace = name_space
                                self.lsa_refresh_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsa-start-time"):
                                self.lsa_start_time = value
                                self.lsa_start_time.value_namespace = name_space
                                self.lsa_start_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsd-bound"):
                                self.lsd_bound = value
                                self.lsd_bound.value_namespace = name_space
                                self.lsd_bound.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsd-connected"):
                                self.lsd_connected = value
                                self.lsd_connected.value_namespace = name_space
                                self.lsd_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsd-connection-revision"):
                                self.lsd_connection_revision = value
                                self.lsd_connection_revision.value_namespace = name_space
                                self.lsd_connection_revision.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsd-registered"):
                                self.lsd_registered = value
                                self.lsd_registered.value_namespace = name_space
                                self.lsd_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-enabled"):
                                self.max_lsa_enabled = value
                                self.max_lsa_enabled.value_namespace = name_space
                                self.max_lsa_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-ignore-count"):
                                self.max_lsa_ignore_count = value
                                self.max_lsa_ignore_count.value_namespace = name_space
                                self.max_lsa_ignore_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-ignore-limit"):
                                self.max_lsa_ignore_limit = value
                                self.max_lsa_ignore_limit.value_namespace = name_space
                                self.max_lsa_ignore_limit.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-ignore-time"):
                                self.max_lsa_ignore_time = value
                                self.max_lsa_ignore_time.value_namespace = name_space
                                self.max_lsa_ignore_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-ignore-timer"):
                                self.max_lsa_ignore_timer = value
                                self.max_lsa_ignore_timer.value_namespace = name_space
                                self.max_lsa_ignore_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-limit"):
                                self.max_lsa_limit = value
                                self.max_lsa_limit.value_namespace = name_space
                                self.max_lsa_limit.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-reset-time"):
                                self.max_lsa_reset_time = value
                                self.max_lsa_reset_time.value_namespace = name_space
                                self.max_lsa_reset_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-reset-timer"):
                                self.max_lsa_reset_timer = value
                                self.max_lsa_reset_timer.value_namespace = name_space
                                self.max_lsa_reset_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-treshold"):
                                self.max_lsa_treshold = value
                                self.max_lsa_treshold.value_namespace = name_space
                                self.max_lsa_treshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-warning-only"):
                                self.max_lsa_warning_only = value
                                self.max_lsa_warning_only.value_namespace = name_space
                                self.max_lsa_warning_only.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-interfaces"):
                                self.maximum_interfaces = value
                                self.maximum_interfaces.value_namespace = name_space
                                self.maximum_interfaces.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-metric-abr-off-buffer-time"):
                                self.maximum_metric_abr_off_buffer_time = value
                                self.maximum_metric_abr_off_buffer_time.value_namespace = name_space
                                self.maximum_metric_abr_off_buffer_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-metric-abr-off-mode"):
                                self.maximum_metric_abr_off_mode = value
                                self.maximum_metric_abr_off_mode.value_namespace = name_space
                                self.maximum_metric_abr_off_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-metric-abr-off-reasons"):
                                self.maximum_metric_abr_off_reasons = value
                                self.maximum_metric_abr_off_reasons.value_namespace = name_space
                                self.maximum_metric_abr_off_reasons.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-metric-set-reason"):
                                self.maximum_metric_set_reason = value
                                self.maximum_metric_set_reason.value_namespace = name_space
                                self.maximum_metric_set_reason.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-metric-start"):
                                self.maximum_metric_start = value
                                self.maximum_metric_start.value_namespace = name_space
                                self.maximum_metric_start.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-metric-start-timer"):
                                self.maximum_metric_start_timer = value
                                self.maximum_metric_start_timer.value_namespace = name_space
                                self.maximum_metric_start_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "microloop-avoidance-active"):
                                self.microloop_avoidance_active = value
                                self.microloop_avoidance_active.value_namespace = name_space
                                self.microloop_avoidance_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "microloop-avoidance-delay"):
                                self.microloop_avoidance_delay = value
                                self.microloop_avoidance_delay.value_namespace = name_space
                                self.microloop_avoidance_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "microloop-avoidance-delay-expiry"):
                                self.microloop_avoidance_delay_expiry = value
                                self.microloop_avoidance_delay_expiry.value_namespace = name_space
                                self.microloop_avoidance_delay_expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "microloop-avoidance-type"):
                                self.microloop_avoidance_type = value
                                self.microloop_avoidance_type.value_namespace = name_space
                                self.microloop_avoidance_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-lsa-arrival-interval"):
                                self.minimum_lsa_arrival_interval = value
                                self.minimum_lsa_arrival_interval.value_namespace = name_space
                                self.minimum_lsa_arrival_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-lsa-arrival-interval-u32"):
                                self.minimum_lsa_arrival_interval_u32 = value
                                self.minimum_lsa_arrival_interval_u32.value_namespace = name_space
                                self.minimum_lsa_arrival_interval_u32.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-lsa-interval"):
                                self.minimum_lsa_interval = value
                                self.minimum_lsa_interval.value_namespace = name_space
                                self.minimum_lsa_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-lsa-interval-u32"):
                                self.minimum_lsa_interval_u32 = value
                                self.minimum_lsa_interval_u32.value_namespace = name_space
                                self.minimum_lsa_interval_u32.value_namespace_prefix = name_space_prefix
                            if(value_path == "non-self-lsa-count"):
                                self.non_self_lsa_count = value
                                self.non_self_lsa_count.value_namespace = name_space
                                self.non_self_lsa_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "normal-area-count"):
                                self.normal_area_count = value
                                self.normal_area_count.value_namespace = name_space
                                self.normal_area_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsf-enabled"):
                                self.nsf_enabled = value
                                self.nsf_enabled.value_namespace = name_space
                                self.nsf_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsf-time"):
                                self.nsf_time = value
                                self.nsf_time.value_namespace = name_space
                                self.nsf_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-enabled"):
                                self.nsr_enabled = value
                                self.nsr_enabled.value_namespace = name_space
                                self.nsr_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-switchover-on-restart"):
                                self.nsr_switchover_on_restart = value
                                self.nsr_switchover_on_restart.value_namespace = name_space
                                self.nsr_switchover_on_restart.value_namespace_prefix = name_space_prefix
                            if(value_path == "nssa-area-count"):
                                self.nssa_area_count = value
                                self.nssa_area_count.value_namespace = name_space
                                self.nssa_area_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-nbrs-full"):
                                self.number_nbrs_full = value
                                self.number_nbrs_full.value_namespace = name_space
                                self.number_nbrs_full.value_namespace_prefix = name_space_prefix
                            if(value_path == "opaque-capable"):
                                self.opaque_capable = value
                                self.opaque_capable.value_namespace = name_space
                                self.opaque_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "opaque-lsa-checksum"):
                                self.opaque_lsa_checksum = value
                                self.opaque_lsa_checksum.value_namespace = name_space
                                self.opaque_lsa_checksum.value_namespace_prefix = name_space_prefix
                            if(value_path == "opaque-lsa-count"):
                                self.opaque_lsa_count = value
                                self.opaque_lsa_count.value_namespace = name_space
                                self.opaque_lsa_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "redistribution-limit"):
                                self.redistribution_limit = value
                                self.redistribution_limit.value_namespace = name_space
                                self.redistribution_limit.value_namespace_prefix = name_space_prefix
                            if(value_path == "redistribution-limit-warn"):
                                self.redistribution_limit_warn = value
                                self.redistribution_limit_warn.value_namespace = name_space
                                self.redistribution_limit_warn.value_namespace_prefix = name_space_prefix
                            if(value_path == "redistribution-threshold"):
                                self.redistribution_threshold = value
                                self.redistribution_threshold.value_namespace = name_space
                                self.redistribution_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "role"):
                                self.role = value
                                self.role.value_namespace = name_space
                                self.role.value_namespace_prefix = name_space_prefix
                            if(value_path == "role-standby"):
                                self.role_standby = value
                                self.role_standby.value_namespace = name_space
                                self.role_standby.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-id"):
                                self.router_id = value
                                self.router_id.value_namespace = name_space
                                self.router_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "snmp-trap-enabled"):
                                self.snmp_trap_enabled = value
                                self.snmp_trap_enabled.value_namespace = name_space
                                self.snmp_trap_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "spf-hold-time"):
                                self.spf_hold_time = value
                                self.spf_hold_time.value_namespace = name_space
                                self.spf_hold_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "spf-hold-time-u32"):
                                self.spf_hold_time_u32 = value
                                self.spf_hold_time_u32.value_namespace = name_space
                                self.spf_hold_time_u32.value_namespace_prefix = name_space_prefix
                            if(value_path == "spf-maximum-time"):
                                self.spf_maximum_time = value
                                self.spf_maximum_time.value_namespace = name_space
                                self.spf_maximum_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "spf-maximum-time-u32"):
                                self.spf_maximum_time_u32 = value
                                self.spf_maximum_time_u32.value_namespace = name_space
                                self.spf_maximum_time_u32.value_namespace_prefix = name_space_prefix
                            if(value_path == "spf-prefix-priority"):
                                self.spf_prefix_priority = value
                                self.spf_prefix_priority.value_namespace = name_space
                                self.spf_prefix_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "spf-prefix-priority-route-policy"):
                                self.spf_prefix_priority_route_policy = value
                                self.spf_prefix_priority_route_policy.value_namespace = name_space
                                self.spf_prefix_priority_route_policy.value_namespace_prefix = name_space_prefix
                            if(value_path == "spf-start-time"):
                                self.spf_start_time = value
                                self.spf_start_time.value_namespace = name_space
                                self.spf_start_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "spf-start-time-u32"):
                                self.spf_start_time_u32 = value
                                self.spf_start_time_u32.value_namespace = name_space
                                self.spf_start_time_u32.value_namespace_prefix = name_space_prefix
                            if(value_path == "sr-strict-spf-cap"):
                                self.sr_strict_spf_cap = value
                                self.sr_strict_spf_cap.value_namespace = name_space
                                self.sr_strict_spf_cap.value_namespace_prefix = name_space_prefix
                            if(value_path == "srgb-configured"):
                                self.srgb_configured = value
                                self.srgb_configured.value_namespace = name_space
                                self.srgb_configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "srgb-end"):
                                self.srgb_end = value
                                self.srgb_end.value_namespace = name_space
                                self.srgb_end.value_namespace_prefix = name_space_prefix
                            if(value_path == "srgb-start"):
                                self.srgb_start = value
                                self.srgb_start.value_namespace = name_space
                                self.srgb_start.value_namespace_prefix = name_space_prefix
                            if(value_path == "srgb-status"):
                                self.srgb_status = value
                                self.srgb_status.value_namespace = name_space
                                self.srgb_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "stub-area-count"):
                                self.stub_area_count = value
                                self.stub_area_count.value_namespace = name_space
                                self.stub_area_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-prefix-limit-reached"):
                                self.table_prefix_limit_reached = value
                                self.table_prefix_limit_reached.value_namespace = name_space
                                self.table_prefix_limit_reached.value_namespace_prefix = name_space_prefix
                            if(value_path == "tos-options"):
                                self.tos_options = value
                                self.tos_options.value_namespace = name_space
                                self.tos_options.value_namespace_prefix = name_space_prefix
                            if(value_path == "ucmp"):
                                self.ucmp = value
                                self.ucmp.value_namespace = name_space
                                self.ucmp.value_namespace_prefix = name_space_prefix
                            if(value_path == "ucmp-delay"):
                                self.ucmp_delay = value
                                self.ucmp_delay.value_namespace = name_space
                                self.ucmp_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "ucmp-prefix-list"):
                                self.ucmp_prefix_list = value
                                self.ucmp_prefix_list.value_namespace = name_space
                                self.ucmp_prefix_list.value_namespace_prefix = name_space_prefix
                            if(value_path == "ucmp-variance"):
                                self.ucmp_variance = value
                                self.ucmp_variance.value_namespace = name_space
                                self.ucmp_variance.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-lite-enabled"):
                                self.vrf_lite_enabled = value
                                self.vrf_lite_enabled.value_namespace = name_space
                                self.vrf_lite_enabled.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            (self.process_areas is not None and self.process_areas.has_data()) or
                            (self.process_summary is not None and self.process_summary.has_data()) or
                            (self.protocol_areas is not None and self.protocol_areas.has_data()) or
                            (self.protocol_summary is not None and self.protocol_summary.has_data()) or
                            (self.redistributions is not None and self.redistributions.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.process_areas is not None and self.process_areas.has_operation()) or
                            (self.process_summary is not None and self.process_summary.has_operation()) or
                            (self.protocol_areas is not None and self.protocol_areas.has_operation()) or
                            (self.protocol_summary is not None and self.protocol_summary.has_operation()) or
                            (self.redistributions is not None and self.redistributions.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "process-information" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "process-areas"):
                            if (self.process_areas is None):
                                self.process_areas = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas()
                                self.process_areas.parent = self
                                self._children_name_map["process_areas"] = "process-areas"
                            return self.process_areas

                        if (child_yang_name == "process-summary"):
                            if (self.process_summary is None):
                                self.process_summary = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary()
                                self.process_summary.parent = self
                                self._children_name_map["process_summary"] = "process-summary"
                            return self.process_summary

                        if (child_yang_name == "protocol-areas"):
                            if (self.protocol_areas is None):
                                self.protocol_areas = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas()
                                self.protocol_areas.parent = self
                                self._children_name_map["protocol_areas"] = "protocol-areas"
                            return self.protocol_areas

                        if (child_yang_name == "protocol-summary"):
                            if (self.protocol_summary is None):
                                self.protocol_summary = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolSummary()
                                self.protocol_summary.parent = self
                                self._children_name_map["protocol_summary"] = "protocol-summary"
                            return self.protocol_summary

                        if (child_yang_name == "redistributions"):
                            if (self.redistributions is None):
                                self.redistributions = Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions()
                                self.redistributions.parent = self
                                self._children_name_map["redistributions"] = "redistributions"
                            return self.redistributions

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "process-areas" or name == "process-summary" or name == "protocol-areas" or name == "protocol-summary" or name == "redistributions"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Areas(Entity):
                    """
                    Area table
                    
                    .. attribute:: area
                    
                    	Container for per area data
                    	**type**\: list of    :py:class:`Area <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Areas, self).__init__()

                        self.yang_name = "areas"
                        self.yang_parent_name = "default-vrf"

                        self.area = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.Areas, self).__setattr__(name, value)


                    class Area(Entity):
                        """
                        Container for per area data
                        
                        .. attribute:: area_id  <key>
                        
                        	Area ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: area_statistics
                        
                        	Container for Statistics
                        	**type**\:   :py:class:`AreaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics>`
                        
                        .. attribute:: flood_list_area_table
                        
                        	Area specific flood list table
                        	**type**\:   :py:class:`FloodListAreaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable>`
                        
                        .. attribute:: interface_briefs
                        
                        	OSPF Interface Brief Table
                        	**type**\:   :py:class:`InterfaceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs>`
                        
                        .. attribute:: interfaces
                        
                        	OSPF Interface Table
                        	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces>`
                        
                        .. attribute:: neighbor_details
                        
                        	Neighbor detail table
                        	**type**\:   :py:class:`NeighborDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails>`
                        
                        .. attribute:: neighbors
                        
                        	Neighbor table
                        	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors>`
                        
                        .. attribute:: requests
                        
                        	Request List table
                        	**type**\:   :py:class:`Requests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests>`
                        
                        .. attribute:: retransmissions
                        
                        	Retransmission list table
                        	**type**\:   :py:class:`Retransmissions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area, self).__init__()

                            self.yang_name = "area"
                            self.yang_parent_name = "areas"

                            self.area_id = YLeaf(YType.int32, "area-id")

                            self.area_statistics = Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics()
                            self.area_statistics.parent = self
                            self._children_name_map["area_statistics"] = "area-statistics"
                            self._children_yang_names.add("area-statistics")

                            self.flood_list_area_table = Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable()
                            self.flood_list_area_table.parent = self
                            self._children_name_map["flood_list_area_table"] = "flood-list-area-table"
                            self._children_yang_names.add("flood-list-area-table")

                            self.interface_briefs = Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs()
                            self.interface_briefs.parent = self
                            self._children_name_map["interface_briefs"] = "interface-briefs"
                            self._children_yang_names.add("interface-briefs")

                            self.interfaces = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                            self._children_yang_names.add("interfaces")

                            self.neighbor_details = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails()
                            self.neighbor_details.parent = self
                            self._children_name_map["neighbor_details"] = "neighbor-details"
                            self._children_yang_names.add("neighbor-details")

                            self.neighbors = Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"
                            self._children_yang_names.add("neighbors")

                            self.requests = Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests()
                            self.requests.parent = self
                            self._children_name_map["requests"] = "requests"
                            self._children_yang_names.add("requests")

                            self.retransmissions = Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions()
                            self.retransmissions.parent = self
                            self._children_name_map["retransmissions"] = "retransmissions"
                            self._children_yang_names.add("retransmissions")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("area_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area, self).__setattr__(name, value)


                        class FloodListAreaTable(Entity):
                            """
                            Area specific flood list table
                            
                            .. attribute:: flood
                            
                            	Flooding information for a specific interface
                            	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable, self).__init__()

                                self.yang_name = "flood-list-area-table"
                                self.yang_parent_name = "area"

                                self.flood = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable, self).__setattr__(name, value)


                            class Flood(Entity):
                                """
                                Flooding information for a specific interface
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: area_flood
                                
                                	Area scope floodlist
                                	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood>`
                                
                                .. attribute:: as_flood
                                
                                	AS scope floodlist
                                	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AsFlood>`
                                
                                .. attribute:: flood_interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: flood_lsa_count
                                
                                	Number of LSAs currently being flooded
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flood_pacing_timer
                                
                                	Time until next LS update due (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood, self).__init__()

                                    self.yang_name = "flood"
                                    self.yang_parent_name = "flood-list-area-table"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.flood_interface_name = YLeaf(YType.str, "flood-interface-name")

                                    self.flood_lsa_count = YLeaf(YType.uint32, "flood-lsa-count")

                                    self.flood_pacing_timer = YLeaf(YType.uint32, "flood-pacing-timer")

                                    self.area_flood = YList(self)
                                    self.as_flood = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "flood_interface_name",
                                                    "flood_lsa_count",
                                                    "flood_pacing_timer") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood, self).__setattr__(name, value)


                                class AreaFlood(Entity):
                                    """
                                    Area scope floodlist
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood, self).__init__()

                                        self.yang_name = "area-flood"
                                        self.yang_parent_name = "flood"

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("header_advertising_router",
                                                        "header_ls_id",
                                                        "header_lsa_age",
                                                        "header_lsa_checksum",
                                                        "header_lsa_type",
                                                        "header_sequence_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.header_advertising_router.is_set or
                                            self.header_ls_id.is_set or
                                            self.header_lsa_age.is_set or
                                            self.header_lsa_checksum.is_set or
                                            self.header_lsa_type.is_set or
                                            self.header_sequence_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.header_advertising_router.yfilter != YFilter.not_set or
                                            self.header_ls_id.yfilter != YFilter.not_set or
                                            self.header_lsa_age.yfilter != YFilter.not_set or
                                            self.header_lsa_checksum.yfilter != YFilter.not_set or
                                            self.header_lsa_type.yfilter != YFilter.not_set or
                                            self.header_sequence_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "area-flood" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                        if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                        if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                        if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                        if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                        if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "header-advertising-router"):
                                            self.header_advertising_router = value
                                            self.header_advertising_router.value_namespace = name_space
                                            self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-ls-id"):
                                            self.header_ls_id = value
                                            self.header_ls_id.value_namespace = name_space
                                            self.header_ls_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-age"):
                                            self.header_lsa_age = value
                                            self.header_lsa_age.value_namespace = name_space
                                            self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-checksum"):
                                            self.header_lsa_checksum = value
                                            self.header_lsa_checksum.value_namespace = name_space
                                            self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-type"):
                                            self.header_lsa_type = value
                                            self.header_lsa_type.value_namespace = name_space
                                            self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-sequence-number"):
                                            self.header_sequence_number = value
                                            self.header_sequence_number.value_namespace = name_space
                                            self.header_sequence_number.value_namespace_prefix = name_space_prefix


                                class AsFlood(Entity):
                                    """
                                    AS scope floodlist
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AsFlood, self).__init__()

                                        self.yang_name = "as-flood"
                                        self.yang_parent_name = "flood"

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("header_advertising_router",
                                                        "header_ls_id",
                                                        "header_lsa_age",
                                                        "header_lsa_checksum",
                                                        "header_lsa_type",
                                                        "header_sequence_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AsFlood, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AsFlood, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.header_advertising_router.is_set or
                                            self.header_ls_id.is_set or
                                            self.header_lsa_age.is_set or
                                            self.header_lsa_checksum.is_set or
                                            self.header_lsa_type.is_set or
                                            self.header_sequence_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.header_advertising_router.yfilter != YFilter.not_set or
                                            self.header_ls_id.yfilter != YFilter.not_set or
                                            self.header_lsa_age.yfilter != YFilter.not_set or
                                            self.header_lsa_checksum.yfilter != YFilter.not_set or
                                            self.header_lsa_type.yfilter != YFilter.not_set or
                                            self.header_sequence_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "as-flood" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                        if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                        if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                        if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                        if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                        if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "header-advertising-router"):
                                            self.header_advertising_router = value
                                            self.header_advertising_router.value_namespace = name_space
                                            self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-ls-id"):
                                            self.header_ls_id = value
                                            self.header_ls_id.value_namespace = name_space
                                            self.header_ls_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-age"):
                                            self.header_lsa_age = value
                                            self.header_lsa_age.value_namespace = name_space
                                            self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-checksum"):
                                            self.header_lsa_checksum = value
                                            self.header_lsa_checksum.value_namespace = name_space
                                            self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-type"):
                                            self.header_lsa_type = value
                                            self.header_lsa_type.value_namespace = name_space
                                            self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-sequence-number"):
                                            self.header_sequence_number = value
                                            self.header_sequence_number.value_namespace = name_space
                                            self.header_sequence_number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.area_flood:
                                        if (c.has_data()):
                                            return True
                                    for c in self.as_flood:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.interface_name.is_set or
                                        self.flood_interface_name.is_set or
                                        self.flood_lsa_count.is_set or
                                        self.flood_pacing_timer.is_set)

                                def has_operation(self):
                                    for c in self.area_flood:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.as_flood:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.flood_interface_name.yfilter != YFilter.not_set or
                                        self.flood_lsa_count.yfilter != YFilter.not_set or
                                        self.flood_pacing_timer.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flood" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.flood_interface_name.is_set or self.flood_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_interface_name.get_name_leafdata())
                                    if (self.flood_lsa_count.is_set or self.flood_lsa_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_lsa_count.get_name_leafdata())
                                    if (self.flood_pacing_timer.is_set or self.flood_pacing_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_pacing_timer.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "area-flood"):
                                        for c in self.area_flood:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.area_flood.append(c)
                                        return c

                                    if (child_yang_name == "as-flood"):
                                        for c in self.as_flood:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AsFlood()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.as_flood.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "area-flood" or name == "as-flood" or name == "interface-name" or name == "flood-interface-name" or name == "flood-lsa-count" or name == "flood-pacing-timer"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-interface-name"):
                                        self.flood_interface_name = value
                                        self.flood_interface_name.value_namespace = name_space
                                        self.flood_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-lsa-count"):
                                        self.flood_lsa_count = value
                                        self.flood_lsa_count.value_namespace = name_space
                                        self.flood_lsa_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-pacing-timer"):
                                        self.flood_pacing_timer = value
                                        self.flood_pacing_timer.value_namespace = name_space
                                        self.flood_pacing_timer.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.flood:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.flood:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "flood-list-area-table" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "flood"):
                                    for c in self.flood:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.flood.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flood"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Neighbors(Entity):
                            """
                            Neighbor table
                            
                            .. attribute:: neighbor
                            
                            	Neighbor information
                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors, self).__init__()

                                self.yang_name = "neighbors"
                                self.yang_parent_name = "area"

                                self.neighbor = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors, self).__setattr__(name, value)


                            class Neighbor(Entity):
                                """
                                Neighbor information
                                
                                .. attribute:: dr_bdr_state
                                
                                	Designated Router state
                                	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_address_xr
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_information
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation>`
                                
                                .. attribute:: neighbor_dead_timer
                                
                                	Time until neighbor's dead timer expires (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_dr_priority
                                
                                	Neighbor's DR priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_interface_name
                                
                                	Interface via which the neighbor is seen
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: neighbor_madj_interface
                                
                                	Interface is MADJ
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_state
                                
                                	Neighbor's state
                                	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                
                                .. attribute:: neighbor_up_time
                                
                                	Amount of time since the adjacency is up (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "neighbors"

                                    self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                    self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                    self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                    self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                    self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                    self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                    self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                    self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation()
                                    self.neighbor_bfd_information.parent = self
                                    self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                    self._children_yang_names.add("neighbor-bfd-information")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dr_bdr_state",
                                                    "interface_name",
                                                    "neighbor_address",
                                                    "neighbor_address_xr",
                                                    "neighbor_dead_timer",
                                                    "neighbor_dr_priority",
                                                    "neighbor_id",
                                                    "neighbor_interface_name",
                                                    "neighbor_madj_interface",
                                                    "neighbor_state",
                                                    "neighbor_up_time") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor, self).__setattr__(name, value)


                                class NeighborBfdInformation(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation, self).__init__()

                                        self.yang_name = "neighbor-bfd-information"
                                        self.yang_parent_name = "neighbor"

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bfd_intf_enable_mode",
                                                        "bfd_status_flag") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bfd_intf_enable_mode.is_set or
                                            self.bfd_status_flag.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                            self.bfd_status_flag.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-bfd-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                        if (self.bfd_status_flag.is_set or self.bfd_status_flag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bfd_status_flag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bfd-intf-enable-mode" or name == "bfd-status-flag"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bfd-intf-enable-mode"):
                                            self.bfd_intf_enable_mode = value
                                            self.bfd_intf_enable_mode.value_namespace = name_space
                                            self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bfd-status-flag"):
                                            self.bfd_status_flag = value
                                            self.bfd_status_flag.value_namespace = name_space
                                            self.bfd_status_flag.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.dr_bdr_state.is_set or
                                        self.interface_name.is_set or
                                        self.neighbor_address.is_set or
                                        self.neighbor_address_xr.is_set or
                                        self.neighbor_dead_timer.is_set or
                                        self.neighbor_dr_priority.is_set or
                                        self.neighbor_id.is_set or
                                        self.neighbor_interface_name.is_set or
                                        self.neighbor_madj_interface.is_set or
                                        self.neighbor_state.is_set or
                                        self.neighbor_up_time.is_set or
                                        (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dr_bdr_state.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.neighbor_address.yfilter != YFilter.not_set or
                                        self.neighbor_address_xr.yfilter != YFilter.not_set or
                                        self.neighbor_dead_timer.yfilter != YFilter.not_set or
                                        self.neighbor_dr_priority.yfilter != YFilter.not_set or
                                        self.neighbor_id.yfilter != YFilter.not_set or
                                        self.neighbor_interface_name.yfilter != YFilter.not_set or
                                        self.neighbor_madj_interface.yfilter != YFilter.not_set or
                                        self.neighbor_state.yfilter != YFilter.not_set or
                                        self.neighbor_up_time.yfilter != YFilter.not_set or
                                        (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "neighbor" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dr_bdr_state.is_set or self.dr_bdr_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dr_bdr_state.get_name_leafdata())
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                    if (self.neighbor_address_xr.is_set or self.neighbor_address_xr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address_xr.get_name_leafdata())
                                    if (self.neighbor_dead_timer.is_set or self.neighbor_dead_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_dead_timer.get_name_leafdata())
                                    if (self.neighbor_dr_priority.is_set or self.neighbor_dr_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_dr_priority.get_name_leafdata())
                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                    if (self.neighbor_interface_name.is_set or self.neighbor_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_interface_name.get_name_leafdata())
                                    if (self.neighbor_madj_interface.is_set or self.neighbor_madj_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_madj_interface.get_name_leafdata())
                                    if (self.neighbor_state.is_set or self.neighbor_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_state.get_name_leafdata())
                                    if (self.neighbor_up_time.is_set or self.neighbor_up_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_up_time.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "neighbor-bfd-information"):
                                        if (self.neighbor_bfd_information is None):
                                            self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation()
                                            self.neighbor_bfd_information.parent = self
                                            self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                        return self.neighbor_bfd_information

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "neighbor-bfd-information" or name == "dr-bdr-state" or name == "interface-name" or name == "neighbor-address" or name == "neighbor-address-xr" or name == "neighbor-dead-timer" or name == "neighbor-dr-priority" or name == "neighbor-id" or name == "neighbor-interface-name" or name == "neighbor-madj-interface" or name == "neighbor-state" or name == "neighbor-up-time"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dr-bdr-state"):
                                        self.dr_bdr_state = value
                                        self.dr_bdr_state.value_namespace = name_space
                                        self.dr_bdr_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-address"):
                                        self.neighbor_address = value
                                        self.neighbor_address.value_namespace = name_space
                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-address-xr"):
                                        self.neighbor_address_xr = value
                                        self.neighbor_address_xr.value_namespace = name_space
                                        self.neighbor_address_xr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-dead-timer"):
                                        self.neighbor_dead_timer = value
                                        self.neighbor_dead_timer.value_namespace = name_space
                                        self.neighbor_dead_timer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-dr-priority"):
                                        self.neighbor_dr_priority = value
                                        self.neighbor_dr_priority.value_namespace = name_space
                                        self.neighbor_dr_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-id"):
                                        self.neighbor_id = value
                                        self.neighbor_id.value_namespace = name_space
                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-interface-name"):
                                        self.neighbor_interface_name = value
                                        self.neighbor_interface_name.value_namespace = name_space
                                        self.neighbor_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-madj-interface"):
                                        self.neighbor_madj_interface = value
                                        self.neighbor_madj_interface.value_namespace = name_space
                                        self.neighbor_madj_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-state"):
                                        self.neighbor_state = value
                                        self.neighbor_state.value_namespace = name_space
                                        self.neighbor_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-up-time"):
                                        self.neighbor_up_time = value
                                        self.neighbor_up_time.value_namespace = name_space
                                        self.neighbor_up_time.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.neighbor:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.neighbor:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbors" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "neighbor"):
                                    for c in self.neighbor:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.neighbor.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "neighbor"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class InterfaceBriefs(Entity):
                            """
                            OSPF Interface Brief Table
                            
                            .. attribute:: interface_brief
                            
                            	OSPF interface brief information
                            	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs, self).__init__()

                                self.yang_name = "interface-briefs"
                                self.yang_parent_name = "area"

                                self.interface_brief = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs, self).__setattr__(name, value)


                            class InterfaceBrief(Entity):
                                """
                                OSPF interface brief information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: interface_address
                                
                                	Interface IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_adj_neighbor_count
                                
                                	Total number of Adjacent Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_area
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: interface_fast_detect_hold_down
                                
                                	Interface in fast detect hold down state
                                	**type**\:  bool
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_madj
                                
                                	Information for multi\-area on the interface
                                	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj>`
                                
                                .. attribute:: interface_madj_count
                                
                                	Total number of multi\-area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_mask
                                
                                	Interface IP Mask
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: interface_neighbor_count
                                
                                	Total number of Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interfaceis_madj
                                
                                	If true, interface is multi\-area
                                	**type**\:  bool
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief, self).__init__()

                                    self.yang_name = "interface-brief"
                                    self.yang_parent_name = "interface-briefs"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.interface_address = YLeaf(YType.str, "interface-address")

                                    self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                    self.interface_area = YLeaf(YType.str, "interface-area")

                                    self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                    self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                    self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                    self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                    self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                    self.interface_madj = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "interface_address",
                                                    "interface_adj_neighbor_count",
                                                    "interface_area",
                                                    "interface_fast_detect_hold_down",
                                                    "interface_link_cost",
                                                    "interface_madj_count",
                                                    "interface_mask",
                                                    "interface_name_xr",
                                                    "interface_neighbor_count",
                                                    "interfaceis_madj",
                                                    "ospf_interface_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief, self).__setattr__(name, value)


                                class InterfaceMadj(Entity):
                                    """
                                    Information for multi\-area on the interface
                                    
                                    .. attribute:: interface_adj_neighbor_count
                                    
                                    	Total number of Adjacent Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_area
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: madj_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__init__()

                                        self.yang_name = "interface-madj"
                                        self.yang_parent_name = "interface-brief"

                                        self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                        self.interface_area = YLeaf(YType.str, "interface-area")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_adj_neighbor_count",
                                                        "interface_area",
                                                        "interface_link_cost",
                                                        "interface_neighbor_count",
                                                        "madj_area_id",
                                                        "ospf_interface_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interface_adj_neighbor_count.is_set or
                                            self.interface_area.is_set or
                                            self.interface_link_cost.is_set or
                                            self.interface_neighbor_count.is_set or
                                            self.madj_area_id.is_set or
                                            self.ospf_interface_state.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_adj_neighbor_count.yfilter != YFilter.not_set or
                                            self.interface_area.yfilter != YFilter.not_set or
                                            self.interface_link_cost.yfilter != YFilter.not_set or
                                            self.interface_neighbor_count.yfilter != YFilter.not_set or
                                            self.madj_area_id.yfilter != YFilter.not_set or
                                            self.ospf_interface_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-madj" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_adj_neighbor_count.is_set or self.interface_adj_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_adj_neighbor_count.get_name_leafdata())
                                        if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_area.get_name_leafdata())
                                        if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                        if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                        if (self.madj_area_id.is_set or self.madj_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.madj_area_id.get_name_leafdata())
                                        if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-adj-neighbor-count" or name == "interface-area" or name == "interface-link-cost" or name == "interface-neighbor-count" or name == "madj-area-id" or name == "ospf-interface-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-adj-neighbor-count"):
                                            self.interface_adj_neighbor_count = value
                                            self.interface_adj_neighbor_count.value_namespace = name_space
                                            self.interface_adj_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-area"):
                                            self.interface_area = value
                                            self.interface_area.value_namespace = name_space
                                            self.interface_area.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-link-cost"):
                                            self.interface_link_cost = value
                                            self.interface_link_cost.value_namespace = name_space
                                            self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-neighbor-count"):
                                            self.interface_neighbor_count = value
                                            self.interface_neighbor_count.value_namespace = name_space
                                            self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "madj-area-id"):
                                            self.madj_area_id = value
                                            self.madj_area_id.value_namespace = name_space
                                            self.madj_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-interface-state"):
                                            self.ospf_interface_state = value
                                            self.ospf_interface_state.value_namespace = name_space
                                            self.ospf_interface_state.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.interface_madj:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.interface_name.is_set or
                                        self.interface_address.is_set or
                                        self.interface_adj_neighbor_count.is_set or
                                        self.interface_area.is_set or
                                        self.interface_fast_detect_hold_down.is_set or
                                        self.interface_link_cost.is_set or
                                        self.interface_madj_count.is_set or
                                        self.interface_mask.is_set or
                                        self.interface_name_xr.is_set or
                                        self.interface_neighbor_count.is_set or
                                        self.interfaceis_madj.is_set or
                                        self.ospf_interface_state.is_set)

                                def has_operation(self):
                                    for c in self.interface_madj:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.interface_address.yfilter != YFilter.not_set or
                                        self.interface_adj_neighbor_count.yfilter != YFilter.not_set or
                                        self.interface_area.yfilter != YFilter.not_set or
                                        self.interface_fast_detect_hold_down.yfilter != YFilter.not_set or
                                        self.interface_link_cost.yfilter != YFilter.not_set or
                                        self.interface_madj_count.yfilter != YFilter.not_set or
                                        self.interface_mask.yfilter != YFilter.not_set or
                                        self.interface_name_xr.yfilter != YFilter.not_set or
                                        self.interface_neighbor_count.yfilter != YFilter.not_set or
                                        self.interfaceis_madj.yfilter != YFilter.not_set or
                                        self.ospf_interface_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface-brief" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.interface_address.is_set or self.interface_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_address.get_name_leafdata())
                                    if (self.interface_adj_neighbor_count.is_set or self.interface_adj_neighbor_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_adj_neighbor_count.get_name_leafdata())
                                    if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_area.get_name_leafdata())
                                    if (self.interface_fast_detect_hold_down.is_set or self.interface_fast_detect_hold_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_fast_detect_hold_down.get_name_leafdata())
                                    if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                    if (self.interface_madj_count.is_set or self.interface_madj_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_madj_count.get_name_leafdata())
                                    if (self.interface_mask.is_set or self.interface_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_mask.get_name_leafdata())
                                    if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                    if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                    if (self.interfaceis_madj.is_set or self.interfaceis_madj.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interfaceis_madj.get_name_leafdata())
                                    if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-madj"):
                                        for c in self.interface_madj:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.interface_madj.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-madj" or name == "interface-name" or name == "interface-address" or name == "interface-adj-neighbor-count" or name == "interface-area" or name == "interface-fast-detect-hold-down" or name == "interface-link-cost" or name == "interface-madj-count" or name == "interface-mask" or name == "interface-name-xr" or name == "interface-neighbor-count" or name == "interfaceis-madj" or name == "ospf-interface-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-address"):
                                        self.interface_address = value
                                        self.interface_address.value_namespace = name_space
                                        self.interface_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-adj-neighbor-count"):
                                        self.interface_adj_neighbor_count = value
                                        self.interface_adj_neighbor_count.value_namespace = name_space
                                        self.interface_adj_neighbor_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-area"):
                                        self.interface_area = value
                                        self.interface_area.value_namespace = name_space
                                        self.interface_area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-fast-detect-hold-down"):
                                        self.interface_fast_detect_hold_down = value
                                        self.interface_fast_detect_hold_down.value_namespace = name_space
                                        self.interface_fast_detect_hold_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-link-cost"):
                                        self.interface_link_cost = value
                                        self.interface_link_cost.value_namespace = name_space
                                        self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-madj-count"):
                                        self.interface_madj_count = value
                                        self.interface_madj_count.value_namespace = name_space
                                        self.interface_madj_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-mask"):
                                        self.interface_mask = value
                                        self.interface_mask.value_namespace = name_space
                                        self.interface_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name-xr"):
                                        self.interface_name_xr = value
                                        self.interface_name_xr.value_namespace = name_space
                                        self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-neighbor-count"):
                                        self.interface_neighbor_count = value
                                        self.interface_neighbor_count.value_namespace = name_space
                                        self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interfaceis-madj"):
                                        self.interfaceis_madj = value
                                        self.interfaceis_madj.value_namespace = name_space
                                        self.interfaceis_madj.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-interface-state"):
                                        self.ospf_interface_state = value
                                        self.ospf_interface_state.value_namespace = name_space
                                        self.ospf_interface_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface_brief:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.interface_brief:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-briefs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface-brief"):
                                    for c in self.interface_brief:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface_brief.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-brief"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Requests(Entity):
                            """
                            Request List table
                            
                            .. attribute:: request
                            
                            	Request list for a particular adjacency
                            	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests, self).__init__()

                                self.yang_name = "requests"
                                self.yang_parent_name = "area"

                                self.request = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests, self).__setattr__(name, value)


                            class Request(Entity):
                                """
                                Request list for a particular adjacency
                                
                                .. attribute:: interface_name
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: request
                                
                                	List of request list entries
                                	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request.Request>`
                                
                                .. attribute:: request_interface_name
                                
                                	Request list interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: request_neighbor_address
                                
                                	Neighbor IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: request_neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request, self).__init__()

                                    self.yang_name = "request"
                                    self.yang_parent_name = "requests"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.request_interface_name = YLeaf(YType.str, "request-interface-name")

                                    self.request_neighbor_address = YLeaf(YType.str, "request-neighbor-address")

                                    self.request_neighbor_id = YLeaf(YType.str, "request-neighbor-id")

                                    self.request = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "neighbor_address",
                                                    "request_interface_name",
                                                    "request_neighbor_address",
                                                    "request_neighbor_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request, self).__setattr__(name, value)


                                class Request(Entity):
                                    """
                                    List of request list entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request.Request, self).__init__()

                                        self.yang_name = "request"
                                        self.yang_parent_name = "request"

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("header_advertising_router",
                                                        "header_ls_id",
                                                        "header_lsa_age",
                                                        "header_lsa_checksum",
                                                        "header_lsa_type",
                                                        "header_sequence_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request.Request, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request.Request, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.header_advertising_router.is_set or
                                            self.header_ls_id.is_set or
                                            self.header_lsa_age.is_set or
                                            self.header_lsa_checksum.is_set or
                                            self.header_lsa_type.is_set or
                                            self.header_sequence_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.header_advertising_router.yfilter != YFilter.not_set or
                                            self.header_ls_id.yfilter != YFilter.not_set or
                                            self.header_lsa_age.yfilter != YFilter.not_set or
                                            self.header_lsa_checksum.yfilter != YFilter.not_set or
                                            self.header_lsa_type.yfilter != YFilter.not_set or
                                            self.header_sequence_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "request" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                        if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                        if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                        if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                        if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                        if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "header-advertising-router"):
                                            self.header_advertising_router = value
                                            self.header_advertising_router.value_namespace = name_space
                                            self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-ls-id"):
                                            self.header_ls_id = value
                                            self.header_ls_id.value_namespace = name_space
                                            self.header_ls_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-age"):
                                            self.header_lsa_age = value
                                            self.header_lsa_age.value_namespace = name_space
                                            self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-checksum"):
                                            self.header_lsa_checksum = value
                                            self.header_lsa_checksum.value_namespace = name_space
                                            self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-type"):
                                            self.header_lsa_type = value
                                            self.header_lsa_type.value_namespace = name_space
                                            self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-sequence-number"):
                                            self.header_sequence_number = value
                                            self.header_sequence_number.value_namespace = name_space
                                            self.header_sequence_number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.request:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.interface_name.is_set or
                                        self.neighbor_address.is_set or
                                        self.request_interface_name.is_set or
                                        self.request_neighbor_address.is_set or
                                        self.request_neighbor_id.is_set)

                                def has_operation(self):
                                    for c in self.request:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.neighbor_address.yfilter != YFilter.not_set or
                                        self.request_interface_name.yfilter != YFilter.not_set or
                                        self.request_neighbor_address.yfilter != YFilter.not_set or
                                        self.request_neighbor_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "request" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                    if (self.request_interface_name.is_set or self.request_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.request_interface_name.get_name_leafdata())
                                    if (self.request_neighbor_address.is_set or self.request_neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.request_neighbor_address.get_name_leafdata())
                                    if (self.request_neighbor_id.is_set or self.request_neighbor_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.request_neighbor_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "request"):
                                        for c in self.request:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request.Request()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.request.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "request" or name == "interface-name" or name == "neighbor-address" or name == "request-interface-name" or name == "request-neighbor-address" or name == "request-neighbor-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-address"):
                                        self.neighbor_address = value
                                        self.neighbor_address.value_namespace = name_space
                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "request-interface-name"):
                                        self.request_interface_name = value
                                        self.request_interface_name.value_namespace = name_space
                                        self.request_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "request-neighbor-address"):
                                        self.request_neighbor_address = value
                                        self.request_neighbor_address.value_namespace = name_space
                                        self.request_neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "request-neighbor-id"):
                                        self.request_neighbor_id = value
                                        self.request_neighbor_id.value_namespace = name_space
                                        self.request_neighbor_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.request:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.request:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "requests" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "request"):
                                    for c in self.request:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.request.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "request"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Retransmissions(Entity):
                            """
                            Retransmission list table
                            
                            .. attribute:: retransmission
                            
                            	Retransmission list for a particular adjacency
                            	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions, self).__init__()

                                self.yang_name = "retransmissions"
                                self.yang_parent_name = "area"

                                self.retransmission = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions, self).__setattr__(name, value)


                            class Retransmission(Entity):
                                """
                                Retransmission list for a particular adjacency
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_area_db
                                
                                	List of Area scope entries
                                	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb>`
                                
                                .. attribute:: retransmission_asdb
                                
                                	List of AS Scope entries
                                	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb>`
                                
                                .. attribute:: retransmission_count
                                
                                	Retransmission queue length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmission_interface_name
                                
                                	Retransmission list interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: retransmission_neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_neighbor_ip_address
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_timer
                                
                                	Amount of time remaining on retransmission timer (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission, self).__init__()

                                    self.yang_name = "retransmission"
                                    self.yang_parent_name = "retransmissions"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.retransmission_count = YLeaf(YType.uint32, "retransmission-count")

                                    self.retransmission_interface_name = YLeaf(YType.str, "retransmission-interface-name")

                                    self.retransmission_neighbor_id = YLeaf(YType.str, "retransmission-neighbor-id")

                                    self.retransmission_neighbor_ip_address = YLeaf(YType.str, "retransmission-neighbor-ip-address")

                                    self.retransmission_timer = YLeaf(YType.uint32, "retransmission-timer")

                                    self.retransmission_area_db = YList(self)
                                    self.retransmission_asdb = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "neighbor_address",
                                                    "retransmission_count",
                                                    "retransmission_interface_name",
                                                    "retransmission_neighbor_id",
                                                    "retransmission_neighbor_ip_address",
                                                    "retransmission_timer") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission, self).__setattr__(name, value)


                                class RetransmissionAreaDb(Entity):
                                    """
                                    List of Area scope entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb, self).__init__()

                                        self.yang_name = "retransmission-area-db"
                                        self.yang_parent_name = "retransmission"

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("header_advertising_router",
                                                        "header_ls_id",
                                                        "header_lsa_age",
                                                        "header_lsa_checksum",
                                                        "header_lsa_type",
                                                        "header_sequence_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.header_advertising_router.is_set or
                                            self.header_ls_id.is_set or
                                            self.header_lsa_age.is_set or
                                            self.header_lsa_checksum.is_set or
                                            self.header_lsa_type.is_set or
                                            self.header_sequence_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.header_advertising_router.yfilter != YFilter.not_set or
                                            self.header_ls_id.yfilter != YFilter.not_set or
                                            self.header_lsa_age.yfilter != YFilter.not_set or
                                            self.header_lsa_checksum.yfilter != YFilter.not_set or
                                            self.header_lsa_type.yfilter != YFilter.not_set or
                                            self.header_sequence_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "retransmission-area-db" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                        if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                        if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                        if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                        if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                        if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "header-advertising-router"):
                                            self.header_advertising_router = value
                                            self.header_advertising_router.value_namespace = name_space
                                            self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-ls-id"):
                                            self.header_ls_id = value
                                            self.header_ls_id.value_namespace = name_space
                                            self.header_ls_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-age"):
                                            self.header_lsa_age = value
                                            self.header_lsa_age.value_namespace = name_space
                                            self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-checksum"):
                                            self.header_lsa_checksum = value
                                            self.header_lsa_checksum.value_namespace = name_space
                                            self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-type"):
                                            self.header_lsa_type = value
                                            self.header_lsa_type.value_namespace = name_space
                                            self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-sequence-number"):
                                            self.header_sequence_number = value
                                            self.header_sequence_number.value_namespace = name_space
                                            self.header_sequence_number.value_namespace_prefix = name_space_prefix


                                class RetransmissionAsdb(Entity):
                                    """
                                    List of AS Scope entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb, self).__init__()

                                        self.yang_name = "retransmission-asdb"
                                        self.yang_parent_name = "retransmission"

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("header_advertising_router",
                                                        "header_ls_id",
                                                        "header_lsa_age",
                                                        "header_lsa_checksum",
                                                        "header_lsa_type",
                                                        "header_sequence_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.header_advertising_router.is_set or
                                            self.header_ls_id.is_set or
                                            self.header_lsa_age.is_set or
                                            self.header_lsa_checksum.is_set or
                                            self.header_lsa_type.is_set or
                                            self.header_sequence_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.header_advertising_router.yfilter != YFilter.not_set or
                                            self.header_ls_id.yfilter != YFilter.not_set or
                                            self.header_lsa_age.yfilter != YFilter.not_set or
                                            self.header_lsa_checksum.yfilter != YFilter.not_set or
                                            self.header_lsa_type.yfilter != YFilter.not_set or
                                            self.header_sequence_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "retransmission-asdb" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.header_advertising_router.is_set or self.header_advertising_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_advertising_router.get_name_leafdata())
                                        if (self.header_ls_id.is_set or self.header_ls_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_ls_id.get_name_leafdata())
                                        if (self.header_lsa_age.is_set or self.header_lsa_age.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_age.get_name_leafdata())
                                        if (self.header_lsa_checksum.is_set or self.header_lsa_checksum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_checksum.get_name_leafdata())
                                        if (self.header_lsa_type.is_set or self.header_lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_lsa_type.get_name_leafdata())
                                        if (self.header_sequence_number.is_set or self.header_sequence_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.header_sequence_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "header-advertising-router" or name == "header-ls-id" or name == "header-lsa-age" or name == "header-lsa-checksum" or name == "header-lsa-type" or name == "header-sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "header-advertising-router"):
                                            self.header_advertising_router = value
                                            self.header_advertising_router.value_namespace = name_space
                                            self.header_advertising_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-ls-id"):
                                            self.header_ls_id = value
                                            self.header_ls_id.value_namespace = name_space
                                            self.header_ls_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-age"):
                                            self.header_lsa_age = value
                                            self.header_lsa_age.value_namespace = name_space
                                            self.header_lsa_age.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-checksum"):
                                            self.header_lsa_checksum = value
                                            self.header_lsa_checksum.value_namespace = name_space
                                            self.header_lsa_checksum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-lsa-type"):
                                            self.header_lsa_type = value
                                            self.header_lsa_type.value_namespace = name_space
                                            self.header_lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "header-sequence-number"):
                                            self.header_sequence_number = value
                                            self.header_sequence_number.value_namespace = name_space
                                            self.header_sequence_number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.retransmission_area_db:
                                        if (c.has_data()):
                                            return True
                                    for c in self.retransmission_asdb:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.interface_name.is_set or
                                        self.neighbor_address.is_set or
                                        self.retransmission_count.is_set or
                                        self.retransmission_interface_name.is_set or
                                        self.retransmission_neighbor_id.is_set or
                                        self.retransmission_neighbor_ip_address.is_set or
                                        self.retransmission_timer.is_set)

                                def has_operation(self):
                                    for c in self.retransmission_area_db:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.retransmission_asdb:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.neighbor_address.yfilter != YFilter.not_set or
                                        self.retransmission_count.yfilter != YFilter.not_set or
                                        self.retransmission_interface_name.yfilter != YFilter.not_set or
                                        self.retransmission_neighbor_id.yfilter != YFilter.not_set or
                                        self.retransmission_neighbor_ip_address.yfilter != YFilter.not_set or
                                        self.retransmission_timer.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "retransmission" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                    if (self.retransmission_count.is_set or self.retransmission_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmission_count.get_name_leafdata())
                                    if (self.retransmission_interface_name.is_set or self.retransmission_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmission_interface_name.get_name_leafdata())
                                    if (self.retransmission_neighbor_id.is_set or self.retransmission_neighbor_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmission_neighbor_id.get_name_leafdata())
                                    if (self.retransmission_neighbor_ip_address.is_set or self.retransmission_neighbor_ip_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmission_neighbor_ip_address.get_name_leafdata())
                                    if (self.retransmission_timer.is_set or self.retransmission_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmission_timer.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "retransmission-area-db"):
                                        for c in self.retransmission_area_db:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.retransmission_area_db.append(c)
                                        return c

                                    if (child_yang_name == "retransmission-asdb"):
                                        for c in self.retransmission_asdb:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.retransmission_asdb.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "retransmission-area-db" or name == "retransmission-asdb" or name == "interface-name" or name == "neighbor-address" or name == "retransmission-count" or name == "retransmission-interface-name" or name == "retransmission-neighbor-id" or name == "retransmission-neighbor-ip-address" or name == "retransmission-timer"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-address"):
                                        self.neighbor_address = value
                                        self.neighbor_address.value_namespace = name_space
                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmission-count"):
                                        self.retransmission_count = value
                                        self.retransmission_count.value_namespace = name_space
                                        self.retransmission_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmission-interface-name"):
                                        self.retransmission_interface_name = value
                                        self.retransmission_interface_name.value_namespace = name_space
                                        self.retransmission_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmission-neighbor-id"):
                                        self.retransmission_neighbor_id = value
                                        self.retransmission_neighbor_id.value_namespace = name_space
                                        self.retransmission_neighbor_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmission-neighbor-ip-address"):
                                        self.retransmission_neighbor_ip_address = value
                                        self.retransmission_neighbor_ip_address.value_namespace = name_space
                                        self.retransmission_neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmission-timer"):
                                        self.retransmission_timer = value
                                        self.retransmission_timer.value_namespace = name_space
                                        self.retransmission_timer.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.retransmission:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.retransmission:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "retransmissions" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "retransmission"):
                                    for c in self.retransmission:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.retransmission.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "retransmission"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class AreaStatistics(Entity):
                            """
                            Container for Statistics
                            
                            .. attribute:: interface_stats_entries
                            
                            	Statistics innformation Interface table
                            	**type**\:   :py:class:`InterfaceStatsEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics, self).__init__()

                                self.yang_name = "area-statistics"
                                self.yang_parent_name = "area"

                                self.interface_stats_entries = Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries()
                                self.interface_stats_entries.parent = self
                                self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                                self._children_yang_names.add("interface-stats-entries")


                            class InterfaceStatsEntries(Entity):
                                """
                                Statistics innformation Interface table
                                
                                .. attribute:: interface_stats_entry
                                
                                	Statistics information for a specific interface
                                	**type**\: list of    :py:class:`InterfaceStatsEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries, self).__init__()

                                    self.yang_name = "interface-stats-entries"
                                    self.yang_parent_name = "area-statistics"

                                    self.interface_stats_entry = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries, self).__setattr__(name, value)


                                class InterfaceStatsEntry(Entity):
                                    """
                                    Statistics information for a specific interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: handle
                                    
                                    	interface handle type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: if_entry
                                    
                                    	interface entry
                                    	**type**\: list of    :py:class:`IfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry>`
                                    
                                    .. attribute:: if_name_str
                                    
                                    	interface name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__init__()

                                        self.yang_name = "interface-stats-entry"
                                        self.yang_parent_name = "interface-stats-entries"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.handle = YLeaf(YType.str, "handle")

                                        self.if_name_str = YLeaf(YType.str, "if-name-str")

                                        self.if_entry = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name",
                                                        "handle",
                                                        "if_name_str") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__setattr__(name, value)


                                    class IfEntry(Entity):
                                        """
                                        interface entry
                                        
                                        .. attribute:: area_id
                                        
                                        	OSPF area id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_id_str
                                        
                                        	OSPF aread id string
                                        	**type**\:  str
                                        
                                        .. attribute:: if_stat
                                        
                                        	OSPF interface statistics
                                        	**type**\: list of    :py:class:`IfStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat>`
                                        
                                        .. attribute:: madj_intf
                                        
                                        	OSPF madj interface
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__init__()

                                            self.yang_name = "if-entry"
                                            self.yang_parent_name = "interface-stats-entry"

                                            self.area_id = YLeaf(YType.uint32, "area-id")

                                            self.area_id_str = YLeaf(YType.str, "area-id-str")

                                            self.madj_intf = YLeaf(YType.boolean, "madj-intf")

                                            self.if_stat = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("area_id",
                                                            "area_id_str",
                                                            "madj_intf") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__setattr__(name, value)


                                        class IfStat(Entity):
                                            """
                                            OSPF interface statistics
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__init__()

                                                self.yang_name = "if-stat"
                                                self.yang_parent_name = "if-entry"

                                                self.entry = YLeaf(YType.uint32, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "if-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.if_stat:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.area_id.is_set or
                                                self.area_id_str.is_set or
                                                self.madj_intf.is_set)

                                        def has_operation(self):
                                            for c in self.if_stat:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.area_id.yfilter != YFilter.not_set or
                                                self.area_id_str.yfilter != YFilter.not_set or
                                                self.madj_intf.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "if-entry" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_id.get_name_leafdata())
                                            if (self.area_id_str.is_set or self.area_id_str.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.area_id_str.get_name_leafdata())
                                            if (self.madj_intf.is_set or self.madj_intf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.madj_intf.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "if-stat"):
                                                for c in self.if_stat:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.if_stat.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "if-stat" or name == "area-id" or name == "area-id-str" or name == "madj-intf"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "area-id"):
                                                self.area_id = value
                                                self.area_id.value_namespace = name_space
                                                self.area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "area-id-str"):
                                                self.area_id_str = value
                                                self.area_id_str.value_namespace = name_space
                                                self.area_id_str.value_namespace_prefix = name_space_prefix
                                            if(value_path == "madj-intf"):
                                                self.madj_intf = value
                                                self.madj_intf.value_namespace = name_space
                                                self.madj_intf.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.if_entry:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_name.is_set or
                                            self.handle.is_set or
                                            self.if_name_str.is_set)

                                    def has_operation(self):
                                        for c in self.if_entry:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.handle.yfilter != YFilter.not_set or
                                            self.if_name_str.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-stats-entry" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.handle.is_set or self.handle.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.handle.get_name_leafdata())
                                        if (self.if_name_str.is_set or self.if_name_str.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.if_name_str.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "if-entry"):
                                            for c in self.if_entry:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.if_entry.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "if-entry" or name == "interface-name" or name == "handle" or name == "if-name-str"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "handle"):
                                            self.handle = value
                                            self.handle.value_namespace = name_space
                                            self.handle.value_namespace_prefix = name_space_prefix
                                        if(value_path == "if-name-str"):
                                            self.if_name_str = value
                                            self.if_name_str.value_namespace = name_space
                                            self.if_name_str.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.interface_stats_entry:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.interface_stats_entry:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface-stats-entries" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-stats-entry"):
                                        for c in self.interface_stats_entry:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.interface_stats_entry.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-stats-entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.interface_stats_entries is not None and self.interface_stats_entries.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.interface_stats_entries is not None and self.interface_stats_entries.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "area-statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface-stats-entries"):
                                    if (self.interface_stats_entries is None):
                                        self.interface_stats_entries = Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries()
                                        self.interface_stats_entries.parent = self
                                        self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                                    return self.interface_stats_entries

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-stats-entries"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class NeighborDetails(Entity):
                            """
                            Neighbor detail table
                            
                            .. attribute:: neighbor_detail
                            
                            	A single neighbor's detail information
                            	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails, self).__init__()

                                self.yang_name = "neighbor-details"
                                self.yang_parent_name = "area"

                                self.neighbor_detail = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails, self).__setattr__(name, value)


                            class NeighborDetail(Entity):
                                """
                                A single neighbor's detail information
                                
                                .. attribute:: adjacency_sid_label
                                
                                	SR Adjacency SID Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: adjacency_sid_protected
                                
                                	SR Adjacency SID Protected
                                	**type**\:  bool
                                
                                .. attribute:: adjacency_sid_unprotected_label
                                
                                	SR Adjacency SID Unprotected Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: interface_type
                                
                                	Interface type
                                	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                                
                                .. attribute:: last_oob_time
                                
                                	The amount of time in seconds since last time Out\-Of\-Band resynchronization was done with this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: lfa_interface
                                
                                	LFA Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: lfa_neighbor_id
                                
                                	LFA Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lfa_neighbor_revision
                                
                                	LFA Neighbor Revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lfa_next_hop
                                
                                	LFA Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_ack_list_count
                                
                                	Ack List Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_ack_list_high_watermark
                                
                                	Ack List High Watermark
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_area_id
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: neighbor_backup_designated_router_address
                                
                                	Address of backup designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_information
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation>`
                                
                                .. attribute:: neighbor_cost
                                
                                	Cost of path to this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_designated_router_address
                                
                                	Address of designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_filter
                                
                                	If true, filter outgoing LSAs
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_lls_option
                                
                                	This is a bitmask of Link Local signalling options received from the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_option
                                
                                	 This is bitmaks of neighbor's option field received
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_retransmission_information
                                
                                	Retransmission information with this neighbor
                                	**type**\:   :py:class:`NeighborRetransmissionInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation>`
                                
                                .. attribute:: neighbor_summary
                                
                                	Neighbor summary information
                                	**type**\:   :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary>`
                                
                                .. attribute:: next_poll_interval
                                
                                	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nsf_router_state
                                
                                	For cisco NSF, the router is either Requester or Receiver
                                	**type**\:   :py:class:`NsfRtr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NsfRtr>`
                                
                                .. attribute:: oob_resynchronization
                                
                                	Out\-Of\-Bound resynchronization in progress
                                	**type**\:  bool
                                
                                .. attribute:: pending_events
                                
                                	Number of pending events
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: poll_interval
                                
                                	Poll interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_change_count
                                
                                	Number of state changes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail, self).__init__()

                                    self.yang_name = "neighbor-detail"
                                    self.yang_parent_name = "neighbor-details"

                                    self.adjacency_sid_label = YLeaf(YType.uint32, "adjacency-sid-label")

                                    self.adjacency_sid_protected = YLeaf(YType.boolean, "adjacency-sid-protected")

                                    self.adjacency_sid_unprotected_label = YLeaf(YType.uint32, "adjacency-sid-unprotected-label")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                    self.last_oob_time = YLeaf(YType.uint32, "last-oob-time")

                                    self.lfa_interface = YLeaf(YType.str, "lfa-interface")

                                    self.lfa_neighbor_id = YLeaf(YType.str, "lfa-neighbor-id")

                                    self.lfa_neighbor_revision = YLeaf(YType.uint32, "lfa-neighbor-revision")

                                    self.lfa_next_hop = YLeaf(YType.str, "lfa-next-hop")

                                    self.neighbor_ack_list_count = YLeaf(YType.uint32, "neighbor-ack-list-count")

                                    self.neighbor_ack_list_high_watermark = YLeaf(YType.uint32, "neighbor-ack-list-high-watermark")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.neighbor_area_id = YLeaf(YType.str, "neighbor-area-id")

                                    self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                    self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                    self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                    self.neighbor_filter = YLeaf(YType.boolean, "neighbor-filter")

                                    self.neighbor_lls_option = YLeaf(YType.uint16, "neighbor-lls-option")

                                    self.neighbor_option = YLeaf(YType.uint8, "neighbor-option")

                                    self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                    self.nsf_router_state = YLeaf(YType.enumeration, "nsf-router-state")

                                    self.oob_resynchronization = YLeaf(YType.boolean, "oob-resynchronization")

                                    self.pending_events = YLeaf(YType.uint16, "pending-events")

                                    self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                    self.state_change_count = YLeaf(YType.uint16, "state-change-count")

                                    self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation()
                                    self.neighbor_bfd_information.parent = self
                                    self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                    self._children_yang_names.add("neighbor-bfd-information")

                                    self.neighbor_retransmission_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation()
                                    self.neighbor_retransmission_information.parent = self
                                    self._children_name_map["neighbor_retransmission_information"] = "neighbor-retransmission-information"
                                    self._children_yang_names.add("neighbor-retransmission-information")

                                    self.neighbor_summary = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary()
                                    self.neighbor_summary.parent = self
                                    self._children_name_map["neighbor_summary"] = "neighbor-summary"
                                    self._children_yang_names.add("neighbor-summary")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("adjacency_sid_label",
                                                    "adjacency_sid_protected",
                                                    "adjacency_sid_unprotected_label",
                                                    "interface_name",
                                                    "interface_type",
                                                    "last_oob_time",
                                                    "lfa_interface",
                                                    "lfa_neighbor_id",
                                                    "lfa_neighbor_revision",
                                                    "lfa_next_hop",
                                                    "neighbor_ack_list_count",
                                                    "neighbor_ack_list_high_watermark",
                                                    "neighbor_address",
                                                    "neighbor_area_id",
                                                    "neighbor_backup_designated_router_address",
                                                    "neighbor_cost",
                                                    "neighbor_designated_router_address",
                                                    "neighbor_filter",
                                                    "neighbor_lls_option",
                                                    "neighbor_option",
                                                    "next_poll_interval",
                                                    "nsf_router_state",
                                                    "oob_resynchronization",
                                                    "pending_events",
                                                    "poll_interval",
                                                    "state_change_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail, self).__setattr__(name, value)


                                class NeighborSummary(Entity):
                                    """
                                    Neighbor summary information
                                    
                                    .. attribute:: dr_bdr_state
                                    
                                    	Designated Router state
                                    	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bfd_information
                                    
                                    	Neighbor BFD information
                                    	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation>`
                                    
                                    .. attribute:: neighbor_dead_timer
                                    
                                    	Time until neighbor's dead timer expires (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_dr_priority
                                    
                                    	Neighbor's DR priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_id
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_interface_name
                                    
                                    	Interface via which the neighbor is seen
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: neighbor_madj_interface
                                    
                                    	Interface is MADJ
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_state
                                    
                                    	Neighbor's state
                                    	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                    
                                    .. attribute:: neighbor_up_time
                                    
                                    	Amount of time since the adjacency is up (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary, self).__init__()

                                        self.yang_name = "neighbor-summary"
                                        self.yang_parent_name = "neighbor-detail"

                                        self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                        self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                        self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                        self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                        self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                        self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                        self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                        self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                        self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                        self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation()
                                        self.neighbor_bfd_information.parent = self
                                        self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                        self._children_yang_names.add("neighbor-bfd-information")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dr_bdr_state",
                                                        "neighbor_address_xr",
                                                        "neighbor_dead_timer",
                                                        "neighbor_dr_priority",
                                                        "neighbor_id",
                                                        "neighbor_interface_name",
                                                        "neighbor_madj_interface",
                                                        "neighbor_state",
                                                        "neighbor_up_time") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary, self).__setattr__(name, value)


                                    class NeighborBfdInformation(Entity):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__init__()

                                            self.yang_name = "neighbor-bfd-information"
                                            self.yang_parent_name = "neighbor-summary"

                                            self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                            self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bfd_intf_enable_mode",
                                                            "bfd_status_flag") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bfd_intf_enable_mode.is_set or
                                                self.bfd_status_flag.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                                self.bfd_status_flag.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor-bfd-information" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                            if (self.bfd_status_flag.is_set or self.bfd_status_flag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bfd_status_flag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bfd-intf-enable-mode" or name == "bfd-status-flag"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bfd-intf-enable-mode"):
                                                self.bfd_intf_enable_mode = value
                                                self.bfd_intf_enable_mode.value_namespace = name_space
                                                self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bfd-status-flag"):
                                                self.bfd_status_flag = value
                                                self.bfd_status_flag.value_namespace = name_space
                                                self.bfd_status_flag.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.dr_bdr_state.is_set or
                                            self.neighbor_address_xr.is_set or
                                            self.neighbor_dead_timer.is_set or
                                            self.neighbor_dr_priority.is_set or
                                            self.neighbor_id.is_set or
                                            self.neighbor_interface_name.is_set or
                                            self.neighbor_madj_interface.is_set or
                                            self.neighbor_state.is_set or
                                            self.neighbor_up_time.is_set or
                                            (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dr_bdr_state.yfilter != YFilter.not_set or
                                            self.neighbor_address_xr.yfilter != YFilter.not_set or
                                            self.neighbor_dead_timer.yfilter != YFilter.not_set or
                                            self.neighbor_dr_priority.yfilter != YFilter.not_set or
                                            self.neighbor_id.yfilter != YFilter.not_set or
                                            self.neighbor_interface_name.yfilter != YFilter.not_set or
                                            self.neighbor_madj_interface.yfilter != YFilter.not_set or
                                            self.neighbor_state.yfilter != YFilter.not_set or
                                            self.neighbor_up_time.yfilter != YFilter.not_set or
                                            (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-summary" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dr_bdr_state.is_set or self.dr_bdr_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dr_bdr_state.get_name_leafdata())
                                        if (self.neighbor_address_xr.is_set or self.neighbor_address_xr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_address_xr.get_name_leafdata())
                                        if (self.neighbor_dead_timer.is_set or self.neighbor_dead_timer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_dead_timer.get_name_leafdata())
                                        if (self.neighbor_dr_priority.is_set or self.neighbor_dr_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_dr_priority.get_name_leafdata())
                                        if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                        if (self.neighbor_interface_name.is_set or self.neighbor_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_interface_name.get_name_leafdata())
                                        if (self.neighbor_madj_interface.is_set or self.neighbor_madj_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_madj_interface.get_name_leafdata())
                                        if (self.neighbor_state.is_set or self.neighbor_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_state.get_name_leafdata())
                                        if (self.neighbor_up_time.is_set or self.neighbor_up_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_up_time.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "neighbor-bfd-information"):
                                            if (self.neighbor_bfd_information is None):
                                                self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation()
                                                self.neighbor_bfd_information.parent = self
                                                self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                            return self.neighbor_bfd_information

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "neighbor-bfd-information" or name == "dr-bdr-state" or name == "neighbor-address-xr" or name == "neighbor-dead-timer" or name == "neighbor-dr-priority" or name == "neighbor-id" or name == "neighbor-interface-name" or name == "neighbor-madj-interface" or name == "neighbor-state" or name == "neighbor-up-time"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dr-bdr-state"):
                                            self.dr_bdr_state = value
                                            self.dr_bdr_state.value_namespace = name_space
                                            self.dr_bdr_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-address-xr"):
                                            self.neighbor_address_xr = value
                                            self.neighbor_address_xr.value_namespace = name_space
                                            self.neighbor_address_xr.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-dead-timer"):
                                            self.neighbor_dead_timer = value
                                            self.neighbor_dead_timer.value_namespace = name_space
                                            self.neighbor_dead_timer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-dr-priority"):
                                            self.neighbor_dr_priority = value
                                            self.neighbor_dr_priority.value_namespace = name_space
                                            self.neighbor_dr_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-id"):
                                            self.neighbor_id = value
                                            self.neighbor_id.value_namespace = name_space
                                            self.neighbor_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-interface-name"):
                                            self.neighbor_interface_name = value
                                            self.neighbor_interface_name.value_namespace = name_space
                                            self.neighbor_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-madj-interface"):
                                            self.neighbor_madj_interface = value
                                            self.neighbor_madj_interface.value_namespace = name_space
                                            self.neighbor_madj_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-state"):
                                            self.neighbor_state = value
                                            self.neighbor_state.value_namespace = name_space
                                            self.neighbor_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-up-time"):
                                            self.neighbor_up_time = value
                                            self.neighbor_up_time.value_namespace = name_space
                                            self.neighbor_up_time.value_namespace_prefix = name_space_prefix


                                class NeighborBfdInformation(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__init__()

                                        self.yang_name = "neighbor-bfd-information"
                                        self.yang_parent_name = "neighbor-detail"

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bfd_intf_enable_mode",
                                                        "bfd_status_flag") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bfd_intf_enable_mode.is_set or
                                            self.bfd_status_flag.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                            self.bfd_status_flag.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-bfd-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                        if (self.bfd_status_flag.is_set or self.bfd_status_flag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bfd_status_flag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bfd-intf-enable-mode" or name == "bfd-status-flag"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bfd-intf-enable-mode"):
                                            self.bfd_intf_enable_mode = value
                                            self.bfd_intf_enable_mode.value_namespace = name_space
                                            self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bfd-status-flag"):
                                            self.bfd_status_flag = value
                                            self.bfd_status_flag.value_namespace = name_space
                                            self.bfd_status_flag.value_namespace_prefix = name_space_prefix


                                class NeighborRetransmissionInformation(Entity):
                                    """
                                    Retransmission information with this neighbor
                                    
                                    .. attribute:: area_first_flood_information
                                    
                                    	First flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood_information_index
                                    
                                    	Index of the first flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_flooding_index
                                    
                                    	Area scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_information
                                    
                                    	Next flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_information_index
                                    
                                    	Index of next flood item for Area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_information
                                    
                                    	First flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_information_index
                                    
                                    	Index for first flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_flood_index
                                    
                                    	AS scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_information
                                    
                                    	Next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_information_index
                                    
                                    	Index of next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dbd_retransmission_count
                                    
                                    	Number of DBD retransmissions during last exchange
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dbd_retransmission_total_count
                                    
                                    	Total number of DBD retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_length
                                    
                                    	Number of LSAs sent in last retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_time
                                    
                                    	Last retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_retransmission_timer
                                    
                                    	Time until next LSA retransmission (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_length
                                    
                                    	Maximum number of LSAs sent in a retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_time
                                    
                                    	Maximum retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmission_count
                                    
                                    	Retransmission queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_retransmissions
                                    
                                    	Number of retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__init__()

                                        self.yang_name = "neighbor-retransmission-information"
                                        self.yang_parent_name = "neighbor-detail"

                                        self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                        self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                        self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                        self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                        self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                        self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                        self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                        self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                        self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                        self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                        self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                        self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                        self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                        self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                        self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                        self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                        self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                        self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                        self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("area_first_flood_information",
                                                        "area_first_flood_information_index",
                                                        "area_flooding_index",
                                                        "area_next_flood_information",
                                                        "area_next_flood_information_index",
                                                        "as_first_flood_information",
                                                        "as_first_flood_information_index",
                                                        "as_flood_index",
                                                        "as_next_flood_information",
                                                        "as_next_flood_information_index",
                                                        "dbd_retransmission_count",
                                                        "dbd_retransmission_total_count",
                                                        "last_retransmission_length",
                                                        "last_retransmission_time",
                                                        "lsa_retransmission_timer",
                                                        "maximum_retransmission_length",
                                                        "maximum_retransmission_time",
                                                        "neighbor_retransmission_count",
                                                        "number_of_retransmissions") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.area_first_flood_information.is_set or
                                            self.area_first_flood_information_index.is_set or
                                            self.area_flooding_index.is_set or
                                            self.area_next_flood_information.is_set or
                                            self.area_next_flood_information_index.is_set or
                                            self.as_first_flood_information.is_set or
                                            self.as_first_flood_information_index.is_set or
                                            self.as_flood_index.is_set or
                                            self.as_next_flood_information.is_set or
                                            self.as_next_flood_information_index.is_set or
                                            self.dbd_retransmission_count.is_set or
                                            self.dbd_retransmission_total_count.is_set or
                                            self.last_retransmission_length.is_set or
                                            self.last_retransmission_time.is_set or
                                            self.lsa_retransmission_timer.is_set or
                                            self.maximum_retransmission_length.is_set or
                                            self.maximum_retransmission_time.is_set or
                                            self.neighbor_retransmission_count.is_set or
                                            self.number_of_retransmissions.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.area_first_flood_information.yfilter != YFilter.not_set or
                                            self.area_first_flood_information_index.yfilter != YFilter.not_set or
                                            self.area_flooding_index.yfilter != YFilter.not_set or
                                            self.area_next_flood_information.yfilter != YFilter.not_set or
                                            self.area_next_flood_information_index.yfilter != YFilter.not_set or
                                            self.as_first_flood_information.yfilter != YFilter.not_set or
                                            self.as_first_flood_information_index.yfilter != YFilter.not_set or
                                            self.as_flood_index.yfilter != YFilter.not_set or
                                            self.as_next_flood_information.yfilter != YFilter.not_set or
                                            self.as_next_flood_information_index.yfilter != YFilter.not_set or
                                            self.dbd_retransmission_count.yfilter != YFilter.not_set or
                                            self.dbd_retransmission_total_count.yfilter != YFilter.not_set or
                                            self.last_retransmission_length.yfilter != YFilter.not_set or
                                            self.last_retransmission_time.yfilter != YFilter.not_set or
                                            self.lsa_retransmission_timer.yfilter != YFilter.not_set or
                                            self.maximum_retransmission_length.yfilter != YFilter.not_set or
                                            self.maximum_retransmission_time.yfilter != YFilter.not_set or
                                            self.neighbor_retransmission_count.yfilter != YFilter.not_set or
                                            self.number_of_retransmissions.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbor-retransmission-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.area_first_flood_information.is_set or self.area_first_flood_information.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_first_flood_information.get_name_leafdata())
                                        if (self.area_first_flood_information_index.is_set or self.area_first_flood_information_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_first_flood_information_index.get_name_leafdata())
                                        if (self.area_flooding_index.is_set or self.area_flooding_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_flooding_index.get_name_leafdata())
                                        if (self.area_next_flood_information.is_set or self.area_next_flood_information.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_next_flood_information.get_name_leafdata())
                                        if (self.area_next_flood_information_index.is_set or self.area_next_flood_information_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_next_flood_information_index.get_name_leafdata())
                                        if (self.as_first_flood_information.is_set or self.as_first_flood_information.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_first_flood_information.get_name_leafdata())
                                        if (self.as_first_flood_information_index.is_set or self.as_first_flood_information_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_first_flood_information_index.get_name_leafdata())
                                        if (self.as_flood_index.is_set or self.as_flood_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_flood_index.get_name_leafdata())
                                        if (self.as_next_flood_information.is_set or self.as_next_flood_information.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_next_flood_information.get_name_leafdata())
                                        if (self.as_next_flood_information_index.is_set or self.as_next_flood_information_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_next_flood_information_index.get_name_leafdata())
                                        if (self.dbd_retransmission_count.is_set or self.dbd_retransmission_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dbd_retransmission_count.get_name_leafdata())
                                        if (self.dbd_retransmission_total_count.is_set or self.dbd_retransmission_total_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dbd_retransmission_total_count.get_name_leafdata())
                                        if (self.last_retransmission_length.is_set or self.last_retransmission_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_retransmission_length.get_name_leafdata())
                                        if (self.last_retransmission_time.is_set or self.last_retransmission_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_retransmission_time.get_name_leafdata())
                                        if (self.lsa_retransmission_timer.is_set or self.lsa_retransmission_timer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsa_retransmission_timer.get_name_leafdata())
                                        if (self.maximum_retransmission_length.is_set or self.maximum_retransmission_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_retransmission_length.get_name_leafdata())
                                        if (self.maximum_retransmission_time.is_set or self.maximum_retransmission_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_retransmission_time.get_name_leafdata())
                                        if (self.neighbor_retransmission_count.is_set or self.neighbor_retransmission_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_retransmission_count.get_name_leafdata())
                                        if (self.number_of_retransmissions.is_set or self.number_of_retransmissions.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number_of_retransmissions.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "area-first-flood-information" or name == "area-first-flood-information-index" or name == "area-flooding-index" or name == "area-next-flood-information" or name == "area-next-flood-information-index" or name == "as-first-flood-information" or name == "as-first-flood-information-index" or name == "as-flood-index" or name == "as-next-flood-information" or name == "as-next-flood-information-index" or name == "dbd-retransmission-count" or name == "dbd-retransmission-total-count" or name == "last-retransmission-length" or name == "last-retransmission-time" or name == "lsa-retransmission-timer" or name == "maximum-retransmission-length" or name == "maximum-retransmission-time" or name == "neighbor-retransmission-count" or name == "number-of-retransmissions"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "area-first-flood-information"):
                                            self.area_first_flood_information = value
                                            self.area_first_flood_information.value_namespace = name_space
                                            self.area_first_flood_information.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-first-flood-information-index"):
                                            self.area_first_flood_information_index = value
                                            self.area_first_flood_information_index.value_namespace = name_space
                                            self.area_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-flooding-index"):
                                            self.area_flooding_index = value
                                            self.area_flooding_index.value_namespace = name_space
                                            self.area_flooding_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-next-flood-information"):
                                            self.area_next_flood_information = value
                                            self.area_next_flood_information.value_namespace = name_space
                                            self.area_next_flood_information.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-next-flood-information-index"):
                                            self.area_next_flood_information_index = value
                                            self.area_next_flood_information_index.value_namespace = name_space
                                            self.area_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-first-flood-information"):
                                            self.as_first_flood_information = value
                                            self.as_first_flood_information.value_namespace = name_space
                                            self.as_first_flood_information.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-first-flood-information-index"):
                                            self.as_first_flood_information_index = value
                                            self.as_first_flood_information_index.value_namespace = name_space
                                            self.as_first_flood_information_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-flood-index"):
                                            self.as_flood_index = value
                                            self.as_flood_index.value_namespace = name_space
                                            self.as_flood_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-next-flood-information"):
                                            self.as_next_flood_information = value
                                            self.as_next_flood_information.value_namespace = name_space
                                            self.as_next_flood_information.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-next-flood-information-index"):
                                            self.as_next_flood_information_index = value
                                            self.as_next_flood_information_index.value_namespace = name_space
                                            self.as_next_flood_information_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dbd-retransmission-count"):
                                            self.dbd_retransmission_count = value
                                            self.dbd_retransmission_count.value_namespace = name_space
                                            self.dbd_retransmission_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dbd-retransmission-total-count"):
                                            self.dbd_retransmission_total_count = value
                                            self.dbd_retransmission_total_count.value_namespace = name_space
                                            self.dbd_retransmission_total_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-retransmission-length"):
                                            self.last_retransmission_length = value
                                            self.last_retransmission_length.value_namespace = name_space
                                            self.last_retransmission_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-retransmission-time"):
                                            self.last_retransmission_time = value
                                            self.last_retransmission_time.value_namespace = name_space
                                            self.last_retransmission_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsa-retransmission-timer"):
                                            self.lsa_retransmission_timer = value
                                            self.lsa_retransmission_timer.value_namespace = name_space
                                            self.lsa_retransmission_timer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-retransmission-length"):
                                            self.maximum_retransmission_length = value
                                            self.maximum_retransmission_length.value_namespace = name_space
                                            self.maximum_retransmission_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-retransmission-time"):
                                            self.maximum_retransmission_time = value
                                            self.maximum_retransmission_time.value_namespace = name_space
                                            self.maximum_retransmission_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-retransmission-count"):
                                            self.neighbor_retransmission_count = value
                                            self.neighbor_retransmission_count.value_namespace = name_space
                                            self.neighbor_retransmission_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "number-of-retransmissions"):
                                            self.number_of_retransmissions = value
                                            self.number_of_retransmissions.value_namespace = name_space
                                            self.number_of_retransmissions.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.adjacency_sid_label.is_set or
                                        self.adjacency_sid_protected.is_set or
                                        self.adjacency_sid_unprotected_label.is_set or
                                        self.interface_name.is_set or
                                        self.interface_type.is_set or
                                        self.last_oob_time.is_set or
                                        self.lfa_interface.is_set or
                                        self.lfa_neighbor_id.is_set or
                                        self.lfa_neighbor_revision.is_set or
                                        self.lfa_next_hop.is_set or
                                        self.neighbor_ack_list_count.is_set or
                                        self.neighbor_ack_list_high_watermark.is_set or
                                        self.neighbor_address.is_set or
                                        self.neighbor_area_id.is_set or
                                        self.neighbor_backup_designated_router_address.is_set or
                                        self.neighbor_cost.is_set or
                                        self.neighbor_designated_router_address.is_set or
                                        self.neighbor_filter.is_set or
                                        self.neighbor_lls_option.is_set or
                                        self.neighbor_option.is_set or
                                        self.next_poll_interval.is_set or
                                        self.nsf_router_state.is_set or
                                        self.oob_resynchronization.is_set or
                                        self.pending_events.is_set or
                                        self.poll_interval.is_set or
                                        self.state_change_count.is_set or
                                        (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_data()) or
                                        (self.neighbor_retransmission_information is not None and self.neighbor_retransmission_information.has_data()) or
                                        (self.neighbor_summary is not None and self.neighbor_summary.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.adjacency_sid_label.yfilter != YFilter.not_set or
                                        self.adjacency_sid_protected.yfilter != YFilter.not_set or
                                        self.adjacency_sid_unprotected_label.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.interface_type.yfilter != YFilter.not_set or
                                        self.last_oob_time.yfilter != YFilter.not_set or
                                        self.lfa_interface.yfilter != YFilter.not_set or
                                        self.lfa_neighbor_id.yfilter != YFilter.not_set or
                                        self.lfa_neighbor_revision.yfilter != YFilter.not_set or
                                        self.lfa_next_hop.yfilter != YFilter.not_set or
                                        self.neighbor_ack_list_count.yfilter != YFilter.not_set or
                                        self.neighbor_ack_list_high_watermark.yfilter != YFilter.not_set or
                                        self.neighbor_address.yfilter != YFilter.not_set or
                                        self.neighbor_area_id.yfilter != YFilter.not_set or
                                        self.neighbor_backup_designated_router_address.yfilter != YFilter.not_set or
                                        self.neighbor_cost.yfilter != YFilter.not_set or
                                        self.neighbor_designated_router_address.yfilter != YFilter.not_set or
                                        self.neighbor_filter.yfilter != YFilter.not_set or
                                        self.neighbor_lls_option.yfilter != YFilter.not_set or
                                        self.neighbor_option.yfilter != YFilter.not_set or
                                        self.next_poll_interval.yfilter != YFilter.not_set or
                                        self.nsf_router_state.yfilter != YFilter.not_set or
                                        self.oob_resynchronization.yfilter != YFilter.not_set or
                                        self.pending_events.yfilter != YFilter.not_set or
                                        self.poll_interval.yfilter != YFilter.not_set or
                                        self.state_change_count.yfilter != YFilter.not_set or
                                        (self.neighbor_bfd_information is not None and self.neighbor_bfd_information.has_operation()) or
                                        (self.neighbor_retransmission_information is not None and self.neighbor_retransmission_information.has_operation()) or
                                        (self.neighbor_summary is not None and self.neighbor_summary.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "neighbor-detail" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.adjacency_sid_label.is_set or self.adjacency_sid_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.adjacency_sid_label.get_name_leafdata())
                                    if (self.adjacency_sid_protected.is_set or self.adjacency_sid_protected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.adjacency_sid_protected.get_name_leafdata())
                                    if (self.adjacency_sid_unprotected_label.is_set or self.adjacency_sid_unprotected_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.adjacency_sid_unprotected_label.get_name_leafdata())
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.interface_type.is_set or self.interface_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_type.get_name_leafdata())
                                    if (self.last_oob_time.is_set or self.last_oob_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_oob_time.get_name_leafdata())
                                    if (self.lfa_interface.is_set or self.lfa_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lfa_interface.get_name_leafdata())
                                    if (self.lfa_neighbor_id.is_set or self.lfa_neighbor_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lfa_neighbor_id.get_name_leafdata())
                                    if (self.lfa_neighbor_revision.is_set or self.lfa_neighbor_revision.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lfa_neighbor_revision.get_name_leafdata())
                                    if (self.lfa_next_hop.is_set or self.lfa_next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lfa_next_hop.get_name_leafdata())
                                    if (self.neighbor_ack_list_count.is_set or self.neighbor_ack_list_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_ack_list_count.get_name_leafdata())
                                    if (self.neighbor_ack_list_high_watermark.is_set or self.neighbor_ack_list_high_watermark.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_ack_list_high_watermark.get_name_leafdata())
                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                    if (self.neighbor_area_id.is_set or self.neighbor_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_area_id.get_name_leafdata())
                                    if (self.neighbor_backup_designated_router_address.is_set or self.neighbor_backup_designated_router_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_backup_designated_router_address.get_name_leafdata())
                                    if (self.neighbor_cost.is_set or self.neighbor_cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_cost.get_name_leafdata())
                                    if (self.neighbor_designated_router_address.is_set or self.neighbor_designated_router_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_designated_router_address.get_name_leafdata())
                                    if (self.neighbor_filter.is_set or self.neighbor_filter.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_filter.get_name_leafdata())
                                    if (self.neighbor_lls_option.is_set or self.neighbor_lls_option.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_lls_option.get_name_leafdata())
                                    if (self.neighbor_option.is_set or self.neighbor_option.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_option.get_name_leafdata())
                                    if (self.next_poll_interval.is_set or self.next_poll_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_poll_interval.get_name_leafdata())
                                    if (self.nsf_router_state.is_set or self.nsf_router_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsf_router_state.get_name_leafdata())
                                    if (self.oob_resynchronization.is_set or self.oob_resynchronization.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.oob_resynchronization.get_name_leafdata())
                                    if (self.pending_events.is_set or self.pending_events.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pending_events.get_name_leafdata())
                                    if (self.poll_interval.is_set or self.poll_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.poll_interval.get_name_leafdata())
                                    if (self.state_change_count.is_set or self.state_change_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state_change_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "neighbor-bfd-information"):
                                        if (self.neighbor_bfd_information is None):
                                            self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation()
                                            self.neighbor_bfd_information.parent = self
                                            self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                        return self.neighbor_bfd_information

                                    if (child_yang_name == "neighbor-retransmission-information"):
                                        if (self.neighbor_retransmission_information is None):
                                            self.neighbor_retransmission_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation()
                                            self.neighbor_retransmission_information.parent = self
                                            self._children_name_map["neighbor_retransmission_information"] = "neighbor-retransmission-information"
                                        return self.neighbor_retransmission_information

                                    if (child_yang_name == "neighbor-summary"):
                                        if (self.neighbor_summary is None):
                                            self.neighbor_summary = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary()
                                            self.neighbor_summary.parent = self
                                            self._children_name_map["neighbor_summary"] = "neighbor-summary"
                                        return self.neighbor_summary

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "neighbor-bfd-information" or name == "neighbor-retransmission-information" or name == "neighbor-summary" or name == "adjacency-sid-label" or name == "adjacency-sid-protected" or name == "adjacency-sid-unprotected-label" or name == "interface-name" or name == "interface-type" or name == "last-oob-time" or name == "lfa-interface" or name == "lfa-neighbor-id" or name == "lfa-neighbor-revision" or name == "lfa-next-hop" or name == "neighbor-ack-list-count" or name == "neighbor-ack-list-high-watermark" or name == "neighbor-address" or name == "neighbor-area-id" or name == "neighbor-backup-designated-router-address" or name == "neighbor-cost" or name == "neighbor-designated-router-address" or name == "neighbor-filter" or name == "neighbor-lls-option" or name == "neighbor-option" or name == "next-poll-interval" or name == "nsf-router-state" or name == "oob-resynchronization" or name == "pending-events" or name == "poll-interval" or name == "state-change-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "adjacency-sid-label"):
                                        self.adjacency_sid_label = value
                                        self.adjacency_sid_label.value_namespace = name_space
                                        self.adjacency_sid_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "adjacency-sid-protected"):
                                        self.adjacency_sid_protected = value
                                        self.adjacency_sid_protected.value_namespace = name_space
                                        self.adjacency_sid_protected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "adjacency-sid-unprotected-label"):
                                        self.adjacency_sid_unprotected_label = value
                                        self.adjacency_sid_unprotected_label.value_namespace = name_space
                                        self.adjacency_sid_unprotected_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-type"):
                                        self.interface_type = value
                                        self.interface_type.value_namespace = name_space
                                        self.interface_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-oob-time"):
                                        self.last_oob_time = value
                                        self.last_oob_time.value_namespace = name_space
                                        self.last_oob_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lfa-interface"):
                                        self.lfa_interface = value
                                        self.lfa_interface.value_namespace = name_space
                                        self.lfa_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lfa-neighbor-id"):
                                        self.lfa_neighbor_id = value
                                        self.lfa_neighbor_id.value_namespace = name_space
                                        self.lfa_neighbor_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lfa-neighbor-revision"):
                                        self.lfa_neighbor_revision = value
                                        self.lfa_neighbor_revision.value_namespace = name_space
                                        self.lfa_neighbor_revision.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lfa-next-hop"):
                                        self.lfa_next_hop = value
                                        self.lfa_next_hop.value_namespace = name_space
                                        self.lfa_next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-ack-list-count"):
                                        self.neighbor_ack_list_count = value
                                        self.neighbor_ack_list_count.value_namespace = name_space
                                        self.neighbor_ack_list_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-ack-list-high-watermark"):
                                        self.neighbor_ack_list_high_watermark = value
                                        self.neighbor_ack_list_high_watermark.value_namespace = name_space
                                        self.neighbor_ack_list_high_watermark.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-address"):
                                        self.neighbor_address = value
                                        self.neighbor_address.value_namespace = name_space
                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-area-id"):
                                        self.neighbor_area_id = value
                                        self.neighbor_area_id.value_namespace = name_space
                                        self.neighbor_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-backup-designated-router-address"):
                                        self.neighbor_backup_designated_router_address = value
                                        self.neighbor_backup_designated_router_address.value_namespace = name_space
                                        self.neighbor_backup_designated_router_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-cost"):
                                        self.neighbor_cost = value
                                        self.neighbor_cost.value_namespace = name_space
                                        self.neighbor_cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-designated-router-address"):
                                        self.neighbor_designated_router_address = value
                                        self.neighbor_designated_router_address.value_namespace = name_space
                                        self.neighbor_designated_router_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-filter"):
                                        self.neighbor_filter = value
                                        self.neighbor_filter.value_namespace = name_space
                                        self.neighbor_filter.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-lls-option"):
                                        self.neighbor_lls_option = value
                                        self.neighbor_lls_option.value_namespace = name_space
                                        self.neighbor_lls_option.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-option"):
                                        self.neighbor_option = value
                                        self.neighbor_option.value_namespace = name_space
                                        self.neighbor_option.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-poll-interval"):
                                        self.next_poll_interval = value
                                        self.next_poll_interval.value_namespace = name_space
                                        self.next_poll_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsf-router-state"):
                                        self.nsf_router_state = value
                                        self.nsf_router_state.value_namespace = name_space
                                        self.nsf_router_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "oob-resynchronization"):
                                        self.oob_resynchronization = value
                                        self.oob_resynchronization.value_namespace = name_space
                                        self.oob_resynchronization.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pending-events"):
                                        self.pending_events = value
                                        self.pending_events.value_namespace = name_space
                                        self.pending_events.value_namespace_prefix = name_space_prefix
                                    if(value_path == "poll-interval"):
                                        self.poll_interval = value
                                        self.poll_interval.value_namespace = name_space
                                        self.poll_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state-change-count"):
                                        self.state_change_count = value
                                        self.state_change_count.value_namespace = name_space
                                        self.state_change_count.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.neighbor_detail:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.neighbor_detail:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbor-details" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "neighbor-detail"):
                                    for c in self.neighbor_detail:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.neighbor_detail.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "neighbor-detail"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Interfaces(Entity):
                            """
                            OSPF Interface Table
                            
                            .. attribute:: interface
                            
                            	OSPF interface information
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces, self).__init__()

                                self.yang_name = "interfaces"
                                self.yang_parent_name = "area"

                                self.interface = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces, self).__setattr__(name, value)


                            class Interface(Entity):
                                """
                                OSPF interface information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: active_interface
                                
                                	Active interface details
                                	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface>`
                                
                                .. attribute:: backup_designated_router
                                
                                	If true, backup designated router
                                	**type**\:  bool
                                
                                .. attribute:: backup_designated_router_address
                                
                                	Backup designated router interface address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_designated_router_id
                                
                                	Backup designated router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: cfg_cost_fallback
                                
                                	If true, cost fallback is configured
                                	**type**\:  bool
                                
                                .. attribute:: configured_demand_circuit
                                
                                	If true, configured as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: configured_ldp_sync
                                
                                	If true, configured as LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: configured_ldp_sync_igp_shortcuts
                                
                                	If true, sync igp shortcuts
                                	**type**\:  bool
                                
                                .. attribute:: cost_fallback_active
                                
                                	If true, cost fallback is active
                                	**type**\:  bool
                                
                                .. attribute:: dead_interval
                                
                                	Configured dead interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: designated_router
                                
                                	If true, designated router
                                	**type**\:  bool
                                
                                .. attribute:: designated_router_address
                                
                                	Designated router interface address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: designated_router_id
                                
                                	Designated router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: fast_detect_hold_down_time
                                
                                	Hold\-down time in ms for fast\-detect event
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fast_detect_hold_down_time_remaining
                                
                                	Remaining hold down time in ms
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fast_reroute_topology_independent_lfa
                                
                                	Topology Independent LFA
                                	**type**\:  bool
                                
                                .. attribute:: fast_reroute_type
                                
                                	IP Fast Reroute Type
                                	**type**\:   :py:class:`Ipfrr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ipfrr>`
                                
                                .. attribute:: hello_interval
                                
                                	Configured hello interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: hello_interval_ms
                                
                                	Configured hello interval (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ack_list_count
                                
                                	Ack List Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ack_list_high_watermark
                                
                                	Ack List High Watermark
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_address
                                
                                	Interface IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_area
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: interface_bandwidth
                                
                                	Interface bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_bfd_information
                                
                                	BFD information
                                	**type**\:   :py:class:`InterfaceBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation>`
                                
                                .. attribute:: interface_cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_dc_bitless_lsa_count
                                
                                	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_demand_circuit
                                
                                	If true, interface running as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: interface_fast_detect_hold_down
                                
                                	Link in hold\-down state due to fast detect event
                                	**type**\:  bool
                                
                                .. attribute:: interface_last_nsf
                                
                                	Time since last NSF restart (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ldp_sync
                                
                                	If true, interface LDP sync is achieved
                                	**type**\:  bool
                                
                                .. attribute:: interface_line_state
                                
                                	If true, line protocol is up
                                	**type**\:  bool
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_lsa_filter
                                
                                	Filter is configured for out going LSAs
                                	**type**\:  bool
                                
                                .. attribute:: interface_madj
                                
                                	Information for multi\-area on the interface
                                	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceMadj>`
                                
                                .. attribute:: interface_madj_count
                                
                                	Total number of multi\-area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_mask
                                
                                	Interface IP Mask
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: interface_neighbor
                                
                                	Information for neighbors on the interface
                                	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor>`
                                
                                .. attribute:: interface_nsf
                                
                                	If true, NSF restart in progress on this interface
                                	**type**\:  bool
                                
                                .. attribute:: interface_nsf_enabled
                                
                                	If true, NSF is enabled
                                	**type**\:  bool
                                
                                .. attribute:: interface_priority
                                
                                	Interface priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: interface_retransmission_interrval
                                
                                	Configured retransmit interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_router_id
                                
                                	Interface Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_sid
                                
                                	Interface SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_sid_n_flag_clear
                                
                                	SID N\-Flag Clear
                                	**type**\:  bool
                                
                                .. attribute:: interface_sid_php_off
                                
                                	SID PHP Off
                                	**type**\:  bool
                                
                                .. attribute:: interface_state
                                
                                	Interface state
                                	**type**\:   :py:class:`InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.InterfaceState>`
                                
                                .. attribute:: interface_strict_spf_sid
                                
                                	Interface Strict\-SPF SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_strict_spf_sid_n_flag_clear
                                
                                	Strict\-SPF SID N\-Flag Clear
                                	**type**\:  bool
                                
                                .. attribute:: interface_strict_spf_sid_php_off
                                
                                	Strict\-SPF SID PHP Off
                                	**type**\:  bool
                                
                                .. attribute:: interface_tunnel_flags
                                
                                	Interface tunnel flags
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interfaceis_madj
                                
                                	If true, interface is multi\-area
                                	**type**\:  bool
                                
                                .. attribute:: ip_mtu
                                
                                	IP MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ipfrr_tiebreakers
                                
                                	IPFRR\-Tiebreakers list
                                	**type**\: list of    :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers>`
                                
                                .. attribute:: is_loopback_stub_network
                                
                                	If true, loopback interface is advertised as a stub network
                                	**type**\:  bool
                                
                                .. attribute:: maximum_packet_size
                                
                                	Maximum Packet Size
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: network_lsa_flush_timer
                                
                                	The amount of time in seconds before flush timer for old network LSA expires
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: network_type
                                
                                	Network type
                                	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                                
                                .. attribute:: next_hello_time
                                
                                	Time until next Hello (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hello_time_ms
                                
                                	Time until next Hello (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                .. attribute:: passive_interface
                                
                                	If true, passive interface
                                	**type**\:  bool
                                
                                .. attribute:: prefix_suppress_primary_addresses
                                
                                	Prefix Suppression for primary addresses
                                	**type**\:  bool
                                
                                .. attribute:: prefix_suppress_secondary_addresses
                                
                                	Prefix Suppression for secondary addresses
                                	**type**\:  bool
                                
                                .. attribute:: registered_for_link_down_fast_detection
                                
                                	Registered for Link Down Fast Detection
                                	**type**\:  bool
                                
                                .. attribute:: srlg
                                
                                	SRLG Values
                                	**type**\: list of    :py:class:`Srlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.Srlg>`
                                
                                .. attribute:: transmission_delay
                                
                                	Interface Transmission delay
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL security enabled on the interface
                                	**type**\:  bool
                                
                                .. attribute:: ttl_security_hop_count
                                
                                	TTL security hop counts
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wait_interval
                                
                                	Configured wait interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interfaces"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.backup_designated_router = YLeaf(YType.boolean, "backup-designated-router")

                                    self.backup_designated_router_address = YLeaf(YType.str, "backup-designated-router-address")

                                    self.backup_designated_router_id = YLeaf(YType.str, "backup-designated-router-id")

                                    self.cfg_cost_fallback = YLeaf(YType.boolean, "cfg-cost-fallback")

                                    self.configured_demand_circuit = YLeaf(YType.boolean, "configured-demand-circuit")

                                    self.configured_ldp_sync = YLeaf(YType.boolean, "configured-ldp-sync")

                                    self.configured_ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "configured-ldp-sync-igp-shortcuts")

                                    self.cost_fallback_active = YLeaf(YType.boolean, "cost-fallback-active")

                                    self.dead_interval = YLeaf(YType.uint32, "dead-interval")

                                    self.designated_router = YLeaf(YType.boolean, "designated-router")

                                    self.designated_router_address = YLeaf(YType.str, "designated-router-address")

                                    self.designated_router_id = YLeaf(YType.str, "designated-router-id")

                                    self.fast_detect_hold_down_time = YLeaf(YType.uint32, "fast-detect-hold-down-time")

                                    self.fast_detect_hold_down_time_remaining = YLeaf(YType.uint32, "fast-detect-hold-down-time-remaining")

                                    self.fast_reroute_topology_independent_lfa = YLeaf(YType.boolean, "fast-reroute-topology-independent-lfa")

                                    self.fast_reroute_type = YLeaf(YType.enumeration, "fast-reroute-type")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.hello_interval_ms = YLeaf(YType.uint32, "hello-interval-ms")

                                    self.interface_ack_list_count = YLeaf(YType.uint32, "interface-ack-list-count")

                                    self.interface_ack_list_high_watermark = YLeaf(YType.uint32, "interface-ack-list-high-watermark")

                                    self.interface_address = YLeaf(YType.str, "interface-address")

                                    self.interface_area = YLeaf(YType.str, "interface-area")

                                    self.interface_bandwidth = YLeaf(YType.uint32, "interface-bandwidth")

                                    self.interface_cost_fallback = YLeaf(YType.uint16, "interface-cost-fallback")

                                    self.interface_dc_bitless_lsa_count = YLeaf(YType.uint32, "interface-dc-bitless-lsa-count")

                                    self.interface_demand_circuit = YLeaf(YType.boolean, "interface-demand-circuit")

                                    self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                    self.interface_last_nsf = YLeaf(YType.uint32, "interface-last-nsf")

                                    self.interface_ldp_sync = YLeaf(YType.boolean, "interface-ldp-sync")

                                    self.interface_line_state = YLeaf(YType.boolean, "interface-line-state")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_lsa_filter = YLeaf(YType.boolean, "interface-lsa-filter")

                                    self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                    self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                    self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                    self.interface_nsf = YLeaf(YType.boolean, "interface-nsf")

                                    self.interface_nsf_enabled = YLeaf(YType.boolean, "interface-nsf-enabled")

                                    self.interface_priority = YLeaf(YType.uint8, "interface-priority")

                                    self.interface_retransmission_interrval = YLeaf(YType.uint32, "interface-retransmission-interrval")

                                    self.interface_router_id = YLeaf(YType.str, "interface-router-id")

                                    self.interface_sid = YLeaf(YType.uint32, "interface-sid")

                                    self.interface_sid_n_flag_clear = YLeaf(YType.boolean, "interface-sid-n-flag-clear")

                                    self.interface_sid_php_off = YLeaf(YType.boolean, "interface-sid-php-off")

                                    self.interface_state = YLeaf(YType.enumeration, "interface-state")

                                    self.interface_strict_spf_sid = YLeaf(YType.uint32, "interface-strict-spf-sid")

                                    self.interface_strict_spf_sid_n_flag_clear = YLeaf(YType.boolean, "interface-strict-spf-sid-n-flag-clear")

                                    self.interface_strict_spf_sid_php_off = YLeaf(YType.boolean, "interface-strict-spf-sid-php-off")

                                    self.interface_tunnel_flags = YLeaf(YType.uint32, "interface-tunnel-flags")

                                    self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                    self.ip_mtu = YLeaf(YType.uint16, "ip-mtu")

                                    self.is_loopback_stub_network = YLeaf(YType.boolean, "is-loopback-stub-network")

                                    self.maximum_packet_size = YLeaf(YType.uint16, "maximum-packet-size")

                                    self.network_lsa_flush_timer = YLeaf(YType.uint32, "network-lsa-flush-timer")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.next_hello_time = YLeaf(YType.uint32, "next-hello-time")

                                    self.next_hello_time_ms = YLeaf(YType.uint32, "next-hello-time-ms")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                    self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                                    self.prefix_suppress_primary_addresses = YLeaf(YType.boolean, "prefix-suppress-primary-addresses")

                                    self.prefix_suppress_secondary_addresses = YLeaf(YType.boolean, "prefix-suppress-secondary-addresses")

                                    self.registered_for_link_down_fast_detection = YLeaf(YType.boolean, "registered-for-link-down-fast-detection")

                                    self.transmission_delay = YLeaf(YType.uint16, "transmission-delay")

                                    self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                    self.ttl_security_hop_count = YLeaf(YType.uint32, "ttl-security-hop-count")

                                    self.wait_interval = YLeaf(YType.uint32, "wait-interval")

                                    self.active_interface = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface()
                                    self.active_interface.parent = self
                                    self._children_name_map["active_interface"] = "active-interface"
                                    self._children_yang_names.add("active-interface")

                                    self.interface_bfd_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation()
                                    self.interface_bfd_information.parent = self
                                    self._children_name_map["interface_bfd_information"] = "interface-bfd-information"
                                    self._children_yang_names.add("interface-bfd-information")

                                    self.interface_madj = YList(self)
                                    self.interface_neighbor = YList(self)
                                    self.ipfrr_tiebreakers = YList(self)
                                    self.srlg = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "backup_designated_router",
                                                    "backup_designated_router_address",
                                                    "backup_designated_router_id",
                                                    "cfg_cost_fallback",
                                                    "configured_demand_circuit",
                                                    "configured_ldp_sync",
                                                    "configured_ldp_sync_igp_shortcuts",
                                                    "cost_fallback_active",
                                                    "dead_interval",
                                                    "designated_router",
                                                    "designated_router_address",
                                                    "designated_router_id",
                                                    "fast_detect_hold_down_time",
                                                    "fast_detect_hold_down_time_remaining",
                                                    "fast_reroute_topology_independent_lfa",
                                                    "fast_reroute_type",
                                                    "hello_interval",
                                                    "hello_interval_ms",
                                                    "interface_ack_list_count",
                                                    "interface_ack_list_high_watermark",
                                                    "interface_address",
                                                    "interface_area",
                                                    "interface_bandwidth",
                                                    "interface_cost_fallback",
                                                    "interface_dc_bitless_lsa_count",
                                                    "interface_demand_circuit",
                                                    "interface_fast_detect_hold_down",
                                                    "interface_last_nsf",
                                                    "interface_ldp_sync",
                                                    "interface_line_state",
                                                    "interface_link_cost",
                                                    "interface_lsa_filter",
                                                    "interface_madj_count",
                                                    "interface_mask",
                                                    "interface_name_xr",
                                                    "interface_nsf",
                                                    "interface_nsf_enabled",
                                                    "interface_priority",
                                                    "interface_retransmission_interrval",
                                                    "interface_router_id",
                                                    "interface_sid",
                                                    "interface_sid_n_flag_clear",
                                                    "interface_sid_php_off",
                                                    "interface_state",
                                                    "interface_strict_spf_sid",
                                                    "interface_strict_spf_sid_n_flag_clear",
                                                    "interface_strict_spf_sid_php_off",
                                                    "interface_tunnel_flags",
                                                    "interfaceis_madj",
                                                    "ip_mtu",
                                                    "is_loopback_stub_network",
                                                    "maximum_packet_size",
                                                    "network_lsa_flush_timer",
                                                    "network_type",
                                                    "next_hello_time",
                                                    "next_hello_time_ms",
                                                    "ospf_interface_state",
                                                    "passive_interface",
                                                    "prefix_suppress_primary_addresses",
                                                    "prefix_suppress_secondary_addresses",
                                                    "registered_for_link_down_fast_detection",
                                                    "transmission_delay",
                                                    "ttl_security_enabled",
                                                    "ttl_security_hop_count",
                                                    "wait_interval") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface, self).__setattr__(name, value)


                                class InterfaceBfdInformation(Entity):
                                    """
                                    BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	BFD detection multiplier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interval
                                    
                                    	BFD interval (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation, self).__init__()

                                        self.yang_name = "interface-bfd-information"
                                        self.yang_parent_name = "interface"

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                        self.interval = YLeaf(YType.uint32, "interval")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bfd_intf_enable_mode",
                                                        "detection_multiplier",
                                                        "interval") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bfd_intf_enable_mode.is_set or
                                            self.detection_multiplier.is_set or
                                            self.interval.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bfd_intf_enable_mode.yfilter != YFilter.not_set or
                                            self.detection_multiplier.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-bfd-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bfd_intf_enable_mode.is_set or self.bfd_intf_enable_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bfd_intf_enable_mode.get_name_leafdata())
                                        if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bfd-intf-enable-mode" or name == "detection-multiplier" or name == "interval"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bfd-intf-enable-mode"):
                                            self.bfd_intf_enable_mode = value
                                            self.bfd_intf_enable_mode.value_namespace = name_space
                                            self.bfd_intf_enable_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "detection-multiplier"):
                                            self.detection_multiplier = value
                                            self.detection_multiplier.value_namespace = name_space
                                            self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix


                                class ActiveInterface(Entity):
                                    """
                                    Active interface details
                                    
                                    .. attribute:: flood_scan_length
                                    
                                    	Last flood scan length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_flood_index
                                    
                                    	Area scope LSAs flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood
                                    
                                    	Next LSA to flood (Area scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood_index
                                    
                                    	Index of next LSA to flood (Area scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_flood_index
                                    
                                    	AS scope LSAs flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood
                                    
                                    	Next LSA to flood (AS scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood_index
                                    
                                    	Index of next LSA to flood (AS scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_authentication_type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                    
                                    .. attribute:: interface_flood_length
                                    
                                    	Flood queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_flood_pacing_timer
                                    
                                    	Time until next flood pacing timer (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Total number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: keychain_id
                                    
                                    	Keychain ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: last_flood_time
                                    
                                    	Last flood scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_length
                                    
                                    	Maximum flood length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_time
                                    
                                    	Maximum flood time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: md_keys
                                    
                                    	List of old MD keys
                                    	**type**\: list of    :py:class:`MdKeys <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys>`
                                    
                                    .. attribute:: old_md5_key_neighbor_count
                                    
                                    	Number of neighbors using the old key (if rollover in progress)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: suppress_hello_count
                                    
                                    	Number of neighbors for which hellos are suppressed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: wait_time
                                    
                                    	Wait time for DR/BDR selection (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: youngest_md_key
                                    
                                    	If true, MD key is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: youngest_md_key_id
                                    
                                    	Youngest MD key ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface, self).__init__()

                                        self.yang_name = "active-interface"
                                        self.yang_parent_name = "interface"

                                        self.flood_scan_length = YLeaf(YType.uint32, "flood-scan-length")

                                        self.interface_area_flood_index = YLeaf(YType.uint32, "interface-area-flood-index")

                                        self.interface_area_next_flood = YLeaf(YType.uint32, "interface-area-next-flood")

                                        self.interface_area_next_flood_index = YLeaf(YType.uint32, "interface-area-next-flood-index")

                                        self.interface_as_flood_index = YLeaf(YType.uint32, "interface-as-flood-index")

                                        self.interface_as_next_flood = YLeaf(YType.uint32, "interface-as-next-flood")

                                        self.interface_as_next_flood_index = YLeaf(YType.uint32, "interface-as-next-flood-index")

                                        self.interface_authentication_type = YLeaf(YType.enumeration, "interface-authentication-type")

                                        self.interface_flood_length = YLeaf(YType.uint32, "interface-flood-length")

                                        self.interface_flood_pacing_timer = YLeaf(YType.uint32, "interface-flood-pacing-timer")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.keychain_id = YLeaf(YType.uint64, "keychain-id")

                                        self.last_flood_time = YLeaf(YType.uint32, "last-flood-time")

                                        self.maximum_flood_length = YLeaf(YType.uint32, "maximum-flood-length")

                                        self.maximum_flood_time = YLeaf(YType.uint32, "maximum-flood-time")

                                        self.old_md5_key_neighbor_count = YLeaf(YType.uint32, "old-md5-key-neighbor-count")

                                        self.suppress_hello_count = YLeaf(YType.uint16, "suppress-hello-count")

                                        self.wait_time = YLeaf(YType.uint32, "wait-time")

                                        self.youngest_md_key = YLeaf(YType.boolean, "youngest-md-key")

                                        self.youngest_md_key_id = YLeaf(YType.uint16, "youngest-md-key-id")

                                        self.md_keys = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("flood_scan_length",
                                                        "interface_area_flood_index",
                                                        "interface_area_next_flood",
                                                        "interface_area_next_flood_index",
                                                        "interface_as_flood_index",
                                                        "interface_as_next_flood",
                                                        "interface_as_next_flood_index",
                                                        "interface_authentication_type",
                                                        "interface_flood_length",
                                                        "interface_flood_pacing_timer",
                                                        "interface_neighbor_count",
                                                        "keychain_id",
                                                        "last_flood_time",
                                                        "maximum_flood_length",
                                                        "maximum_flood_time",
                                                        "old_md5_key_neighbor_count",
                                                        "suppress_hello_count",
                                                        "wait_time",
                                                        "youngest_md_key",
                                                        "youngest_md_key_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface, self).__setattr__(name, value)


                                    class MdKeys(Entity):
                                        """
                                        List of old MD keys
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys, self).__init__()

                                            self.yang_name = "md-keys"
                                            self.yang_parent_name = "active-interface"

                                            self.entry = YLeaf(YType.uint16, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "md-keys" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.md_keys:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.flood_scan_length.is_set or
                                            self.interface_area_flood_index.is_set or
                                            self.interface_area_next_flood.is_set or
                                            self.interface_area_next_flood_index.is_set or
                                            self.interface_as_flood_index.is_set or
                                            self.interface_as_next_flood.is_set or
                                            self.interface_as_next_flood_index.is_set or
                                            self.interface_authentication_type.is_set or
                                            self.interface_flood_length.is_set or
                                            self.interface_flood_pacing_timer.is_set or
                                            self.interface_neighbor_count.is_set or
                                            self.keychain_id.is_set or
                                            self.last_flood_time.is_set or
                                            self.maximum_flood_length.is_set or
                                            self.maximum_flood_time.is_set or
                                            self.old_md5_key_neighbor_count.is_set or
                                            self.suppress_hello_count.is_set or
                                            self.wait_time.is_set or
                                            self.youngest_md_key.is_set or
                                            self.youngest_md_key_id.is_set)

                                    def has_operation(self):
                                        for c in self.md_keys:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.flood_scan_length.yfilter != YFilter.not_set or
                                            self.interface_area_flood_index.yfilter != YFilter.not_set or
                                            self.interface_area_next_flood.yfilter != YFilter.not_set or
                                            self.interface_area_next_flood_index.yfilter != YFilter.not_set or
                                            self.interface_as_flood_index.yfilter != YFilter.not_set or
                                            self.interface_as_next_flood.yfilter != YFilter.not_set or
                                            self.interface_as_next_flood_index.yfilter != YFilter.not_set or
                                            self.interface_authentication_type.yfilter != YFilter.not_set or
                                            self.interface_flood_length.yfilter != YFilter.not_set or
                                            self.interface_flood_pacing_timer.yfilter != YFilter.not_set or
                                            self.interface_neighbor_count.yfilter != YFilter.not_set or
                                            self.keychain_id.yfilter != YFilter.not_set or
                                            self.last_flood_time.yfilter != YFilter.not_set or
                                            self.maximum_flood_length.yfilter != YFilter.not_set or
                                            self.maximum_flood_time.yfilter != YFilter.not_set or
                                            self.old_md5_key_neighbor_count.yfilter != YFilter.not_set or
                                            self.suppress_hello_count.yfilter != YFilter.not_set or
                                            self.wait_time.yfilter != YFilter.not_set or
                                            self.youngest_md_key.yfilter != YFilter.not_set or
                                            self.youngest_md_key_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "active-interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.flood_scan_length.is_set or self.flood_scan_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_scan_length.get_name_leafdata())
                                        if (self.interface_area_flood_index.is_set or self.interface_area_flood_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_area_flood_index.get_name_leafdata())
                                        if (self.interface_area_next_flood.is_set or self.interface_area_next_flood.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_area_next_flood.get_name_leafdata())
                                        if (self.interface_area_next_flood_index.is_set or self.interface_area_next_flood_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_area_next_flood_index.get_name_leafdata())
                                        if (self.interface_as_flood_index.is_set or self.interface_as_flood_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_as_flood_index.get_name_leafdata())
                                        if (self.interface_as_next_flood.is_set or self.interface_as_next_flood.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_as_next_flood.get_name_leafdata())
                                        if (self.interface_as_next_flood_index.is_set or self.interface_as_next_flood_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_as_next_flood_index.get_name_leafdata())
                                        if (self.interface_authentication_type.is_set or self.interface_authentication_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_authentication_type.get_name_leafdata())
                                        if (self.interface_flood_length.is_set or self.interface_flood_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_flood_length.get_name_leafdata())
                                        if (self.interface_flood_pacing_timer.is_set or self.interface_flood_pacing_timer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_flood_pacing_timer.get_name_leafdata())
                                        if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                        if (self.keychain_id.is_set or self.keychain_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_id.get_name_leafdata())
                                        if (self.last_flood_time.is_set or self.last_flood_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_flood_time.get_name_leafdata())
                                        if (self.maximum_flood_length.is_set or self.maximum_flood_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_flood_length.get_name_leafdata())
                                        if (self.maximum_flood_time.is_set or self.maximum_flood_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_flood_time.get_name_leafdata())
                                        if (self.old_md5_key_neighbor_count.is_set or self.old_md5_key_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.old_md5_key_neighbor_count.get_name_leafdata())
                                        if (self.suppress_hello_count.is_set or self.suppress_hello_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.suppress_hello_count.get_name_leafdata())
                                        if (self.wait_time.is_set or self.wait_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.wait_time.get_name_leafdata())
                                        if (self.youngest_md_key.is_set or self.youngest_md_key.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.youngest_md_key.get_name_leafdata())
                                        if (self.youngest_md_key_id.is_set or self.youngest_md_key_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.youngest_md_key_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "md-keys"):
                                            for c in self.md_keys:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.md_keys.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "md-keys" or name == "flood-scan-length" or name == "interface-area-flood-index" or name == "interface-area-next-flood" or name == "interface-area-next-flood-index" or name == "interface-as-flood-index" or name == "interface-as-next-flood" or name == "interface-as-next-flood-index" or name == "interface-authentication-type" or name == "interface-flood-length" or name == "interface-flood-pacing-timer" or name == "interface-neighbor-count" or name == "keychain-id" or name == "last-flood-time" or name == "maximum-flood-length" or name == "maximum-flood-time" or name == "old-md5-key-neighbor-count" or name == "suppress-hello-count" or name == "wait-time" or name == "youngest-md-key" or name == "youngest-md-key-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "flood-scan-length"):
                                            self.flood_scan_length = value
                                            self.flood_scan_length.value_namespace = name_space
                                            self.flood_scan_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-area-flood-index"):
                                            self.interface_area_flood_index = value
                                            self.interface_area_flood_index.value_namespace = name_space
                                            self.interface_area_flood_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-area-next-flood"):
                                            self.interface_area_next_flood = value
                                            self.interface_area_next_flood.value_namespace = name_space
                                            self.interface_area_next_flood.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-area-next-flood-index"):
                                            self.interface_area_next_flood_index = value
                                            self.interface_area_next_flood_index.value_namespace = name_space
                                            self.interface_area_next_flood_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-as-flood-index"):
                                            self.interface_as_flood_index = value
                                            self.interface_as_flood_index.value_namespace = name_space
                                            self.interface_as_flood_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-as-next-flood"):
                                            self.interface_as_next_flood = value
                                            self.interface_as_next_flood.value_namespace = name_space
                                            self.interface_as_next_flood.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-as-next-flood-index"):
                                            self.interface_as_next_flood_index = value
                                            self.interface_as_next_flood_index.value_namespace = name_space
                                            self.interface_as_next_flood_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-authentication-type"):
                                            self.interface_authentication_type = value
                                            self.interface_authentication_type.value_namespace = name_space
                                            self.interface_authentication_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-flood-length"):
                                            self.interface_flood_length = value
                                            self.interface_flood_length.value_namespace = name_space
                                            self.interface_flood_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-flood-pacing-timer"):
                                            self.interface_flood_pacing_timer = value
                                            self.interface_flood_pacing_timer.value_namespace = name_space
                                            self.interface_flood_pacing_timer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-neighbor-count"):
                                            self.interface_neighbor_count = value
                                            self.interface_neighbor_count.value_namespace = name_space
                                            self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keychain-id"):
                                            self.keychain_id = value
                                            self.keychain_id.value_namespace = name_space
                                            self.keychain_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-flood-time"):
                                            self.last_flood_time = value
                                            self.last_flood_time.value_namespace = name_space
                                            self.last_flood_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-flood-length"):
                                            self.maximum_flood_length = value
                                            self.maximum_flood_length.value_namespace = name_space
                                            self.maximum_flood_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-flood-time"):
                                            self.maximum_flood_time = value
                                            self.maximum_flood_time.value_namespace = name_space
                                            self.maximum_flood_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "old-md5-key-neighbor-count"):
                                            self.old_md5_key_neighbor_count = value
                                            self.old_md5_key_neighbor_count.value_namespace = name_space
                                            self.old_md5_key_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "suppress-hello-count"):
                                            self.suppress_hello_count = value
                                            self.suppress_hello_count.value_namespace = name_space
                                            self.suppress_hello_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "wait-time"):
                                            self.wait_time = value
                                            self.wait_time.value_namespace = name_space
                                            self.wait_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "youngest-md-key"):
                                            self.youngest_md_key = value
                                            self.youngest_md_key.value_namespace = name_space
                                            self.youngest_md_key.value_namespace_prefix = name_space_prefix
                                        if(value_path == "youngest-md-key-id"):
                                            self.youngest_md_key_id = value
                                            self.youngest_md_key_id.value_namespace = name_space
                                            self.youngest_md_key_id.value_namespace_prefix = name_space_prefix


                                class Srlg(Entity):
                                    """
                                    SRLG Values
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.Srlg, self).__init__()

                                        self.yang_name = "srlg"
                                        self.yang_parent_name = "interface"

                                        self.entry = YLeaf(YType.uint32, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.Srlg, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.Srlg, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "srlg" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix


                                class InterfaceNeighbor(Entity):
                                    """
                                    Information for neighbors on the interface
                                    
                                    .. attribute:: interface_neighbor_cost
                                    
                                    	Cost of link to neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_neighbor_id
                                    
                                    	Neighbor Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bdr
                                    
                                    	If true, Backup designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_dr
                                    
                                    	If true, Designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: suppress_hello
                                    
                                    	If true, hellos suppressed
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor, self).__init__()

                                        self.yang_name = "interface-neighbor"
                                        self.yang_parent_name = "interface"

                                        self.interface_neighbor_cost = YLeaf(YType.uint32, "interface-neighbor-cost")

                                        self.interface_neighbor_id = YLeaf(YType.str, "interface-neighbor-id")

                                        self.neighbor_bdr = YLeaf(YType.boolean, "neighbor-bdr")

                                        self.neighbor_dr = YLeaf(YType.boolean, "neighbor-dr")

                                        self.suppress_hello = YLeaf(YType.boolean, "suppress-hello")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_neighbor_cost",
                                                        "interface_neighbor_id",
                                                        "neighbor_bdr",
                                                        "neighbor_dr",
                                                        "suppress_hello") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interface_neighbor_cost.is_set or
                                            self.interface_neighbor_id.is_set or
                                            self.neighbor_bdr.is_set or
                                            self.neighbor_dr.is_set or
                                            self.suppress_hello.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_neighbor_cost.yfilter != YFilter.not_set or
                                            self.interface_neighbor_id.yfilter != YFilter.not_set or
                                            self.neighbor_bdr.yfilter != YFilter.not_set or
                                            self.neighbor_dr.yfilter != YFilter.not_set or
                                            self.suppress_hello.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-neighbor" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_neighbor_cost.is_set or self.interface_neighbor_cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_neighbor_cost.get_name_leafdata())
                                        if (self.interface_neighbor_id.is_set or self.interface_neighbor_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_neighbor_id.get_name_leafdata())
                                        if (self.neighbor_bdr.is_set or self.neighbor_bdr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_bdr.get_name_leafdata())
                                        if (self.neighbor_dr.is_set or self.neighbor_dr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_dr.get_name_leafdata())
                                        if (self.suppress_hello.is_set or self.suppress_hello.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.suppress_hello.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-neighbor-cost" or name == "interface-neighbor-id" or name == "neighbor-bdr" or name == "neighbor-dr" or name == "suppress-hello"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-neighbor-cost"):
                                            self.interface_neighbor_cost = value
                                            self.interface_neighbor_cost.value_namespace = name_space
                                            self.interface_neighbor_cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-neighbor-id"):
                                            self.interface_neighbor_id = value
                                            self.interface_neighbor_id.value_namespace = name_space
                                            self.interface_neighbor_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-bdr"):
                                            self.neighbor_bdr = value
                                            self.neighbor_bdr.value_namespace = name_space
                                            self.neighbor_bdr.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-dr"):
                                            self.neighbor_dr = value
                                            self.neighbor_dr.value_namespace = name_space
                                            self.neighbor_dr.value_namespace_prefix = name_space_prefix
                                        if(value_path == "suppress-hello"):
                                            self.suppress_hello = value
                                            self.suppress_hello.value_namespace = name_space
                                            self.suppress_hello.value_namespace_prefix = name_space_prefix


                                class InterfaceMadj(Entity):
                                    """
                                    Information for multi\-area on the interface
                                    
                                    .. attribute:: interface_adj_neighbor_count
                                    
                                    	Total number of Adjacent Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_area
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: madj_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceMadj, self).__init__()

                                        self.yang_name = "interface-madj"
                                        self.yang_parent_name = "interface"

                                        self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                        self.interface_area = YLeaf(YType.str, "interface-area")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_adj_neighbor_count",
                                                        "interface_area",
                                                        "interface_link_cost",
                                                        "interface_neighbor_count",
                                                        "madj_area_id",
                                                        "ospf_interface_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceMadj, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceMadj, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interface_adj_neighbor_count.is_set or
                                            self.interface_area.is_set or
                                            self.interface_link_cost.is_set or
                                            self.interface_neighbor_count.is_set or
                                            self.madj_area_id.is_set or
                                            self.ospf_interface_state.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_adj_neighbor_count.yfilter != YFilter.not_set or
                                            self.interface_area.yfilter != YFilter.not_set or
                                            self.interface_link_cost.yfilter != YFilter.not_set or
                                            self.interface_neighbor_count.yfilter != YFilter.not_set or
                                            self.madj_area_id.yfilter != YFilter.not_set or
                                            self.ospf_interface_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-madj" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_adj_neighbor_count.is_set or self.interface_adj_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_adj_neighbor_count.get_name_leafdata())
                                        if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_area.get_name_leafdata())
                                        if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                        if (self.interface_neighbor_count.is_set or self.interface_neighbor_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_neighbor_count.get_name_leafdata())
                                        if (self.madj_area_id.is_set or self.madj_area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.madj_area_id.get_name_leafdata())
                                        if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-adj-neighbor-count" or name == "interface-area" or name == "interface-link-cost" or name == "interface-neighbor-count" or name == "madj-area-id" or name == "ospf-interface-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-adj-neighbor-count"):
                                            self.interface_adj_neighbor_count = value
                                            self.interface_adj_neighbor_count.value_namespace = name_space
                                            self.interface_adj_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-area"):
                                            self.interface_area = value
                                            self.interface_area.value_namespace = name_space
                                            self.interface_area.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-link-cost"):
                                            self.interface_link_cost = value
                                            self.interface_link_cost.value_namespace = name_space
                                            self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-neighbor-count"):
                                            self.interface_neighbor_count = value
                                            self.interface_neighbor_count.value_namespace = name_space
                                            self.interface_neighbor_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "madj-area-id"):
                                            self.madj_area_id = value
                                            self.madj_area_id.value_namespace = name_space
                                            self.madj_area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-interface-state"):
                                            self.ospf_interface_state = value
                                            self.ospf_interface_state.value_namespace = name_space
                                            self.ospf_interface_state.value_namespace_prefix = name_space_prefix


                                class IpfrrTiebreakers(Entity):
                                    """
                                    IPFRR\-Tiebreakers list
                                    
                                    .. attribute:: tiebreaker_index
                                    
                                    	Tiebreaker Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tiebreaker_type
                                    
                                    	Tiebreaker Type
                                    	**type**\:   :py:class:`IpfrrTbrkr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IpfrrTbrkr>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers, self).__init__()

                                        self.yang_name = "ipfrr-tiebreakers"
                                        self.yang_parent_name = "interface"

                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tiebreaker_index",
                                                        "tiebreaker_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.tiebreaker_index.is_set or
                                            self.tiebreaker_type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tiebreaker_index.yfilter != YFilter.not_set or
                                            self.tiebreaker_type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipfrr-tiebreakers" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())
                                        if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tiebreaker-index" or name == "tiebreaker-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tiebreaker-index"):
                                            self.tiebreaker_index = value
                                            self.tiebreaker_index.value_namespace = name_space
                                            self.tiebreaker_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tiebreaker-type"):
                                            self.tiebreaker_type = value
                                            self.tiebreaker_type.value_namespace = name_space
                                            self.tiebreaker_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.interface_madj:
                                        if (c.has_data()):
                                            return True
                                    for c in self.interface_neighbor:
                                        if (c.has_data()):
                                            return True
                                    for c in self.ipfrr_tiebreakers:
                                        if (c.has_data()):
                                            return True
                                    for c in self.srlg:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.interface_name.is_set or
                                        self.backup_designated_router.is_set or
                                        self.backup_designated_router_address.is_set or
                                        self.backup_designated_router_id.is_set or
                                        self.cfg_cost_fallback.is_set or
                                        self.configured_demand_circuit.is_set or
                                        self.configured_ldp_sync.is_set or
                                        self.configured_ldp_sync_igp_shortcuts.is_set or
                                        self.cost_fallback_active.is_set or
                                        self.dead_interval.is_set or
                                        self.designated_router.is_set or
                                        self.designated_router_address.is_set or
                                        self.designated_router_id.is_set or
                                        self.fast_detect_hold_down_time.is_set or
                                        self.fast_detect_hold_down_time_remaining.is_set or
                                        self.fast_reroute_topology_independent_lfa.is_set or
                                        self.fast_reroute_type.is_set or
                                        self.hello_interval.is_set or
                                        self.hello_interval_ms.is_set or
                                        self.interface_ack_list_count.is_set or
                                        self.interface_ack_list_high_watermark.is_set or
                                        self.interface_address.is_set or
                                        self.interface_area.is_set or
                                        self.interface_bandwidth.is_set or
                                        self.interface_cost_fallback.is_set or
                                        self.interface_dc_bitless_lsa_count.is_set or
                                        self.interface_demand_circuit.is_set or
                                        self.interface_fast_detect_hold_down.is_set or
                                        self.interface_last_nsf.is_set or
                                        self.interface_ldp_sync.is_set or
                                        self.interface_line_state.is_set or
                                        self.interface_link_cost.is_set or
                                        self.interface_lsa_filter.is_set or
                                        self.interface_madj_count.is_set or
                                        self.interface_mask.is_set or
                                        self.interface_name_xr.is_set or
                                        self.interface_nsf.is_set or
                                        self.interface_nsf_enabled.is_set or
                                        self.interface_priority.is_set or
                                        self.interface_retransmission_interrval.is_set or
                                        self.interface_router_id.is_set or
                                        self.interface_sid.is_set or
                                        self.interface_sid_n_flag_clear.is_set or
                                        self.interface_sid_php_off.is_set or
                                        self.interface_state.is_set or
                                        self.interface_strict_spf_sid.is_set or
                                        self.interface_strict_spf_sid_n_flag_clear.is_set or
                                        self.interface_strict_spf_sid_php_off.is_set or
                                        self.interface_tunnel_flags.is_set or
                                        self.interfaceis_madj.is_set or
                                        self.ip_mtu.is_set or
                                        self.is_loopback_stub_network.is_set or
                                        self.maximum_packet_size.is_set or
                                        self.network_lsa_flush_timer.is_set or
                                        self.network_type.is_set or
                                        self.next_hello_time.is_set or
                                        self.next_hello_time_ms.is_set or
                                        self.ospf_interface_state.is_set or
                                        self.passive_interface.is_set or
                                        self.prefix_suppress_primary_addresses.is_set or
                                        self.prefix_suppress_secondary_addresses.is_set or
                                        self.registered_for_link_down_fast_detection.is_set or
                                        self.transmission_delay.is_set or
                                        self.ttl_security_enabled.is_set or
                                        self.ttl_security_hop_count.is_set or
                                        self.wait_interval.is_set or
                                        (self.active_interface is not None and self.active_interface.has_data()) or
                                        (self.interface_bfd_information is not None and self.interface_bfd_information.has_data()))

                                def has_operation(self):
                                    for c in self.interface_madj:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.interface_neighbor:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.ipfrr_tiebreakers:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.srlg:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.backup_designated_router.yfilter != YFilter.not_set or
                                        self.backup_designated_router_address.yfilter != YFilter.not_set or
                                        self.backup_designated_router_id.yfilter != YFilter.not_set or
                                        self.cfg_cost_fallback.yfilter != YFilter.not_set or
                                        self.configured_demand_circuit.yfilter != YFilter.not_set or
                                        self.configured_ldp_sync.yfilter != YFilter.not_set or
                                        self.configured_ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                                        self.cost_fallback_active.yfilter != YFilter.not_set or
                                        self.dead_interval.yfilter != YFilter.not_set or
                                        self.designated_router.yfilter != YFilter.not_set or
                                        self.designated_router_address.yfilter != YFilter.not_set or
                                        self.designated_router_id.yfilter != YFilter.not_set or
                                        self.fast_detect_hold_down_time.yfilter != YFilter.not_set or
                                        self.fast_detect_hold_down_time_remaining.yfilter != YFilter.not_set or
                                        self.fast_reroute_topology_independent_lfa.yfilter != YFilter.not_set or
                                        self.fast_reroute_type.yfilter != YFilter.not_set or
                                        self.hello_interval.yfilter != YFilter.not_set or
                                        self.hello_interval_ms.yfilter != YFilter.not_set or
                                        self.interface_ack_list_count.yfilter != YFilter.not_set or
                                        self.interface_ack_list_high_watermark.yfilter != YFilter.not_set or
                                        self.interface_address.yfilter != YFilter.not_set or
                                        self.interface_area.yfilter != YFilter.not_set or
                                        self.interface_bandwidth.yfilter != YFilter.not_set or
                                        self.interface_cost_fallback.yfilter != YFilter.not_set or
                                        self.interface_dc_bitless_lsa_count.yfilter != YFilter.not_set or
                                        self.interface_demand_circuit.yfilter != YFilter.not_set or
                                        self.interface_fast_detect_hold_down.yfilter != YFilter.not_set or
                                        self.interface_last_nsf.yfilter != YFilter.not_set or
                                        self.interface_ldp_sync.yfilter != YFilter.not_set or
                                        self.interface_line_state.yfilter != YFilter.not_set or
                                        self.interface_link_cost.yfilter != YFilter.not_set or
                                        self.interface_lsa_filter.yfilter != YFilter.not_set or
                                        self.interface_madj_count.yfilter != YFilter.not_set or
                                        self.interface_mask.yfilter != YFilter.not_set or
                                        self.interface_name_xr.yfilter != YFilter.not_set or
                                        self.interface_nsf.yfilter != YFilter.not_set or
                                        self.interface_nsf_enabled.yfilter != YFilter.not_set or
                                        self.interface_priority.yfilter != YFilter.not_set or
                                        self.interface_retransmission_interrval.yfilter != YFilter.not_set or
                                        self.interface_router_id.yfilter != YFilter.not_set or
                                        self.interface_sid.yfilter != YFilter.not_set or
                                        self.interface_sid_n_flag_clear.yfilter != YFilter.not_set or
                                        self.interface_sid_php_off.yfilter != YFilter.not_set or
                                        self.interface_state.yfilter != YFilter.not_set or
                                        self.interface_strict_spf_sid.yfilter != YFilter.not_set or
                                        self.interface_strict_spf_sid_n_flag_clear.yfilter != YFilter.not_set or
                                        self.interface_strict_spf_sid_php_off.yfilter != YFilter.not_set or
                                        self.interface_tunnel_flags.yfilter != YFilter.not_set or
                                        self.interfaceis_madj.yfilter != YFilter.not_set or
                                        self.ip_mtu.yfilter != YFilter.not_set or
                                        self.is_loopback_stub_network.yfilter != YFilter.not_set or
                                        self.maximum_packet_size.yfilter != YFilter.not_set or
                                        self.network_lsa_flush_timer.yfilter != YFilter.not_set or
                                        self.network_type.yfilter != YFilter.not_set or
                                        self.next_hello_time.yfilter != YFilter.not_set or
                                        self.next_hello_time_ms.yfilter != YFilter.not_set or
                                        self.ospf_interface_state.yfilter != YFilter.not_set or
                                        self.passive_interface.yfilter != YFilter.not_set or
                                        self.prefix_suppress_primary_addresses.yfilter != YFilter.not_set or
                                        self.prefix_suppress_secondary_addresses.yfilter != YFilter.not_set or
                                        self.registered_for_link_down_fast_detection.yfilter != YFilter.not_set or
                                        self.transmission_delay.yfilter != YFilter.not_set or
                                        self.ttl_security_enabled.yfilter != YFilter.not_set or
                                        self.ttl_security_hop_count.yfilter != YFilter.not_set or
                                        self.wait_interval.yfilter != YFilter.not_set or
                                        (self.active_interface is not None and self.active_interface.has_operation()) or
                                        (self.interface_bfd_information is not None and self.interface_bfd_information.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.backup_designated_router.is_set or self.backup_designated_router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_designated_router.get_name_leafdata())
                                    if (self.backup_designated_router_address.is_set or self.backup_designated_router_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_designated_router_address.get_name_leafdata())
                                    if (self.backup_designated_router_id.is_set or self.backup_designated_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_designated_router_id.get_name_leafdata())
                                    if (self.cfg_cost_fallback.is_set or self.cfg_cost_fallback.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cfg_cost_fallback.get_name_leafdata())
                                    if (self.configured_demand_circuit.is_set or self.configured_demand_circuit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.configured_demand_circuit.get_name_leafdata())
                                    if (self.configured_ldp_sync.is_set or self.configured_ldp_sync.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.configured_ldp_sync.get_name_leafdata())
                                    if (self.configured_ldp_sync_igp_shortcuts.is_set or self.configured_ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.configured_ldp_sync_igp_shortcuts.get_name_leafdata())
                                    if (self.cost_fallback_active.is_set or self.cost_fallback_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cost_fallback_active.get_name_leafdata())
                                    if (self.dead_interval.is_set or self.dead_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dead_interval.get_name_leafdata())
                                    if (self.designated_router.is_set or self.designated_router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.designated_router.get_name_leafdata())
                                    if (self.designated_router_address.is_set or self.designated_router_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.designated_router_address.get_name_leafdata())
                                    if (self.designated_router_id.is_set or self.designated_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.designated_router_id.get_name_leafdata())
                                    if (self.fast_detect_hold_down_time.is_set or self.fast_detect_hold_down_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_detect_hold_down_time.get_name_leafdata())
                                    if (self.fast_detect_hold_down_time_remaining.is_set or self.fast_detect_hold_down_time_remaining.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_detect_hold_down_time_remaining.get_name_leafdata())
                                    if (self.fast_reroute_topology_independent_lfa.is_set or self.fast_reroute_topology_independent_lfa.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_reroute_topology_independent_lfa.get_name_leafdata())
                                    if (self.fast_reroute_type.is_set or self.fast_reroute_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_reroute_type.get_name_leafdata())
                                    if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                    if (self.hello_interval_ms.is_set or self.hello_interval_ms.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval_ms.get_name_leafdata())
                                    if (self.interface_ack_list_count.is_set or self.interface_ack_list_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_ack_list_count.get_name_leafdata())
                                    if (self.interface_ack_list_high_watermark.is_set or self.interface_ack_list_high_watermark.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_ack_list_high_watermark.get_name_leafdata())
                                    if (self.interface_address.is_set or self.interface_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_address.get_name_leafdata())
                                    if (self.interface_area.is_set or self.interface_area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_area.get_name_leafdata())
                                    if (self.interface_bandwidth.is_set or self.interface_bandwidth.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_bandwidth.get_name_leafdata())
                                    if (self.interface_cost_fallback.is_set or self.interface_cost_fallback.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_cost_fallback.get_name_leafdata())
                                    if (self.interface_dc_bitless_lsa_count.is_set or self.interface_dc_bitless_lsa_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_dc_bitless_lsa_count.get_name_leafdata())
                                    if (self.interface_demand_circuit.is_set or self.interface_demand_circuit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_demand_circuit.get_name_leafdata())
                                    if (self.interface_fast_detect_hold_down.is_set or self.interface_fast_detect_hold_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_fast_detect_hold_down.get_name_leafdata())
                                    if (self.interface_last_nsf.is_set or self.interface_last_nsf.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_last_nsf.get_name_leafdata())
                                    if (self.interface_ldp_sync.is_set or self.interface_ldp_sync.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_ldp_sync.get_name_leafdata())
                                    if (self.interface_line_state.is_set or self.interface_line_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_line_state.get_name_leafdata())
                                    if (self.interface_link_cost.is_set or self.interface_link_cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_link_cost.get_name_leafdata())
                                    if (self.interface_lsa_filter.is_set or self.interface_lsa_filter.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_lsa_filter.get_name_leafdata())
                                    if (self.interface_madj_count.is_set or self.interface_madj_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_madj_count.get_name_leafdata())
                                    if (self.interface_mask.is_set or self.interface_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_mask.get_name_leafdata())
                                    if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                    if (self.interface_nsf.is_set or self.interface_nsf.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_nsf.get_name_leafdata())
                                    if (self.interface_nsf_enabled.is_set or self.interface_nsf_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_nsf_enabled.get_name_leafdata())
                                    if (self.interface_priority.is_set or self.interface_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_priority.get_name_leafdata())
                                    if (self.interface_retransmission_interrval.is_set or self.interface_retransmission_interrval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_retransmission_interrval.get_name_leafdata())
                                    if (self.interface_router_id.is_set or self.interface_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_router_id.get_name_leafdata())
                                    if (self.interface_sid.is_set or self.interface_sid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_sid.get_name_leafdata())
                                    if (self.interface_sid_n_flag_clear.is_set or self.interface_sid_n_flag_clear.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_sid_n_flag_clear.get_name_leafdata())
                                    if (self.interface_sid_php_off.is_set or self.interface_sid_php_off.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_sid_php_off.get_name_leafdata())
                                    if (self.interface_state.is_set or self.interface_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_state.get_name_leafdata())
                                    if (self.interface_strict_spf_sid.is_set or self.interface_strict_spf_sid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_strict_spf_sid.get_name_leafdata())
                                    if (self.interface_strict_spf_sid_n_flag_clear.is_set or self.interface_strict_spf_sid_n_flag_clear.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_strict_spf_sid_n_flag_clear.get_name_leafdata())
                                    if (self.interface_strict_spf_sid_php_off.is_set or self.interface_strict_spf_sid_php_off.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_strict_spf_sid_php_off.get_name_leafdata())
                                    if (self.interface_tunnel_flags.is_set or self.interface_tunnel_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_tunnel_flags.get_name_leafdata())
                                    if (self.interfaceis_madj.is_set or self.interfaceis_madj.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interfaceis_madj.get_name_leafdata())
                                    if (self.ip_mtu.is_set or self.ip_mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ip_mtu.get_name_leafdata())
                                    if (self.is_loopback_stub_network.is_set or self.is_loopback_stub_network.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_loopback_stub_network.get_name_leafdata())
                                    if (self.maximum_packet_size.is_set or self.maximum_packet_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_packet_size.get_name_leafdata())
                                    if (self.network_lsa_flush_timer.is_set or self.network_lsa_flush_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.network_lsa_flush_timer.get_name_leafdata())
                                    if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.network_type.get_name_leafdata())
                                    if (self.next_hello_time.is_set or self.next_hello_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hello_time.get_name_leafdata())
                                    if (self.next_hello_time_ms.is_set or self.next_hello_time_ms.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hello_time_ms.get_name_leafdata())
                                    if (self.ospf_interface_state.is_set or self.ospf_interface_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_interface_state.get_name_leafdata())
                                    if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.passive_interface.get_name_leafdata())
                                    if (self.prefix_suppress_primary_addresses.is_set or self.prefix_suppress_primary_addresses.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_suppress_primary_addresses.get_name_leafdata())
                                    if (self.prefix_suppress_secondary_addresses.is_set or self.prefix_suppress_secondary_addresses.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_suppress_secondary_addresses.get_name_leafdata())
                                    if (self.registered_for_link_down_fast_detection.is_set or self.registered_for_link_down_fast_detection.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.registered_for_link_down_fast_detection.get_name_leafdata())
                                    if (self.transmission_delay.is_set or self.transmission_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transmission_delay.get_name_leafdata())
                                    if (self.ttl_security_enabled.is_set or self.ttl_security_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl_security_enabled.get_name_leafdata())
                                    if (self.ttl_security_hop_count.is_set or self.ttl_security_hop_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl_security_hop_count.get_name_leafdata())
                                    if (self.wait_interval.is_set or self.wait_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wait_interval.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "active-interface"):
                                        if (self.active_interface is None):
                                            self.active_interface = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface()
                                            self.active_interface.parent = self
                                            self._children_name_map["active_interface"] = "active-interface"
                                        return self.active_interface

                                    if (child_yang_name == "interface-bfd-information"):
                                        if (self.interface_bfd_information is None):
                                            self.interface_bfd_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation()
                                            self.interface_bfd_information.parent = self
                                            self._children_name_map["interface_bfd_information"] = "interface-bfd-information"
                                        return self.interface_bfd_information

                                    if (child_yang_name == "interface-madj"):
                                        for c in self.interface_madj:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceMadj()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.interface_madj.append(c)
                                        return c

                                    if (child_yang_name == "interface-neighbor"):
                                        for c in self.interface_neighbor:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.interface_neighbor.append(c)
                                        return c

                                    if (child_yang_name == "ipfrr-tiebreakers"):
                                        for c in self.ipfrr_tiebreakers:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.ipfrr_tiebreakers.append(c)
                                        return c

                                    if (child_yang_name == "srlg"):
                                        for c in self.srlg:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.Srlg()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.srlg.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "active-interface" or name == "interface-bfd-information" or name == "interface-madj" or name == "interface-neighbor" or name == "ipfrr-tiebreakers" or name == "srlg" or name == "interface-name" or name == "backup-designated-router" or name == "backup-designated-router-address" or name == "backup-designated-router-id" or name == "cfg-cost-fallback" or name == "configured-demand-circuit" or name == "configured-ldp-sync" or name == "configured-ldp-sync-igp-shortcuts" or name == "cost-fallback-active" or name == "dead-interval" or name == "designated-router" or name == "designated-router-address" or name == "designated-router-id" or name == "fast-detect-hold-down-time" or name == "fast-detect-hold-down-time-remaining" or name == "fast-reroute-topology-independent-lfa" or name == "fast-reroute-type" or name == "hello-interval" or name == "hello-interval-ms" or name == "interface-ack-list-count" or name == "interface-ack-list-high-watermark" or name == "interface-address" or name == "interface-area" or name == "interface-bandwidth" or name == "interface-cost-fallback" or name == "interface-dc-bitless-lsa-count" or name == "interface-demand-circuit" or name == "interface-fast-detect-hold-down" or name == "interface-last-nsf" or name == "interface-ldp-sync" or name == "interface-line-state" or name == "interface-link-cost" or name == "interface-lsa-filter" or name == "interface-madj-count" or name == "interface-mask" or name == "interface-name-xr" or name == "interface-nsf" or name == "interface-nsf-enabled" or name == "interface-priority" or name == "interface-retransmission-interrval" or name == "interface-router-id" or name == "interface-sid" or name == "interface-sid-n-flag-clear" or name == "interface-sid-php-off" or name == "interface-state" or name == "interface-strict-spf-sid" or name == "interface-strict-spf-sid-n-flag-clear" or name == "interface-strict-spf-sid-php-off" or name == "interface-tunnel-flags" or name == "interfaceis-madj" or name == "ip-mtu" or name == "is-loopback-stub-network" or name == "maximum-packet-size" or name == "network-lsa-flush-timer" or name == "network-type" or name == "next-hello-time" or name == "next-hello-time-ms" or name == "ospf-interface-state" or name == "passive-interface" or name == "prefix-suppress-primary-addresses" or name == "prefix-suppress-secondary-addresses" or name == "registered-for-link-down-fast-detection" or name == "transmission-delay" or name == "ttl-security-enabled" or name == "ttl-security-hop-count" or name == "wait-interval"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-designated-router"):
                                        self.backup_designated_router = value
                                        self.backup_designated_router.value_namespace = name_space
                                        self.backup_designated_router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-designated-router-address"):
                                        self.backup_designated_router_address = value
                                        self.backup_designated_router_address.value_namespace = name_space
                                        self.backup_designated_router_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-designated-router-id"):
                                        self.backup_designated_router_id = value
                                        self.backup_designated_router_id.value_namespace = name_space
                                        self.backup_designated_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cfg-cost-fallback"):
                                        self.cfg_cost_fallback = value
                                        self.cfg_cost_fallback.value_namespace = name_space
                                        self.cfg_cost_fallback.value_namespace_prefix = name_space_prefix
                                    if(value_path == "configured-demand-circuit"):
                                        self.configured_demand_circuit = value
                                        self.configured_demand_circuit.value_namespace = name_space
                                        self.configured_demand_circuit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "configured-ldp-sync"):
                                        self.configured_ldp_sync = value
                                        self.configured_ldp_sync.value_namespace = name_space
                                        self.configured_ldp_sync.value_namespace_prefix = name_space_prefix
                                    if(value_path == "configured-ldp-sync-igp-shortcuts"):
                                        self.configured_ldp_sync_igp_shortcuts = value
                                        self.configured_ldp_sync_igp_shortcuts.value_namespace = name_space
                                        self.configured_ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cost-fallback-active"):
                                        self.cost_fallback_active = value
                                        self.cost_fallback_active.value_namespace = name_space
                                        self.cost_fallback_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dead-interval"):
                                        self.dead_interval = value
                                        self.dead_interval.value_namespace = name_space
                                        self.dead_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "designated-router"):
                                        self.designated_router = value
                                        self.designated_router.value_namespace = name_space
                                        self.designated_router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "designated-router-address"):
                                        self.designated_router_address = value
                                        self.designated_router_address.value_namespace = name_space
                                        self.designated_router_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "designated-router-id"):
                                        self.designated_router_id = value
                                        self.designated_router_id.value_namespace = name_space
                                        self.designated_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fast-detect-hold-down-time"):
                                        self.fast_detect_hold_down_time = value
                                        self.fast_detect_hold_down_time.value_namespace = name_space
                                        self.fast_detect_hold_down_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fast-detect-hold-down-time-remaining"):
                                        self.fast_detect_hold_down_time_remaining = value
                                        self.fast_detect_hold_down_time_remaining.value_namespace = name_space
                                        self.fast_detect_hold_down_time_remaining.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fast-reroute-topology-independent-lfa"):
                                        self.fast_reroute_topology_independent_lfa = value
                                        self.fast_reroute_topology_independent_lfa.value_namespace = name_space
                                        self.fast_reroute_topology_independent_lfa.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fast-reroute-type"):
                                        self.fast_reroute_type = value
                                        self.fast_reroute_type.value_namespace = name_space
                                        self.fast_reroute_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval"):
                                        self.hello_interval = value
                                        self.hello_interval.value_namespace = name_space
                                        self.hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval-ms"):
                                        self.hello_interval_ms = value
                                        self.hello_interval_ms.value_namespace = name_space
                                        self.hello_interval_ms.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-ack-list-count"):
                                        self.interface_ack_list_count = value
                                        self.interface_ack_list_count.value_namespace = name_space
                                        self.interface_ack_list_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-ack-list-high-watermark"):
                                        self.interface_ack_list_high_watermark = value
                                        self.interface_ack_list_high_watermark.value_namespace = name_space
                                        self.interface_ack_list_high_watermark.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-address"):
                                        self.interface_address = value
                                        self.interface_address.value_namespace = name_space
                                        self.interface_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-area"):
                                        self.interface_area = value
                                        self.interface_area.value_namespace = name_space
                                        self.interface_area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-bandwidth"):
                                        self.interface_bandwidth = value
                                        self.interface_bandwidth.value_namespace = name_space
                                        self.interface_bandwidth.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-cost-fallback"):
                                        self.interface_cost_fallback = value
                                        self.interface_cost_fallback.value_namespace = name_space
                                        self.interface_cost_fallback.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-dc-bitless-lsa-count"):
                                        self.interface_dc_bitless_lsa_count = value
                                        self.interface_dc_bitless_lsa_count.value_namespace = name_space
                                        self.interface_dc_bitless_lsa_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-demand-circuit"):
                                        self.interface_demand_circuit = value
                                        self.interface_demand_circuit.value_namespace = name_space
                                        self.interface_demand_circuit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-fast-detect-hold-down"):
                                        self.interface_fast_detect_hold_down = value
                                        self.interface_fast_detect_hold_down.value_namespace = name_space
                                        self.interface_fast_detect_hold_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-last-nsf"):
                                        self.interface_last_nsf = value
                                        self.interface_last_nsf.value_namespace = name_space
                                        self.interface_last_nsf.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-ldp-sync"):
                                        self.interface_ldp_sync = value
                                        self.interface_ldp_sync.value_namespace = name_space
                                        self.interface_ldp_sync.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-line-state"):
                                        self.interface_line_state = value
                                        self.interface_line_state.value_namespace = name_space
                                        self.interface_line_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-link-cost"):
                                        self.interface_link_cost = value
                                        self.interface_link_cost.value_namespace = name_space
                                        self.interface_link_cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-lsa-filter"):
                                        self.interface_lsa_filter = value
                                        self.interface_lsa_filter.value_namespace = name_space
                                        self.interface_lsa_filter.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-madj-count"):
                                        self.interface_madj_count = value
                                        self.interface_madj_count.value_namespace = name_space
                                        self.interface_madj_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-mask"):
                                        self.interface_mask = value
                                        self.interface_mask.value_namespace = name_space
                                        self.interface_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name-xr"):
                                        self.interface_name_xr = value
                                        self.interface_name_xr.value_namespace = name_space
                                        self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-nsf"):
                                        self.interface_nsf = value
                                        self.interface_nsf.value_namespace = name_space
                                        self.interface_nsf.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-nsf-enabled"):
                                        self.interface_nsf_enabled = value
                                        self.interface_nsf_enabled.value_namespace = name_space
                                        self.interface_nsf_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-priority"):
                                        self.interface_priority = value
                                        self.interface_priority.value_namespace = name_space
                                        self.interface_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-retransmission-interrval"):
                                        self.interface_retransmission_interrval = value
                                        self.interface_retransmission_interrval.value_namespace = name_space
                                        self.interface_retransmission_interrval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-router-id"):
                                        self.interface_router_id = value
                                        self.interface_router_id.value_namespace = name_space
                                        self.interface_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-sid"):
                                        self.interface_sid = value
                                        self.interface_sid.value_namespace = name_space
                                        self.interface_sid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-sid-n-flag-clear"):
                                        self.interface_sid_n_flag_clear = value
                                        self.interface_sid_n_flag_clear.value_namespace = name_space
                                        self.interface_sid_n_flag_clear.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-sid-php-off"):
                                        self.interface_sid_php_off = value
                                        self.interface_sid_php_off.value_namespace = name_space
                                        self.interface_sid_php_off.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-state"):
                                        self.interface_state = value
                                        self.interface_state.value_namespace = name_space
                                        self.interface_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-strict-spf-sid"):
                                        self.interface_strict_spf_sid = value
                                        self.interface_strict_spf_sid.value_namespace = name_space
                                        self.interface_strict_spf_sid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-strict-spf-sid-n-flag-clear"):
                                        self.interface_strict_spf_sid_n_flag_clear = value
                                        self.interface_strict_spf_sid_n_flag_clear.value_namespace = name_space
                                        self.interface_strict_spf_sid_n_flag_clear.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-strict-spf-sid-php-off"):
                                        self.interface_strict_spf_sid_php_off = value
                                        self.interface_strict_spf_sid_php_off.value_namespace = name_space
                                        self.interface_strict_spf_sid_php_off.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-tunnel-flags"):
                                        self.interface_tunnel_flags = value
                                        self.interface_tunnel_flags.value_namespace = name_space
                                        self.interface_tunnel_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interfaceis-madj"):
                                        self.interfaceis_madj = value
                                        self.interfaceis_madj.value_namespace = name_space
                                        self.interfaceis_madj.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ip-mtu"):
                                        self.ip_mtu = value
                                        self.ip_mtu.value_namespace = name_space
                                        self.ip_mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-loopback-stub-network"):
                                        self.is_loopback_stub_network = value
                                        self.is_loopback_stub_network.value_namespace = name_space
                                        self.is_loopback_stub_network.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-packet-size"):
                                        self.maximum_packet_size = value
                                        self.maximum_packet_size.value_namespace = name_space
                                        self.maximum_packet_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "network-lsa-flush-timer"):
                                        self.network_lsa_flush_timer = value
                                        self.network_lsa_flush_timer.value_namespace = name_space
                                        self.network_lsa_flush_timer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "network-type"):
                                        self.network_type = value
                                        self.network_type.value_namespace = name_space
                                        self.network_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hello-time"):
                                        self.next_hello_time = value
                                        self.next_hello_time.value_namespace = name_space
                                        self.next_hello_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hello-time-ms"):
                                        self.next_hello_time_ms = value
                                        self.next_hello_time_ms.value_namespace = name_space
                                        self.next_hello_time_ms.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-interface-state"):
                                        self.ospf_interface_state = value
                                        self.ospf_interface_state.value_namespace = name_space
                                        self.ospf_interface_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "passive-interface"):
                                        self.passive_interface = value
                                        self.passive_interface.value_namespace = name_space
                                        self.passive_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-suppress-primary-addresses"):
                                        self.prefix_suppress_primary_addresses = value
                                        self.prefix_suppress_primary_addresses.value_namespace = name_space
                                        self.prefix_suppress_primary_addresses.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-suppress-secondary-addresses"):
                                        self.prefix_suppress_secondary_addresses = value
                                        self.prefix_suppress_secondary_addresses.value_namespace = name_space
                                        self.prefix_suppress_secondary_addresses.value_namespace_prefix = name_space_prefix
                                    if(value_path == "registered-for-link-down-fast-detection"):
                                        self.registered_for_link_down_fast_detection = value
                                        self.registered_for_link_down_fast_detection.value_namespace = name_space
                                        self.registered_for_link_down_fast_detection.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transmission-delay"):
                                        self.transmission_delay = value
                                        self.transmission_delay.value_namespace = name_space
                                        self.transmission_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl-security-enabled"):
                                        self.ttl_security_enabled = value
                                        self.ttl_security_enabled.value_namespace = name_space
                                        self.ttl_security_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl-security-hop-count"):
                                        self.ttl_security_hop_count = value
                                        self.ttl_security_hop_count.value_namespace = name_space
                                        self.ttl_security_hop_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wait-interval"):
                                        self.wait_interval = value
                                        self.wait_interval.value_namespace = name_space
                                        self.wait_interval.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.interface:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interfaces" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface"):
                                    for c in self.interface:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.area_id.is_set or
                                (self.area_statistics is not None and self.area_statistics.has_data()) or
                                (self.flood_list_area_table is not None and self.flood_list_area_table.has_data()) or
                                (self.interface_briefs is not None and self.interface_briefs.has_data()) or
                                (self.interfaces is not None and self.interfaces.has_data()) or
                                (self.neighbor_details is not None and self.neighbor_details.has_data()) or
                                (self.neighbors is not None and self.neighbors.has_data()) or
                                (self.requests is not None and self.requests.has_data()) or
                                (self.retransmissions is not None and self.retransmissions.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.area_id.yfilter != YFilter.not_set or
                                (self.area_statistics is not None and self.area_statistics.has_operation()) or
                                (self.flood_list_area_table is not None and self.flood_list_area_table.has_operation()) or
                                (self.interface_briefs is not None and self.interface_briefs.has_operation()) or
                                (self.interfaces is not None and self.interfaces.has_operation()) or
                                (self.neighbor_details is not None and self.neighbor_details.has_operation()) or
                                (self.neighbors is not None and self.neighbors.has_operation()) or
                                (self.requests is not None and self.requests.has_operation()) or
                                (self.retransmissions is not None and self.retransmissions.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "area" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.area_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "area-statistics"):
                                if (self.area_statistics is None):
                                    self.area_statistics = Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics()
                                    self.area_statistics.parent = self
                                    self._children_name_map["area_statistics"] = "area-statistics"
                                return self.area_statistics

                            if (child_yang_name == "flood-list-area-table"):
                                if (self.flood_list_area_table is None):
                                    self.flood_list_area_table = Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable()
                                    self.flood_list_area_table.parent = self
                                    self._children_name_map["flood_list_area_table"] = "flood-list-area-table"
                                return self.flood_list_area_table

                            if (child_yang_name == "interface-briefs"):
                                if (self.interface_briefs is None):
                                    self.interface_briefs = Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs()
                                    self.interface_briefs.parent = self
                                    self._children_name_map["interface_briefs"] = "interface-briefs"
                                return self.interface_briefs

                            if (child_yang_name == "interfaces"):
                                if (self.interfaces is None):
                                    self.interfaces = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces()
                                    self.interfaces.parent = self
                                    self._children_name_map["interfaces"] = "interfaces"
                                return self.interfaces

                            if (child_yang_name == "neighbor-details"):
                                if (self.neighbor_details is None):
                                    self.neighbor_details = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails()
                                    self.neighbor_details.parent = self
                                    self._children_name_map["neighbor_details"] = "neighbor-details"
                                return self.neighbor_details

                            if (child_yang_name == "neighbors"):
                                if (self.neighbors is None):
                                    self.neighbors = Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors()
                                    self.neighbors.parent = self
                                    self._children_name_map["neighbors"] = "neighbors"
                                return self.neighbors

                            if (child_yang_name == "requests"):
                                if (self.requests is None):
                                    self.requests = Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests()
                                    self.requests.parent = self
                                    self._children_name_map["requests"] = "requests"
                                return self.requests

                            if (child_yang_name == "retransmissions"):
                                if (self.retransmissions is None):
                                    self.retransmissions = Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions()
                                    self.retransmissions.parent = self
                                    self._children_name_map["retransmissions"] = "retransmissions"
                                return self.retransmissions

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "area-statistics" or name == "flood-list-area-table" or name == "interface-briefs" or name == "interfaces" or name == "neighbor-details" or name == "neighbors" or name == "requests" or name == "retransmissions" or name == "area-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "area-id"):
                                self.area_id = value
                                self.area_id.value_namespace = name_space
                                self.area_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.area:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.area:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "areas" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "area"):
                            for c in self.area:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ospf.Processes.Process.DefaultVrf.Areas.Area()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.area.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "area"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Database(Entity):
                    """
                    OSPF Link State Database
                    
                    .. attribute:: database_areas
                    
                    	Per\-Area view of Link state database
                    	**type**\:   :py:class:`DatabaseAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas>`
                    
                    .. attribute:: database_summaries
                    
                    	Link State database summary table
                    	**type**\:   :py:class:`DatabaseSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries>`
                    
                    .. attribute:: database_summary_as
                    
                    	Link State Database summary for the AS
                    	**type**\:   :py:class:`DatabaseSummaryAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs>`
                    
                    .. attribute:: lsa_summaries
                    
                    	Link state advertisement summary table
                    	**type**\:   :py:class:`LsaSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries>`
                    
                    .. attribute:: lsas
                    
                    	Link State Database Table
                    	**type**\:   :py:class:`Lsas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Database, self).__init__()

                        self.yang_name = "database"
                        self.yang_parent_name = "default-vrf"

                        self.database_areas = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas()
                        self.database_areas.parent = self
                        self._children_name_map["database_areas"] = "database-areas"
                        self._children_yang_names.add("database-areas")

                        self.database_summaries = Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries()
                        self.database_summaries.parent = self
                        self._children_name_map["database_summaries"] = "database-summaries"
                        self._children_yang_names.add("database-summaries")

                        self.database_summary_as = Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs()
                        self.database_summary_as.parent = self
                        self._children_name_map["database_summary_as"] = "database-summary-as"
                        self._children_yang_names.add("database-summary-as")

                        self.lsa_summaries = Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries()
                        self.lsa_summaries.parent = self
                        self._children_name_map["lsa_summaries"] = "lsa-summaries"
                        self._children_yang_names.add("lsa-summaries")

                        self.lsas = Ospf.Processes.Process.DefaultVrf.Database.Lsas()
                        self.lsas.parent = self
                        self._children_name_map["lsas"] = "lsas"
                        self._children_yang_names.add("lsas")


                    class DatabaseAreas(Entity):
                        """
                        Per\-Area view of Link state database
                        
                        .. attribute:: database_area
                        
                        	Per\-Area Link State Database data
                        	**type**\: list of    :py:class:`DatabaseArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas, self).__init__()

                            self.yang_name = "database-areas"
                            self.yang_parent_name = "database"

                            self.database_area = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas, self).__setattr__(name, value)


                        class DatabaseArea(Entity):
                            """
                            Per\-Area Link State Database data
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: lsa_summaries
                            
                            	Link state advertisement summary table
                            	**type**\:   :py:class:`LsaSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries>`
                            
                            .. attribute:: lsas
                            
                            	Link State Database Table
                            	**type**\:   :py:class:`Lsas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea, self).__init__()

                                self.yang_name = "database-area"
                                self.yang_parent_name = "database-areas"

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.lsa_summaries = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries()
                                self.lsa_summaries.parent = self
                                self._children_name_map["lsa_summaries"] = "lsa-summaries"
                                self._children_yang_names.add("lsa-summaries")

                                self.lsas = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas()
                                self.lsas.parent = self
                                self._children_name_map["lsas"] = "lsas"
                                self._children_yang_names.add("lsas")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("area_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea, self).__setattr__(name, value)


                            class Lsas(Entity):
                                """
                                Link State Database Table
                                
                                .. attribute:: lsa
                                
                                	Link State Advertisement information
                                	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas, self).__init__()

                                    self.yang_name = "lsas"
                                    self.yang_parent_name = "database-area"

                                    self.lsa = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas, self).__setattr__(name, value)


                                class Lsa(Entity):
                                    """
                                    Link State Advertisement information
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Advertising Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: interface_name
                                    
                                    	InterfaceName
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: ls_id
                                    
                                    	Link state ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ls_type
                                    
                                    	Link state type
                                    	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                                    
                                    .. attribute:: lsa_detail_data
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetailData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader>`
                                    
                                    .. attribute:: lsa_internal_data
                                    
                                    	Information pertaining to a specific LSA type
                                    	**type**\:   :py:class:`LsaInternalData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa, self).__init__()

                                        self.yang_name = "lsa"
                                        self.yang_parent_name = "lsas"

                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                        self.area_id = YLeaf(YType.int32, "area-id")

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.ls_id = YLeaf(YType.str, "ls-id")

                                        self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                        self.lsa_detail_data = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData()
                                        self.lsa_detail_data.parent = self
                                        self._children_name_map["lsa_detail_data"] = "lsa-detail-data"
                                        self._children_yang_names.add("lsa-detail-data")

                                        self.lsa_header = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")

                                        self.lsa_internal_data = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData()
                                        self.lsa_internal_data.parent = self
                                        self._children_name_map["lsa_internal_data"] = "lsa-internal-data"
                                        self._children_yang_names.add("lsa-internal-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("advertising_router",
                                                        "area_id",
                                                        "interface_name",
                                                        "ls_id",
                                                        "ls_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa, self).__setattr__(name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: dn_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsid
                                        
                                        	LS ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: nsf
                                        
                                        	If true,  LSA received from neighbor during NSF
                                        	**type**\:  bool
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "lsa"

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                            self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsid = YLeaf(YType.str, "lsid")

                                            self.nsf = YLeaf(YType.boolean, "nsf")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("advertising_router",
                                                            "checksum",
                                                            "dn_age_lsa",
                                                            "ls_type",
                                                            "lsa_age",
                                                            "lsa_area_id",
                                                            "lsid",
                                                            "nsf",
                                                            "sequence_number") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.advertising_router.is_set or
                                                self.checksum.is_set or
                                                self.dn_age_lsa.is_set or
                                                self.ls_type.is_set or
                                                self.lsa_age.is_set or
                                                self.lsa_area_id.is_set or
                                                self.lsid.is_set or
                                                self.nsf.is_set or
                                                self.sequence_number.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.advertising_router.yfilter != YFilter.not_set or
                                                self.checksum.yfilter != YFilter.not_set or
                                                self.dn_age_lsa.yfilter != YFilter.not_set or
                                                self.ls_type.yfilter != YFilter.not_set or
                                                self.lsa_age.yfilter != YFilter.not_set or
                                                self.lsa_area_id.yfilter != YFilter.not_set or
                                                self.lsid.yfilter != YFilter.not_set or
                                                self.nsf.yfilter != YFilter.not_set or
                                                self.sequence_number.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "lsa-header" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                            if (self.checksum.is_set or self.checksum.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.checksum.get_name_leafdata())
                                            if (self.dn_age_lsa.is_set or self.dn_age_lsa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dn_age_lsa.get_name_leafdata())
                                            if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ls_type.get_name_leafdata())
                                            if (self.lsa_age.is_set or self.lsa_age.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_age.get_name_leafdata())
                                            if (self.lsa_area_id.is_set or self.lsa_area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_area_id.get_name_leafdata())
                                            if (self.lsid.is_set or self.lsid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsid.get_name_leafdata())
                                            if (self.nsf.is_set or self.nsf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nsf.get_name_leafdata())
                                            if (self.sequence_number.is_set or self.sequence_number.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "advertising-router" or name == "checksum" or name == "dn-age-lsa" or name == "ls-type" or name == "lsa-age" or name == "lsa-area-id" or name == "lsid" or name == "nsf" or name == "sequence-number"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "advertising-router"):
                                                self.advertising_router = value
                                                self.advertising_router.value_namespace = name_space
                                                self.advertising_router.value_namespace_prefix = name_space_prefix
                                            if(value_path == "checksum"):
                                                self.checksum = value
                                                self.checksum.value_namespace = name_space
                                                self.checksum.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dn-age-lsa"):
                                                self.dn_age_lsa = value
                                                self.dn_age_lsa.value_namespace = name_space
                                                self.dn_age_lsa.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ls-type"):
                                                self.ls_type = value
                                                self.ls_type.value_namespace = name_space
                                                self.ls_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-age"):
                                                self.lsa_age = value
                                                self.lsa_age.value_namespace = name_space
                                                self.lsa_age.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-area-id"):
                                                self.lsa_area_id = value
                                                self.lsa_area_id.value_namespace = name_space
                                                self.lsa_area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsid"):
                                                self.lsid = value
                                                self.lsid.value_namespace = name_space
                                                self.lsid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "nsf"):
                                                self.nsf = value
                                                self.nsf.value_namespace = name_space
                                                self.nsf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number"):
                                                self.sequence_number = value
                                                self.sequence_number.value_namespace = name_space
                                                self.sequence_number.value_namespace_prefix = name_space_prefix


                                    class LsaDetailData(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: ase_origin
                                        
                                        	External Origin
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: demand_circuit
                                        
                                        	If true, capable of demand circuit as indicated by LSA's option field
                                        	**type**\:  bool
                                        
                                        .. attribute:: dn_bit
                                        
                                        	if true, DN bit set on the summary LSA indicated by LSA's option field
                                        	**type**\:  bool
                                        
                                        .. attribute:: in_sync
                                        
                                        	Not In Sync With Active
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_last_updated_time
                                        
                                        	Time LSA was last updated
                                        	**type**\:   :py:class:`LsaLastUpdatedTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime>`
                                        
                                        .. attribute:: lsa_prefix_priority
                                        
                                        	Current LSA prefix priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: lsa_rate_limit_due_time
                                        
                                        	Due time for rate\-limit timer (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_throttle_timer
                                        
                                        	LSA throttle timer table information
                                        	**type**\:   :py:class:`LsaThrottleTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer>`
                                        
                                        .. attribute:: lsadb_base_clock
                                        
                                        	Clock stamp since boot
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: lsadb_base_time_stamp
                                        
                                        	Current time stamp
                                        	**type**\:   :py:class:`LsadbBaseTimeStamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp>`
                                        
                                        .. attribute:: new_lsa_prefix_priority
                                        
                                        	New LSA prefix priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: not_delete
                                        
                                        	Reason why LSA is not deleted
                                        	**type**\:   :py:class:`NotDelete <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete>`
                                        
                                        .. attribute:: nssa_translation
                                        
                                        	If true,  capable of type 7 to 5 translation indicated by LSA's option field
                                        	**type**\:  bool
                                        
                                        .. attribute:: routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: sum_origin
                                        
                                        	Summary Origin
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tos_capable
                                        
                                        	If true, type of service capable indicated by LSA's option field
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData, self).__init__()

                                            self.yang_name = "lsa-detail-data"
                                            self.yang_parent_name = "lsa"

                                            self.advertising_router_reachable = YLeaf(YType.boolean, "advertising-router-reachable")

                                            self.ase_origin = YLeaf(YType.uint16, "ase-origin")

                                            self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                            self.dn_bit = YLeaf(YType.boolean, "dn-bit")

                                            self.in_sync = YLeaf(YType.uint8, "in-sync")

                                            self.length = YLeaf(YType.uint16, "length")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_prefix_priority = YLeaf(YType.uint8, "lsa-prefix-priority")

                                            self.lsa_rate_limit_due_time = YLeaf(YType.uint32, "lsa-rate-limit-due-time")

                                            self.lsadb_base_clock = YLeaf(YType.uint64, "lsadb-base-clock")

                                            self.new_lsa_prefix_priority = YLeaf(YType.uint8, "new-lsa-prefix-priority")

                                            self.nssa_translation = YLeaf(YType.boolean, "nssa-translation")

                                            self.routing_bit = YLeaf(YType.boolean, "routing-bit")

                                            self.sum_origin = YLeaf(YType.uint16, "sum-origin")

                                            self.tos_capable = YLeaf(YType.boolean, "tos-capable")

                                            self.lsa_last_updated_time = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime()
                                            self.lsa_last_updated_time.parent = self
                                            self._children_name_map["lsa_last_updated_time"] = "lsa-last-updated-time"
                                            self._children_yang_names.add("lsa-last-updated-time")

                                            self.lsa_throttle_timer = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer()
                                            self.lsa_throttle_timer.parent = self
                                            self._children_name_map["lsa_throttle_timer"] = "lsa-throttle-timer"
                                            self._children_yang_names.add("lsa-throttle-timer")

                                            self.lsadb_base_time_stamp = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp()
                                            self.lsadb_base_time_stamp.parent = self
                                            self._children_name_map["lsadb_base_time_stamp"] = "lsadb-base-time-stamp"
                                            self._children_yang_names.add("lsadb-base-time-stamp")

                                            self.not_delete = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete()
                                            self.not_delete.parent = self
                                            self._children_name_map["not_delete"] = "not-delete"
                                            self._children_yang_names.add("not-delete")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("advertising_router_reachable",
                                                            "ase_origin",
                                                            "demand_circuit",
                                                            "dn_bit",
                                                            "in_sync",
                                                            "length",
                                                            "lsa_flood_required_post_fail_over",
                                                            "lsa_prefix_priority",
                                                            "lsa_rate_limit_due_time",
                                                            "lsadb_base_clock",
                                                            "new_lsa_prefix_priority",
                                                            "nssa_translation",
                                                            "routing_bit",
                                                            "sum_origin",
                                                            "tos_capable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData, self).__setattr__(name, value)


                                        class LsaThrottleTimer(Entity):
                                            """
                                            LSA throttle timer table information
                                            
                                            .. attribute:: last_inst_minute_table_index
                                            
                                            	Last Minute table index processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: last_inst_second_table_index
                                            
                                            	Last Second table index processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timer_location
                                            
                                            	Timer table
                                            	**type**\:   :py:class:`TimerTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.TimerTable>`
                                            
                                            .. attribute:: timer_type
                                            
                                            	Timer type
                                            	**type**\:   :py:class:`Timer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Timer>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__init__()

                                                self.yang_name = "lsa-throttle-timer"
                                                self.yang_parent_name = "lsa-detail-data"

                                                self.last_inst_minute_table_index = YLeaf(YType.uint8, "last-inst-minute-table-index")

                                                self.last_inst_second_table_index = YLeaf(YType.uint8, "last-inst-second-table-index")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")

                                                self.timer_location = YLeaf(YType.enumeration, "timer-location")

                                                self.timer_type = YLeaf(YType.enumeration, "timer-type")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("last_inst_minute_table_index",
                                                                "last_inst_second_table_index",
                                                                "minute_table_index",
                                                                "second_table_index",
                                                                "timer_location",
                                                                "timer_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.last_inst_minute_table_index.is_set or
                                                    self.last_inst_second_table_index.is_set or
                                                    self.minute_table_index.is_set or
                                                    self.second_table_index.is_set or
                                                    self.timer_location.is_set or
                                                    self.timer_type.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.last_inst_minute_table_index.yfilter != YFilter.not_set or
                                                    self.last_inst_second_table_index.yfilter != YFilter.not_set or
                                                    self.minute_table_index.yfilter != YFilter.not_set or
                                                    self.second_table_index.yfilter != YFilter.not_set or
                                                    self.timer_location.yfilter != YFilter.not_set or
                                                    self.timer_type.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "lsa-throttle-timer" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.last_inst_minute_table_index.is_set or self.last_inst_minute_table_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_inst_minute_table_index.get_name_leafdata())
                                                if (self.last_inst_second_table_index.is_set or self.last_inst_second_table_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_inst_second_table_index.get_name_leafdata())
                                                if (self.minute_table_index.is_set or self.minute_table_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.minute_table_index.get_name_leafdata())
                                                if (self.second_table_index.is_set or self.second_table_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second_table_index.get_name_leafdata())
                                                if (self.timer_location.is_set or self.timer_location.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timer_location.get_name_leafdata())
                                                if (self.timer_type.is_set or self.timer_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timer_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "last-inst-minute-table-index" or name == "last-inst-second-table-index" or name == "minute-table-index" or name == "second-table-index" or name == "timer-location" or name == "timer-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "last-inst-minute-table-index"):
                                                    self.last_inst_minute_table_index = value
                                                    self.last_inst_minute_table_index.value_namespace = name_space
                                                    self.last_inst_minute_table_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-inst-second-table-index"):
                                                    self.last_inst_second_table_index = value
                                                    self.last_inst_second_table_index.value_namespace = name_space
                                                    self.last_inst_second_table_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "minute-table-index"):
                                                    self.minute_table_index = value
                                                    self.minute_table_index.value_namespace = name_space
                                                    self.minute_table_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second-table-index"):
                                                    self.second_table_index = value
                                                    self.second_table_index.value_namespace = name_space
                                                    self.second_table_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timer-location"):
                                                    self.timer_location = value
                                                    self.timer_location.value_namespace = name_space
                                                    self.timer_location.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timer-type"):
                                                    self.timer_type = value
                                                    self.timer_type.value_namespace = name_space
                                                    self.timer_type.value_namespace_prefix = name_space_prefix


                                        class LsaLastUpdatedTime(Entity):
                                            """
                                            Time LSA was last updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__init__()

                                                self.yang_name = "lsa-last-updated-time"
                                                self.yang_parent_name = "lsa-detail-data"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "lsa-last-updated-time" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix


                                        class LsadbBaseTimeStamp(Entity):
                                            """
                                            Current time stamp
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__init__()

                                                self.yang_name = "lsadb-base-time-stamp"
                                                self.yang_parent_name = "lsa-detail-data"

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nanosecond",
                                                                "second") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nanosecond.is_set or
                                                    self.second.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nanosecond.yfilter != YFilter.not_set or
                                                    self.second.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "lsadb-base-time-stamp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                                if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.second.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nanosecond" or name == "second"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nanosecond"):
                                                    self.nanosecond = value
                                                    self.nanosecond.value_namespace = name_space
                                                    self.nanosecond.value_namespace_prefix = name_space_prefix
                                                if(value_path == "second"):
                                                    self.second = value
                                                    self.second.value_namespace = name_space
                                                    self.second.value_namespace_prefix = name_space_prefix


                                        class NotDelete(Entity):
                                            """
                                            Reason why LSA is not deleted
                                            
                                            .. attribute:: acknowledgement
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty
                                            	**type**\:  bool
                                            
                                            .. attribute:: flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_age
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table
                                            	**type**\:  bool
                                            
                                            .. attribute:: sum_orig_pending
                                            
                                            	If true, the reason not to delete this LSA is because it is pending summary LSA originating
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete, self).__init__()

                                                self.yang_name = "not-delete"
                                                self.yang_parent_name = "lsa-detail-data"

                                                self.acknowledgement = YLeaf(YType.boolean, "acknowledgement")

                                                self.flood_pending = YLeaf(YType.boolean, "flood-pending")

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.maximum_age = YLeaf(YType.boolean, "maximum-age")

                                                self.neighbor_exchange = YLeaf(YType.boolean, "neighbor-exchange")

                                                self.no_delete = YLeaf(YType.boolean, "no-delete")

                                                self.nsr_ack_pending = YLeaf(YType.boolean, "nsr-ack-pending")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.partial_spf = YLeaf(YType.boolean, "partial-spf")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.routing_table = YLeaf(YType.boolean, "routing-table")

                                                self.sum_orig_pending = YLeaf(YType.boolean, "sum-orig-pending")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("acknowledgement",
                                                                "flood_pending",
                                                                "free_time",
                                                                "maximum_age",
                                                                "neighbor_exchange",
                                                                "no_delete",
                                                                "nsr_ack_pending",
                                                                "nsr_flood_required",
                                                                "partial_spf",
                                                                "rate_limit",
                                                                "routing_table",
                                                                "sum_orig_pending") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.acknowledgement.is_set or
                                                    self.flood_pending.is_set or
                                                    self.free_time.is_set or
                                                    self.maximum_age.is_set or
                                                    self.neighbor_exchange.is_set or
                                                    self.no_delete.is_set or
                                                    self.nsr_ack_pending.is_set or
                                                    self.nsr_flood_required.is_set or
                                                    self.partial_spf.is_set or
                                                    self.rate_limit.is_set or
                                                    self.routing_table.is_set or
                                                    self.sum_orig_pending.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.acknowledgement.yfilter != YFilter.not_set or
                                                    self.flood_pending.yfilter != YFilter.not_set or
                                                    self.free_time.yfilter != YFilter.not_set or
                                                    self.maximum_age.yfilter != YFilter.not_set or
                                                    self.neighbor_exchange.yfilter != YFilter.not_set or
                                                    self.no_delete.yfilter != YFilter.not_set or
                                                    self.nsr_ack_pending.yfilter != YFilter.not_set or
                                                    self.nsr_flood_required.yfilter != YFilter.not_set or
                                                    self.partial_spf.yfilter != YFilter.not_set or
                                                    self.rate_limit.yfilter != YFilter.not_set or
                                                    self.routing_table.yfilter != YFilter.not_set or
                                                    self.sum_orig_pending.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "not-delete" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.acknowledgement.is_set or self.acknowledgement.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.acknowledgement.get_name_leafdata())
                                                if (self.flood_pending.is_set or self.flood_pending.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flood_pending.get_name_leafdata())
                                                if (self.free_time.is_set or self.free_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.free_time.get_name_leafdata())
                                                if (self.maximum_age.is_set or self.maximum_age.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_age.get_name_leafdata())
                                                if (self.neighbor_exchange.is_set or self.neighbor_exchange.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_exchange.get_name_leafdata())
                                                if (self.no_delete.is_set or self.no_delete.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.no_delete.get_name_leafdata())
                                                if (self.nsr_ack_pending.is_set or self.nsr_ack_pending.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nsr_ack_pending.get_name_leafdata())
                                                if (self.nsr_flood_required.is_set or self.nsr_flood_required.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nsr_flood_required.get_name_leafdata())
                                                if (self.partial_spf.is_set or self.partial_spf.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.partial_spf.get_name_leafdata())
                                                if (self.rate_limit.is_set or self.rate_limit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rate_limit.get_name_leafdata())
                                                if (self.routing_table.is_set or self.routing_table.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.routing_table.get_name_leafdata())
                                                if (self.sum_orig_pending.is_set or self.sum_orig_pending.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sum_orig_pending.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "acknowledgement" or name == "flood-pending" or name == "free-time" or name == "maximum-age" or name == "neighbor-exchange" or name == "no-delete" or name == "nsr-ack-pending" or name == "nsr-flood-required" or name == "partial-spf" or name == "rate-limit" or name == "routing-table" or name == "sum-orig-pending"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "acknowledgement"):
                                                    self.acknowledgement = value
                                                    self.acknowledgement.value_namespace = name_space
                                                    self.acknowledgement.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flood-pending"):
                                                    self.flood_pending = value
                                                    self.flood_pending.value_namespace = name_space
                                                    self.flood_pending.value_namespace_prefix = name_space_prefix
                                                if(value_path == "free-time"):
                                                    self.free_time = value
                                                    self.free_time.value_namespace = name_space
                                                    self.free_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-age"):
                                                    self.maximum_age = value
                                                    self.maximum_age.value_namespace = name_space
                                                    self.maximum_age.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-exchange"):
                                                    self.neighbor_exchange = value
                                                    self.neighbor_exchange.value_namespace = name_space
                                                    self.neighbor_exchange.value_namespace_prefix = name_space_prefix
                                                if(value_path == "no-delete"):
                                                    self.no_delete = value
                                                    self.no_delete.value_namespace = name_space
                                                    self.no_delete.value_namespace_prefix = name_space_prefix
                                                if(value_path == "nsr-ack-pending"):
                                                    self.nsr_ack_pending = value
                                                    self.nsr_ack_pending.value_namespace = name_space
                                                    self.nsr_ack_pending.value_namespace_prefix = name_space_prefix
                                                if(value_path == "nsr-flood-required"):
                                                    self.nsr_flood_required = value
                                                    self.nsr_flood_required.value_namespace = name_space
                                                    self.nsr_flood_required.value_namespace_prefix = name_space_prefix
                                                if(value_path == "partial-spf"):
                                                    self.partial_spf = value
                                                    self.partial_spf.value_namespace = name_space
                                                    self.partial_spf.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rate-limit"):
                                                    self.rate_limit = value
                                                    self.rate_limit.value_namespace = name_space
                                                    self.rate_limit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "routing-table"):
                                                    self.routing_table = value
                                                    self.routing_table.value_namespace = name_space
                                                    self.routing_table.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sum-orig-pending"):
                                                    self.sum_orig_pending = value
                                                    self.sum_orig_pending.value_namespace = name_space
                                                    self.sum_orig_pending.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.advertising_router_reachable.is_set or
                                                self.ase_origin.is_set or
                                                self.demand_circuit.is_set or
                                                self.dn_bit.is_set or
                                                self.in_sync.is_set or
                                                self.length.is_set or
                                                self.lsa_flood_required_post_fail_over.is_set or
                                                self.lsa_prefix_priority.is_set or
                                                self.lsa_rate_limit_due_time.is_set or
                                                self.lsadb_base_clock.is_set or
                                                self.new_lsa_prefix_priority.is_set or
                                                self.nssa_translation.is_set or
                                                self.routing_bit.is_set or
                                                self.sum_origin.is_set or
                                                self.tos_capable.is_set or
                                                (self.lsa_last_updated_time is not None and self.lsa_last_updated_time.has_data()) or
                                                (self.lsa_throttle_timer is not None and self.lsa_throttle_timer.has_data()) or
                                                (self.lsadb_base_time_stamp is not None and self.lsadb_base_time_stamp.has_data()) or
                                                (self.not_delete is not None and self.not_delete.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.advertising_router_reachable.yfilter != YFilter.not_set or
                                                self.ase_origin.yfilter != YFilter.not_set or
                                                self.demand_circuit.yfilter != YFilter.not_set or
                                                self.dn_bit.yfilter != YFilter.not_set or
                                                self.in_sync.yfilter != YFilter.not_set or
                                                self.length.yfilter != YFilter.not_set or
                                                self.lsa_flood_required_post_fail_over.yfilter != YFilter.not_set or
                                                self.lsa_prefix_priority.yfilter != YFilter.not_set or
                                                self.lsa_rate_limit_due_time.yfilter != YFilter.not_set or
                                                self.lsadb_base_clock.yfilter != YFilter.not_set or
                                                self.new_lsa_prefix_priority.yfilter != YFilter.not_set or
                                                self.nssa_translation.yfilter != YFilter.not_set or
                                                self.routing_bit.yfilter != YFilter.not_set or
                                                self.sum_origin.yfilter != YFilter.not_set or
                                                self.tos_capable.yfilter != YFilter.not_set or
                                                (self.lsa_last_updated_time is not None and self.lsa_last_updated_time.has_operation()) or
                                                (self.lsa_throttle_timer is not None and self.lsa_throttle_timer.has_operation()) or
                                                (self.lsadb_base_time_stamp is not None and self.lsadb_base_time_stamp.has_operation()) or
                                                (self.not_delete is not None and self.not_delete.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "lsa-detail-data" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.advertising_router_reachable.is_set or self.advertising_router_reachable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertising_router_reachable.get_name_leafdata())
                                            if (self.ase_origin.is_set or self.ase_origin.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ase_origin.get_name_leafdata())
                                            if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                                            if (self.dn_bit.is_set or self.dn_bit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dn_bit.get_name_leafdata())
                                            if (self.in_sync.is_set or self.in_sync.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.in_sync.get_name_leafdata())
                                            if (self.length.is_set or self.length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.length.get_name_leafdata())
                                            if (self.lsa_flood_required_post_fail_over.is_set or self.lsa_flood_required_post_fail_over.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_flood_required_post_fail_over.get_name_leafdata())
                                            if (self.lsa_prefix_priority.is_set or self.lsa_prefix_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_prefix_priority.get_name_leafdata())
                                            if (self.lsa_rate_limit_due_time.is_set or self.lsa_rate_limit_due_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_rate_limit_due_time.get_name_leafdata())
                                            if (self.lsadb_base_clock.is_set or self.lsadb_base_clock.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsadb_base_clock.get_name_leafdata())
                                            if (self.new_lsa_prefix_priority.is_set or self.new_lsa_prefix_priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.new_lsa_prefix_priority.get_name_leafdata())
                                            if (self.nssa_translation.is_set or self.nssa_translation.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nssa_translation.get_name_leafdata())
                                            if (self.routing_bit.is_set or self.routing_bit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.routing_bit.get_name_leafdata())
                                            if (self.sum_origin.is_set or self.sum_origin.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sum_origin.get_name_leafdata())
                                            if (self.tos_capable.is_set or self.tos_capable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tos_capable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "lsa-last-updated-time"):
                                                if (self.lsa_last_updated_time is None):
                                                    self.lsa_last_updated_time = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime()
                                                    self.lsa_last_updated_time.parent = self
                                                    self._children_name_map["lsa_last_updated_time"] = "lsa-last-updated-time"
                                                return self.lsa_last_updated_time

                                            if (child_yang_name == "lsa-throttle-timer"):
                                                if (self.lsa_throttle_timer is None):
                                                    self.lsa_throttle_timer = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer()
                                                    self.lsa_throttle_timer.parent = self
                                                    self._children_name_map["lsa_throttle_timer"] = "lsa-throttle-timer"
                                                return self.lsa_throttle_timer

                                            if (child_yang_name == "lsadb-base-time-stamp"):
                                                if (self.lsadb_base_time_stamp is None):
                                                    self.lsadb_base_time_stamp = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp()
                                                    self.lsadb_base_time_stamp.parent = self
                                                    self._children_name_map["lsadb_base_time_stamp"] = "lsadb-base-time-stamp"
                                                return self.lsadb_base_time_stamp

                                            if (child_yang_name == "not-delete"):
                                                if (self.not_delete is None):
                                                    self.not_delete = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete()
                                                    self.not_delete.parent = self
                                                    self._children_name_map["not_delete"] = "not-delete"
                                                return self.not_delete

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lsa-last-updated-time" or name == "lsa-throttle-timer" or name == "lsadb-base-time-stamp" or name == "not-delete" or name == "advertising-router-reachable" or name == "ase-origin" or name == "demand-circuit" or name == "dn-bit" or name == "in-sync" or name == "length" or name == "lsa-flood-required-post-fail-over" or name == "lsa-prefix-priority" or name == "lsa-rate-limit-due-time" or name == "lsadb-base-clock" or name == "new-lsa-prefix-priority" or name == "nssa-translation" or name == "routing-bit" or name == "sum-origin" or name == "tos-capable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "advertising-router-reachable"):
                                                self.advertising_router_reachable = value
                                                self.advertising_router_reachable.value_namespace = name_space
                                                self.advertising_router_reachable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ase-origin"):
                                                self.ase_origin = value
                                                self.ase_origin.value_namespace = name_space
                                                self.ase_origin.value_namespace_prefix = name_space_prefix
                                            if(value_path == "demand-circuit"):
                                                self.demand_circuit = value
                                                self.demand_circuit.value_namespace = name_space
                                                self.demand_circuit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dn-bit"):
                                                self.dn_bit = value
                                                self.dn_bit.value_namespace = name_space
                                                self.dn_bit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "in-sync"):
                                                self.in_sync = value
                                                self.in_sync.value_namespace = name_space
                                                self.in_sync.value_namespace_prefix = name_space_prefix
                                            if(value_path == "length"):
                                                self.length = value
                                                self.length.value_namespace = name_space
                                                self.length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-flood-required-post-fail-over"):
                                                self.lsa_flood_required_post_fail_over = value
                                                self.lsa_flood_required_post_fail_over.value_namespace = name_space
                                                self.lsa_flood_required_post_fail_over.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-prefix-priority"):
                                                self.lsa_prefix_priority = value
                                                self.lsa_prefix_priority.value_namespace = name_space
                                                self.lsa_prefix_priority.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-rate-limit-due-time"):
                                                self.lsa_rate_limit_due_time = value
                                                self.lsa_rate_limit_due_time.value_namespace = name_space
                                                self.lsa_rate_limit_due_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsadb-base-clock"):
                                                self.lsadb_base_clock = value
                                                self.lsadb_base_clock.value_namespace = name_space
                                                self.lsadb_base_clock.value_namespace_prefix = name_space_prefix
                                            if(value_path == "new-lsa-prefix-priority"):
                                                self.new_lsa_prefix_priority = value
                                                self.new_lsa_prefix_priority.value_namespace = name_space
                                                self.new_lsa_prefix_priority.value_namespace_prefix = name_space_prefix
                                            if(value_path == "nssa-translation"):
                                                self.nssa_translation = value
                                                self.nssa_translation.value_namespace = name_space
                                                self.nssa_translation.value_namespace_prefix = name_space_prefix
                                            if(value_path == "routing-bit"):
                                                self.routing_bit = value
                                                self.routing_bit.value_namespace = name_space
                                                self.routing_bit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sum-origin"):
                                                self.sum_origin = value
                                                self.sum_origin.value_namespace = name_space
                                                self.sum_origin.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tos-capable"):
                                                self.tos_capable = value
                                                self.tos_capable.value_namespace = name_space
                                                self.tos_capable.value_namespace_prefix = name_space_prefix


                                    class LsaInternalData(Entity):
                                        """
                                        Information pertaining to a specific LSA type
                                        
                                        .. attribute:: external_lsa_type
                                        
                                        	External LSA
                                        	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType>`
                                        
                                        .. attribute:: internal_lsa_type
                                        
                                        	InternalLSAType
                                        	**type**\:   :py:class:`OspfInternalLsaTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInternalLsaTypes>`
                                        
                                        .. attribute:: network_lsa_type
                                        
                                        	Network LSA
                                        	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType>`
                                        
                                        .. attribute:: opaque_el_lsa_type
                                        
                                        	Extended Link LSA type
                                        	**type**\:   :py:class:`OpaqueElLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType>`
                                        
                                        .. attribute:: opaque_ep_lsa_type
                                        
                                        	Extende Prefix LSA type
                                        	**type**\:   :py:class:`OpaqueEpLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType>`
                                        
                                        .. attribute:: opaque_grace_lsa
                                        
                                        	Opaque\-link, opaque type 3 Grace LSA
                                        	**type**\:   :py:class:`OpaqueGraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa>`
                                        
                                        .. attribute:: opaque_link_lsa_type
                                        
                                        	Opaque\-Link LSA
                                        	**type**\:   :py:class:`OpaqueLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType>`
                                        
                                        .. attribute:: opaque_mpls_te_lsa_type
                                        
                                        	Opaque\-Area, opaque type 1 LSA
                                        	**type**\:   :py:class:`OpaqueMplsTeLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType>`
                                        
                                        .. attribute:: opaque_router_info_lsa_type
                                        
                                        	Opaque Router Information LSA
                                        	**type**\:   :py:class:`OpaqueRouterInfoLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType>`
                                        
                                        .. attribute:: router_lsa_type
                                        
                                        	Router LSA
                                        	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType>`
                                        
                                        .. attribute:: summary_lsa_type
                                        
                                        	Summary LSA
                                        	**type**\:   :py:class:`SummaryLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData, self).__init__()

                                            self.yang_name = "lsa-internal-data"
                                            self.yang_parent_name = "lsa"

                                            self.internal_lsa_type = YLeaf(YType.enumeration, "internal-lsa-type")

                                            self.external_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType()
                                            self.external_lsa_type.parent = self
                                            self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                            self._children_yang_names.add("external-lsa-type")

                                            self.network_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType()
                                            self.network_lsa_type.parent = self
                                            self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                            self._children_yang_names.add("network-lsa-type")

                                            self.opaque_el_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType()
                                            self.opaque_el_lsa_type.parent = self
                                            self._children_name_map["opaque_el_lsa_type"] = "opaque-el-lsa-type"
                                            self._children_yang_names.add("opaque-el-lsa-type")

                                            self.opaque_ep_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType()
                                            self.opaque_ep_lsa_type.parent = self
                                            self._children_name_map["opaque_ep_lsa_type"] = "opaque-ep-lsa-type"
                                            self._children_yang_names.add("opaque-ep-lsa-type")

                                            self.opaque_grace_lsa = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa()
                                            self.opaque_grace_lsa.parent = self
                                            self._children_name_map["opaque_grace_lsa"] = "opaque-grace-lsa"
                                            self._children_yang_names.add("opaque-grace-lsa")

                                            self.opaque_link_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType()
                                            self.opaque_link_lsa_type.parent = self
                                            self._children_name_map["opaque_link_lsa_type"] = "opaque-link-lsa-type"
                                            self._children_yang_names.add("opaque-link-lsa-type")

                                            self.opaque_mpls_te_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType()
                                            self.opaque_mpls_te_lsa_type.parent = self
                                            self._children_name_map["opaque_mpls_te_lsa_type"] = "opaque-mpls-te-lsa-type"
                                            self._children_yang_names.add("opaque-mpls-te-lsa-type")

                                            self.opaque_router_info_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType()
                                            self.opaque_router_info_lsa_type.parent = self
                                            self._children_name_map["opaque_router_info_lsa_type"] = "opaque-router-info-lsa-type"
                                            self._children_yang_names.add("opaque-router-info-lsa-type")

                                            self.router_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType()
                                            self.router_lsa_type.parent = self
                                            self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                            self._children_yang_names.add("router-lsa-type")

                                            self.summary_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType()
                                            self.summary_lsa_type.parent = self
                                            self._children_name_map["summary_lsa_type"] = "summary-lsa-type"
                                            self._children_yang_names.add("summary-lsa-type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_lsa_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData, self).__setattr__(name, value)


                                        class RouterLsaType(Entity):
                                            """
                                            Router LSA
                                            
                                            .. attribute:: internal_link
                                            
                                            	List of links for internal LSA
                                            	**type**\: list of    :py:class:`InternalLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink>`
                                            
                                            .. attribute:: internal_lsa
                                            
                                            	If true, internal LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: link
                                            
                                            	List of links in this LSA
                                            	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link>`
                                            
                                            .. attribute:: router_abr
                                            
                                            	If True, router is an Area Border Router
                                            	**type**\:  bool
                                            
                                            .. attribute:: router_asbr
                                            
                                            	If True, router is an Autonomous system Border Router
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__init__()

                                                self.yang_name = "router-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"

                                                self.internal_lsa = YLeaf(YType.boolean, "internal-lsa")

                                                self.router_abr = YLeaf(YType.boolean, "router-abr")

                                                self.router_asbr = YLeaf(YType.boolean, "router-asbr")

                                                self.internal_link = YList(self)
                                                self.link = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_lsa",
                                                                "router_abr",
                                                                "router_asbr") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__setattr__(name, value)


                                            class Link(Entity):
                                                """
                                                List of links in this LSA
                                                
                                                .. attribute:: link_data
                                                
                                                	Link Data
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: link_id
                                                
                                                	Link ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: link_metric
                                                
                                                	Cost for using this link
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: link_tos
                                                
                                                	List of type of service metrics
                                                	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos>`
                                                
                                                .. attribute:: link_type
                                                
                                                	Type of link
                                                	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__init__()

                                                    self.yang_name = "link"
                                                    self.yang_parent_name = "router-lsa-type"

                                                    self.link_data = YLeaf(YType.str, "link-data")

                                                    self.link_id = YLeaf(YType.str, "link-id")

                                                    self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                    self.link_type = YLeaf(YType.enumeration, "link-type")

                                                    self.link_tos = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("link_data",
                                                                    "link_id",
                                                                    "link_metric",
                                                                    "link_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__setattr__(name, value)


                                                class LinkTos(Entity):
                                                    """
                                                    List of type of service metrics
                                                    
                                                    .. attribute:: router_tos
                                                    
                                                    	Type of Service
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: tos_cost
                                                    
                                                    	Type of service specific metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__init__()

                                                        self.yang_name = "link-tos"
                                                        self.yang_parent_name = "link"

                                                        self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                        self.tos_cost = YLeaf(YType.uint16, "tos-cost")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("router_tos",
                                                                        "tos_cost") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.router_tos.is_set or
                                                            self.tos_cost.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.router_tos.yfilter != YFilter.not_set or
                                                            self.tos_cost.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "link-tos" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.router_tos.is_set or self.router_tos.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.router_tos.get_name_leafdata())
                                                        if (self.tos_cost.is_set or self.tos_cost.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tos_cost.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "router-tos" or name == "tos-cost"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "router-tos"):
                                                            self.router_tos = value
                                                            self.router_tos.value_namespace = name_space
                                                            self.router_tos.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tos-cost"):
                                                            self.tos_cost = value
                                                            self.tos_cost.value_namespace = name_space
                                                            self.tos_cost.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.link_tos:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.link_data.is_set or
                                                        self.link_id.is_set or
                                                        self.link_metric.is_set or
                                                        self.link_type.is_set)

                                                def has_operation(self):
                                                    for c in self.link_tos:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.link_data.yfilter != YFilter.not_set or
                                                        self.link_id.yfilter != YFilter.not_set or
                                                        self.link_metric.yfilter != YFilter.not_set or
                                                        self.link_type.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "link" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.link_data.is_set or self.link_data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.link_data.get_name_leafdata())
                                                    if (self.link_id.is_set or self.link_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.link_id.get_name_leafdata())
                                                    if (self.link_metric.is_set or self.link_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.link_metric.get_name_leafdata())
                                                    if (self.link_type.is_set or self.link_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.link_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "link-tos"):
                                                        for c in self.link_tos:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.link_tos.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "link-tos" or name == "link-data" or name == "link-id" or name == "link-metric" or name == "link-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "link-data"):
                                                        self.link_data = value
                                                        self.link_data.value_namespace = name_space
                                                        self.link_data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "link-id"):
                                                        self.link_id = value
                                                        self.link_id.value_namespace = name_space
                                                        self.link_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "link-metric"):
                                                        self.link_metric = value
                                                        self.link_metric.value_namespace = name_space
                                                        self.link_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "link-type"):
                                                        self.link_type = value
                                                        self.link_type.value_namespace = name_space
                                                        self.link_type.value_namespace_prefix = name_space_prefix


                                            class InternalLink(Entity):
                                                """
                                                List of links for internal LSA
                                                
                                                .. attribute:: link_data
                                                
                                                	Link Data
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: link_id
                                                
                                                	Link ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: link_metric
                                                
                                                	Cost for using this link
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: link_tos
                                                
                                                	List of type of service metrics
                                                	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos>`
                                                
                                                .. attribute:: link_type
                                                
                                                	Type of link
                                                	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__init__()

                                                    self.yang_name = "internal-link"
                                                    self.yang_parent_name = "router-lsa-type"

                                                    self.link_data = YLeaf(YType.str, "link-data")

                                                    self.link_id = YLeaf(YType.str, "link-id")

                                                    self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                    self.link_type = YLeaf(YType.enumeration, "link-type")

                                                    self.link_tos = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("link_data",
                                                                    "link_id",
                                                                    "link_metric",
                                                                    "link_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__setattr__(name, value)


                                                class LinkTos(Entity):
                                                    """
                                                    List of type of service metrics
                                                    
                                                    .. attribute:: router_tos
                                                    
                                                    	Type of Service
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: tos_cost
                                                    
                                                    	Type of service specific metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__init__()

                                                        self.yang_name = "link-tos"
                                                        self.yang_parent_name = "internal-link"

                                                        self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                        self.tos_cost = YLeaf(YType.uint16, "tos-cost")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("router_tos",
                                                                        "tos_cost") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.router_tos.is_set or
                                                            self.tos_cost.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.router_tos.yfilter != YFilter.not_set or
                                                            self.tos_cost.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "link-tos" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.router_tos.is_set or self.router_tos.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.router_tos.get_name_leafdata())
                                                        if (self.tos_cost.is_set or self.tos_cost.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tos_cost.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "router-tos" or name == "tos-cost"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "router-tos"):
                                                            self.router_tos = value
                                                            self.router_tos.value_namespace = name_space
                                                            self.router_tos.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tos-cost"):
                                                            self.tos_cost = value
                                                            self.tos_cost.value_namespace = name_space
                                                            self.tos_cost.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.link_tos:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.link_data.is_set or
                                                        self.link_id.is_set or
                                                        self.link_metric.is_set or
                                                        self.link_type.is_set)

                                                def has_operation(self):
                                                    for c in self.link_tos:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.link_data.yfilter != YFilter.not_set or
                                                        self.link_id.yfilter != YFilter.not_set or
                                                        self.link_metric.yfilter != YFilter.not_set or
                                                        self.link_type.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "internal-link" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.link_data.is_set or self.link_data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.link_data.get_name_leafdata())
                                                    if (self.link_id.is_set or self.link_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.link_id.get_name_leafdata())
                                                    if (self.link_metric.is_set or self.link_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.link_metric.get_name_leafdata())
                                                    if (self.link_type.is_set or self.link_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.link_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "link-tos"):
                                                        for c in self.link_tos:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.link_tos.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "link-tos" or name == "link-data" or name == "link-id" or name == "link-metric" or name == "link-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "link-data"):
                                                        self.link_data = value
                                                        self.link_data.value_namespace = name_space
                                                        self.link_data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "link-id"):
                                                        self.link_id = value
                                                        self.link_id.value_namespace = name_space
                                                        self.link_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "link-metric"):
                                                        self.link_metric = value
                                                        self.link_metric.value_namespace = name_space
                                                        self.link_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "link-type"):
                                                        self.link_type = value
                                                        self.link_type.value_namespace = name_space
                                                        self.link_type.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.internal_link:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.link:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.internal_lsa.is_set or
                                                    self.router_abr.is_set or
                                                    self.router_asbr.is_set)

                                            def has_operation(self):
                                                for c in self.internal_link:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.link:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_lsa.yfilter != YFilter.not_set or
                                                    self.router_abr.yfilter != YFilter.not_set or
                                                    self.router_asbr.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "router-lsa-type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_lsa.is_set or self.internal_lsa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_lsa.get_name_leafdata())
                                                if (self.router_abr.is_set or self.router_abr.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.router_abr.get_name_leafdata())
                                                if (self.router_asbr.is_set or self.router_asbr.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.router_asbr.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "internal-link"):
                                                    for c in self.internal_link:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.internal_link.append(c)
                                                    return c

                                                if (child_yang_name == "link"):
                                                    for c in self.link:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.link.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "internal-link" or name == "link" or name == "internal-lsa" or name == "router-abr" or name == "router-asbr"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-lsa"):
                                                    self.internal_lsa = value
                                                    self.internal_lsa.value_namespace = name_space
                                                    self.internal_lsa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "router-abr"):
                                                    self.router_abr = value
                                                    self.router_abr.value_namespace = name_space
                                                    self.router_abr.value_namespace_prefix = name_space_prefix
                                                if(value_path == "router-asbr"):
                                                    self.router_asbr = value
                                                    self.router_asbr.value_namespace = name_space
                                                    self.router_asbr.value_namespace_prefix = name_space_prefix


                                        class NetworkLsaType(Entity):
                                            """
                                            Network LSA
                                            
                                            .. attribute:: neighbor_router
                                            
                                            	Neighbor router list
                                            	**type**\: list of    :py:class:`NeighborRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter>`
                                            
                                            .. attribute:: network_prefix_length
                                            
                                            	Network prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__init__()

                                                self.yang_name = "network-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"

                                                self.network_prefix_length = YLeaf(YType.uint32, "network-prefix-length")

                                                self.neighbor_router = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("network_prefix_length") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__setattr__(name, value)


                                            class NeighborRouter(Entity):
                                                """
                                                Neighbor router list
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__init__()

                                                    self.yang_name = "neighbor-router"
                                                    self.yang_parent_name = "network-lsa-type"

                                                    self.entry = YLeaf(YType.str, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "neighbor-router" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.neighbor_router:
                                                    if (c.has_data()):
                                                        return True
                                                return self.network_prefix_length.is_set

                                            def has_operation(self):
                                                for c in self.neighbor_router:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.network_prefix_length.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "network-lsa-type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.network_prefix_length.is_set or self.network_prefix_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.network_prefix_length.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "neighbor-router"):
                                                    for c in self.neighbor_router:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.neighbor_router.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "neighbor-router" or name == "network-prefix-length"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "network-prefix-length"):
                                                    self.network_prefix_length = value
                                                    self.network_prefix_length.value_namespace = name_space
                                                    self.network_prefix_length.value_namespace_prefix = name_space_prefix


                                        class SummaryLsaType(Entity):
                                            """
                                            Summary LSA
                                            
                                            .. attribute:: internal_sum_lsa
                                            
                                            	If true, internal max\-metric LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: summary_lsa_metric
                                            
                                            	Metric
                                            	**type**\: list of    :py:class:`SummaryLsaMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric>`
                                            
                                            .. attribute:: summary_prefix_length
                                            
                                            	Summary LSA prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__init__()

                                                self.yang_name = "summary-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"

                                                self.internal_sum_lsa = YLeaf(YType.boolean, "internal-sum-lsa")

                                                self.summary_prefix_length = YLeaf(YType.uint32, "summary-prefix-length")

                                                self.summary_lsa_metric = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_sum_lsa",
                                                                "summary_prefix_length") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__setattr__(name, value)


                                            class SummaryLsaMetric(Entity):
                                                """
                                                Metric
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__init__()

                                                    self.yang_name = "summary-lsa-metric"
                                                    self.yang_parent_name = "summary-lsa-type"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "summary-lsa-metric" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.summary_lsa_metric:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.internal_sum_lsa.is_set or
                                                    self.summary_prefix_length.is_set)

                                            def has_operation(self):
                                                for c in self.summary_lsa_metric:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_sum_lsa.yfilter != YFilter.not_set or
                                                    self.summary_prefix_length.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "summary-lsa-type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_sum_lsa.is_set or self.internal_sum_lsa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_sum_lsa.get_name_leafdata())
                                                if (self.summary_prefix_length.is_set or self.summary_prefix_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.summary_prefix_length.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "summary-lsa-metric"):
                                                    for c in self.summary_lsa_metric:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.summary_lsa_metric.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "summary-lsa-metric" or name == "internal-sum-lsa" or name == "summary-prefix-length"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-sum-lsa"):
                                                    self.internal_sum_lsa = value
                                                    self.internal_sum_lsa.value_namespace = name_space
                                                    self.internal_sum_lsa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "summary-prefix-length"):
                                                    self.summary_prefix_length = value
                                                    self.summary_prefix_length.value_namespace = name_space
                                                    self.summary_prefix_length.value_namespace_prefix = name_space_prefix


                                        class ExternalLsaType(Entity):
                                            """
                                            External LSA
                                            
                                            .. attribute:: external_prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: external_tos_metric
                                            
                                            	Type of service information
                                            	**type**\: list of    :py:class:`ExternalTosMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric>`
                                            
                                            .. attribute:: internal_external_lsa
                                            
                                            	If true, internal max\-metric LSA
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__init__()

                                                self.yang_name = "external-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"

                                                self.external_prefix_length = YLeaf(YType.uint32, "external-prefix-length")

                                                self.internal_external_lsa = YLeaf(YType.boolean, "internal-external-lsa")

                                                self.external_tos_metric = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("external_prefix_length",
                                                                "internal_external_lsa") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__setattr__(name, value)


                                            class ExternalTosMetric(Entity):
                                                """
                                                Type of service information
                                                
                                                .. attribute:: external_metric
                                                
                                                	Cost of this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: external_metric_type
                                                
                                                	External LSA metric type
                                                	**type**\:   :py:class:`ExMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.ExMetric>`
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: external_tos
                                                
                                                	Type of Service
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__init__()

                                                    self.yang_name = "external-tos-metric"
                                                    self.yang_parent_name = "external-lsa-type"

                                                    self.external_metric = YLeaf(YType.uint32, "external-metric")

                                                    self.external_metric_type = YLeaf(YType.enumeration, "external-metric-type")

                                                    self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                    self.external_tos = YLeaf(YType.uint32, "external-tos")

                                                    self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("external_metric",
                                                                    "external_metric_type",
                                                                    "external_tag",
                                                                    "external_tos",
                                                                    "forwarding_address") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.external_metric.is_set or
                                                        self.external_metric_type.is_set or
                                                        self.external_tag.is_set or
                                                        self.external_tos.is_set or
                                                        self.forwarding_address.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.external_metric.yfilter != YFilter.not_set or
                                                        self.external_metric_type.yfilter != YFilter.not_set or
                                                        self.external_tag.yfilter != YFilter.not_set or
                                                        self.external_tos.yfilter != YFilter.not_set or
                                                        self.forwarding_address.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "external-tos-metric" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.external_metric.is_set or self.external_metric.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.external_metric.get_name_leafdata())
                                                    if (self.external_metric_type.is_set or self.external_metric_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.external_metric_type.get_name_leafdata())
                                                    if (self.external_tag.is_set or self.external_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.external_tag.get_name_leafdata())
                                                    if (self.external_tos.is_set or self.external_tos.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.external_tos.get_name_leafdata())
                                                    if (self.forwarding_address.is_set or self.forwarding_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.forwarding_address.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "external-metric" or name == "external-metric-type" or name == "external-tag" or name == "external-tos" or name == "forwarding-address"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "external-metric"):
                                                        self.external_metric = value
                                                        self.external_metric.value_namespace = name_space
                                                        self.external_metric.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "external-metric-type"):
                                                        self.external_metric_type = value
                                                        self.external_metric_type.value_namespace = name_space
                                                        self.external_metric_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "external-tag"):
                                                        self.external_tag = value
                                                        self.external_tag.value_namespace = name_space
                                                        self.external_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "external-tos"):
                                                        self.external_tos = value
                                                        self.external_tos.value_namespace = name_space
                                                        self.external_tos.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "forwarding-address"):
                                                        self.forwarding_address = value
                                                        self.forwarding_address.value_namespace = name_space
                                                        self.forwarding_address.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.external_tos_metric:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.external_prefix_length.is_set or
                                                    self.internal_external_lsa.is_set)

                                            def has_operation(self):
                                                for c in self.external_tos_metric:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.external_prefix_length.yfilter != YFilter.not_set or
                                                    self.internal_external_lsa.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "external-lsa-type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.external_prefix_length.is_set or self.external_prefix_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.external_prefix_length.get_name_leafdata())
                                                if (self.internal_external_lsa.is_set or self.internal_external_lsa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_external_lsa.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "external-tos-metric"):
                                                    for c in self.external_tos_metric:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.external_tos_metric.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "external-tos-metric" or name == "external-prefix-length" or name == "internal-external-lsa"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "external-prefix-length"):
                                                    self.external_prefix_length = value
                                                    self.external_prefix_length.value_namespace = name_space
                                                    self.external_prefix_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "internal-external-lsa"):
                                                    self.internal_external_lsa = value
                                                    self.internal_external_lsa.value_namespace = name_space
                                                    self.internal_external_lsa.value_namespace_prefix = name_space_prefix


                                        class OpaqueLinkLsaType(Entity):
                                            """
                                            Opaque\-Link LSA
                                            
                                            .. attribute:: opaque_interface_name
                                            
                                            	Interface on which the Opaque link LSA is received
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__init__()

                                                self.yang_name = "opaque-link-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"

                                                self.opaque_interface_name = YLeaf(YType.str, "opaque-interface-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("opaque_interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.opaque_interface_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.opaque_interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "opaque-link-lsa-type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.opaque_interface_name.is_set or self.opaque_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.opaque_interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "opaque-interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "opaque-interface-name"):
                                                    self.opaque_interface_name = value
                                                    self.opaque_interface_name.value_namespace = name_space
                                                    self.opaque_interface_name.value_namespace_prefix = name_space_prefix


                                        class OpaqueMplsTeLsaType(Entity):
                                            """
                                            Opaque\-Area, opaque type 1 LSA
                                            
                                            .. attribute:: tlv
                                            
                                            	List of TLVs
                                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__init__()

                                                self.yang_name = "opaque-mpls-te-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"

                                                self.tlv = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__setattr__(name, value)


                                            class Tlv(Entity):
                                                """
                                                List of TLVs
                                                
                                                .. attribute:: mpls_dste_link
                                                
                                                	MPLS DS\-TE supported
                                                	**type**\:  bool
                                                
                                                .. attribute:: mpls_router_id
                                                
                                                	MPLS\-TE Router ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: te_link_sub_tlv
                                                
                                                	List of Sub\-TLVs
                                                	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv>`
                                                
                                                .. attribute:: tlv_data
                                                
                                                	TLV direct data
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tlv_length
                                                
                                                	Length of top\-level TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: tlv_type
                                                
                                                	Type of top\-level TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__init__()

                                                    self.yang_name = "tlv"
                                                    self.yang_parent_name = "opaque-mpls-te-lsa-type"

                                                    self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                    self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                    self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                    self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                    self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                    self.te_link_sub_tlv = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("mpls_dste_link",
                                                                    "mpls_router_id",
                                                                    "tlv_data",
                                                                    "tlv_length",
                                                                    "tlv_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__setattr__(name, value)


                                                class TeLinkSubTlv(Entity):
                                                    """
                                                    List of Sub\-TLVs
                                                    
                                                    .. attribute:: sub_tlv_length
                                                    
                                                    	Length of sub TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sub_tlv_type
                                                    
                                                    	Type of sub TLV
                                                    	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                    
                                                    .. attribute:: sub_tlv_value
                                                    
                                                    	Value of sub TLV
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                        self.yang_name = "te-link-sub-tlv"
                                                        self.yang_parent_name = "tlv"

                                                        self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                        self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                        self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("sub_tlv_length",
                                                                        "sub_tlv_type",
                                                                        "sub_tlv_value") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.sub_tlv_length.is_set or
                                                            self.sub_tlv_type.is_set or
                                                            self.sub_tlv_value.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.sub_tlv_length.yfilter != YFilter.not_set or
                                                            self.sub_tlv_type.yfilter != YFilter.not_set or
                                                            self.sub_tlv_value.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "te-link-sub-tlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.sub_tlv_length.is_set or self.sub_tlv_length.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sub_tlv_length.get_name_leafdata())
                                                        if (self.sub_tlv_type.is_set or self.sub_tlv_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sub_tlv_type.get_name_leafdata())
                                                        if (self.sub_tlv_value.is_set or self.sub_tlv_value.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sub_tlv_value.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "sub-tlv-length" or name == "sub-tlv-type" or name == "sub-tlv-value"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "sub-tlv-length"):
                                                            self.sub_tlv_length = value
                                                            self.sub_tlv_length.value_namespace = name_space
                                                            self.sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "sub-tlv-type"):
                                                            self.sub_tlv_type = value
                                                            self.sub_tlv_type.value_namespace = name_space
                                                            self.sub_tlv_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "sub-tlv-value"):
                                                            self.sub_tlv_value = value
                                                            self.sub_tlv_value.value_namespace = name_space
                                                            self.sub_tlv_value.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.te_link_sub_tlv:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.mpls_dste_link.is_set or
                                                        self.mpls_router_id.is_set or
                                                        self.tlv_data.is_set or
                                                        self.tlv_length.is_set or
                                                        self.tlv_type.is_set)

                                                def has_operation(self):
                                                    for c in self.te_link_sub_tlv:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.mpls_dste_link.yfilter != YFilter.not_set or
                                                        self.mpls_router_id.yfilter != YFilter.not_set or
                                                        self.tlv_data.yfilter != YFilter.not_set or
                                                        self.tlv_length.yfilter != YFilter.not_set or
                                                        self.tlv_type.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tlv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.mpls_dste_link.is_set or self.mpls_dste_link.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.mpls_dste_link.get_name_leafdata())
                                                    if (self.mpls_router_id.is_set or self.mpls_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.mpls_router_id.get_name_leafdata())
                                                    if (self.tlv_data.is_set or self.tlv_data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tlv_data.get_name_leafdata())
                                                    if (self.tlv_length.is_set or self.tlv_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tlv_length.get_name_leafdata())
                                                    if (self.tlv_type.is_set or self.tlv_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tlv_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "te-link-sub-tlv"):
                                                        for c in self.te_link_sub_tlv:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.te_link_sub_tlv.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "te-link-sub-tlv" or name == "mpls-dste-link" or name == "mpls-router-id" or name == "tlv-data" or name == "tlv-length" or name == "tlv-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "mpls-dste-link"):
                                                        self.mpls_dste_link = value
                                                        self.mpls_dste_link.value_namespace = name_space
                                                        self.mpls_dste_link.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "mpls-router-id"):
                                                        self.mpls_router_id = value
                                                        self.mpls_router_id.value_namespace = name_space
                                                        self.mpls_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tlv-data"):
                                                        self.tlv_data = value
                                                        self.tlv_data.value_namespace = name_space
                                                        self.tlv_data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tlv-length"):
                                                        self.tlv_length = value
                                                        self.tlv_length.value_namespace = name_space
                                                        self.tlv_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tlv-type"):
                                                        self.tlv_type = value
                                                        self.tlv_type.value_namespace = name_space
                                                        self.tlv_type.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.tlv:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.tlv:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "opaque-mpls-te-lsa-type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tlv"):
                                                    for c in self.tlv:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tlv.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tlv"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class OpaqueGraceLsa(Entity):
                                            """
                                            Opaque\-link, opaque type 3 Grace LSA
                                            
                                            .. attribute:: grace_period
                                            
                                            	The amount of time the router's neighbor should advertise it fully adjacent (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: grace_reason
                                            
                                            	Reason for router restart
                                            	**type**\:   :py:class:`OspfGrReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfGrReason>`
                                            
                                            .. attribute:: ip_address
                                            
                                            	IP interface address on the subnet associated with the grace LSA
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__init__()

                                                self.yang_name = "opaque-grace-lsa"
                                                self.yang_parent_name = "lsa-internal-data"

                                                self.grace_period = YLeaf(YType.uint32, "grace-period")

                                                self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                                self.ip_address = YLeaf(YType.str, "ip-address")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("grace_period",
                                                                "grace_reason",
                                                                "ip_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.grace_period.is_set or
                                                    self.grace_reason.is_set or
                                                    self.ip_address.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.grace_period.yfilter != YFilter.not_set or
                                                    self.grace_reason.yfilter != YFilter.not_set or
                                                    self.ip_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "opaque-grace-lsa" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.grace_period.is_set or self.grace_period.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.grace_period.get_name_leafdata())
                                                if (self.grace_reason.is_set or self.grace_reason.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.grace_reason.get_name_leafdata())
                                                if (self.ip_address.is_set or self.ip_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ip_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "grace-period" or name == "grace-reason" or name == "ip-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "grace-period"):
                                                    self.grace_period = value
                                                    self.grace_period.value_namespace = name_space
                                                    self.grace_period.value_namespace_prefix = name_space_prefix
                                                if(value_path == "grace-reason"):
                                                    self.grace_reason = value
                                                    self.grace_reason.value_namespace = name_space
                                                    self.grace_reason.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ip-address"):
                                                    self.ip_address = value
                                                    self.ip_address.value_namespace = name_space
                                                    self.ip_address.value_namespace_prefix = name_space_prefix


                                        class OpaqueRouterInfoLsaType(Entity):
                                            """
                                            Opaque Router Information LSA
                                            
                                            .. attribute:: opaque_ri_interface_name
                                            
                                            	Interface on which this Link\-Local Opaque link LSA is received
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: opaque_rilsa_scope
                                            
                                            	Opaque LSA flooding scope, a.k.a., Opaque LSA Type
                                            	**type**\:   :py:class:`OspfLsaOpqRiScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLsaOpqRiScope>`
                                            
                                            .. attribute:: opaque_ritlv
                                            
                                            	Router Information TLV
                                            	**type**\: list of    :py:class:`OpaqueRitlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__init__()

                                                self.yang_name = "opaque-router-info-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"

                                                self.opaque_ri_interface_name = YLeaf(YType.str, "opaque-ri-interface-name")

                                                self.opaque_rilsa_scope = YLeaf(YType.enumeration, "opaque-rilsa-scope")

                                                self.opaque_ritlv = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("opaque_ri_interface_name",
                                                                "opaque_rilsa_scope") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__setattr__(name, value)


                                            class OpaqueRitlv(Entity):
                                                """
                                                Router Information TLV
                                                
                                                .. attribute:: pcedtlv
                                                
                                                	PCE Discovery TLV
                                                	**type**\:   :py:class:`Pcedtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv>`
                                                
                                                .. attribute:: ritlv_internal_type
                                                
                                                	RITLVInternalType
                                                	**type**\:   :py:class:`OspfShOpqRiTlvTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiTlvTypes>`
                                                
                                                .. attribute:: rtr_cap_tlv
                                                
                                                	Rtr Cap TLV
                                                	**type**\:   :py:class:`RtrCapTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv>`
                                                
                                                .. attribute:: sr_algo_tlv
                                                
                                                	SR Algorithm TLV
                                                	**type**\:   :py:class:`SrAlgoTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv>`
                                                
                                                .. attribute:: sr_range_tlv
                                                
                                                	SR Range TLV
                                                	**type**\:   :py:class:`SrRangeTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv>`
                                                
                                                .. attribute:: unknown_tlv
                                                
                                                	Unknown Rtr Info TLV
                                                	**type**\:   :py:class:`UnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__init__()

                                                    self.yang_name = "opaque-ritlv"
                                                    self.yang_parent_name = "opaque-router-info-lsa-type"

                                                    self.ritlv_internal_type = YLeaf(YType.enumeration, "ritlv-internal-type")

                                                    self.pcedtlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv()
                                                    self.pcedtlv.parent = self
                                                    self._children_name_map["pcedtlv"] = "pcedtlv"
                                                    self._children_yang_names.add("pcedtlv")

                                                    self.rtr_cap_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv()
                                                    self.rtr_cap_tlv.parent = self
                                                    self._children_name_map["rtr_cap_tlv"] = "rtr-cap-tlv"
                                                    self._children_yang_names.add("rtr-cap-tlv")

                                                    self.sr_algo_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv()
                                                    self.sr_algo_tlv.parent = self
                                                    self._children_name_map["sr_algo_tlv"] = "sr-algo-tlv"
                                                    self._children_yang_names.add("sr-algo-tlv")

                                                    self.sr_range_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv()
                                                    self.sr_range_tlv.parent = self
                                                    self._children_name_map["sr_range_tlv"] = "sr-range-tlv"
                                                    self._children_yang_names.add("sr-range-tlv")

                                                    self.unknown_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv()
                                                    self.unknown_tlv.parent = self
                                                    self._children_name_map["unknown_tlv"] = "unknown-tlv"
                                                    self._children_yang_names.add("unknown-tlv")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("ritlv_internal_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__setattr__(name, value)


                                                class UnknownTlv(Entity):
                                                    """
                                                    Unknown Rtr Info TLV
                                                    
                                                    .. attribute:: ri_gen_tlv_length
                                                    
                                                    	Length of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ri_gen_tlv_type
                                                    
                                                    	Type of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ri_genvalue
                                                    
                                                    	Data in TLV
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__init__()

                                                        self.yang_name = "unknown-tlv"
                                                        self.yang_parent_name = "opaque-ritlv"

                                                        self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                        self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                        self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("ri_gen_tlv_length",
                                                                        "ri_gen_tlv_type",
                                                                        "ri_genvalue") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.ri_gen_tlv_length.is_set or
                                                            self.ri_gen_tlv_type.is_set or
                                                            self.ri_genvalue.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.ri_gen_tlv_length.yfilter != YFilter.not_set or
                                                            self.ri_gen_tlv_type.yfilter != YFilter.not_set or
                                                            self.ri_genvalue.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "unknown-tlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.ri_gen_tlv_length.is_set or self.ri_gen_tlv_length.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ri_gen_tlv_length.get_name_leafdata())
                                                        if (self.ri_gen_tlv_type.is_set or self.ri_gen_tlv_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ri_gen_tlv_type.get_name_leafdata())
                                                        if (self.ri_genvalue.is_set or self.ri_genvalue.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ri_genvalue.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ri-gen-tlv-length" or name == "ri-gen-tlv-type" or name == "ri-genvalue"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "ri-gen-tlv-length"):
                                                            self.ri_gen_tlv_length = value
                                                            self.ri_gen_tlv_length.value_namespace = name_space
                                                            self.ri_gen_tlv_length.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ri-gen-tlv-type"):
                                                            self.ri_gen_tlv_type = value
                                                            self.ri_gen_tlv_type.value_namespace = name_space
                                                            self.ri_gen_tlv_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ri-genvalue"):
                                                            self.ri_genvalue = value
                                                            self.ri_genvalue.value_namespace = name_space
                                                            self.ri_genvalue.value_namespace_prefix = name_space_prefix


                                                class RtrCapTlv(Entity):
                                                    """
                                                    Rtr Cap TLV
                                                    
                                                    .. attribute:: rtr_cap_additional_info
                                                    
                                                    	Additional Information in TLV
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: rtr_cap_all_bits
                                                    
                                                    	All capability bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rtr_cap_area_te
                                                    
                                                    	Traffic Engineering capability of area
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rtr_cap_graceful_restart
                                                    
                                                    	Graceful Restart Capability
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rtr_cap_graceful_restart_helper
                                                    
                                                    	Graceful Restart Helper Capability
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rtr_cap_p2plan
                                                    
                                                    	P2P LAN Capability
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rtr_cap_stub_rtr
                                                    
                                                    	Stub Router capability
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rtr_cap_te_exp
                                                    
                                                    	TE Experimental bit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rtr_cap_tlv_length
                                                    
                                                    	Length of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__init__()

                                                        self.yang_name = "rtr-cap-tlv"
                                                        self.yang_parent_name = "opaque-ritlv"

                                                        self.rtr_cap_additional_info = YLeaf(YType.str, "rtr-cap-additional-info")

                                                        self.rtr_cap_all_bits = YLeaf(YType.uint32, "rtr-cap-all-bits")

                                                        self.rtr_cap_area_te = YLeaf(YType.boolean, "rtr-cap-area-te")

                                                        self.rtr_cap_graceful_restart = YLeaf(YType.boolean, "rtr-cap-graceful-restart")

                                                        self.rtr_cap_graceful_restart_helper = YLeaf(YType.boolean, "rtr-cap-graceful-restart-helper")

                                                        self.rtr_cap_p2plan = YLeaf(YType.boolean, "rtr-cap-p2plan")

                                                        self.rtr_cap_stub_rtr = YLeaf(YType.boolean, "rtr-cap-stub-rtr")

                                                        self.rtr_cap_te_exp = YLeaf(YType.boolean, "rtr-cap-te-exp")

                                                        self.rtr_cap_tlv_length = YLeaf(YType.uint16, "rtr-cap-tlv-length")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("rtr_cap_additional_info",
                                                                        "rtr_cap_all_bits",
                                                                        "rtr_cap_area_te",
                                                                        "rtr_cap_graceful_restart",
                                                                        "rtr_cap_graceful_restart_helper",
                                                                        "rtr_cap_p2plan",
                                                                        "rtr_cap_stub_rtr",
                                                                        "rtr_cap_te_exp",
                                                                        "rtr_cap_tlv_length") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.rtr_cap_additional_info.is_set or
                                                            self.rtr_cap_all_bits.is_set or
                                                            self.rtr_cap_area_te.is_set or
                                                            self.rtr_cap_graceful_restart.is_set or
                                                            self.rtr_cap_graceful_restart_helper.is_set or
                                                            self.rtr_cap_p2plan.is_set or
                                                            self.rtr_cap_stub_rtr.is_set or
                                                            self.rtr_cap_te_exp.is_set or
                                                            self.rtr_cap_tlv_length.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.rtr_cap_additional_info.yfilter != YFilter.not_set or
                                                            self.rtr_cap_all_bits.yfilter != YFilter.not_set or
                                                            self.rtr_cap_area_te.yfilter != YFilter.not_set or
                                                            self.rtr_cap_graceful_restart.yfilter != YFilter.not_set or
                                                            self.rtr_cap_graceful_restart_helper.yfilter != YFilter.not_set or
                                                            self.rtr_cap_p2plan.yfilter != YFilter.not_set or
                                                            self.rtr_cap_stub_rtr.yfilter != YFilter.not_set or
                                                            self.rtr_cap_te_exp.yfilter != YFilter.not_set or
                                                            self.rtr_cap_tlv_length.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "rtr-cap-tlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.rtr_cap_additional_info.is_set or self.rtr_cap_additional_info.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtr_cap_additional_info.get_name_leafdata())
                                                        if (self.rtr_cap_all_bits.is_set or self.rtr_cap_all_bits.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtr_cap_all_bits.get_name_leafdata())
                                                        if (self.rtr_cap_area_te.is_set or self.rtr_cap_area_te.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtr_cap_area_te.get_name_leafdata())
                                                        if (self.rtr_cap_graceful_restart.is_set or self.rtr_cap_graceful_restart.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtr_cap_graceful_restart.get_name_leafdata())
                                                        if (self.rtr_cap_graceful_restart_helper.is_set or self.rtr_cap_graceful_restart_helper.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtr_cap_graceful_restart_helper.get_name_leafdata())
                                                        if (self.rtr_cap_p2plan.is_set or self.rtr_cap_p2plan.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtr_cap_p2plan.get_name_leafdata())
                                                        if (self.rtr_cap_stub_rtr.is_set or self.rtr_cap_stub_rtr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtr_cap_stub_rtr.get_name_leafdata())
                                                        if (self.rtr_cap_te_exp.is_set or self.rtr_cap_te_exp.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtr_cap_te_exp.get_name_leafdata())
                                                        if (self.rtr_cap_tlv_length.is_set or self.rtr_cap_tlv_length.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtr_cap_tlv_length.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "rtr-cap-additional-info" or name == "rtr-cap-all-bits" or name == "rtr-cap-area-te" or name == "rtr-cap-graceful-restart" or name == "rtr-cap-graceful-restart-helper" or name == "rtr-cap-p2plan" or name == "rtr-cap-stub-rtr" or name == "rtr-cap-te-exp" or name == "rtr-cap-tlv-length"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "rtr-cap-additional-info"):
                                                            self.rtr_cap_additional_info = value
                                                            self.rtr_cap_additional_info.value_namespace = name_space
                                                            self.rtr_cap_additional_info.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtr-cap-all-bits"):
                                                            self.rtr_cap_all_bits = value
                                                            self.rtr_cap_all_bits.value_namespace = name_space
                                                            self.rtr_cap_all_bits.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtr-cap-area-te"):
                                                            self.rtr_cap_area_te = value
                                                            self.rtr_cap_area_te.value_namespace = name_space
                                                            self.rtr_cap_area_te.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtr-cap-graceful-restart"):
                                                            self.rtr_cap_graceful_restart = value
                                                            self.rtr_cap_graceful_restart.value_namespace = name_space
                                                            self.rtr_cap_graceful_restart.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtr-cap-graceful-restart-helper"):
                                                            self.rtr_cap_graceful_restart_helper = value
                                                            self.rtr_cap_graceful_restart_helper.value_namespace = name_space
                                                            self.rtr_cap_graceful_restart_helper.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtr-cap-p2plan"):
                                                            self.rtr_cap_p2plan = value
                                                            self.rtr_cap_p2plan.value_namespace = name_space
                                                            self.rtr_cap_p2plan.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtr-cap-stub-rtr"):
                                                            self.rtr_cap_stub_rtr = value
                                                            self.rtr_cap_stub_rtr.value_namespace = name_space
                                                            self.rtr_cap_stub_rtr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtr-cap-te-exp"):
                                                            self.rtr_cap_te_exp = value
                                                            self.rtr_cap_te_exp.value_namespace = name_space
                                                            self.rtr_cap_te_exp.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtr-cap-tlv-length"):
                                                            self.rtr_cap_tlv_length = value
                                                            self.rtr_cap_tlv_length.value_namespace = name_space
                                                            self.rtr_cap_tlv_length.value_namespace_prefix = name_space_prefix


                                                class Pcedtlv(Entity):
                                                    """
                                                    PCE Discovery TLV
                                                    
                                                    .. attribute:: pced_addr
                                                    
                                                    	PCE Address
                                                    	**type**\:   :py:class:`PcedAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr>`
                                                    
                                                    .. attribute:: pced_scope
                                                    
                                                    	PCE Scope Information
                                                    	**type**\:   :py:class:`PcedScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope>`
                                                    
                                                    .. attribute:: pcedtlv_length
                                                    
                                                    	Length of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__init__()

                                                        self.yang_name = "pcedtlv"
                                                        self.yang_parent_name = "opaque-ritlv"

                                                        self.pcedtlv_length = YLeaf(YType.uint16, "pcedtlv-length")

                                                        self.pced_addr = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr()
                                                        self.pced_addr.parent = self
                                                        self._children_name_map["pced_addr"] = "pced-addr"
                                                        self._children_yang_names.add("pced-addr")

                                                        self.pced_scope = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope()
                                                        self.pced_scope.parent = self
                                                        self._children_name_map["pced_scope"] = "pced-scope"
                                                        self._children_yang_names.add("pced-scope")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("pcedtlv_length") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__setattr__(name, value)


                                                    class PcedAddr(Entity):
                                                        """
                                                        PCE Address
                                                        
                                                        .. attribute:: ipv4pce_addr
                                                        
                                                        	IPv4 PCE Address
                                                        	**type**\:   :py:class:`Ipv4PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr>`
                                                        
                                                        .. attribute:: ipv6pce_addr
                                                        
                                                        	IPv6 PCE Address
                                                        	**type**\:   :py:class:`Ipv6PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr>`
                                                        
                                                        .. attribute:: pce_addr_type
                                                        
                                                        	PCEAddrType
                                                        	**type**\:   :py:class:`OspfShOpqRiPceAddrTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiPceAddrTypes>`
                                                        
                                                        .. attribute:: pce_addr_unknown_tlv
                                                        
                                                        	Unknown PCE Addr TLV
                                                        	**type**\:   :py:class:`PceAddrUnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__init__()

                                                            self.yang_name = "pced-addr"
                                                            self.yang_parent_name = "pcedtlv"

                                                            self.pce_addr_type = YLeaf(YType.enumeration, "pce-addr-type")

                                                            self.ipv4pce_addr = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr()
                                                            self.ipv4pce_addr.parent = self
                                                            self._children_name_map["ipv4pce_addr"] = "ipv4pce-addr"
                                                            self._children_yang_names.add("ipv4pce-addr")

                                                            self.ipv6pce_addr = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr()
                                                            self.ipv6pce_addr.parent = self
                                                            self._children_name_map["ipv6pce_addr"] = "ipv6pce-addr"
                                                            self._children_yang_names.add("ipv6pce-addr")

                                                            self.pce_addr_unknown_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv()
                                                            self.pce_addr_unknown_tlv.parent = self
                                                            self._children_name_map["pce_addr_unknown_tlv"] = "pce-addr-unknown-tlv"
                                                            self._children_yang_names.add("pce-addr-unknown-tlv")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("pce_addr_type") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__setattr__(name, value)


                                                        class PceAddrUnknownTlv(Entity):
                                                            """
                                                            Unknown PCE Addr TLV
                                                            
                                                            .. attribute:: ri_gen_tlv_length
                                                            
                                                            	Length of TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: ri_gen_tlv_type
                                                            
                                                            	Type of TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: ri_genvalue
                                                            
                                                            	Data in TLV
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__init__()

                                                                self.yang_name = "pce-addr-unknown-tlv"
                                                                self.yang_parent_name = "pced-addr"

                                                                self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                                self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                                self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("ri_gen_tlv_length",
                                                                                "ri_gen_tlv_type",
                                                                                "ri_genvalue") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__setattr__(name, value)

                                                            def has_data(self):
                                                                return (
                                                                    self.ri_gen_tlv_length.is_set or
                                                                    self.ri_gen_tlv_type.is_set or
                                                                    self.ri_genvalue.is_set)

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.ri_gen_tlv_length.yfilter != YFilter.not_set or
                                                                    self.ri_gen_tlv_type.yfilter != YFilter.not_set or
                                                                    self.ri_genvalue.yfilter != YFilter.not_set)

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "pce-addr-unknown-tlv" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.ri_gen_tlv_length.is_set or self.ri_gen_tlv_length.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.ri_gen_tlv_length.get_name_leafdata())
                                                                if (self.ri_gen_tlv_type.is_set or self.ri_gen_tlv_type.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.ri_gen_tlv_type.get_name_leafdata())
                                                                if (self.ri_genvalue.is_set or self.ri_genvalue.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.ri_genvalue.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "ri-gen-tlv-length" or name == "ri-gen-tlv-type" or name == "ri-genvalue"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "ri-gen-tlv-length"):
                                                                    self.ri_gen_tlv_length = value
                                                                    self.ri_gen_tlv_length.value_namespace = name_space
                                                                    self.ri_gen_tlv_length.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "ri-gen-tlv-type"):
                                                                    self.ri_gen_tlv_type = value
                                                                    self.ri_gen_tlv_type.value_namespace = name_space
                                                                    self.ri_gen_tlv_type.value_namespace_prefix = name_space_prefix
                                                                if(value_path == "ri-genvalue"):
                                                                    self.ri_genvalue = value
                                                                    self.ri_genvalue.value_namespace = name_space
                                                                    self.ri_genvalue.value_namespace_prefix = name_space_prefix


                                                        class Ipv4PceAddr(Entity):
                                                            """
                                                            IPv4 PCE Address
                                                            
                                                            .. attribute:: pceipv4_addr
                                                            
                                                            	PCE IPv4 Address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__init__()

                                                                self.yang_name = "ipv4pce-addr"
                                                                self.yang_parent_name = "pced-addr"

                                                                self.pceipv4_addr = YLeaf(YType.str, "pceipv4-addr")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("pceipv4_addr") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__setattr__(name, value)

                                                            def has_data(self):
                                                                return self.pceipv4_addr.is_set

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.pceipv4_addr.yfilter != YFilter.not_set)

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "ipv4pce-addr" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.pceipv4_addr.is_set or self.pceipv4_addr.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.pceipv4_addr.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "pceipv4-addr"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "pceipv4-addr"):
                                                                    self.pceipv4_addr = value
                                                                    self.pceipv4_addr.value_namespace = name_space
                                                                    self.pceipv4_addr.value_namespace_prefix = name_space_prefix


                                                        class Ipv6PceAddr(Entity):
                                                            """
                                                            IPv6 PCE Address
                                                            
                                                            .. attribute:: pceipv6_addr
                                                            
                                                            	PCE IPv6 Address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-01-02'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__init__()

                                                                self.yang_name = "ipv6pce-addr"
                                                                self.yang_parent_name = "pced-addr"

                                                                self.pceipv6_addr = YLeaf(YType.str, "pceipv6-addr")

                                                            def __setattr__(self, name, value):
                                                                self._check_monkey_patching_error(name, value)
                                                                with _handle_type_error():
                                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                            "Please use list append or extend method."
                                                                                            .format(value))
                                                                    if isinstance(value, Enum.YLeaf):
                                                                        value = value.name
                                                                    if name in ("pceipv6_addr") and name in self.__dict__:
                                                                        if isinstance(value, YLeaf):
                                                                            self.__dict__[name].set(value.get())
                                                                        elif isinstance(value, YLeafList):
                                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__setattr__(name, value)
                                                                        else:
                                                                            self.__dict__[name].set(value)
                                                                    else:
                                                                        if hasattr(value, "parent") and name != "parent":
                                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                                value.parent = self
                                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                                value.parent = self
                                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__setattr__(name, value)

                                                            def has_data(self):
                                                                return self.pceipv6_addr.is_set

                                                            def has_operation(self):
                                                                return (
                                                                    self.yfilter != YFilter.not_set or
                                                                    self.pceipv6_addr.yfilter != YFilter.not_set)

                                                            def get_segment_path(self):
                                                                path_buffer = ""
                                                                path_buffer = "ipv6pce-addr" + path_buffer

                                                                return path_buffer

                                                            def get_entity_path(self, ancestor):
                                                                path_buffer = ""
                                                                if (ancestor is None):
                                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                                else:
                                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                                leaf_name_data = LeafDataList()
                                                                if (self.pceipv6_addr.is_set or self.pceipv6_addr.yfilter != YFilter.not_set):
                                                                    leaf_name_data.append(self.pceipv6_addr.get_name_leafdata())

                                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                                return entity_path

                                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                                if child is not None:
                                                                    return child

                                                                return None

                                                            def has_leaf_or_child_of_name(self, name):
                                                                if(name == "pceipv6-addr"):
                                                                    return True
                                                                return False

                                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                                if(value_path == "pceipv6-addr"):
                                                                    self.pceipv6_addr = value
                                                                    self.pceipv6_addr.value_namespace = name_space
                                                                    self.pceipv6_addr.value_namespace_prefix = name_space_prefix

                                                        def has_data(self):
                                                            return (
                                                                self.pce_addr_type.is_set or
                                                                (self.ipv4pce_addr is not None and self.ipv4pce_addr.has_data()) or
                                                                (self.ipv6pce_addr is not None and self.ipv6pce_addr.has_data()) or
                                                                (self.pce_addr_unknown_tlv is not None and self.pce_addr_unknown_tlv.has_data()))

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.pce_addr_type.yfilter != YFilter.not_set or
                                                                (self.ipv4pce_addr is not None and self.ipv4pce_addr.has_operation()) or
                                                                (self.ipv6pce_addr is not None and self.ipv6pce_addr.has_operation()) or
                                                                (self.pce_addr_unknown_tlv is not None and self.pce_addr_unknown_tlv.has_operation()))

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "pced-addr" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.pce_addr_type.is_set or self.pce_addr_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pce_addr_type.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            if (child_yang_name == "ipv4pce-addr"):
                                                                if (self.ipv4pce_addr is None):
                                                                    self.ipv4pce_addr = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr()
                                                                    self.ipv4pce_addr.parent = self
                                                                    self._children_name_map["ipv4pce_addr"] = "ipv4pce-addr"
                                                                return self.ipv4pce_addr

                                                            if (child_yang_name == "ipv6pce-addr"):
                                                                if (self.ipv6pce_addr is None):
                                                                    self.ipv6pce_addr = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr()
                                                                    self.ipv6pce_addr.parent = self
                                                                    self._children_name_map["ipv6pce_addr"] = "ipv6pce-addr"
                                                                return self.ipv6pce_addr

                                                            if (child_yang_name == "pce-addr-unknown-tlv"):
                                                                if (self.pce_addr_unknown_tlv is None):
                                                                    self.pce_addr_unknown_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv()
                                                                    self.pce_addr_unknown_tlv.parent = self
                                                                    self._children_name_map["pce_addr_unknown_tlv"] = "pce-addr-unknown-tlv"
                                                                return self.pce_addr_unknown_tlv

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "ipv4pce-addr" or name == "ipv6pce-addr" or name == "pce-addr-unknown-tlv" or name == "pce-addr-type"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "pce-addr-type"):
                                                                self.pce_addr_type = value
                                                                self.pce_addr_type.value_namespace = name_space
                                                                self.pce_addr_type.value_namespace_prefix = name_space_prefix


                                                    class PcedScope(Entity):
                                                        """
                                                        PCE Scope Information
                                                        
                                                        .. attribute:: all_scope_info_bits
                                                        
                                                        	PCE Scope Information
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: lbit
                                                        
                                                        	L Bit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pref_l
                                                        
                                                        	Pref L
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pref_r
                                                        
                                                        	Pref R
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pref_s
                                                        
                                                        	Pref S
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pref_y
                                                        
                                                        	Pref Y
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rbit
                                                        
                                                        	R Bit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rd_bit
                                                        
                                                        	Rd Bit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sbit
                                                        
                                                        	S Bit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sd_bit
                                                        
                                                        	Sd Bit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ybit
                                                        
                                                        	Y Bit
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__init__()

                                                            self.yang_name = "pced-scope"
                                                            self.yang_parent_name = "pcedtlv"

                                                            self.all_scope_info_bits = YLeaf(YType.uint32, "all-scope-info-bits")

                                                            self.lbit = YLeaf(YType.boolean, "lbit")

                                                            self.pref_l = YLeaf(YType.uint8, "pref-l")

                                                            self.pref_r = YLeaf(YType.uint8, "pref-r")

                                                            self.pref_s = YLeaf(YType.uint8, "pref-s")

                                                            self.pref_y = YLeaf(YType.uint8, "pref-y")

                                                            self.rbit = YLeaf(YType.boolean, "rbit")

                                                            self.rd_bit = YLeaf(YType.boolean, "rd-bit")

                                                            self.sbit = YLeaf(YType.boolean, "sbit")

                                                            self.sd_bit = YLeaf(YType.boolean, "sd-bit")

                                                            self.ybit = YLeaf(YType.boolean, "ybit")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("all_scope_info_bits",
                                                                            "lbit",
                                                                            "pref_l",
                                                                            "pref_r",
                                                                            "pref_s",
                                                                            "pref_y",
                                                                            "rbit",
                                                                            "rd_bit",
                                                                            "sbit",
                                                                            "sd_bit",
                                                                            "ybit") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.all_scope_info_bits.is_set or
                                                                self.lbit.is_set or
                                                                self.pref_l.is_set or
                                                                self.pref_r.is_set or
                                                                self.pref_s.is_set or
                                                                self.pref_y.is_set or
                                                                self.rbit.is_set or
                                                                self.rd_bit.is_set or
                                                                self.sbit.is_set or
                                                                self.sd_bit.is_set or
                                                                self.ybit.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.all_scope_info_bits.yfilter != YFilter.not_set or
                                                                self.lbit.yfilter != YFilter.not_set or
                                                                self.pref_l.yfilter != YFilter.not_set or
                                                                self.pref_r.yfilter != YFilter.not_set or
                                                                self.pref_s.yfilter != YFilter.not_set or
                                                                self.pref_y.yfilter != YFilter.not_set or
                                                                self.rbit.yfilter != YFilter.not_set or
                                                                self.rd_bit.yfilter != YFilter.not_set or
                                                                self.sbit.yfilter != YFilter.not_set or
                                                                self.sd_bit.yfilter != YFilter.not_set or
                                                                self.ybit.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "pced-scope" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.all_scope_info_bits.is_set or self.all_scope_info_bits.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.all_scope_info_bits.get_name_leafdata())
                                                            if (self.lbit.is_set or self.lbit.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.lbit.get_name_leafdata())
                                                            if (self.pref_l.is_set or self.pref_l.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pref_l.get_name_leafdata())
                                                            if (self.pref_r.is_set or self.pref_r.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pref_r.get_name_leafdata())
                                                            if (self.pref_s.is_set or self.pref_s.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pref_s.get_name_leafdata())
                                                            if (self.pref_y.is_set or self.pref_y.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.pref_y.get_name_leafdata())
                                                            if (self.rbit.is_set or self.rbit.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.rbit.get_name_leafdata())
                                                            if (self.rd_bit.is_set or self.rd_bit.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.rd_bit.get_name_leafdata())
                                                            if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sbit.get_name_leafdata())
                                                            if (self.sd_bit.is_set or self.sd_bit.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sd_bit.get_name_leafdata())
                                                            if (self.ybit.is_set or self.ybit.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.ybit.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "all-scope-info-bits" or name == "lbit" or name == "pref-l" or name == "pref-r" or name == "pref-s" or name == "pref-y" or name == "rbit" or name == "rd-bit" or name == "sbit" or name == "sd-bit" or name == "ybit"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "all-scope-info-bits"):
                                                                self.all_scope_info_bits = value
                                                                self.all_scope_info_bits.value_namespace = name_space
                                                                self.all_scope_info_bits.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "lbit"):
                                                                self.lbit = value
                                                                self.lbit.value_namespace = name_space
                                                                self.lbit.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pref-l"):
                                                                self.pref_l = value
                                                                self.pref_l.value_namespace = name_space
                                                                self.pref_l.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pref-r"):
                                                                self.pref_r = value
                                                                self.pref_r.value_namespace = name_space
                                                                self.pref_r.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pref-s"):
                                                                self.pref_s = value
                                                                self.pref_s.value_namespace = name_space
                                                                self.pref_s.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "pref-y"):
                                                                self.pref_y = value
                                                                self.pref_y.value_namespace = name_space
                                                                self.pref_y.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "rbit"):
                                                                self.rbit = value
                                                                self.rbit.value_namespace = name_space
                                                                self.rbit.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "rd-bit"):
                                                                self.rd_bit = value
                                                                self.rd_bit.value_namespace = name_space
                                                                self.rd_bit.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "sbit"):
                                                                self.sbit = value
                                                                self.sbit.value_namespace = name_space
                                                                self.sbit.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "sd-bit"):
                                                                self.sd_bit = value
                                                                self.sd_bit.value_namespace = name_space
                                                                self.sd_bit.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "ybit"):
                                                                self.ybit = value
                                                                self.ybit.value_namespace = name_space
                                                                self.ybit.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        return (
                                                            self.pcedtlv_length.is_set or
                                                            (self.pced_addr is not None and self.pced_addr.has_data()) or
                                                            (self.pced_scope is not None and self.pced_scope.has_data()))

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.pcedtlv_length.yfilter != YFilter.not_set or
                                                            (self.pced_addr is not None and self.pced_addr.has_operation()) or
                                                            (self.pced_scope is not None and self.pced_scope.has_operation()))

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "pcedtlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.pcedtlv_length.is_set or self.pcedtlv_length.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pcedtlv_length.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "pced-addr"):
                                                            if (self.pced_addr is None):
                                                                self.pced_addr = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr()
                                                                self.pced_addr.parent = self
                                                                self._children_name_map["pced_addr"] = "pced-addr"
                                                            return self.pced_addr

                                                        if (child_yang_name == "pced-scope"):
                                                            if (self.pced_scope is None):
                                                                self.pced_scope = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope()
                                                                self.pced_scope.parent = self
                                                                self._children_name_map["pced_scope"] = "pced-scope"
                                                            return self.pced_scope

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "pced-addr" or name == "pced-scope" or name == "pcedtlv-length"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "pcedtlv-length"):
                                                            self.pcedtlv_length = value
                                                            self.pcedtlv_length.value_namespace = name_space
                                                            self.pcedtlv_length.value_namespace_prefix = name_space_prefix


                                                class SrAlgoTlv(Entity):
                                                    """
                                                    SR Algorithm TLV
                                                    
                                                    .. attribute:: sr_algo_length
                                                    
                                                    	Length of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sr_algo_value
                                                    
                                                    	SR Algorithms
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__init__()

                                                        self.yang_name = "sr-algo-tlv"
                                                        self.yang_parent_name = "opaque-ritlv"

                                                        self.sr_algo_length = YLeaf(YType.uint16, "sr-algo-length")

                                                        self.sr_algo_value = YLeaf(YType.str, "sr-algo-value")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("sr_algo_length",
                                                                        "sr_algo_value") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.sr_algo_length.is_set or
                                                            self.sr_algo_value.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.sr_algo_length.yfilter != YFilter.not_set or
                                                            self.sr_algo_value.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "sr-algo-tlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.sr_algo_length.is_set or self.sr_algo_length.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sr_algo_length.get_name_leafdata())
                                                        if (self.sr_algo_value.is_set or self.sr_algo_value.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sr_algo_value.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "sr-algo-length" or name == "sr-algo-value"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "sr-algo-length"):
                                                            self.sr_algo_length = value
                                                            self.sr_algo_length.value_namespace = name_space
                                                            self.sr_algo_length.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "sr-algo-value"):
                                                            self.sr_algo_value = value
                                                            self.sr_algo_value.value_namespace = name_space
                                                            self.sr_algo_value.value_namespace_prefix = name_space_prefix


                                                class SrRangeTlv(Entity):
                                                    """
                                                    SR Range TLV
                                                    
                                                    .. attribute:: sidtlv
                                                    
                                                    	SID sub\-TLV
                                                    	**type**\:   :py:class:`Sidtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv>`
                                                    
                                                    .. attribute:: sr_range_length
                                                    
                                                    	Length of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sr_range_size
                                                    
                                                    	SR Range Size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__init__()

                                                        self.yang_name = "sr-range-tlv"
                                                        self.yang_parent_name = "opaque-ritlv"

                                                        self.sr_range_length = YLeaf(YType.uint16, "sr-range-length")

                                                        self.sr_range_size = YLeaf(YType.uint32, "sr-range-size")

                                                        self.sidtlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv()
                                                        self.sidtlv.parent = self
                                                        self._children_name_map["sidtlv"] = "sidtlv"
                                                        self._children_yang_names.add("sidtlv")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("sr_range_length",
                                                                        "sr_range_size") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__setattr__(name, value)


                                                    class Sidtlv(Entity):
                                                        """
                                                        SID sub\-TLV
                                                        
                                                        .. attribute:: sr_sid_length
                                                        
                                                        	Length of sub\-TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: sr_sid_value
                                                        
                                                        	SID Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-01-02'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__init__()

                                                            self.yang_name = "sidtlv"
                                                            self.yang_parent_name = "sr-range-tlv"

                                                            self.sr_sid_length = YLeaf(YType.uint16, "sr-sid-length")

                                                            self.sr_sid_value = YLeaf(YType.uint32, "sr-sid-value")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("sr_sid_length",
                                                                            "sr_sid_value") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.sr_sid_length.is_set or
                                                                self.sr_sid_value.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.sr_sid_length.yfilter != YFilter.not_set or
                                                                self.sr_sid_value.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "sidtlv" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.sr_sid_length.is_set or self.sr_sid_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sr_sid_length.get_name_leafdata())
                                                            if (self.sr_sid_value.is_set or self.sr_sid_value.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.sr_sid_value.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "sr-sid-length" or name == "sr-sid-value"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "sr-sid-length"):
                                                                self.sr_sid_length = value
                                                                self.sr_sid_length.value_namespace = name_space
                                                                self.sr_sid_length.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "sr-sid-value"):
                                                                self.sr_sid_value = value
                                                                self.sr_sid_value.value_namespace = name_space
                                                                self.sr_sid_value.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        return (
                                                            self.sr_range_length.is_set or
                                                            self.sr_range_size.is_set or
                                                            (self.sidtlv is not None and self.sidtlv.has_data()))

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.sr_range_length.yfilter != YFilter.not_set or
                                                            self.sr_range_size.yfilter != YFilter.not_set or
                                                            (self.sidtlv is not None and self.sidtlv.has_operation()))

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "sr-range-tlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.sr_range_length.is_set or self.sr_range_length.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sr_range_length.get_name_leafdata())
                                                        if (self.sr_range_size.is_set or self.sr_range_size.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sr_range_size.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "sidtlv"):
                                                            if (self.sidtlv is None):
                                                                self.sidtlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv()
                                                                self.sidtlv.parent = self
                                                                self._children_name_map["sidtlv"] = "sidtlv"
                                                            return self.sidtlv

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "sidtlv" or name == "sr-range-length" or name == "sr-range-size"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "sr-range-length"):
                                                            self.sr_range_length = value
                                                            self.sr_range_length.value_namespace = name_space
                                                            self.sr_range_length.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "sr-range-size"):
                                                            self.sr_range_size = value
                                                            self.sr_range_size.value_namespace = name_space
                                                            self.sr_range_size.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.ritlv_internal_type.is_set or
                                                        (self.pcedtlv is not None and self.pcedtlv.has_data()) or
                                                        (self.rtr_cap_tlv is not None and self.rtr_cap_tlv.has_data()) or
                                                        (self.sr_algo_tlv is not None and self.sr_algo_tlv.has_data()) or
                                                        (self.sr_range_tlv is not None and self.sr_range_tlv.has_data()) or
                                                        (self.unknown_tlv is not None and self.unknown_tlv.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.ritlv_internal_type.yfilter != YFilter.not_set or
                                                        (self.pcedtlv is not None and self.pcedtlv.has_operation()) or
                                                        (self.rtr_cap_tlv is not None and self.rtr_cap_tlv.has_operation()) or
                                                        (self.sr_algo_tlv is not None and self.sr_algo_tlv.has_operation()) or
                                                        (self.sr_range_tlv is not None and self.sr_range_tlv.has_operation()) or
                                                        (self.unknown_tlv is not None and self.unknown_tlv.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opaque-ritlv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.ritlv_internal_type.is_set or self.ritlv_internal_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ritlv_internal_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "pcedtlv"):
                                                        if (self.pcedtlv is None):
                                                            self.pcedtlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv()
                                                            self.pcedtlv.parent = self
                                                            self._children_name_map["pcedtlv"] = "pcedtlv"
                                                        return self.pcedtlv

                                                    if (child_yang_name == "rtr-cap-tlv"):
                                                        if (self.rtr_cap_tlv is None):
                                                            self.rtr_cap_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv()
                                                            self.rtr_cap_tlv.parent = self
                                                            self._children_name_map["rtr_cap_tlv"] = "rtr-cap-tlv"
                                                        return self.rtr_cap_tlv

                                                    if (child_yang_name == "sr-algo-tlv"):
                                                        if (self.sr_algo_tlv is None):
                                                            self.sr_algo_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv()
                                                            self.sr_algo_tlv.parent = self
                                                            self._children_name_map["sr_algo_tlv"] = "sr-algo-tlv"
                                                        return self.sr_algo_tlv

                                                    if (child_yang_name == "sr-range-tlv"):
                                                        if (self.sr_range_tlv is None):
                                                            self.sr_range_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv()
                                                            self.sr_range_tlv.parent = self
                                                            self._children_name_map["sr_range_tlv"] = "sr-range-tlv"
                                                        return self.sr_range_tlv

                                                    if (child_yang_name == "unknown-tlv"):
                                                        if (self.unknown_tlv is None):
                                                            self.unknown_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv()
                                                            self.unknown_tlv.parent = self
                                                            self._children_name_map["unknown_tlv"] = "unknown-tlv"
                                                        return self.unknown_tlv

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "pcedtlv" or name == "rtr-cap-tlv" or name == "sr-algo-tlv" or name == "sr-range-tlv" or name == "unknown-tlv" or name == "ritlv-internal-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "ritlv-internal-type"):
                                                        self.ritlv_internal_type = value
                                                        self.ritlv_internal_type.value_namespace = name_space
                                                        self.ritlv_internal_type.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.opaque_ritlv:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.opaque_ri_interface_name.is_set or
                                                    self.opaque_rilsa_scope.is_set)

                                            def has_operation(self):
                                                for c in self.opaque_ritlv:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.opaque_ri_interface_name.yfilter != YFilter.not_set or
                                                    self.opaque_rilsa_scope.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "opaque-router-info-lsa-type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.opaque_ri_interface_name.is_set or self.opaque_ri_interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.opaque_ri_interface_name.get_name_leafdata())
                                                if (self.opaque_rilsa_scope.is_set or self.opaque_rilsa_scope.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.opaque_rilsa_scope.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "opaque-ritlv"):
                                                    for c in self.opaque_ritlv:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.opaque_ritlv.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "opaque-ritlv" or name == "opaque-ri-interface-name" or name == "opaque-rilsa-scope"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "opaque-ri-interface-name"):
                                                    self.opaque_ri_interface_name = value
                                                    self.opaque_ri_interface_name.value_namespace = name_space
                                                    self.opaque_ri_interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "opaque-rilsa-scope"):
                                                    self.opaque_rilsa_scope = value
                                                    self.opaque_rilsa_scope.value_namespace = name_space
                                                    self.opaque_rilsa_scope.value_namespace_prefix = name_space_prefix


                                        class OpaqueEpLsaType(Entity):
                                            """
                                            Extende Prefix LSA type
                                            
                                            .. attribute:: tlv
                                            
                                            	List of TLVs
                                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__init__()

                                                self.yang_name = "opaque-ep-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"

                                                self.tlv = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__setattr__(name, value)


                                            class Tlv(Entity):
                                                """
                                                List of TLVs
                                                
                                                .. attribute:: mpls_dste_link
                                                
                                                	MPLS DS\-TE supported
                                                	**type**\:  bool
                                                
                                                .. attribute:: mpls_router_id
                                                
                                                	MPLS\-TE Router ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: te_link_sub_tlv
                                                
                                                	List of Sub\-TLVs
                                                	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv>`
                                                
                                                .. attribute:: tlv_data
                                                
                                                	TLV direct data
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tlv_length
                                                
                                                	Length of top\-level TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: tlv_type
                                                
                                                	Type of top\-level TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__init__()

                                                    self.yang_name = "tlv"
                                                    self.yang_parent_name = "opaque-ep-lsa-type"

                                                    self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                    self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                    self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                    self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                    self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                    self.te_link_sub_tlv = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("mpls_dste_link",
                                                                    "mpls_router_id",
                                                                    "tlv_data",
                                                                    "tlv_length",
                                                                    "tlv_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__setattr__(name, value)


                                                class TeLinkSubTlv(Entity):
                                                    """
                                                    List of Sub\-TLVs
                                                    
                                                    .. attribute:: sub_tlv_length
                                                    
                                                    	Length of sub TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sub_tlv_type
                                                    
                                                    	Type of sub TLV
                                                    	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                    
                                                    .. attribute:: sub_tlv_value
                                                    
                                                    	Value of sub TLV
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                        self.yang_name = "te-link-sub-tlv"
                                                        self.yang_parent_name = "tlv"

                                                        self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                        self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                        self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("sub_tlv_length",
                                                                        "sub_tlv_type",
                                                                        "sub_tlv_value") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.sub_tlv_length.is_set or
                                                            self.sub_tlv_type.is_set or
                                                            self.sub_tlv_value.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.sub_tlv_length.yfilter != YFilter.not_set or
                                                            self.sub_tlv_type.yfilter != YFilter.not_set or
                                                            self.sub_tlv_value.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "te-link-sub-tlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.sub_tlv_length.is_set or self.sub_tlv_length.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sub_tlv_length.get_name_leafdata())
                                                        if (self.sub_tlv_type.is_set or self.sub_tlv_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sub_tlv_type.get_name_leafdata())
                                                        if (self.sub_tlv_value.is_set or self.sub_tlv_value.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sub_tlv_value.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "sub-tlv-length" or name == "sub-tlv-type" or name == "sub-tlv-value"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "sub-tlv-length"):
                                                            self.sub_tlv_length = value
                                                            self.sub_tlv_length.value_namespace = name_space
                                                            self.sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "sub-tlv-type"):
                                                            self.sub_tlv_type = value
                                                            self.sub_tlv_type.value_namespace = name_space
                                                            self.sub_tlv_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "sub-tlv-value"):
                                                            self.sub_tlv_value = value
                                                            self.sub_tlv_value.value_namespace = name_space
                                                            self.sub_tlv_value.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.te_link_sub_tlv:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.mpls_dste_link.is_set or
                                                        self.mpls_router_id.is_set or
                                                        self.tlv_data.is_set or
                                                        self.tlv_length.is_set or
                                                        self.tlv_type.is_set)

                                                def has_operation(self):
                                                    for c in self.te_link_sub_tlv:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.mpls_dste_link.yfilter != YFilter.not_set or
                                                        self.mpls_router_id.yfilter != YFilter.not_set or
                                                        self.tlv_data.yfilter != YFilter.not_set or
                                                        self.tlv_length.yfilter != YFilter.not_set or
                                                        self.tlv_type.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tlv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.mpls_dste_link.is_set or self.mpls_dste_link.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.mpls_dste_link.get_name_leafdata())
                                                    if (self.mpls_router_id.is_set or self.mpls_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.mpls_router_id.get_name_leafdata())
                                                    if (self.tlv_data.is_set or self.tlv_data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tlv_data.get_name_leafdata())
                                                    if (self.tlv_length.is_set or self.tlv_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tlv_length.get_name_leafdata())
                                                    if (self.tlv_type.is_set or self.tlv_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tlv_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "te-link-sub-tlv"):
                                                        for c in self.te_link_sub_tlv:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.te_link_sub_tlv.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "te-link-sub-tlv" or name == "mpls-dste-link" or name == "mpls-router-id" or name == "tlv-data" or name == "tlv-length" or name == "tlv-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "mpls-dste-link"):
                                                        self.mpls_dste_link = value
                                                        self.mpls_dste_link.value_namespace = name_space
                                                        self.mpls_dste_link.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "mpls-router-id"):
                                                        self.mpls_router_id = value
                                                        self.mpls_router_id.value_namespace = name_space
                                                        self.mpls_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tlv-data"):
                                                        self.tlv_data = value
                                                        self.tlv_data.value_namespace = name_space
                                                        self.tlv_data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tlv-length"):
                                                        self.tlv_length = value
                                                        self.tlv_length.value_namespace = name_space
                                                        self.tlv_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tlv-type"):
                                                        self.tlv_type = value
                                                        self.tlv_type.value_namespace = name_space
                                                        self.tlv_type.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.tlv:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.tlv:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "opaque-ep-lsa-type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tlv"):
                                                    for c in self.tlv:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tlv.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tlv"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class OpaqueElLsaType(Entity):
                                            """
                                            Extended Link LSA type
                                            
                                            .. attribute:: tlv
                                            
                                            	List of TLVs
                                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__init__()

                                                self.yang_name = "opaque-el-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"

                                                self.tlv = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__setattr__(name, value)


                                            class Tlv(Entity):
                                                """
                                                List of TLVs
                                                
                                                .. attribute:: mpls_dste_link
                                                
                                                	MPLS DS\-TE supported
                                                	**type**\:  bool
                                                
                                                .. attribute:: mpls_router_id
                                                
                                                	MPLS\-TE Router ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: te_link_sub_tlv
                                                
                                                	List of Sub\-TLVs
                                                	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv>`
                                                
                                                .. attribute:: tlv_data
                                                
                                                	TLV direct data
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tlv_length
                                                
                                                	Length of top\-level TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: tlv_type
                                                
                                                	Type of top\-level TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__init__()

                                                    self.yang_name = "tlv"
                                                    self.yang_parent_name = "opaque-el-lsa-type"

                                                    self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                    self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                    self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                    self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                    self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                    self.te_link_sub_tlv = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("mpls_dste_link",
                                                                    "mpls_router_id",
                                                                    "tlv_data",
                                                                    "tlv_length",
                                                                    "tlv_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__setattr__(name, value)


                                                class TeLinkSubTlv(Entity):
                                                    """
                                                    List of Sub\-TLVs
                                                    
                                                    .. attribute:: sub_tlv_length
                                                    
                                                    	Length of sub TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sub_tlv_type
                                                    
                                                    	Type of sub TLV
                                                    	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                    
                                                    .. attribute:: sub_tlv_value
                                                    
                                                    	Value of sub TLV
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                        self.yang_name = "te-link-sub-tlv"
                                                        self.yang_parent_name = "tlv"

                                                        self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                        self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                        self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("sub_tlv_length",
                                                                        "sub_tlv_type",
                                                                        "sub_tlv_value") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.sub_tlv_length.is_set or
                                                            self.sub_tlv_type.is_set or
                                                            self.sub_tlv_value.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.sub_tlv_length.yfilter != YFilter.not_set or
                                                            self.sub_tlv_type.yfilter != YFilter.not_set or
                                                            self.sub_tlv_value.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "te-link-sub-tlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.sub_tlv_length.is_set or self.sub_tlv_length.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sub_tlv_length.get_name_leafdata())
                                                        if (self.sub_tlv_type.is_set or self.sub_tlv_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sub_tlv_type.get_name_leafdata())
                                                        if (self.sub_tlv_value.is_set or self.sub_tlv_value.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.sub_tlv_value.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "sub-tlv-length" or name == "sub-tlv-type" or name == "sub-tlv-value"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "sub-tlv-length"):
                                                            self.sub_tlv_length = value
                                                            self.sub_tlv_length.value_namespace = name_space
                                                            self.sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "sub-tlv-type"):
                                                            self.sub_tlv_type = value
                                                            self.sub_tlv_type.value_namespace = name_space
                                                            self.sub_tlv_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "sub-tlv-value"):
                                                            self.sub_tlv_value = value
                                                            self.sub_tlv_value.value_namespace = name_space
                                                            self.sub_tlv_value.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.te_link_sub_tlv:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.mpls_dste_link.is_set or
                                                        self.mpls_router_id.is_set or
                                                        self.tlv_data.is_set or
                                                        self.tlv_length.is_set or
                                                        self.tlv_type.is_set)

                                                def has_operation(self):
                                                    for c in self.te_link_sub_tlv:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.mpls_dste_link.yfilter != YFilter.not_set or
                                                        self.mpls_router_id.yfilter != YFilter.not_set or
                                                        self.tlv_data.yfilter != YFilter.not_set or
                                                        self.tlv_length.yfilter != YFilter.not_set or
                                                        self.tlv_type.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tlv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.mpls_dste_link.is_set or self.mpls_dste_link.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.mpls_dste_link.get_name_leafdata())
                                                    if (self.mpls_router_id.is_set or self.mpls_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.mpls_router_id.get_name_leafdata())
                                                    if (self.tlv_data.is_set or self.tlv_data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tlv_data.get_name_leafdata())
                                                    if (self.tlv_length.is_set or self.tlv_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tlv_length.get_name_leafdata())
                                                    if (self.tlv_type.is_set or self.tlv_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tlv_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "te-link-sub-tlv"):
                                                        for c in self.te_link_sub_tlv:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.te_link_sub_tlv.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "te-link-sub-tlv" or name == "mpls-dste-link" or name == "mpls-router-id" or name == "tlv-data" or name == "tlv-length" or name == "tlv-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "mpls-dste-link"):
                                                        self.mpls_dste_link = value
                                                        self.mpls_dste_link.value_namespace = name_space
                                                        self.mpls_dste_link.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "mpls-router-id"):
                                                        self.mpls_router_id = value
                                                        self.mpls_router_id.value_namespace = name_space
                                                        self.mpls_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tlv-data"):
                                                        self.tlv_data = value
                                                        self.tlv_data.value_namespace = name_space
                                                        self.tlv_data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tlv-length"):
                                                        self.tlv_length = value
                                                        self.tlv_length.value_namespace = name_space
                                                        self.tlv_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tlv-type"):
                                                        self.tlv_type = value
                                                        self.tlv_type.value_namespace = name_space
                                                        self.tlv_type.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.tlv:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.tlv:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "opaque-el-lsa-type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tlv"):
                                                    for c in self.tlv:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tlv.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tlv"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.internal_lsa_type.is_set or
                                                (self.external_lsa_type is not None and self.external_lsa_type.has_data()) or
                                                (self.network_lsa_type is not None and self.network_lsa_type.has_data()) or
                                                (self.opaque_el_lsa_type is not None and self.opaque_el_lsa_type.has_data()) or
                                                (self.opaque_ep_lsa_type is not None and self.opaque_ep_lsa_type.has_data()) or
                                                (self.opaque_grace_lsa is not None and self.opaque_grace_lsa.has_data()) or
                                                (self.opaque_link_lsa_type is not None and self.opaque_link_lsa_type.has_data()) or
                                                (self.opaque_mpls_te_lsa_type is not None and self.opaque_mpls_te_lsa_type.has_data()) or
                                                (self.opaque_router_info_lsa_type is not None and self.opaque_router_info_lsa_type.has_data()) or
                                                (self.router_lsa_type is not None and self.router_lsa_type.has_data()) or
                                                (self.summary_lsa_type is not None and self.summary_lsa_type.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_lsa_type.yfilter != YFilter.not_set or
                                                (self.external_lsa_type is not None and self.external_lsa_type.has_operation()) or
                                                (self.network_lsa_type is not None and self.network_lsa_type.has_operation()) or
                                                (self.opaque_el_lsa_type is not None and self.opaque_el_lsa_type.has_operation()) or
                                                (self.opaque_ep_lsa_type is not None and self.opaque_ep_lsa_type.has_operation()) or
                                                (self.opaque_grace_lsa is not None and self.opaque_grace_lsa.has_operation()) or
                                                (self.opaque_link_lsa_type is not None and self.opaque_link_lsa_type.has_operation()) or
                                                (self.opaque_mpls_te_lsa_type is not None and self.opaque_mpls_te_lsa_type.has_operation()) or
                                                (self.opaque_router_info_lsa_type is not None and self.opaque_router_info_lsa_type.has_operation()) or
                                                (self.router_lsa_type is not None and self.router_lsa_type.has_operation()) or
                                                (self.summary_lsa_type is not None and self.summary_lsa_type.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "lsa-internal-data" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_lsa_type.is_set or self.internal_lsa_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_lsa_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "external-lsa-type"):
                                                if (self.external_lsa_type is None):
                                                    self.external_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType()
                                                    self.external_lsa_type.parent = self
                                                    self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                                return self.external_lsa_type

                                            if (child_yang_name == "network-lsa-type"):
                                                if (self.network_lsa_type is None):
                                                    self.network_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType()
                                                    self.network_lsa_type.parent = self
                                                    self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                                return self.network_lsa_type

                                            if (child_yang_name == "opaque-el-lsa-type"):
                                                if (self.opaque_el_lsa_type is None):
                                                    self.opaque_el_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType()
                                                    self.opaque_el_lsa_type.parent = self
                                                    self._children_name_map["opaque_el_lsa_type"] = "opaque-el-lsa-type"
                                                return self.opaque_el_lsa_type

                                            if (child_yang_name == "opaque-ep-lsa-type"):
                                                if (self.opaque_ep_lsa_type is None):
                                                    self.opaque_ep_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType()
                                                    self.opaque_ep_lsa_type.parent = self
                                                    self._children_name_map["opaque_ep_lsa_type"] = "opaque-ep-lsa-type"
                                                return self.opaque_ep_lsa_type

                                            if (child_yang_name == "opaque-grace-lsa"):
                                                if (self.opaque_grace_lsa is None):
                                                    self.opaque_grace_lsa = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa()
                                                    self.opaque_grace_lsa.parent = self
                                                    self._children_name_map["opaque_grace_lsa"] = "opaque-grace-lsa"
                                                return self.opaque_grace_lsa

                                            if (child_yang_name == "opaque-link-lsa-type"):
                                                if (self.opaque_link_lsa_type is None):
                                                    self.opaque_link_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType()
                                                    self.opaque_link_lsa_type.parent = self
                                                    self._children_name_map["opaque_link_lsa_type"] = "opaque-link-lsa-type"
                                                return self.opaque_link_lsa_type

                                            if (child_yang_name == "opaque-mpls-te-lsa-type"):
                                                if (self.opaque_mpls_te_lsa_type is None):
                                                    self.opaque_mpls_te_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType()
                                                    self.opaque_mpls_te_lsa_type.parent = self
                                                    self._children_name_map["opaque_mpls_te_lsa_type"] = "opaque-mpls-te-lsa-type"
                                                return self.opaque_mpls_te_lsa_type

                                            if (child_yang_name == "opaque-router-info-lsa-type"):
                                                if (self.opaque_router_info_lsa_type is None):
                                                    self.opaque_router_info_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType()
                                                    self.opaque_router_info_lsa_type.parent = self
                                                    self._children_name_map["opaque_router_info_lsa_type"] = "opaque-router-info-lsa-type"
                                                return self.opaque_router_info_lsa_type

                                            if (child_yang_name == "router-lsa-type"):
                                                if (self.router_lsa_type is None):
                                                    self.router_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType()
                                                    self.router_lsa_type.parent = self
                                                    self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                                return self.router_lsa_type

                                            if (child_yang_name == "summary-lsa-type"):
                                                if (self.summary_lsa_type is None):
                                                    self.summary_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType()
                                                    self.summary_lsa_type.parent = self
                                                    self._children_name_map["summary_lsa_type"] = "summary-lsa-type"
                                                return self.summary_lsa_type

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "external-lsa-type" or name == "network-lsa-type" or name == "opaque-el-lsa-type" or name == "opaque-ep-lsa-type" or name == "opaque-grace-lsa" or name == "opaque-link-lsa-type" or name == "opaque-mpls-te-lsa-type" or name == "opaque-router-info-lsa-type" or name == "router-lsa-type" or name == "summary-lsa-type" or name == "internal-lsa-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-lsa-type"):
                                                self.internal_lsa_type = value
                                                self.internal_lsa_type.value_namespace = name_space
                                                self.internal_lsa_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.advertising_router.is_set or
                                            self.area_id.is_set or
                                            self.interface_name.is_set or
                                            self.ls_id.is_set or
                                            self.ls_type.is_set or
                                            (self.lsa_detail_data is not None and self.lsa_detail_data.has_data()) or
                                            (self.lsa_header is not None and self.lsa_header.has_data()) or
                                            (self.lsa_internal_data is not None and self.lsa_internal_data.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.advertising_router.yfilter != YFilter.not_set or
                                            self.area_id.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.ls_id.yfilter != YFilter.not_set or
                                            self.ls_type.yfilter != YFilter.not_set or
                                            (self.lsa_detail_data is not None and self.lsa_detail_data.has_operation()) or
                                            (self.lsa_header is not None and self.lsa_header.has_operation()) or
                                            (self.lsa_internal_data is not None and self.lsa_internal_data.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lsa" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                        if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id.get_name_leafdata())
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.ls_id.is_set or self.ls_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ls_id.get_name_leafdata())
                                        if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ls_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "lsa-detail-data"):
                                            if (self.lsa_detail_data is None):
                                                self.lsa_detail_data = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData()
                                                self.lsa_detail_data.parent = self
                                                self._children_name_map["lsa_detail_data"] = "lsa-detail-data"
                                            return self.lsa_detail_data

                                        if (child_yang_name == "lsa-header"):
                                            if (self.lsa_header is None):
                                                self.lsa_header = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                            return self.lsa_header

                                        if (child_yang_name == "lsa-internal-data"):
                                            if (self.lsa_internal_data is None):
                                                self.lsa_internal_data = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData()
                                                self.lsa_internal_data.parent = self
                                                self._children_name_map["lsa_internal_data"] = "lsa-internal-data"
                                            return self.lsa_internal_data

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lsa-detail-data" or name == "lsa-header" or name == "lsa-internal-data" or name == "advertising-router" or name == "area-id" or name == "interface-name" or name == "ls-id" or name == "ls-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "advertising-router"):
                                            self.advertising_router = value
                                            self.advertising_router.value_namespace = name_space
                                            self.advertising_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-id"):
                                            self.area_id = value
                                            self.area_id.value_namespace = name_space
                                            self.area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ls-id"):
                                            self.ls_id = value
                                            self.ls_id.value_namespace = name_space
                                            self.ls_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ls-type"):
                                            self.ls_type = value
                                            self.ls_type.value_namespace = name_space
                                            self.ls_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.lsa:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.lsa:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "lsas" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "lsa"):
                                        for c in self.lsa:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.lsa.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lsa"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class LsaSummaries(Entity):
                                """
                                Link state advertisement summary table
                                
                                .. attribute:: lsa_summary
                                
                                	LSA summary information
                                	**type**\: list of    :py:class:`LsaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries, self).__init__()

                                    self.yang_name = "lsa-summaries"
                                    self.yang_parent_name = "database-area"

                                    self.lsa_summary = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries, self).__setattr__(name, value)


                                class LsaSummary(Entity):
                                    """
                                    LSA summary information
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Advertising Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: link_count
                                    
                                    	Number of links
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ls_id
                                    
                                    	Link state ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ls_type
                                    
                                    	Link state type
                                    	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	LSA header information
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary, self).__init__()

                                        self.yang_name = "lsa-summary"
                                        self.yang_parent_name = "lsa-summaries"

                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                        self.area_id = YLeaf(YType.int32, "area-id")

                                        self.external_tag = YLeaf(YType.uint32, "external-tag")

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.link_count = YLeaf(YType.uint16, "link-count")

                                        self.ls_id = YLeaf(YType.str, "ls-id")

                                        self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                        self.lsa_header = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("advertising_router",
                                                        "area_id",
                                                        "external_tag",
                                                        "interface_name",
                                                        "link_count",
                                                        "ls_id",
                                                        "ls_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary, self).__setattr__(name, value)


                                    class LsaHeader(Entity):
                                        """
                                        LSA header information
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: dn_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsid
                                        
                                        	LS ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: nsf
                                        
                                        	If true,  LSA received from neighbor during NSF
                                        	**type**\:  bool
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "lsa-summary"

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                            self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsid = YLeaf(YType.str, "lsid")

                                            self.nsf = YLeaf(YType.boolean, "nsf")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("advertising_router",
                                                            "checksum",
                                                            "dn_age_lsa",
                                                            "ls_type",
                                                            "lsa_age",
                                                            "lsa_area_id",
                                                            "lsid",
                                                            "nsf",
                                                            "sequence_number") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.advertising_router.is_set or
                                                self.checksum.is_set or
                                                self.dn_age_lsa.is_set or
                                                self.ls_type.is_set or
                                                self.lsa_age.is_set or
                                                self.lsa_area_id.is_set or
                                                self.lsid.is_set or
                                                self.nsf.is_set or
                                                self.sequence_number.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.advertising_router.yfilter != YFilter.not_set or
                                                self.checksum.yfilter != YFilter.not_set or
                                                self.dn_age_lsa.yfilter != YFilter.not_set or
                                                self.ls_type.yfilter != YFilter.not_set or
                                                self.lsa_age.yfilter != YFilter.not_set or
                                                self.lsa_area_id.yfilter != YFilter.not_set or
                                                self.lsid.yfilter != YFilter.not_set or
                                                self.nsf.yfilter != YFilter.not_set or
                                                self.sequence_number.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "lsa-header" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                            if (self.checksum.is_set or self.checksum.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.checksum.get_name_leafdata())
                                            if (self.dn_age_lsa.is_set or self.dn_age_lsa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dn_age_lsa.get_name_leafdata())
                                            if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ls_type.get_name_leafdata())
                                            if (self.lsa_age.is_set or self.lsa_age.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_age.get_name_leafdata())
                                            if (self.lsa_area_id.is_set or self.lsa_area_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsa_area_id.get_name_leafdata())
                                            if (self.lsid.is_set or self.lsid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsid.get_name_leafdata())
                                            if (self.nsf.is_set or self.nsf.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.nsf.get_name_leafdata())
                                            if (self.sequence_number.is_set or self.sequence_number.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "advertising-router" or name == "checksum" or name == "dn-age-lsa" or name == "ls-type" or name == "lsa-age" or name == "lsa-area-id" or name == "lsid" or name == "nsf" or name == "sequence-number"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "advertising-router"):
                                                self.advertising_router = value
                                                self.advertising_router.value_namespace = name_space
                                                self.advertising_router.value_namespace_prefix = name_space_prefix
                                            if(value_path == "checksum"):
                                                self.checksum = value
                                                self.checksum.value_namespace = name_space
                                                self.checksum.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dn-age-lsa"):
                                                self.dn_age_lsa = value
                                                self.dn_age_lsa.value_namespace = name_space
                                                self.dn_age_lsa.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ls-type"):
                                                self.ls_type = value
                                                self.ls_type.value_namespace = name_space
                                                self.ls_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-age"):
                                                self.lsa_age = value
                                                self.lsa_age.value_namespace = name_space
                                                self.lsa_age.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsa-area-id"):
                                                self.lsa_area_id = value
                                                self.lsa_area_id.value_namespace = name_space
                                                self.lsa_area_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsid"):
                                                self.lsid = value
                                                self.lsid.value_namespace = name_space
                                                self.lsid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "nsf"):
                                                self.nsf = value
                                                self.nsf.value_namespace = name_space
                                                self.nsf.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number"):
                                                self.sequence_number = value
                                                self.sequence_number.value_namespace = name_space
                                                self.sequence_number.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.advertising_router.is_set or
                                            self.area_id.is_set or
                                            self.external_tag.is_set or
                                            self.interface_name.is_set or
                                            self.link_count.is_set or
                                            self.ls_id.is_set or
                                            self.ls_type.is_set or
                                            (self.lsa_header is not None and self.lsa_header.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.advertising_router.yfilter != YFilter.not_set or
                                            self.area_id.yfilter != YFilter.not_set or
                                            self.external_tag.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.link_count.yfilter != YFilter.not_set or
                                            self.ls_id.yfilter != YFilter.not_set or
                                            self.ls_type.yfilter != YFilter.not_set or
                                            (self.lsa_header is not None and self.lsa_header.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lsa-summary" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                        if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.area_id.get_name_leafdata())
                                        if (self.external_tag.is_set or self.external_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.external_tag.get_name_leafdata())
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.link_count.is_set or self.link_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_count.get_name_leafdata())
                                        if (self.ls_id.is_set or self.ls_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ls_id.get_name_leafdata())
                                        if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ls_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "lsa-header"):
                                            if (self.lsa_header is None):
                                                self.lsa_header = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                            return self.lsa_header

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lsa-header" or name == "advertising-router" or name == "area-id" or name == "external-tag" or name == "interface-name" or name == "link-count" or name == "ls-id" or name == "ls-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "advertising-router"):
                                            self.advertising_router = value
                                            self.advertising_router.value_namespace = name_space
                                            self.advertising_router.value_namespace_prefix = name_space_prefix
                                        if(value_path == "area-id"):
                                            self.area_id = value
                                            self.area_id.value_namespace = name_space
                                            self.area_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "external-tag"):
                                            self.external_tag = value
                                            self.external_tag.value_namespace = name_space
                                            self.external_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-count"):
                                            self.link_count = value
                                            self.link_count.value_namespace = name_space
                                            self.link_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ls-id"):
                                            self.ls_id = value
                                            self.ls_id.value_namespace = name_space
                                            self.ls_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ls-type"):
                                            self.ls_type = value
                                            self.ls_type.value_namespace = name_space
                                            self.ls_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.lsa_summary:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.lsa_summary:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "lsa-summaries" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "lsa-summary"):
                                        for c in self.lsa_summary:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.lsa_summary.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lsa-summary"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.area_id.is_set or
                                    (self.lsa_summaries is not None and self.lsa_summaries.has_data()) or
                                    (self.lsas is not None and self.lsas.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.area_id.yfilter != YFilter.not_set or
                                    (self.lsa_summaries is not None and self.lsa_summaries.has_operation()) or
                                    (self.lsas is not None and self.lsas.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "database-area" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "lsa-summaries"):
                                    if (self.lsa_summaries is None):
                                        self.lsa_summaries = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries()
                                        self.lsa_summaries.parent = self
                                        self._children_name_map["lsa_summaries"] = "lsa-summaries"
                                    return self.lsa_summaries

                                if (child_yang_name == "lsas"):
                                    if (self.lsas is None):
                                        self.lsas = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas()
                                        self.lsas.parent = self
                                        self._children_name_map["lsas"] = "lsas"
                                    return self.lsas

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "lsa-summaries" or name == "lsas" or name == "area-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "area-id"):
                                    self.area_id = value
                                    self.area_id.value_namespace = name_space
                                    self.area_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.database_area:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.database_area:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "database-areas" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "database-area"):
                                for c in self.database_area:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.database_area.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "database-area"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class DatabaseSummaries(Entity):
                        """
                        Link State database summary table
                        
                        .. attribute:: database_summary
                        
                        	Link State Database summary for a particular area
                        	**type**\: list of    :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries, self).__init__()

                            self.yang_name = "database-summaries"
                            self.yang_parent_name = "database"

                            self.database_summary = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries, self).__setattr__(name, value)


                        class DatabaseSummary(Entity):
                            """
                            Link State Database summary for a particular
                            area
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: area_lsa_counter
                            
                            	Summary counters for Area scope LSAs
                            	**type**\: list of    :py:class:`AreaLsaCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter>`
                            
                            .. attribute:: dbase_sum_area_id_string
                            
                            	Area id
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary, self).__init__()

                                self.yang_name = "database-summary"
                                self.yang_parent_name = "database-summaries"

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.dbase_sum_area_id_string = YLeaf(YType.str, "dbase-sum-area-id-string")

                                self.area_lsa_counter = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("area_id",
                                                "dbase_sum_area_id_string") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary, self).__setattr__(name, value)


                            class AreaLsaCounter(Entity):
                                """
                                Summary counters for Area scope LSAs
                                
                                .. attribute:: lsa_count
                                
                                	Number of LSAs of this type
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_delete_count
                                
                                	Number of deleted LSAs of this type
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_maxage_count
                                
                                	Number of MaxAged LSAs of this type
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_self_count
                                
                                	Number of self\-generated LSAs
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_type
                                
                                	Type of LSAs
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter, self).__init__()

                                    self.yang_name = "area-lsa-counter"
                                    self.yang_parent_name = "database-summary"

                                    self.lsa_count = YLeaf(YType.int32, "lsa-count")

                                    self.lsa_delete_count = YLeaf(YType.int32, "lsa-delete-count")

                                    self.lsa_maxage_count = YLeaf(YType.int32, "lsa-maxage-count")

                                    self.lsa_self_count = YLeaf(YType.int32, "lsa-self-count")

                                    self.lsa_type = YLeaf(YType.enumeration, "lsa-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("lsa_count",
                                                    "lsa_delete_count",
                                                    "lsa_maxage_count",
                                                    "lsa_self_count",
                                                    "lsa_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.lsa_count.is_set or
                                        self.lsa_delete_count.is_set or
                                        self.lsa_maxage_count.is_set or
                                        self.lsa_self_count.is_set or
                                        self.lsa_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.lsa_count.yfilter != YFilter.not_set or
                                        self.lsa_delete_count.yfilter != YFilter.not_set or
                                        self.lsa_maxage_count.yfilter != YFilter.not_set or
                                        self.lsa_self_count.yfilter != YFilter.not_set or
                                        self.lsa_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "area-lsa-counter" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.lsa_count.is_set or self.lsa_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_count.get_name_leafdata())
                                    if (self.lsa_delete_count.is_set or self.lsa_delete_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_delete_count.get_name_leafdata())
                                    if (self.lsa_maxage_count.is_set or self.lsa_maxage_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_maxage_count.get_name_leafdata())
                                    if (self.lsa_self_count.is_set or self.lsa_self_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_self_count.get_name_leafdata())
                                    if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lsa-count" or name == "lsa-delete-count" or name == "lsa-maxage-count" or name == "lsa-self-count" or name == "lsa-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "lsa-count"):
                                        self.lsa_count = value
                                        self.lsa_count.value_namespace = name_space
                                        self.lsa_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-delete-count"):
                                        self.lsa_delete_count = value
                                        self.lsa_delete_count.value_namespace = name_space
                                        self.lsa_delete_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-maxage-count"):
                                        self.lsa_maxage_count = value
                                        self.lsa_maxage_count.value_namespace = name_space
                                        self.lsa_maxage_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-self-count"):
                                        self.lsa_self_count = value
                                        self.lsa_self_count.value_namespace = name_space
                                        self.lsa_self_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-type"):
                                        self.lsa_type = value
                                        self.lsa_type.value_namespace = name_space
                                        self.lsa_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.area_lsa_counter:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.area_id.is_set or
                                    self.dbase_sum_area_id_string.is_set)

                            def has_operation(self):
                                for c in self.area_lsa_counter:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.area_id.yfilter != YFilter.not_set or
                                    self.dbase_sum_area_id_string.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "database-summary" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                if (self.dbase_sum_area_id_string.is_set or self.dbase_sum_area_id_string.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dbase_sum_area_id_string.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "area-lsa-counter"):
                                    for c in self.area_lsa_counter:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.area_lsa_counter.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "area-lsa-counter" or name == "area-id" or name == "dbase-sum-area-id-string"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "area-id"):
                                    self.area_id = value
                                    self.area_id.value_namespace = name_space
                                    self.area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "dbase-sum-area-id-string"):
                                    self.dbase_sum_area_id_string = value
                                    self.dbase_sum_area_id_string.value_namespace = name_space
                                    self.dbase_sum_area_id_string.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.database_summary:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.database_summary:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "database-summaries" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "database-summary"):
                                for c in self.database_summary:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.database_summary.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "database-summary"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class DatabaseSummaryAs(Entity):
                        """
                        Link State Database summary for the AS
                        
                        .. attribute:: as_lsa_counter
                        
                        	Summary counter for AS scope LSAs
                        	**type**\: list of    :py:class:`AsLsaCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs.AsLsaCounter>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs, self).__init__()

                            self.yang_name = "database-summary-as"
                            self.yang_parent_name = "database"

                            self.as_lsa_counter = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs, self).__setattr__(name, value)


                        class AsLsaCounter(Entity):
                            """
                            Summary counter for AS scope LSAs
                            
                            .. attribute:: lsa_count
                            
                            	Number of LSAs of this type
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: lsa_delete_count
                            
                            	Number of deleted LSAs of this type
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: lsa_maxage_count
                            
                            	Number of MaxAged LSAs of this type
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: lsa_self_count
                            
                            	Number of self\-generated LSAs
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: lsa_type
                            
                            	Type of LSAs
                            	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs.AsLsaCounter, self).__init__()

                                self.yang_name = "as-lsa-counter"
                                self.yang_parent_name = "database-summary-as"

                                self.lsa_count = YLeaf(YType.int32, "lsa-count")

                                self.lsa_delete_count = YLeaf(YType.int32, "lsa-delete-count")

                                self.lsa_maxage_count = YLeaf(YType.int32, "lsa-maxage-count")

                                self.lsa_self_count = YLeaf(YType.int32, "lsa-self-count")

                                self.lsa_type = YLeaf(YType.enumeration, "lsa-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("lsa_count",
                                                "lsa_delete_count",
                                                "lsa_maxage_count",
                                                "lsa_self_count",
                                                "lsa_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs.AsLsaCounter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs.AsLsaCounter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.lsa_count.is_set or
                                    self.lsa_delete_count.is_set or
                                    self.lsa_maxage_count.is_set or
                                    self.lsa_self_count.is_set or
                                    self.lsa_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.lsa_count.yfilter != YFilter.not_set or
                                    self.lsa_delete_count.yfilter != YFilter.not_set or
                                    self.lsa_maxage_count.yfilter != YFilter.not_set or
                                    self.lsa_self_count.yfilter != YFilter.not_set or
                                    self.lsa_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "as-lsa-counter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.lsa_count.is_set or self.lsa_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsa_count.get_name_leafdata())
                                if (self.lsa_delete_count.is_set or self.lsa_delete_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsa_delete_count.get_name_leafdata())
                                if (self.lsa_maxage_count.is_set or self.lsa_maxage_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsa_maxage_count.get_name_leafdata())
                                if (self.lsa_self_count.is_set or self.lsa_self_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsa_self_count.get_name_leafdata())
                                if (self.lsa_type.is_set or self.lsa_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsa_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "lsa-count" or name == "lsa-delete-count" or name == "lsa-maxage-count" or name == "lsa-self-count" or name == "lsa-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "lsa-count"):
                                    self.lsa_count = value
                                    self.lsa_count.value_namespace = name_space
                                    self.lsa_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsa-delete-count"):
                                    self.lsa_delete_count = value
                                    self.lsa_delete_count.value_namespace = name_space
                                    self.lsa_delete_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsa-maxage-count"):
                                    self.lsa_maxage_count = value
                                    self.lsa_maxage_count.value_namespace = name_space
                                    self.lsa_maxage_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsa-self-count"):
                                    self.lsa_self_count = value
                                    self.lsa_self_count.value_namespace = name_space
                                    self.lsa_self_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsa-type"):
                                    self.lsa_type = value
                                    self.lsa_type.value_namespace = name_space
                                    self.lsa_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.as_lsa_counter:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.as_lsa_counter:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "database-summary-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "as-lsa-counter"):
                                for c in self.as_lsa_counter:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs.AsLsaCounter()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.as_lsa_counter.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "as-lsa-counter"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Lsas(Entity):
                        """
                        Link State Database Table
                        
                        .. attribute:: lsa
                        
                        	Link State Advertisement information
                        	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas, self).__init__()

                            self.yang_name = "lsas"
                            self.yang_parent_name = "database"

                            self.lsa = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas, self).__setattr__(name, value)


                        class Lsa(Entity):
                            """
                            Link State Advertisement information
                            
                            .. attribute:: advertising_router
                            
                            	Advertising Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_id
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	InterfaceName
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ls_id
                            
                            	Link state ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ls_type
                            
                            	Link state type
                            	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                            
                            .. attribute:: lsa_detail_data
                            
                            	Detailed LSA Information
                            	**type**\:   :py:class:`LsaDetailData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData>`
                            
                            .. attribute:: lsa_header
                            
                            	Header information
                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaHeader>`
                            
                            .. attribute:: lsa_internal_data
                            
                            	Information pertaining to a specific LSA type
                            	**type**\:   :py:class:`LsaInternalData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa, self).__init__()

                                self.yang_name = "lsa"
                                self.yang_parent_name = "lsas"

                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.ls_id = YLeaf(YType.str, "ls-id")

                                self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                self.lsa_detail_data = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData()
                                self.lsa_detail_data.parent = self
                                self._children_name_map["lsa_detail_data"] = "lsa-detail-data"
                                self._children_yang_names.add("lsa-detail-data")

                                self.lsa_header = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaHeader()
                                self.lsa_header.parent = self
                                self._children_name_map["lsa_header"] = "lsa-header"
                                self._children_yang_names.add("lsa-header")

                                self.lsa_internal_data = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData()
                                self.lsa_internal_data.parent = self
                                self._children_name_map["lsa_internal_data"] = "lsa-internal-data"
                                self._children_yang_names.add("lsa-internal-data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("advertising_router",
                                                "area_id",
                                                "interface_name",
                                                "ls_id",
                                                "ls_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa, self).__setattr__(name, value)


                            class LsaHeader(Entity):
                                """
                                Header information
                                
                                .. attribute:: advertising_router
                                
                                	Router ID of Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: checksum
                                
                                	Checksum value
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dn_age_lsa
                                
                                	If true, Do Not Age this LSA
                                	**type**\:  bool
                                
                                .. attribute:: ls_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: lsa_age
                                
                                	LSA's Age (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsa_area_id
                                
                                	Area ID in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: lsid
                                
                                	LS ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: nsf
                                
                                	If true,  LSA received from neighbor during NSF
                                	**type**\:  bool
                                
                                .. attribute:: sequence_number
                                
                                	Current Sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaHeader, self).__init__()

                                    self.yang_name = "lsa-header"
                                    self.yang_parent_name = "lsa"

                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                    self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                    self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                    self.lsid = YLeaf(YType.str, "lsid")

                                    self.nsf = YLeaf(YType.boolean, "nsf")

                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("advertising_router",
                                                    "checksum",
                                                    "dn_age_lsa",
                                                    "ls_type",
                                                    "lsa_age",
                                                    "lsa_area_id",
                                                    "lsid",
                                                    "nsf",
                                                    "sequence_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaHeader, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaHeader, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.advertising_router.is_set or
                                        self.checksum.is_set or
                                        self.dn_age_lsa.is_set or
                                        self.ls_type.is_set or
                                        self.lsa_age.is_set or
                                        self.lsa_area_id.is_set or
                                        self.lsid.is_set or
                                        self.nsf.is_set or
                                        self.sequence_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.advertising_router.yfilter != YFilter.not_set or
                                        self.checksum.yfilter != YFilter.not_set or
                                        self.dn_age_lsa.yfilter != YFilter.not_set or
                                        self.ls_type.yfilter != YFilter.not_set or
                                        self.lsa_age.yfilter != YFilter.not_set or
                                        self.lsa_area_id.yfilter != YFilter.not_set or
                                        self.lsid.yfilter != YFilter.not_set or
                                        self.nsf.yfilter != YFilter.not_set or
                                        self.sequence_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "lsa-header" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                    if (self.checksum.is_set or self.checksum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.checksum.get_name_leafdata())
                                    if (self.dn_age_lsa.is_set or self.dn_age_lsa.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dn_age_lsa.get_name_leafdata())
                                    if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ls_type.get_name_leafdata())
                                    if (self.lsa_age.is_set or self.lsa_age.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_age.get_name_leafdata())
                                    if (self.lsa_area_id.is_set or self.lsa_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_area_id.get_name_leafdata())
                                    if (self.lsid.is_set or self.lsid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsid.get_name_leafdata())
                                    if (self.nsf.is_set or self.nsf.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsf.get_name_leafdata())
                                    if (self.sequence_number.is_set or self.sequence_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "advertising-router" or name == "checksum" or name == "dn-age-lsa" or name == "ls-type" or name == "lsa-age" or name == "lsa-area-id" or name == "lsid" or name == "nsf" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "advertising-router"):
                                        self.advertising_router = value
                                        self.advertising_router.value_namespace = name_space
                                        self.advertising_router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "checksum"):
                                        self.checksum = value
                                        self.checksum.value_namespace = name_space
                                        self.checksum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dn-age-lsa"):
                                        self.dn_age_lsa = value
                                        self.dn_age_lsa.value_namespace = name_space
                                        self.dn_age_lsa.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ls-type"):
                                        self.ls_type = value
                                        self.ls_type.value_namespace = name_space
                                        self.ls_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-age"):
                                        self.lsa_age = value
                                        self.lsa_age.value_namespace = name_space
                                        self.lsa_age.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-area-id"):
                                        self.lsa_area_id = value
                                        self.lsa_area_id.value_namespace = name_space
                                        self.lsa_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsid"):
                                        self.lsid = value
                                        self.lsid.value_namespace = name_space
                                        self.lsid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsf"):
                                        self.nsf = value
                                        self.nsf.value_namespace = name_space
                                        self.nsf.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number"):
                                        self.sequence_number = value
                                        self.sequence_number.value_namespace = name_space
                                        self.sequence_number.value_namespace_prefix = name_space_prefix


                            class LsaDetailData(Entity):
                                """
                                Detailed LSA Information
                                
                                .. attribute:: advertising_router_reachable
                                
                                	If true, Advertising Router is reachable
                                	**type**\:  bool
                                
                                .. attribute:: ase_origin
                                
                                	External Origin
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: demand_circuit
                                
                                	If true, capable of demand circuit as indicated by LSA's option field
                                	**type**\:  bool
                                
                                .. attribute:: dn_bit
                                
                                	if true, DN bit set on the summary LSA indicated by LSA's option field
                                	**type**\:  bool
                                
                                .. attribute:: in_sync
                                
                                	Not In Sync With Active
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: length
                                
                                	Length of the LSA
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsa_flood_required_post_fail_over
                                
                                	LSA flood required after FO
                                	**type**\:  bool
                                
                                .. attribute:: lsa_last_updated_time
                                
                                	Time LSA was last updated
                                	**type**\:   :py:class:`LsaLastUpdatedTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime>`
                                
                                .. attribute:: lsa_prefix_priority
                                
                                	Current LSA prefix priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: lsa_rate_limit_due_time
                                
                                	Due time for rate\-limit timer (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_throttle_timer
                                
                                	LSA throttle timer table information
                                	**type**\:   :py:class:`LsaThrottleTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer>`
                                
                                .. attribute:: lsadb_base_clock
                                
                                	Clock stamp since boot
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: lsadb_base_time_stamp
                                
                                	Current time stamp
                                	**type**\:   :py:class:`LsadbBaseTimeStamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp>`
                                
                                .. attribute:: new_lsa_prefix_priority
                                
                                	New LSA prefix priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: not_delete
                                
                                	Reason why LSA is not deleted
                                	**type**\:   :py:class:`NotDelete <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.NotDelete>`
                                
                                .. attribute:: nssa_translation
                                
                                	If true,  capable of type 7 to 5 translation indicated by LSA's option field
                                	**type**\:  bool
                                
                                .. attribute:: routing_bit
                                
                                	If true, Routing Bit set on the LSA
                                	**type**\:  bool
                                
                                .. attribute:: sum_origin
                                
                                	Summary Origin
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: tos_capable
                                
                                	If true, type of service capable indicated by LSA's option field
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData, self).__init__()

                                    self.yang_name = "lsa-detail-data"
                                    self.yang_parent_name = "lsa"

                                    self.advertising_router_reachable = YLeaf(YType.boolean, "advertising-router-reachable")

                                    self.ase_origin = YLeaf(YType.uint16, "ase-origin")

                                    self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                    self.dn_bit = YLeaf(YType.boolean, "dn-bit")

                                    self.in_sync = YLeaf(YType.uint8, "in-sync")

                                    self.length = YLeaf(YType.uint16, "length")

                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                    self.lsa_prefix_priority = YLeaf(YType.uint8, "lsa-prefix-priority")

                                    self.lsa_rate_limit_due_time = YLeaf(YType.uint32, "lsa-rate-limit-due-time")

                                    self.lsadb_base_clock = YLeaf(YType.uint64, "lsadb-base-clock")

                                    self.new_lsa_prefix_priority = YLeaf(YType.uint8, "new-lsa-prefix-priority")

                                    self.nssa_translation = YLeaf(YType.boolean, "nssa-translation")

                                    self.routing_bit = YLeaf(YType.boolean, "routing-bit")

                                    self.sum_origin = YLeaf(YType.uint16, "sum-origin")

                                    self.tos_capable = YLeaf(YType.boolean, "tos-capable")

                                    self.lsa_last_updated_time = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime()
                                    self.lsa_last_updated_time.parent = self
                                    self._children_name_map["lsa_last_updated_time"] = "lsa-last-updated-time"
                                    self._children_yang_names.add("lsa-last-updated-time")

                                    self.lsa_throttle_timer = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer()
                                    self.lsa_throttle_timer.parent = self
                                    self._children_name_map["lsa_throttle_timer"] = "lsa-throttle-timer"
                                    self._children_yang_names.add("lsa-throttle-timer")

                                    self.lsadb_base_time_stamp = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp()
                                    self.lsadb_base_time_stamp.parent = self
                                    self._children_name_map["lsadb_base_time_stamp"] = "lsadb-base-time-stamp"
                                    self._children_yang_names.add("lsadb-base-time-stamp")

                                    self.not_delete = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.NotDelete()
                                    self.not_delete.parent = self
                                    self._children_name_map["not_delete"] = "not-delete"
                                    self._children_yang_names.add("not-delete")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("advertising_router_reachable",
                                                    "ase_origin",
                                                    "demand_circuit",
                                                    "dn_bit",
                                                    "in_sync",
                                                    "length",
                                                    "lsa_flood_required_post_fail_over",
                                                    "lsa_prefix_priority",
                                                    "lsa_rate_limit_due_time",
                                                    "lsadb_base_clock",
                                                    "new_lsa_prefix_priority",
                                                    "nssa_translation",
                                                    "routing_bit",
                                                    "sum_origin",
                                                    "tos_capable") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData, self).__setattr__(name, value)


                                class LsaThrottleTimer(Entity):
                                    """
                                    LSA throttle timer table information
                                    
                                    .. attribute:: last_inst_minute_table_index
                                    
                                    	Last Minute table index processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_inst_second_table_index
                                    
                                    	Last Second table index processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: minute_table_index
                                    
                                    	Minute table index
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: second_table_index
                                    
                                    	Second table index
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: timer_location
                                    
                                    	Timer table
                                    	**type**\:   :py:class:`TimerTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.TimerTable>`
                                    
                                    .. attribute:: timer_type
                                    
                                    	Timer type
                                    	**type**\:   :py:class:`Timer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Timer>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__init__()

                                        self.yang_name = "lsa-throttle-timer"
                                        self.yang_parent_name = "lsa-detail-data"

                                        self.last_inst_minute_table_index = YLeaf(YType.uint8, "last-inst-minute-table-index")

                                        self.last_inst_second_table_index = YLeaf(YType.uint8, "last-inst-second-table-index")

                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")

                                        self.timer_location = YLeaf(YType.enumeration, "timer-location")

                                        self.timer_type = YLeaf(YType.enumeration, "timer-type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("last_inst_minute_table_index",
                                                        "last_inst_second_table_index",
                                                        "minute_table_index",
                                                        "second_table_index",
                                                        "timer_location",
                                                        "timer_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.last_inst_minute_table_index.is_set or
                                            self.last_inst_second_table_index.is_set or
                                            self.minute_table_index.is_set or
                                            self.second_table_index.is_set or
                                            self.timer_location.is_set or
                                            self.timer_type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.last_inst_minute_table_index.yfilter != YFilter.not_set or
                                            self.last_inst_second_table_index.yfilter != YFilter.not_set or
                                            self.minute_table_index.yfilter != YFilter.not_set or
                                            self.second_table_index.yfilter != YFilter.not_set or
                                            self.timer_location.yfilter != YFilter.not_set or
                                            self.timer_type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lsa-throttle-timer" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.last_inst_minute_table_index.is_set or self.last_inst_minute_table_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_inst_minute_table_index.get_name_leafdata())
                                        if (self.last_inst_second_table_index.is_set or self.last_inst_second_table_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_inst_second_table_index.get_name_leafdata())
                                        if (self.minute_table_index.is_set or self.minute_table_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minute_table_index.get_name_leafdata())
                                        if (self.second_table_index.is_set or self.second_table_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second_table_index.get_name_leafdata())
                                        if (self.timer_location.is_set or self.timer_location.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timer_location.get_name_leafdata())
                                        if (self.timer_type.is_set or self.timer_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timer_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "last-inst-minute-table-index" or name == "last-inst-second-table-index" or name == "minute-table-index" or name == "second-table-index" or name == "timer-location" or name == "timer-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "last-inst-minute-table-index"):
                                            self.last_inst_minute_table_index = value
                                            self.last_inst_minute_table_index.value_namespace = name_space
                                            self.last_inst_minute_table_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-inst-second-table-index"):
                                            self.last_inst_second_table_index = value
                                            self.last_inst_second_table_index.value_namespace = name_space
                                            self.last_inst_second_table_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minute-table-index"):
                                            self.minute_table_index = value
                                            self.minute_table_index.value_namespace = name_space
                                            self.minute_table_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second-table-index"):
                                            self.second_table_index = value
                                            self.second_table_index.value_namespace = name_space
                                            self.second_table_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timer-location"):
                                            self.timer_location = value
                                            self.timer_location.value_namespace = name_space
                                            self.timer_location.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timer-type"):
                                            self.timer_type = value
                                            self.timer_type.value_namespace = name_space
                                            self.timer_type.value_namespace_prefix = name_space_prefix


                                class LsaLastUpdatedTime(Entity):
                                    """
                                    Time LSA was last updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__init__()

                                        self.yang_name = "lsa-last-updated-time"
                                        self.yang_parent_name = "lsa-detail-data"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lsa-last-updated-time" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix


                                class LsadbBaseTimeStamp(Entity):
                                    """
                                    Current time stamp
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__init__()

                                        self.yang_name = "lsadb-base-time-stamp"
                                        self.yang_parent_name = "lsa-detail-data"

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nanosecond",
                                                        "second") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nanosecond.is_set or
                                            self.second.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nanosecond.yfilter != YFilter.not_set or
                                            self.second.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lsadb-base-time-stamp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nanosecond.is_set or self.nanosecond.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nanosecond.get_name_leafdata())
                                        if (self.second.is_set or self.second.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.second.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nanosecond" or name == "second"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nanosecond"):
                                            self.nanosecond = value
                                            self.nanosecond.value_namespace = name_space
                                            self.nanosecond.value_namespace_prefix = name_space_prefix
                                        if(value_path == "second"):
                                            self.second = value
                                            self.second.value_namespace = name_space
                                            self.second.value_namespace_prefix = name_space_prefix


                                class NotDelete(Entity):
                                    """
                                    Reason why LSA is not deleted
                                    
                                    .. attribute:: acknowledgement
                                    
                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_pending
                                    
                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                    	**type**\:  bool
                                    
                                    .. attribute:: free_time
                                    
                                    	The amount of time since the last check was made to free this LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_age
                                    
                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_exchange
                                    
                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                    	**type**\:  bool
                                    
                                    .. attribute:: no_delete
                                    
                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_ack_pending
                                    
                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_flood_required
                                    
                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                    	**type**\:  bool
                                    
                                    .. attribute:: partial_spf
                                    
                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                    	**type**\:  bool
                                    
                                    .. attribute:: rate_limit
                                    
                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                    	**type**\:  bool
                                    
                                    .. attribute:: routing_table
                                    
                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table
                                    	**type**\:  bool
                                    
                                    .. attribute:: sum_orig_pending
                                    
                                    	If true, the reason not to delete this LSA is because it is pending summary LSA originating
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.NotDelete, self).__init__()

                                        self.yang_name = "not-delete"
                                        self.yang_parent_name = "lsa-detail-data"

                                        self.acknowledgement = YLeaf(YType.boolean, "acknowledgement")

                                        self.flood_pending = YLeaf(YType.boolean, "flood-pending")

                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                        self.maximum_age = YLeaf(YType.boolean, "maximum-age")

                                        self.neighbor_exchange = YLeaf(YType.boolean, "neighbor-exchange")

                                        self.no_delete = YLeaf(YType.boolean, "no-delete")

                                        self.nsr_ack_pending = YLeaf(YType.boolean, "nsr-ack-pending")

                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                        self.partial_spf = YLeaf(YType.boolean, "partial-spf")

                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                        self.routing_table = YLeaf(YType.boolean, "routing-table")

                                        self.sum_orig_pending = YLeaf(YType.boolean, "sum-orig-pending")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("acknowledgement",
                                                        "flood_pending",
                                                        "free_time",
                                                        "maximum_age",
                                                        "neighbor_exchange",
                                                        "no_delete",
                                                        "nsr_ack_pending",
                                                        "nsr_flood_required",
                                                        "partial_spf",
                                                        "rate_limit",
                                                        "routing_table",
                                                        "sum_orig_pending") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.NotDelete, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.NotDelete, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.acknowledgement.is_set or
                                            self.flood_pending.is_set or
                                            self.free_time.is_set or
                                            self.maximum_age.is_set or
                                            self.neighbor_exchange.is_set or
                                            self.no_delete.is_set or
                                            self.nsr_ack_pending.is_set or
                                            self.nsr_flood_required.is_set or
                                            self.partial_spf.is_set or
                                            self.rate_limit.is_set or
                                            self.routing_table.is_set or
                                            self.sum_orig_pending.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.acknowledgement.yfilter != YFilter.not_set or
                                            self.flood_pending.yfilter != YFilter.not_set or
                                            self.free_time.yfilter != YFilter.not_set or
                                            self.maximum_age.yfilter != YFilter.not_set or
                                            self.neighbor_exchange.yfilter != YFilter.not_set or
                                            self.no_delete.yfilter != YFilter.not_set or
                                            self.nsr_ack_pending.yfilter != YFilter.not_set or
                                            self.nsr_flood_required.yfilter != YFilter.not_set or
                                            self.partial_spf.yfilter != YFilter.not_set or
                                            self.rate_limit.yfilter != YFilter.not_set or
                                            self.routing_table.yfilter != YFilter.not_set or
                                            self.sum_orig_pending.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "not-delete" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.acknowledgement.is_set or self.acknowledgement.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.acknowledgement.get_name_leafdata())
                                        if (self.flood_pending.is_set or self.flood_pending.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_pending.get_name_leafdata())
                                        if (self.free_time.is_set or self.free_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.free_time.get_name_leafdata())
                                        if (self.maximum_age.is_set or self.maximum_age.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_age.get_name_leafdata())
                                        if (self.neighbor_exchange.is_set or self.neighbor_exchange.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_exchange.get_name_leafdata())
                                        if (self.no_delete.is_set or self.no_delete.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_delete.get_name_leafdata())
                                        if (self.nsr_ack_pending.is_set or self.nsr_ack_pending.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_ack_pending.get_name_leafdata())
                                        if (self.nsr_flood_required.is_set or self.nsr_flood_required.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nsr_flood_required.get_name_leafdata())
                                        if (self.partial_spf.is_set or self.partial_spf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.partial_spf.get_name_leafdata())
                                        if (self.rate_limit.is_set or self.rate_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rate_limit.get_name_leafdata())
                                        if (self.routing_table.is_set or self.routing_table.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.routing_table.get_name_leafdata())
                                        if (self.sum_orig_pending.is_set or self.sum_orig_pending.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sum_orig_pending.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "acknowledgement" or name == "flood-pending" or name == "free-time" or name == "maximum-age" or name == "neighbor-exchange" or name == "no-delete" or name == "nsr-ack-pending" or name == "nsr-flood-required" or name == "partial-spf" or name == "rate-limit" or name == "routing-table" or name == "sum-orig-pending"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "acknowledgement"):
                                            self.acknowledgement = value
                                            self.acknowledgement.value_namespace = name_space
                                            self.acknowledgement.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-pending"):
                                            self.flood_pending = value
                                            self.flood_pending.value_namespace = name_space
                                            self.flood_pending.value_namespace_prefix = name_space_prefix
                                        if(value_path == "free-time"):
                                            self.free_time = value
                                            self.free_time.value_namespace = name_space
                                            self.free_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-age"):
                                            self.maximum_age = value
                                            self.maximum_age.value_namespace = name_space
                                            self.maximum_age.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-exchange"):
                                            self.neighbor_exchange = value
                                            self.neighbor_exchange.value_namespace = name_space
                                            self.neighbor_exchange.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-delete"):
                                            self.no_delete = value
                                            self.no_delete.value_namespace = name_space
                                            self.no_delete.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-ack-pending"):
                                            self.nsr_ack_pending = value
                                            self.nsr_ack_pending.value_namespace = name_space
                                            self.nsr_ack_pending.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nsr-flood-required"):
                                            self.nsr_flood_required = value
                                            self.nsr_flood_required.value_namespace = name_space
                                            self.nsr_flood_required.value_namespace_prefix = name_space_prefix
                                        if(value_path == "partial-spf"):
                                            self.partial_spf = value
                                            self.partial_spf.value_namespace = name_space
                                            self.partial_spf.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rate-limit"):
                                            self.rate_limit = value
                                            self.rate_limit.value_namespace = name_space
                                            self.rate_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "routing-table"):
                                            self.routing_table = value
                                            self.routing_table.value_namespace = name_space
                                            self.routing_table.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sum-orig-pending"):
                                            self.sum_orig_pending = value
                                            self.sum_orig_pending.value_namespace = name_space
                                            self.sum_orig_pending.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.advertising_router_reachable.is_set or
                                        self.ase_origin.is_set or
                                        self.demand_circuit.is_set or
                                        self.dn_bit.is_set or
                                        self.in_sync.is_set or
                                        self.length.is_set or
                                        self.lsa_flood_required_post_fail_over.is_set or
                                        self.lsa_prefix_priority.is_set or
                                        self.lsa_rate_limit_due_time.is_set or
                                        self.lsadb_base_clock.is_set or
                                        self.new_lsa_prefix_priority.is_set or
                                        self.nssa_translation.is_set or
                                        self.routing_bit.is_set or
                                        self.sum_origin.is_set or
                                        self.tos_capable.is_set or
                                        (self.lsa_last_updated_time is not None and self.lsa_last_updated_time.has_data()) or
                                        (self.lsa_throttle_timer is not None and self.lsa_throttle_timer.has_data()) or
                                        (self.lsadb_base_time_stamp is not None and self.lsadb_base_time_stamp.has_data()) or
                                        (self.not_delete is not None and self.not_delete.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.advertising_router_reachable.yfilter != YFilter.not_set or
                                        self.ase_origin.yfilter != YFilter.not_set or
                                        self.demand_circuit.yfilter != YFilter.not_set or
                                        self.dn_bit.yfilter != YFilter.not_set or
                                        self.in_sync.yfilter != YFilter.not_set or
                                        self.length.yfilter != YFilter.not_set or
                                        self.lsa_flood_required_post_fail_over.yfilter != YFilter.not_set or
                                        self.lsa_prefix_priority.yfilter != YFilter.not_set or
                                        self.lsa_rate_limit_due_time.yfilter != YFilter.not_set or
                                        self.lsadb_base_clock.yfilter != YFilter.not_set or
                                        self.new_lsa_prefix_priority.yfilter != YFilter.not_set or
                                        self.nssa_translation.yfilter != YFilter.not_set or
                                        self.routing_bit.yfilter != YFilter.not_set or
                                        self.sum_origin.yfilter != YFilter.not_set or
                                        self.tos_capable.yfilter != YFilter.not_set or
                                        (self.lsa_last_updated_time is not None and self.lsa_last_updated_time.has_operation()) or
                                        (self.lsa_throttle_timer is not None and self.lsa_throttle_timer.has_operation()) or
                                        (self.lsadb_base_time_stamp is not None and self.lsadb_base_time_stamp.has_operation()) or
                                        (self.not_delete is not None and self.not_delete.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "lsa-detail-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.advertising_router_reachable.is_set or self.advertising_router_reachable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.advertising_router_reachable.get_name_leafdata())
                                    if (self.ase_origin.is_set or self.ase_origin.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ase_origin.get_name_leafdata())
                                    if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                                    if (self.dn_bit.is_set or self.dn_bit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dn_bit.get_name_leafdata())
                                    if (self.in_sync.is_set or self.in_sync.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.in_sync.get_name_leafdata())
                                    if (self.length.is_set or self.length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.length.get_name_leafdata())
                                    if (self.lsa_flood_required_post_fail_over.is_set or self.lsa_flood_required_post_fail_over.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_flood_required_post_fail_over.get_name_leafdata())
                                    if (self.lsa_prefix_priority.is_set or self.lsa_prefix_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_prefix_priority.get_name_leafdata())
                                    if (self.lsa_rate_limit_due_time.is_set or self.lsa_rate_limit_due_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_rate_limit_due_time.get_name_leafdata())
                                    if (self.lsadb_base_clock.is_set or self.lsadb_base_clock.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsadb_base_clock.get_name_leafdata())
                                    if (self.new_lsa_prefix_priority.is_set or self.new_lsa_prefix_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.new_lsa_prefix_priority.get_name_leafdata())
                                    if (self.nssa_translation.is_set or self.nssa_translation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nssa_translation.get_name_leafdata())
                                    if (self.routing_bit.is_set or self.routing_bit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.routing_bit.get_name_leafdata())
                                    if (self.sum_origin.is_set or self.sum_origin.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sum_origin.get_name_leafdata())
                                    if (self.tos_capable.is_set or self.tos_capable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos_capable.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "lsa-last-updated-time"):
                                        if (self.lsa_last_updated_time is None):
                                            self.lsa_last_updated_time = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime()
                                            self.lsa_last_updated_time.parent = self
                                            self._children_name_map["lsa_last_updated_time"] = "lsa-last-updated-time"
                                        return self.lsa_last_updated_time

                                    if (child_yang_name == "lsa-throttle-timer"):
                                        if (self.lsa_throttle_timer is None):
                                            self.lsa_throttle_timer = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer()
                                            self.lsa_throttle_timer.parent = self
                                            self._children_name_map["lsa_throttle_timer"] = "lsa-throttle-timer"
                                        return self.lsa_throttle_timer

                                    if (child_yang_name == "lsadb-base-time-stamp"):
                                        if (self.lsadb_base_time_stamp is None):
                                            self.lsadb_base_time_stamp = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp()
                                            self.lsadb_base_time_stamp.parent = self
                                            self._children_name_map["lsadb_base_time_stamp"] = "lsadb-base-time-stamp"
                                        return self.lsadb_base_time_stamp

                                    if (child_yang_name == "not-delete"):
                                        if (self.not_delete is None):
                                            self.not_delete = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.NotDelete()
                                            self.not_delete.parent = self
                                            self._children_name_map["not_delete"] = "not-delete"
                                        return self.not_delete

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lsa-last-updated-time" or name == "lsa-throttle-timer" or name == "lsadb-base-time-stamp" or name == "not-delete" or name == "advertising-router-reachable" or name == "ase-origin" or name == "demand-circuit" or name == "dn-bit" or name == "in-sync" or name == "length" or name == "lsa-flood-required-post-fail-over" or name == "lsa-prefix-priority" or name == "lsa-rate-limit-due-time" or name == "lsadb-base-clock" or name == "new-lsa-prefix-priority" or name == "nssa-translation" or name == "routing-bit" or name == "sum-origin" or name == "tos-capable"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "advertising-router-reachable"):
                                        self.advertising_router_reachable = value
                                        self.advertising_router_reachable.value_namespace = name_space
                                        self.advertising_router_reachable.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ase-origin"):
                                        self.ase_origin = value
                                        self.ase_origin.value_namespace = name_space
                                        self.ase_origin.value_namespace_prefix = name_space_prefix
                                    if(value_path == "demand-circuit"):
                                        self.demand_circuit = value
                                        self.demand_circuit.value_namespace = name_space
                                        self.demand_circuit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dn-bit"):
                                        self.dn_bit = value
                                        self.dn_bit.value_namespace = name_space
                                        self.dn_bit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "in-sync"):
                                        self.in_sync = value
                                        self.in_sync.value_namespace = name_space
                                        self.in_sync.value_namespace_prefix = name_space_prefix
                                    if(value_path == "length"):
                                        self.length = value
                                        self.length.value_namespace = name_space
                                        self.length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-flood-required-post-fail-over"):
                                        self.lsa_flood_required_post_fail_over = value
                                        self.lsa_flood_required_post_fail_over.value_namespace = name_space
                                        self.lsa_flood_required_post_fail_over.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-prefix-priority"):
                                        self.lsa_prefix_priority = value
                                        self.lsa_prefix_priority.value_namespace = name_space
                                        self.lsa_prefix_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-rate-limit-due-time"):
                                        self.lsa_rate_limit_due_time = value
                                        self.lsa_rate_limit_due_time.value_namespace = name_space
                                        self.lsa_rate_limit_due_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsadb-base-clock"):
                                        self.lsadb_base_clock = value
                                        self.lsadb_base_clock.value_namespace = name_space
                                        self.lsadb_base_clock.value_namespace_prefix = name_space_prefix
                                    if(value_path == "new-lsa-prefix-priority"):
                                        self.new_lsa_prefix_priority = value
                                        self.new_lsa_prefix_priority.value_namespace = name_space
                                        self.new_lsa_prefix_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nssa-translation"):
                                        self.nssa_translation = value
                                        self.nssa_translation.value_namespace = name_space
                                        self.nssa_translation.value_namespace_prefix = name_space_prefix
                                    if(value_path == "routing-bit"):
                                        self.routing_bit = value
                                        self.routing_bit.value_namespace = name_space
                                        self.routing_bit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sum-origin"):
                                        self.sum_origin = value
                                        self.sum_origin.value_namespace = name_space
                                        self.sum_origin.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos-capable"):
                                        self.tos_capable = value
                                        self.tos_capable.value_namespace = name_space
                                        self.tos_capable.value_namespace_prefix = name_space_prefix


                            class LsaInternalData(Entity):
                                """
                                Information pertaining to a specific LSA type
                                
                                .. attribute:: external_lsa_type
                                
                                	External LSA
                                	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType>`
                                
                                .. attribute:: internal_lsa_type
                                
                                	InternalLSAType
                                	**type**\:   :py:class:`OspfInternalLsaTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInternalLsaTypes>`
                                
                                .. attribute:: network_lsa_type
                                
                                	Network LSA
                                	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType>`
                                
                                .. attribute:: opaque_el_lsa_type
                                
                                	Extended Link LSA type
                                	**type**\:   :py:class:`OpaqueElLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType>`
                                
                                .. attribute:: opaque_ep_lsa_type
                                
                                	Extende Prefix LSA type
                                	**type**\:   :py:class:`OpaqueEpLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType>`
                                
                                .. attribute:: opaque_grace_lsa
                                
                                	Opaque\-link, opaque type 3 Grace LSA
                                	**type**\:   :py:class:`OpaqueGraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa>`
                                
                                .. attribute:: opaque_link_lsa_type
                                
                                	Opaque\-Link LSA
                                	**type**\:   :py:class:`OpaqueLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType>`
                                
                                .. attribute:: opaque_mpls_te_lsa_type
                                
                                	Opaque\-Area, opaque type 1 LSA
                                	**type**\:   :py:class:`OpaqueMplsTeLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType>`
                                
                                .. attribute:: opaque_router_info_lsa_type
                                
                                	Opaque Router Information LSA
                                	**type**\:   :py:class:`OpaqueRouterInfoLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType>`
                                
                                .. attribute:: router_lsa_type
                                
                                	Router LSA
                                	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType>`
                                
                                .. attribute:: summary_lsa_type
                                
                                	Summary LSA
                                	**type**\:   :py:class:`SummaryLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData, self).__init__()

                                    self.yang_name = "lsa-internal-data"
                                    self.yang_parent_name = "lsa"

                                    self.internal_lsa_type = YLeaf(YType.enumeration, "internal-lsa-type")

                                    self.external_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType()
                                    self.external_lsa_type.parent = self
                                    self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                    self._children_yang_names.add("external-lsa-type")

                                    self.network_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType()
                                    self.network_lsa_type.parent = self
                                    self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                    self._children_yang_names.add("network-lsa-type")

                                    self.opaque_el_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType()
                                    self.opaque_el_lsa_type.parent = self
                                    self._children_name_map["opaque_el_lsa_type"] = "opaque-el-lsa-type"
                                    self._children_yang_names.add("opaque-el-lsa-type")

                                    self.opaque_ep_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType()
                                    self.opaque_ep_lsa_type.parent = self
                                    self._children_name_map["opaque_ep_lsa_type"] = "opaque-ep-lsa-type"
                                    self._children_yang_names.add("opaque-ep-lsa-type")

                                    self.opaque_grace_lsa = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa()
                                    self.opaque_grace_lsa.parent = self
                                    self._children_name_map["opaque_grace_lsa"] = "opaque-grace-lsa"
                                    self._children_yang_names.add("opaque-grace-lsa")

                                    self.opaque_link_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType()
                                    self.opaque_link_lsa_type.parent = self
                                    self._children_name_map["opaque_link_lsa_type"] = "opaque-link-lsa-type"
                                    self._children_yang_names.add("opaque-link-lsa-type")

                                    self.opaque_mpls_te_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType()
                                    self.opaque_mpls_te_lsa_type.parent = self
                                    self._children_name_map["opaque_mpls_te_lsa_type"] = "opaque-mpls-te-lsa-type"
                                    self._children_yang_names.add("opaque-mpls-te-lsa-type")

                                    self.opaque_router_info_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType()
                                    self.opaque_router_info_lsa_type.parent = self
                                    self._children_name_map["opaque_router_info_lsa_type"] = "opaque-router-info-lsa-type"
                                    self._children_yang_names.add("opaque-router-info-lsa-type")

                                    self.router_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType()
                                    self.router_lsa_type.parent = self
                                    self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                    self._children_yang_names.add("router-lsa-type")

                                    self.summary_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType()
                                    self.summary_lsa_type.parent = self
                                    self._children_name_map["summary_lsa_type"] = "summary-lsa-type"
                                    self._children_yang_names.add("summary-lsa-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_lsa_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData, self).__setattr__(name, value)


                                class RouterLsaType(Entity):
                                    """
                                    Router LSA
                                    
                                    .. attribute:: internal_link
                                    
                                    	List of links for internal LSA
                                    	**type**\: list of    :py:class:`InternalLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink>`
                                    
                                    .. attribute:: internal_lsa
                                    
                                    	If true, internal LSA
                                    	**type**\:  bool
                                    
                                    .. attribute:: link
                                    
                                    	List of links in this LSA
                                    	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link>`
                                    
                                    .. attribute:: router_abr
                                    
                                    	If True, router is an Area Border Router
                                    	**type**\:  bool
                                    
                                    .. attribute:: router_asbr
                                    
                                    	If True, router is an Autonomous system Border Router
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__init__()

                                        self.yang_name = "router-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"

                                        self.internal_lsa = YLeaf(YType.boolean, "internal-lsa")

                                        self.router_abr = YLeaf(YType.boolean, "router-abr")

                                        self.router_asbr = YLeaf(YType.boolean, "router-asbr")

                                        self.internal_link = YList(self)
                                        self.link = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_lsa",
                                                        "router_abr",
                                                        "router_asbr") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__setattr__(name, value)


                                    class Link(Entity):
                                        """
                                        List of links in this LSA
                                        
                                        .. attribute:: link_data
                                        
                                        	Link Data
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: link_id
                                        
                                        	Link ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: link_metric
                                        
                                        	Cost for using this link
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: link_tos
                                        
                                        	List of type of service metrics
                                        	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos>`
                                        
                                        .. attribute:: link_type
                                        
                                        	Type of link
                                        	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__init__()

                                            self.yang_name = "link"
                                            self.yang_parent_name = "router-lsa-type"

                                            self.link_data = YLeaf(YType.str, "link-data")

                                            self.link_id = YLeaf(YType.str, "link-id")

                                            self.link_metric = YLeaf(YType.uint16, "link-metric")

                                            self.link_type = YLeaf(YType.enumeration, "link-type")

                                            self.link_tos = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("link_data",
                                                            "link_id",
                                                            "link_metric",
                                                            "link_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__setattr__(name, value)


                                        class LinkTos(Entity):
                                            """
                                            List of type of service metrics
                                            
                                            .. attribute:: router_tos
                                            
                                            	Type of Service
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service specific metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__init__()

                                                self.yang_name = "link-tos"
                                                self.yang_parent_name = "link"

                                                self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                self.tos_cost = YLeaf(YType.uint16, "tos-cost")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("router_tos",
                                                                "tos_cost") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.router_tos.is_set or
                                                    self.tos_cost.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.router_tos.yfilter != YFilter.not_set or
                                                    self.tos_cost.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "link-tos" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.router_tos.is_set or self.router_tos.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.router_tos.get_name_leafdata())
                                                if (self.tos_cost.is_set or self.tos_cost.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tos_cost.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "router-tos" or name == "tos-cost"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "router-tos"):
                                                    self.router_tos = value
                                                    self.router_tos.value_namespace = name_space
                                                    self.router_tos.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tos-cost"):
                                                    self.tos_cost = value
                                                    self.tos_cost.value_namespace = name_space
                                                    self.tos_cost.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.link_tos:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.link_data.is_set or
                                                self.link_id.is_set or
                                                self.link_metric.is_set or
                                                self.link_type.is_set)

                                        def has_operation(self):
                                            for c in self.link_tos:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.link_data.yfilter != YFilter.not_set or
                                                self.link_id.yfilter != YFilter.not_set or
                                                self.link_metric.yfilter != YFilter.not_set or
                                                self.link_type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "link" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.link_data.is_set or self.link_data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_data.get_name_leafdata())
                                            if (self.link_id.is_set or self.link_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_id.get_name_leafdata())
                                            if (self.link_metric.is_set or self.link_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_metric.get_name_leafdata())
                                            if (self.link_type.is_set or self.link_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "link-tos"):
                                                for c in self.link_tos:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.link_tos.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "link-tos" or name == "link-data" or name == "link-id" or name == "link-metric" or name == "link-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "link-data"):
                                                self.link_data = value
                                                self.link_data.value_namespace = name_space
                                                self.link_data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-id"):
                                                self.link_id = value
                                                self.link_id.value_namespace = name_space
                                                self.link_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-metric"):
                                                self.link_metric = value
                                                self.link_metric.value_namespace = name_space
                                                self.link_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-type"):
                                                self.link_type = value
                                                self.link_type.value_namespace = name_space
                                                self.link_type.value_namespace_prefix = name_space_prefix


                                    class InternalLink(Entity):
                                        """
                                        List of links for internal LSA
                                        
                                        .. attribute:: link_data
                                        
                                        	Link Data
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: link_id
                                        
                                        	Link ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: link_metric
                                        
                                        	Cost for using this link
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: link_tos
                                        
                                        	List of type of service metrics
                                        	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos>`
                                        
                                        .. attribute:: link_type
                                        
                                        	Type of link
                                        	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__init__()

                                            self.yang_name = "internal-link"
                                            self.yang_parent_name = "router-lsa-type"

                                            self.link_data = YLeaf(YType.str, "link-data")

                                            self.link_id = YLeaf(YType.str, "link-id")

                                            self.link_metric = YLeaf(YType.uint16, "link-metric")

                                            self.link_type = YLeaf(YType.enumeration, "link-type")

                                            self.link_tos = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("link_data",
                                                            "link_id",
                                                            "link_metric",
                                                            "link_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__setattr__(name, value)


                                        class LinkTos(Entity):
                                            """
                                            List of type of service metrics
                                            
                                            .. attribute:: router_tos
                                            
                                            	Type of Service
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service specific metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__init__()

                                                self.yang_name = "link-tos"
                                                self.yang_parent_name = "internal-link"

                                                self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                self.tos_cost = YLeaf(YType.uint16, "tos-cost")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("router_tos",
                                                                "tos_cost") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.router_tos.is_set or
                                                    self.tos_cost.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.router_tos.yfilter != YFilter.not_set or
                                                    self.tos_cost.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "link-tos" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.router_tos.is_set or self.router_tos.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.router_tos.get_name_leafdata())
                                                if (self.tos_cost.is_set or self.tos_cost.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tos_cost.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "router-tos" or name == "tos-cost"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "router-tos"):
                                                    self.router_tos = value
                                                    self.router_tos.value_namespace = name_space
                                                    self.router_tos.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tos-cost"):
                                                    self.tos_cost = value
                                                    self.tos_cost.value_namespace = name_space
                                                    self.tos_cost.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.link_tos:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.link_data.is_set or
                                                self.link_id.is_set or
                                                self.link_metric.is_set or
                                                self.link_type.is_set)

                                        def has_operation(self):
                                            for c in self.link_tos:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.link_data.yfilter != YFilter.not_set or
                                                self.link_id.yfilter != YFilter.not_set or
                                                self.link_metric.yfilter != YFilter.not_set or
                                                self.link_type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "internal-link" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.link_data.is_set or self.link_data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_data.get_name_leafdata())
                                            if (self.link_id.is_set or self.link_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_id.get_name_leafdata())
                                            if (self.link_metric.is_set or self.link_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_metric.get_name_leafdata())
                                            if (self.link_type.is_set or self.link_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.link_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "link-tos"):
                                                for c in self.link_tos:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.link_tos.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "link-tos" or name == "link-data" or name == "link-id" or name == "link-metric" or name == "link-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "link-data"):
                                                self.link_data = value
                                                self.link_data.value_namespace = name_space
                                                self.link_data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-id"):
                                                self.link_id = value
                                                self.link_id.value_namespace = name_space
                                                self.link_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-metric"):
                                                self.link_metric = value
                                                self.link_metric.value_namespace = name_space
                                                self.link_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "link-type"):
                                                self.link_type = value
                                                self.link_type.value_namespace = name_space
                                                self.link_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.internal_link:
                                            if (c.has_data()):
                                                return True
                                        for c in self.link:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.internal_lsa.is_set or
                                            self.router_abr.is_set or
                                            self.router_asbr.is_set)

                                    def has_operation(self):
                                        for c in self.internal_link:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.link:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_lsa.yfilter != YFilter.not_set or
                                            self.router_abr.yfilter != YFilter.not_set or
                                            self.router_asbr.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "router-lsa-type" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_lsa.is_set or self.internal_lsa.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_lsa.get_name_leafdata())
                                        if (self.router_abr.is_set or self.router_abr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.router_abr.get_name_leafdata())
                                        if (self.router_asbr.is_set or self.router_asbr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.router_asbr.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "internal-link"):
                                            for c in self.internal_link:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.internal_link.append(c)
                                            return c

                                        if (child_yang_name == "link"):
                                            for c in self.link:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.link.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "internal-link" or name == "link" or name == "internal-lsa" or name == "router-abr" or name == "router-asbr"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-lsa"):
                                            self.internal_lsa = value
                                            self.internal_lsa.value_namespace = name_space
                                            self.internal_lsa.value_namespace_prefix = name_space_prefix
                                        if(value_path == "router-abr"):
                                            self.router_abr = value
                                            self.router_abr.value_namespace = name_space
                                            self.router_abr.value_namespace_prefix = name_space_prefix
                                        if(value_path == "router-asbr"):
                                            self.router_asbr = value
                                            self.router_asbr.value_namespace = name_space
                                            self.router_asbr.value_namespace_prefix = name_space_prefix


                                class NetworkLsaType(Entity):
                                    """
                                    Network LSA
                                    
                                    .. attribute:: neighbor_router
                                    
                                    	Neighbor router list
                                    	**type**\: list of    :py:class:`NeighborRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter>`
                                    
                                    .. attribute:: network_prefix_length
                                    
                                    	Network prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__init__()

                                        self.yang_name = "network-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"

                                        self.network_prefix_length = YLeaf(YType.uint32, "network-prefix-length")

                                        self.neighbor_router = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("network_prefix_length") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__setattr__(name, value)


                                    class NeighborRouter(Entity):
                                        """
                                        Neighbor router list
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__init__()

                                            self.yang_name = "neighbor-router"
                                            self.yang_parent_name = "network-lsa-type"

                                            self.entry = YLeaf(YType.str, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor-router" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.neighbor_router:
                                            if (c.has_data()):
                                                return True
                                        return self.network_prefix_length.is_set

                                    def has_operation(self):
                                        for c in self.neighbor_router:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.network_prefix_length.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "network-lsa-type" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.network_prefix_length.is_set or self.network_prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.network_prefix_length.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "neighbor-router"):
                                            for c in self.neighbor_router:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.neighbor_router.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "neighbor-router" or name == "network-prefix-length"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "network-prefix-length"):
                                            self.network_prefix_length = value
                                            self.network_prefix_length.value_namespace = name_space
                                            self.network_prefix_length.value_namespace_prefix = name_space_prefix


                                class SummaryLsaType(Entity):
                                    """
                                    Summary LSA
                                    
                                    .. attribute:: internal_sum_lsa
                                    
                                    	If true, internal max\-metric LSA
                                    	**type**\:  bool
                                    
                                    .. attribute:: summary_lsa_metric
                                    
                                    	Metric
                                    	**type**\: list of    :py:class:`SummaryLsaMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric>`
                                    
                                    .. attribute:: summary_prefix_length
                                    
                                    	Summary LSA prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__init__()

                                        self.yang_name = "summary-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"

                                        self.internal_sum_lsa = YLeaf(YType.boolean, "internal-sum-lsa")

                                        self.summary_prefix_length = YLeaf(YType.uint32, "summary-prefix-length")

                                        self.summary_lsa_metric = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_sum_lsa",
                                                        "summary_prefix_length") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__setattr__(name, value)


                                    class SummaryLsaMetric(Entity):
                                        """
                                        Metric
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__init__()

                                            self.yang_name = "summary-lsa-metric"
                                            self.yang_parent_name = "summary-lsa-type"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "summary-lsa-metric" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.summary_lsa_metric:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.internal_sum_lsa.is_set or
                                            self.summary_prefix_length.is_set)

                                    def has_operation(self):
                                        for c in self.summary_lsa_metric:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_sum_lsa.yfilter != YFilter.not_set or
                                            self.summary_prefix_length.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "summary-lsa-type" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_sum_lsa.is_set or self.internal_sum_lsa.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_sum_lsa.get_name_leafdata())
                                        if (self.summary_prefix_length.is_set or self.summary_prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.summary_prefix_length.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "summary-lsa-metric"):
                                            for c in self.summary_lsa_metric:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.summary_lsa_metric.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "summary-lsa-metric" or name == "internal-sum-lsa" or name == "summary-prefix-length"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-sum-lsa"):
                                            self.internal_sum_lsa = value
                                            self.internal_sum_lsa.value_namespace = name_space
                                            self.internal_sum_lsa.value_namespace_prefix = name_space_prefix
                                        if(value_path == "summary-prefix-length"):
                                            self.summary_prefix_length = value
                                            self.summary_prefix_length.value_namespace = name_space
                                            self.summary_prefix_length.value_namespace_prefix = name_space_prefix


                                class ExternalLsaType(Entity):
                                    """
                                    External LSA
                                    
                                    .. attribute:: external_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_tos_metric
                                    
                                    	Type of service information
                                    	**type**\: list of    :py:class:`ExternalTosMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric>`
                                    
                                    .. attribute:: internal_external_lsa
                                    
                                    	If true, internal max\-metric LSA
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__init__()

                                        self.yang_name = "external-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"

                                        self.external_prefix_length = YLeaf(YType.uint32, "external-prefix-length")

                                        self.internal_external_lsa = YLeaf(YType.boolean, "internal-external-lsa")

                                        self.external_tos_metric = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("external_prefix_length",
                                                        "internal_external_lsa") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__setattr__(name, value)


                                    class ExternalTosMetric(Entity):
                                        """
                                        Type of service information
                                        
                                        .. attribute:: external_metric
                                        
                                        	Cost of this route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_metric_type
                                        
                                        	External LSA metric type
                                        	**type**\:   :py:class:`ExMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.ExMetric>`
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_tos
                                        
                                        	Type of Service
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__init__()

                                            self.yang_name = "external-tos-metric"
                                            self.yang_parent_name = "external-lsa-type"

                                            self.external_metric = YLeaf(YType.uint32, "external-metric")

                                            self.external_metric_type = YLeaf(YType.enumeration, "external-metric-type")

                                            self.external_tag = YLeaf(YType.uint32, "external-tag")

                                            self.external_tos = YLeaf(YType.uint32, "external-tos")

                                            self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("external_metric",
                                                            "external_metric_type",
                                                            "external_tag",
                                                            "external_tos",
                                                            "forwarding_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.external_metric.is_set or
                                                self.external_metric_type.is_set or
                                                self.external_tag.is_set or
                                                self.external_tos.is_set or
                                                self.forwarding_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.external_metric.yfilter != YFilter.not_set or
                                                self.external_metric_type.yfilter != YFilter.not_set or
                                                self.external_tag.yfilter != YFilter.not_set or
                                                self.external_tos.yfilter != YFilter.not_set or
                                                self.forwarding_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "external-tos-metric" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.external_metric.is_set or self.external_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.external_metric.get_name_leafdata())
                                            if (self.external_metric_type.is_set or self.external_metric_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.external_metric_type.get_name_leafdata())
                                            if (self.external_tag.is_set or self.external_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.external_tag.get_name_leafdata())
                                            if (self.external_tos.is_set or self.external_tos.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.external_tos.get_name_leafdata())
                                            if (self.forwarding_address.is_set or self.forwarding_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.forwarding_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "external-metric" or name == "external-metric-type" or name == "external-tag" or name == "external-tos" or name == "forwarding-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "external-metric"):
                                                self.external_metric = value
                                                self.external_metric.value_namespace = name_space
                                                self.external_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "external-metric-type"):
                                                self.external_metric_type = value
                                                self.external_metric_type.value_namespace = name_space
                                                self.external_metric_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "external-tag"):
                                                self.external_tag = value
                                                self.external_tag.value_namespace = name_space
                                                self.external_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "external-tos"):
                                                self.external_tos = value
                                                self.external_tos.value_namespace = name_space
                                                self.external_tos.value_namespace_prefix = name_space_prefix
                                            if(value_path == "forwarding-address"):
                                                self.forwarding_address = value
                                                self.forwarding_address.value_namespace = name_space
                                                self.forwarding_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.external_tos_metric:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.external_prefix_length.is_set or
                                            self.internal_external_lsa.is_set)

                                    def has_operation(self):
                                        for c in self.external_tos_metric:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.external_prefix_length.yfilter != YFilter.not_set or
                                            self.internal_external_lsa.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "external-lsa-type" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.external_prefix_length.is_set or self.external_prefix_length.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.external_prefix_length.get_name_leafdata())
                                        if (self.internal_external_lsa.is_set or self.internal_external_lsa.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_external_lsa.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "external-tos-metric"):
                                            for c in self.external_tos_metric:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.external_tos_metric.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "external-tos-metric" or name == "external-prefix-length" or name == "internal-external-lsa"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "external-prefix-length"):
                                            self.external_prefix_length = value
                                            self.external_prefix_length.value_namespace = name_space
                                            self.external_prefix_length.value_namespace_prefix = name_space_prefix
                                        if(value_path == "internal-external-lsa"):
                                            self.internal_external_lsa = value
                                            self.internal_external_lsa.value_namespace = name_space
                                            self.internal_external_lsa.value_namespace_prefix = name_space_prefix


                                class OpaqueLinkLsaType(Entity):
                                    """
                                    Opaque\-Link LSA
                                    
                                    .. attribute:: opaque_interface_name
                                    
                                    	Interface on which the Opaque link LSA is received
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__init__()

                                        self.yang_name = "opaque-link-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"

                                        self.opaque_interface_name = YLeaf(YType.str, "opaque-interface-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("opaque_interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.opaque_interface_name.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.opaque_interface_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opaque-link-lsa-type" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.opaque_interface_name.is_set or self.opaque_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.opaque_interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "opaque-interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "opaque-interface-name"):
                                            self.opaque_interface_name = value
                                            self.opaque_interface_name.value_namespace = name_space
                                            self.opaque_interface_name.value_namespace_prefix = name_space_prefix


                                class OpaqueMplsTeLsaType(Entity):
                                    """
                                    Opaque\-Area, opaque type 1 LSA
                                    
                                    .. attribute:: tlv
                                    
                                    	List of TLVs
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__init__()

                                        self.yang_name = "opaque-mpls-te-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"

                                        self.tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__setattr__(name, value)


                                    class Tlv(Entity):
                                        """
                                        List of TLVs
                                        
                                        .. attribute:: mpls_dste_link
                                        
                                        	MPLS DS\-TE supported
                                        	**type**\:  bool
                                        
                                        .. attribute:: mpls_router_id
                                        
                                        	MPLS\-TE Router ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: te_link_sub_tlv
                                        
                                        	List of Sub\-TLVs
                                        	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv>`
                                        
                                        .. attribute:: tlv_data
                                        
                                        	TLV direct data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: tlv_length
                                        
                                        	Length of top\-level TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tlv_type
                                        
                                        	Type of top\-level TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "opaque-mpls-te-lsa-type"

                                            self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                            self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                            self.tlv_data = YLeaf(YType.str, "tlv-data")

                                            self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                            self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                            self.te_link_sub_tlv = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("mpls_dste_link",
                                                            "mpls_router_id",
                                                            "tlv_data",
                                                            "tlv_length",
                                                            "tlv_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__setattr__(name, value)


                                        class TeLinkSubTlv(Entity):
                                            """
                                            List of Sub\-TLVs
                                            
                                            .. attribute:: sub_tlv_length
                                            
                                            	Length of sub TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sub_tlv_type
                                            
                                            	Type of sub TLV
                                            	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                            
                                            .. attribute:: sub_tlv_value
                                            
                                            	Value of sub TLV
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                self.yang_name = "te-link-sub-tlv"
                                                self.yang_parent_name = "tlv"

                                                self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("sub_tlv_length",
                                                                "sub_tlv_type",
                                                                "sub_tlv_value") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.sub_tlv_length.is_set or
                                                    self.sub_tlv_type.is_set or
                                                    self.sub_tlv_value.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.sub_tlv_length.yfilter != YFilter.not_set or
                                                    self.sub_tlv_type.yfilter != YFilter.not_set or
                                                    self.sub_tlv_value.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "te-link-sub-tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.sub_tlv_length.is_set or self.sub_tlv_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sub_tlv_length.get_name_leafdata())
                                                if (self.sub_tlv_type.is_set or self.sub_tlv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sub_tlv_type.get_name_leafdata())
                                                if (self.sub_tlv_value.is_set or self.sub_tlv_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sub_tlv_value.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "sub-tlv-length" or name == "sub-tlv-type" or name == "sub-tlv-value"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "sub-tlv-length"):
                                                    self.sub_tlv_length = value
                                                    self.sub_tlv_length.value_namespace = name_space
                                                    self.sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sub-tlv-type"):
                                                    self.sub_tlv_type = value
                                                    self.sub_tlv_type.value_namespace = name_space
                                                    self.sub_tlv_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sub-tlv-value"):
                                                    self.sub_tlv_value = value
                                                    self.sub_tlv_value.value_namespace = name_space
                                                    self.sub_tlv_value.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.te_link_sub_tlv:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.mpls_dste_link.is_set or
                                                self.mpls_router_id.is_set or
                                                self.tlv_data.is_set or
                                                self.tlv_length.is_set or
                                                self.tlv_type.is_set)

                                        def has_operation(self):
                                            for c in self.te_link_sub_tlv:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.mpls_dste_link.yfilter != YFilter.not_set or
                                                self.mpls_router_id.yfilter != YFilter.not_set or
                                                self.tlv_data.yfilter != YFilter.not_set or
                                                self.tlv_length.yfilter != YFilter.not_set or
                                                self.tlv_type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.mpls_dste_link.is_set or self.mpls_dste_link.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mpls_dste_link.get_name_leafdata())
                                            if (self.mpls_router_id.is_set or self.mpls_router_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mpls_router_id.get_name_leafdata())
                                            if (self.tlv_data.is_set or self.tlv_data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tlv_data.get_name_leafdata())
                                            if (self.tlv_length.is_set or self.tlv_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tlv_length.get_name_leafdata())
                                            if (self.tlv_type.is_set or self.tlv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tlv_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "te-link-sub-tlv"):
                                                for c in self.te_link_sub_tlv:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.te_link_sub_tlv.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "te-link-sub-tlv" or name == "mpls-dste-link" or name == "mpls-router-id" or name == "tlv-data" or name == "tlv-length" or name == "tlv-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "mpls-dste-link"):
                                                self.mpls_dste_link = value
                                                self.mpls_dste_link.value_namespace = name_space
                                                self.mpls_dste_link.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mpls-router-id"):
                                                self.mpls_router_id = value
                                                self.mpls_router_id.value_namespace = name_space
                                                self.mpls_router_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tlv-data"):
                                                self.tlv_data = value
                                                self.tlv_data.value_namespace = name_space
                                                self.tlv_data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tlv-length"):
                                                self.tlv_length = value
                                                self.tlv_length.value_namespace = name_space
                                                self.tlv_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tlv-type"):
                                                self.tlv_type = value
                                                self.tlv_type.value_namespace = name_space
                                                self.tlv_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.tlv:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.tlv:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opaque-mpls-te-lsa-type" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tlv"):
                                            for c in self.tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.tlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tlv"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class OpaqueGraceLsa(Entity):
                                    """
                                    Opaque\-link, opaque type 3 Grace LSA
                                    
                                    .. attribute:: grace_period
                                    
                                    	The amount of time the router's neighbor should advertise it fully adjacent (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: grace_reason
                                    
                                    	Reason for router restart
                                    	**type**\:   :py:class:`OspfGrReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfGrReason>`
                                    
                                    .. attribute:: ip_address
                                    
                                    	IP interface address on the subnet associated with the grace LSA
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__init__()

                                        self.yang_name = "opaque-grace-lsa"
                                        self.yang_parent_name = "lsa-internal-data"

                                        self.grace_period = YLeaf(YType.uint32, "grace-period")

                                        self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                        self.ip_address = YLeaf(YType.str, "ip-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("grace_period",
                                                        "grace_reason",
                                                        "ip_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.grace_period.is_set or
                                            self.grace_reason.is_set or
                                            self.ip_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.grace_period.yfilter != YFilter.not_set or
                                            self.grace_reason.yfilter != YFilter.not_set or
                                            self.ip_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opaque-grace-lsa" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.grace_period.is_set or self.grace_period.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.grace_period.get_name_leafdata())
                                        if (self.grace_reason.is_set or self.grace_reason.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.grace_reason.get_name_leafdata())
                                        if (self.ip_address.is_set or self.ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ip_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "grace-period" or name == "grace-reason" or name == "ip-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "grace-period"):
                                            self.grace_period = value
                                            self.grace_period.value_namespace = name_space
                                            self.grace_period.value_namespace_prefix = name_space_prefix
                                        if(value_path == "grace-reason"):
                                            self.grace_reason = value
                                            self.grace_reason.value_namespace = name_space
                                            self.grace_reason.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ip-address"):
                                            self.ip_address = value
                                            self.ip_address.value_namespace = name_space
                                            self.ip_address.value_namespace_prefix = name_space_prefix


                                class OpaqueRouterInfoLsaType(Entity):
                                    """
                                    Opaque Router Information LSA
                                    
                                    .. attribute:: opaque_ri_interface_name
                                    
                                    	Interface on which this Link\-Local Opaque link LSA is received
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: opaque_rilsa_scope
                                    
                                    	Opaque LSA flooding scope, a.k.a., Opaque LSA Type
                                    	**type**\:   :py:class:`OspfLsaOpqRiScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLsaOpqRiScope>`
                                    
                                    .. attribute:: opaque_ritlv
                                    
                                    	Router Information TLV
                                    	**type**\: list of    :py:class:`OpaqueRitlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__init__()

                                        self.yang_name = "opaque-router-info-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"

                                        self.opaque_ri_interface_name = YLeaf(YType.str, "opaque-ri-interface-name")

                                        self.opaque_rilsa_scope = YLeaf(YType.enumeration, "opaque-rilsa-scope")

                                        self.opaque_ritlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("opaque_ri_interface_name",
                                                        "opaque_rilsa_scope") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__setattr__(name, value)


                                    class OpaqueRitlv(Entity):
                                        """
                                        Router Information TLV
                                        
                                        .. attribute:: pcedtlv
                                        
                                        	PCE Discovery TLV
                                        	**type**\:   :py:class:`Pcedtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv>`
                                        
                                        .. attribute:: ritlv_internal_type
                                        
                                        	RITLVInternalType
                                        	**type**\:   :py:class:`OspfShOpqRiTlvTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiTlvTypes>`
                                        
                                        .. attribute:: rtr_cap_tlv
                                        
                                        	Rtr Cap TLV
                                        	**type**\:   :py:class:`RtrCapTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv>`
                                        
                                        .. attribute:: sr_algo_tlv
                                        
                                        	SR Algorithm TLV
                                        	**type**\:   :py:class:`SrAlgoTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv>`
                                        
                                        .. attribute:: sr_range_tlv
                                        
                                        	SR Range TLV
                                        	**type**\:   :py:class:`SrRangeTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv>`
                                        
                                        .. attribute:: unknown_tlv
                                        
                                        	Unknown Rtr Info TLV
                                        	**type**\:   :py:class:`UnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__init__()

                                            self.yang_name = "opaque-ritlv"
                                            self.yang_parent_name = "opaque-router-info-lsa-type"

                                            self.ritlv_internal_type = YLeaf(YType.enumeration, "ritlv-internal-type")

                                            self.pcedtlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv()
                                            self.pcedtlv.parent = self
                                            self._children_name_map["pcedtlv"] = "pcedtlv"
                                            self._children_yang_names.add("pcedtlv")

                                            self.rtr_cap_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv()
                                            self.rtr_cap_tlv.parent = self
                                            self._children_name_map["rtr_cap_tlv"] = "rtr-cap-tlv"
                                            self._children_yang_names.add("rtr-cap-tlv")

                                            self.sr_algo_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv()
                                            self.sr_algo_tlv.parent = self
                                            self._children_name_map["sr_algo_tlv"] = "sr-algo-tlv"
                                            self._children_yang_names.add("sr-algo-tlv")

                                            self.sr_range_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv()
                                            self.sr_range_tlv.parent = self
                                            self._children_name_map["sr_range_tlv"] = "sr-range-tlv"
                                            self._children_yang_names.add("sr-range-tlv")

                                            self.unknown_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv()
                                            self.unknown_tlv.parent = self
                                            self._children_name_map["unknown_tlv"] = "unknown-tlv"
                                            self._children_yang_names.add("unknown-tlv")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ritlv_internal_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__setattr__(name, value)


                                        class UnknownTlv(Entity):
                                            """
                                            Unknown Rtr Info TLV
                                            
                                            .. attribute:: ri_gen_tlv_length
                                            
                                            	Length of TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ri_gen_tlv_type
                                            
                                            	Type of TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ri_genvalue
                                            
                                            	Data in TLV
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__init__()

                                                self.yang_name = "unknown-tlv"
                                                self.yang_parent_name = "opaque-ritlv"

                                                self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ri_gen_tlv_length",
                                                                "ri_gen_tlv_type",
                                                                "ri_genvalue") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ri_gen_tlv_length.is_set or
                                                    self.ri_gen_tlv_type.is_set or
                                                    self.ri_genvalue.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ri_gen_tlv_length.yfilter != YFilter.not_set or
                                                    self.ri_gen_tlv_type.yfilter != YFilter.not_set or
                                                    self.ri_genvalue.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unknown-tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ri_gen_tlv_length.is_set or self.ri_gen_tlv_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ri_gen_tlv_length.get_name_leafdata())
                                                if (self.ri_gen_tlv_type.is_set or self.ri_gen_tlv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ri_gen_tlv_type.get_name_leafdata())
                                                if (self.ri_genvalue.is_set or self.ri_genvalue.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ri_genvalue.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ri-gen-tlv-length" or name == "ri-gen-tlv-type" or name == "ri-genvalue"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ri-gen-tlv-length"):
                                                    self.ri_gen_tlv_length = value
                                                    self.ri_gen_tlv_length.value_namespace = name_space
                                                    self.ri_gen_tlv_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ri-gen-tlv-type"):
                                                    self.ri_gen_tlv_type = value
                                                    self.ri_gen_tlv_type.value_namespace = name_space
                                                    self.ri_gen_tlv_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ri-genvalue"):
                                                    self.ri_genvalue = value
                                                    self.ri_genvalue.value_namespace = name_space
                                                    self.ri_genvalue.value_namespace_prefix = name_space_prefix


                                        class RtrCapTlv(Entity):
                                            """
                                            Rtr Cap TLV
                                            
                                            .. attribute:: rtr_cap_additional_info
                                            
                                            	Additional Information in TLV
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: rtr_cap_all_bits
                                            
                                            	All capability bits
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rtr_cap_area_te
                                            
                                            	Traffic Engineering capability of area
                                            	**type**\:  bool
                                            
                                            .. attribute:: rtr_cap_graceful_restart
                                            
                                            	Graceful Restart Capability
                                            	**type**\:  bool
                                            
                                            .. attribute:: rtr_cap_graceful_restart_helper
                                            
                                            	Graceful Restart Helper Capability
                                            	**type**\:  bool
                                            
                                            .. attribute:: rtr_cap_p2plan
                                            
                                            	P2P LAN Capability
                                            	**type**\:  bool
                                            
                                            .. attribute:: rtr_cap_stub_rtr
                                            
                                            	Stub Router capability
                                            	**type**\:  bool
                                            
                                            .. attribute:: rtr_cap_te_exp
                                            
                                            	TE Experimental bit
                                            	**type**\:  bool
                                            
                                            .. attribute:: rtr_cap_tlv_length
                                            
                                            	Length of TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__init__()

                                                self.yang_name = "rtr-cap-tlv"
                                                self.yang_parent_name = "opaque-ritlv"

                                                self.rtr_cap_additional_info = YLeaf(YType.str, "rtr-cap-additional-info")

                                                self.rtr_cap_all_bits = YLeaf(YType.uint32, "rtr-cap-all-bits")

                                                self.rtr_cap_area_te = YLeaf(YType.boolean, "rtr-cap-area-te")

                                                self.rtr_cap_graceful_restart = YLeaf(YType.boolean, "rtr-cap-graceful-restart")

                                                self.rtr_cap_graceful_restart_helper = YLeaf(YType.boolean, "rtr-cap-graceful-restart-helper")

                                                self.rtr_cap_p2plan = YLeaf(YType.boolean, "rtr-cap-p2plan")

                                                self.rtr_cap_stub_rtr = YLeaf(YType.boolean, "rtr-cap-stub-rtr")

                                                self.rtr_cap_te_exp = YLeaf(YType.boolean, "rtr-cap-te-exp")

                                                self.rtr_cap_tlv_length = YLeaf(YType.uint16, "rtr-cap-tlv-length")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("rtr_cap_additional_info",
                                                                "rtr_cap_all_bits",
                                                                "rtr_cap_area_te",
                                                                "rtr_cap_graceful_restart",
                                                                "rtr_cap_graceful_restart_helper",
                                                                "rtr_cap_p2plan",
                                                                "rtr_cap_stub_rtr",
                                                                "rtr_cap_te_exp",
                                                                "rtr_cap_tlv_length") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.rtr_cap_additional_info.is_set or
                                                    self.rtr_cap_all_bits.is_set or
                                                    self.rtr_cap_area_te.is_set or
                                                    self.rtr_cap_graceful_restart.is_set or
                                                    self.rtr_cap_graceful_restart_helper.is_set or
                                                    self.rtr_cap_p2plan.is_set or
                                                    self.rtr_cap_stub_rtr.is_set or
                                                    self.rtr_cap_te_exp.is_set or
                                                    self.rtr_cap_tlv_length.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.rtr_cap_additional_info.yfilter != YFilter.not_set or
                                                    self.rtr_cap_all_bits.yfilter != YFilter.not_set or
                                                    self.rtr_cap_area_te.yfilter != YFilter.not_set or
                                                    self.rtr_cap_graceful_restart.yfilter != YFilter.not_set or
                                                    self.rtr_cap_graceful_restart_helper.yfilter != YFilter.not_set or
                                                    self.rtr_cap_p2plan.yfilter != YFilter.not_set or
                                                    self.rtr_cap_stub_rtr.yfilter != YFilter.not_set or
                                                    self.rtr_cap_te_exp.yfilter != YFilter.not_set or
                                                    self.rtr_cap_tlv_length.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "rtr-cap-tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.rtr_cap_additional_info.is_set or self.rtr_cap_additional_info.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtr_cap_additional_info.get_name_leafdata())
                                                if (self.rtr_cap_all_bits.is_set or self.rtr_cap_all_bits.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtr_cap_all_bits.get_name_leafdata())
                                                if (self.rtr_cap_area_te.is_set or self.rtr_cap_area_te.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtr_cap_area_te.get_name_leafdata())
                                                if (self.rtr_cap_graceful_restart.is_set or self.rtr_cap_graceful_restart.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtr_cap_graceful_restart.get_name_leafdata())
                                                if (self.rtr_cap_graceful_restart_helper.is_set or self.rtr_cap_graceful_restart_helper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtr_cap_graceful_restart_helper.get_name_leafdata())
                                                if (self.rtr_cap_p2plan.is_set or self.rtr_cap_p2plan.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtr_cap_p2plan.get_name_leafdata())
                                                if (self.rtr_cap_stub_rtr.is_set or self.rtr_cap_stub_rtr.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtr_cap_stub_rtr.get_name_leafdata())
                                                if (self.rtr_cap_te_exp.is_set or self.rtr_cap_te_exp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtr_cap_te_exp.get_name_leafdata())
                                                if (self.rtr_cap_tlv_length.is_set or self.rtr_cap_tlv_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtr_cap_tlv_length.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "rtr-cap-additional-info" or name == "rtr-cap-all-bits" or name == "rtr-cap-area-te" or name == "rtr-cap-graceful-restart" or name == "rtr-cap-graceful-restart-helper" or name == "rtr-cap-p2plan" or name == "rtr-cap-stub-rtr" or name == "rtr-cap-te-exp" or name == "rtr-cap-tlv-length"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "rtr-cap-additional-info"):
                                                    self.rtr_cap_additional_info = value
                                                    self.rtr_cap_additional_info.value_namespace = name_space
                                                    self.rtr_cap_additional_info.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtr-cap-all-bits"):
                                                    self.rtr_cap_all_bits = value
                                                    self.rtr_cap_all_bits.value_namespace = name_space
                                                    self.rtr_cap_all_bits.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtr-cap-area-te"):
                                                    self.rtr_cap_area_te = value
                                                    self.rtr_cap_area_te.value_namespace = name_space
                                                    self.rtr_cap_area_te.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtr-cap-graceful-restart"):
                                                    self.rtr_cap_graceful_restart = value
                                                    self.rtr_cap_graceful_restart.value_namespace = name_space
                                                    self.rtr_cap_graceful_restart.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtr-cap-graceful-restart-helper"):
                                                    self.rtr_cap_graceful_restart_helper = value
                                                    self.rtr_cap_graceful_restart_helper.value_namespace = name_space
                                                    self.rtr_cap_graceful_restart_helper.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtr-cap-p2plan"):
                                                    self.rtr_cap_p2plan = value
                                                    self.rtr_cap_p2plan.value_namespace = name_space
                                                    self.rtr_cap_p2plan.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtr-cap-stub-rtr"):
                                                    self.rtr_cap_stub_rtr = value
                                                    self.rtr_cap_stub_rtr.value_namespace = name_space
                                                    self.rtr_cap_stub_rtr.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtr-cap-te-exp"):
                                                    self.rtr_cap_te_exp = value
                                                    self.rtr_cap_te_exp.value_namespace = name_space
                                                    self.rtr_cap_te_exp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtr-cap-tlv-length"):
                                                    self.rtr_cap_tlv_length = value
                                                    self.rtr_cap_tlv_length.value_namespace = name_space
                                                    self.rtr_cap_tlv_length.value_namespace_prefix = name_space_prefix


                                        class Pcedtlv(Entity):
                                            """
                                            PCE Discovery TLV
                                            
                                            .. attribute:: pced_addr
                                            
                                            	PCE Address
                                            	**type**\:   :py:class:`PcedAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr>`
                                            
                                            .. attribute:: pced_scope
                                            
                                            	PCE Scope Information
                                            	**type**\:   :py:class:`PcedScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope>`
                                            
                                            .. attribute:: pcedtlv_length
                                            
                                            	Length of TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__init__()

                                                self.yang_name = "pcedtlv"
                                                self.yang_parent_name = "opaque-ritlv"

                                                self.pcedtlv_length = YLeaf(YType.uint16, "pcedtlv-length")

                                                self.pced_addr = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr()
                                                self.pced_addr.parent = self
                                                self._children_name_map["pced_addr"] = "pced-addr"
                                                self._children_yang_names.add("pced-addr")

                                                self.pced_scope = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope()
                                                self.pced_scope.parent = self
                                                self._children_name_map["pced_scope"] = "pced-scope"
                                                self._children_yang_names.add("pced-scope")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("pcedtlv_length") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__setattr__(name, value)


                                            class PcedAddr(Entity):
                                                """
                                                PCE Address
                                                
                                                .. attribute:: ipv4pce_addr
                                                
                                                	IPv4 PCE Address
                                                	**type**\:   :py:class:`Ipv4PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr>`
                                                
                                                .. attribute:: ipv6pce_addr
                                                
                                                	IPv6 PCE Address
                                                	**type**\:   :py:class:`Ipv6PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr>`
                                                
                                                .. attribute:: pce_addr_type
                                                
                                                	PCEAddrType
                                                	**type**\:   :py:class:`OspfShOpqRiPceAddrTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiPceAddrTypes>`
                                                
                                                .. attribute:: pce_addr_unknown_tlv
                                                
                                                	Unknown PCE Addr TLV
                                                	**type**\:   :py:class:`PceAddrUnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__init__()

                                                    self.yang_name = "pced-addr"
                                                    self.yang_parent_name = "pcedtlv"

                                                    self.pce_addr_type = YLeaf(YType.enumeration, "pce-addr-type")

                                                    self.ipv4pce_addr = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr()
                                                    self.ipv4pce_addr.parent = self
                                                    self._children_name_map["ipv4pce_addr"] = "ipv4pce-addr"
                                                    self._children_yang_names.add("ipv4pce-addr")

                                                    self.ipv6pce_addr = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr()
                                                    self.ipv6pce_addr.parent = self
                                                    self._children_name_map["ipv6pce_addr"] = "ipv6pce-addr"
                                                    self._children_yang_names.add("ipv6pce-addr")

                                                    self.pce_addr_unknown_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv()
                                                    self.pce_addr_unknown_tlv.parent = self
                                                    self._children_name_map["pce_addr_unknown_tlv"] = "pce-addr-unknown-tlv"
                                                    self._children_yang_names.add("pce-addr-unknown-tlv")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("pce_addr_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__setattr__(name, value)


                                                class PceAddrUnknownTlv(Entity):
                                                    """
                                                    Unknown PCE Addr TLV
                                                    
                                                    .. attribute:: ri_gen_tlv_length
                                                    
                                                    	Length of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ri_gen_tlv_type
                                                    
                                                    	Type of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ri_genvalue
                                                    
                                                    	Data in TLV
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__init__()

                                                        self.yang_name = "pce-addr-unknown-tlv"
                                                        self.yang_parent_name = "pced-addr"

                                                        self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                        self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                        self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("ri_gen_tlv_length",
                                                                        "ri_gen_tlv_type",
                                                                        "ri_genvalue") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.ri_gen_tlv_length.is_set or
                                                            self.ri_gen_tlv_type.is_set or
                                                            self.ri_genvalue.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.ri_gen_tlv_length.yfilter != YFilter.not_set or
                                                            self.ri_gen_tlv_type.yfilter != YFilter.not_set or
                                                            self.ri_genvalue.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "pce-addr-unknown-tlv" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.ri_gen_tlv_length.is_set or self.ri_gen_tlv_length.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ri_gen_tlv_length.get_name_leafdata())
                                                        if (self.ri_gen_tlv_type.is_set or self.ri_gen_tlv_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ri_gen_tlv_type.get_name_leafdata())
                                                        if (self.ri_genvalue.is_set or self.ri_genvalue.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ri_genvalue.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ri-gen-tlv-length" or name == "ri-gen-tlv-type" or name == "ri-genvalue"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "ri-gen-tlv-length"):
                                                            self.ri_gen_tlv_length = value
                                                            self.ri_gen_tlv_length.value_namespace = name_space
                                                            self.ri_gen_tlv_length.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ri-gen-tlv-type"):
                                                            self.ri_gen_tlv_type = value
                                                            self.ri_gen_tlv_type.value_namespace = name_space
                                                            self.ri_gen_tlv_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ri-genvalue"):
                                                            self.ri_genvalue = value
                                                            self.ri_genvalue.value_namespace = name_space
                                                            self.ri_genvalue.value_namespace_prefix = name_space_prefix


                                                class Ipv4PceAddr(Entity):
                                                    """
                                                    IPv4 PCE Address
                                                    
                                                    .. attribute:: pceipv4_addr
                                                    
                                                    	PCE IPv4 Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__init__()

                                                        self.yang_name = "ipv4pce-addr"
                                                        self.yang_parent_name = "pced-addr"

                                                        self.pceipv4_addr = YLeaf(YType.str, "pceipv4-addr")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("pceipv4_addr") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.pceipv4_addr.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.pceipv4_addr.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ipv4pce-addr" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.pceipv4_addr.is_set or self.pceipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pceipv4_addr.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "pceipv4-addr"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "pceipv4-addr"):
                                                            self.pceipv4_addr = value
                                                            self.pceipv4_addr.value_namespace = name_space
                                                            self.pceipv4_addr.value_namespace_prefix = name_space_prefix


                                                class Ipv6PceAddr(Entity):
                                                    """
                                                    IPv6 PCE Address
                                                    
                                                    .. attribute:: pceipv6_addr
                                                    
                                                    	PCE IPv6 Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__init__()

                                                        self.yang_name = "ipv6pce-addr"
                                                        self.yang_parent_name = "pced-addr"

                                                        self.pceipv6_addr = YLeaf(YType.str, "pceipv6-addr")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("pceipv6_addr") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.pceipv6_addr.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.pceipv6_addr.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "ipv6pce-addr" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.pceipv6_addr.is_set or self.pceipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.pceipv6_addr.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "pceipv6-addr"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "pceipv6-addr"):
                                                            self.pceipv6_addr = value
                                                            self.pceipv6_addr.value_namespace = name_space
                                                            self.pceipv6_addr.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.pce_addr_type.is_set or
                                                        (self.ipv4pce_addr is not None and self.ipv4pce_addr.has_data()) or
                                                        (self.ipv6pce_addr is not None and self.ipv6pce_addr.has_data()) or
                                                        (self.pce_addr_unknown_tlv is not None and self.pce_addr_unknown_tlv.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.pce_addr_type.yfilter != YFilter.not_set or
                                                        (self.ipv4pce_addr is not None and self.ipv4pce_addr.has_operation()) or
                                                        (self.ipv6pce_addr is not None and self.ipv6pce_addr.has_operation()) or
                                                        (self.pce_addr_unknown_tlv is not None and self.pce_addr_unknown_tlv.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pced-addr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.pce_addr_type.is_set or self.pce_addr_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pce_addr_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "ipv4pce-addr"):
                                                        if (self.ipv4pce_addr is None):
                                                            self.ipv4pce_addr = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr()
                                                            self.ipv4pce_addr.parent = self
                                                            self._children_name_map["ipv4pce_addr"] = "ipv4pce-addr"
                                                        return self.ipv4pce_addr

                                                    if (child_yang_name == "ipv6pce-addr"):
                                                        if (self.ipv6pce_addr is None):
                                                            self.ipv6pce_addr = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr()
                                                            self.ipv6pce_addr.parent = self
                                                            self._children_name_map["ipv6pce_addr"] = "ipv6pce-addr"
                                                        return self.ipv6pce_addr

                                                    if (child_yang_name == "pce-addr-unknown-tlv"):
                                                        if (self.pce_addr_unknown_tlv is None):
                                                            self.pce_addr_unknown_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv()
                                                            self.pce_addr_unknown_tlv.parent = self
                                                            self._children_name_map["pce_addr_unknown_tlv"] = "pce-addr-unknown-tlv"
                                                        return self.pce_addr_unknown_tlv

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv4pce-addr" or name == "ipv6pce-addr" or name == "pce-addr-unknown-tlv" or name == "pce-addr-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "pce-addr-type"):
                                                        self.pce_addr_type = value
                                                        self.pce_addr_type.value_namespace = name_space
                                                        self.pce_addr_type.value_namespace_prefix = name_space_prefix


                                            class PcedScope(Entity):
                                                """
                                                PCE Scope Information
                                                
                                                .. attribute:: all_scope_info_bits
                                                
                                                	PCE Scope Information
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lbit
                                                
                                                	L Bit
                                                	**type**\:  bool
                                                
                                                .. attribute:: pref_l
                                                
                                                	Pref L
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pref_r
                                                
                                                	Pref R
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pref_s
                                                
                                                	Pref S
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pref_y
                                                
                                                	Pref Y
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rbit
                                                
                                                	R Bit
                                                	**type**\:  bool
                                                
                                                .. attribute:: rd_bit
                                                
                                                	Rd Bit
                                                	**type**\:  bool
                                                
                                                .. attribute:: sbit
                                                
                                                	S Bit
                                                	**type**\:  bool
                                                
                                                .. attribute:: sd_bit
                                                
                                                	Sd Bit
                                                	**type**\:  bool
                                                
                                                .. attribute:: ybit
                                                
                                                	Y Bit
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__init__()

                                                    self.yang_name = "pced-scope"
                                                    self.yang_parent_name = "pcedtlv"

                                                    self.all_scope_info_bits = YLeaf(YType.uint32, "all-scope-info-bits")

                                                    self.lbit = YLeaf(YType.boolean, "lbit")

                                                    self.pref_l = YLeaf(YType.uint8, "pref-l")

                                                    self.pref_r = YLeaf(YType.uint8, "pref-r")

                                                    self.pref_s = YLeaf(YType.uint8, "pref-s")

                                                    self.pref_y = YLeaf(YType.uint8, "pref-y")

                                                    self.rbit = YLeaf(YType.boolean, "rbit")

                                                    self.rd_bit = YLeaf(YType.boolean, "rd-bit")

                                                    self.sbit = YLeaf(YType.boolean, "sbit")

                                                    self.sd_bit = YLeaf(YType.boolean, "sd-bit")

                                                    self.ybit = YLeaf(YType.boolean, "ybit")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("all_scope_info_bits",
                                                                    "lbit",
                                                                    "pref_l",
                                                                    "pref_r",
                                                                    "pref_s",
                                                                    "pref_y",
                                                                    "rbit",
                                                                    "rd_bit",
                                                                    "sbit",
                                                                    "sd_bit",
                                                                    "ybit") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.all_scope_info_bits.is_set or
                                                        self.lbit.is_set or
                                                        self.pref_l.is_set or
                                                        self.pref_r.is_set or
                                                        self.pref_s.is_set or
                                                        self.pref_y.is_set or
                                                        self.rbit.is_set or
                                                        self.rd_bit.is_set or
                                                        self.sbit.is_set or
                                                        self.sd_bit.is_set or
                                                        self.ybit.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.all_scope_info_bits.yfilter != YFilter.not_set or
                                                        self.lbit.yfilter != YFilter.not_set or
                                                        self.pref_l.yfilter != YFilter.not_set or
                                                        self.pref_r.yfilter != YFilter.not_set or
                                                        self.pref_s.yfilter != YFilter.not_set or
                                                        self.pref_y.yfilter != YFilter.not_set or
                                                        self.rbit.yfilter != YFilter.not_set or
                                                        self.rd_bit.yfilter != YFilter.not_set or
                                                        self.sbit.yfilter != YFilter.not_set or
                                                        self.sd_bit.yfilter != YFilter.not_set or
                                                        self.ybit.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pced-scope" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.all_scope_info_bits.is_set or self.all_scope_info_bits.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.all_scope_info_bits.get_name_leafdata())
                                                    if (self.lbit.is_set or self.lbit.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lbit.get_name_leafdata())
                                                    if (self.pref_l.is_set or self.pref_l.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pref_l.get_name_leafdata())
                                                    if (self.pref_r.is_set or self.pref_r.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pref_r.get_name_leafdata())
                                                    if (self.pref_s.is_set or self.pref_s.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pref_s.get_name_leafdata())
                                                    if (self.pref_y.is_set or self.pref_y.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pref_y.get_name_leafdata())
                                                    if (self.rbit.is_set or self.rbit.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rbit.get_name_leafdata())
                                                    if (self.rd_bit.is_set or self.rd_bit.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rd_bit.get_name_leafdata())
                                                    if (self.sbit.is_set or self.sbit.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sbit.get_name_leafdata())
                                                    if (self.sd_bit.is_set or self.sd_bit.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sd_bit.get_name_leafdata())
                                                    if (self.ybit.is_set or self.ybit.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ybit.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "all-scope-info-bits" or name == "lbit" or name == "pref-l" or name == "pref-r" or name == "pref-s" or name == "pref-y" or name == "rbit" or name == "rd-bit" or name == "sbit" or name == "sd-bit" or name == "ybit"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "all-scope-info-bits"):
                                                        self.all_scope_info_bits = value
                                                        self.all_scope_info_bits.value_namespace = name_space
                                                        self.all_scope_info_bits.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lbit"):
                                                        self.lbit = value
                                                        self.lbit.value_namespace = name_space
                                                        self.lbit.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pref-l"):
                                                        self.pref_l = value
                                                        self.pref_l.value_namespace = name_space
                                                        self.pref_l.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pref-r"):
                                                        self.pref_r = value
                                                        self.pref_r.value_namespace = name_space
                                                        self.pref_r.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pref-s"):
                                                        self.pref_s = value
                                                        self.pref_s.value_namespace = name_space
                                                        self.pref_s.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pref-y"):
                                                        self.pref_y = value
                                                        self.pref_y.value_namespace = name_space
                                                        self.pref_y.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rbit"):
                                                        self.rbit = value
                                                        self.rbit.value_namespace = name_space
                                                        self.rbit.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rd-bit"):
                                                        self.rd_bit = value
                                                        self.rd_bit.value_namespace = name_space
                                                        self.rd_bit.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sbit"):
                                                        self.sbit = value
                                                        self.sbit.value_namespace = name_space
                                                        self.sbit.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sd-bit"):
                                                        self.sd_bit = value
                                                        self.sd_bit.value_namespace = name_space
                                                        self.sd_bit.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ybit"):
                                                        self.ybit = value
                                                        self.ybit.value_namespace = name_space
                                                        self.ybit.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.pcedtlv_length.is_set or
                                                    (self.pced_addr is not None and self.pced_addr.has_data()) or
                                                    (self.pced_scope is not None and self.pced_scope.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.pcedtlv_length.yfilter != YFilter.not_set or
                                                    (self.pced_addr is not None and self.pced_addr.has_operation()) or
                                                    (self.pced_scope is not None and self.pced_scope.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pcedtlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.pcedtlv_length.is_set or self.pcedtlv_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pcedtlv_length.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "pced-addr"):
                                                    if (self.pced_addr is None):
                                                        self.pced_addr = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr()
                                                        self.pced_addr.parent = self
                                                        self._children_name_map["pced_addr"] = "pced-addr"
                                                    return self.pced_addr

                                                if (child_yang_name == "pced-scope"):
                                                    if (self.pced_scope is None):
                                                        self.pced_scope = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope()
                                                        self.pced_scope.parent = self
                                                        self._children_name_map["pced_scope"] = "pced-scope"
                                                    return self.pced_scope

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "pced-addr" or name == "pced-scope" or name == "pcedtlv-length"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "pcedtlv-length"):
                                                    self.pcedtlv_length = value
                                                    self.pcedtlv_length.value_namespace = name_space
                                                    self.pcedtlv_length.value_namespace_prefix = name_space_prefix


                                        class SrAlgoTlv(Entity):
                                            """
                                            SR Algorithm TLV
                                            
                                            .. attribute:: sr_algo_length
                                            
                                            	Length of TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sr_algo_value
                                            
                                            	SR Algorithms
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__init__()

                                                self.yang_name = "sr-algo-tlv"
                                                self.yang_parent_name = "opaque-ritlv"

                                                self.sr_algo_length = YLeaf(YType.uint16, "sr-algo-length")

                                                self.sr_algo_value = YLeaf(YType.str, "sr-algo-value")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("sr_algo_length",
                                                                "sr_algo_value") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.sr_algo_length.is_set or
                                                    self.sr_algo_value.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.sr_algo_length.yfilter != YFilter.not_set or
                                                    self.sr_algo_value.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sr-algo-tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.sr_algo_length.is_set or self.sr_algo_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sr_algo_length.get_name_leafdata())
                                                if (self.sr_algo_value.is_set or self.sr_algo_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sr_algo_value.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "sr-algo-length" or name == "sr-algo-value"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "sr-algo-length"):
                                                    self.sr_algo_length = value
                                                    self.sr_algo_length.value_namespace = name_space
                                                    self.sr_algo_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sr-algo-value"):
                                                    self.sr_algo_value = value
                                                    self.sr_algo_value.value_namespace = name_space
                                                    self.sr_algo_value.value_namespace_prefix = name_space_prefix


                                        class SrRangeTlv(Entity):
                                            """
                                            SR Range TLV
                                            
                                            .. attribute:: sidtlv
                                            
                                            	SID sub\-TLV
                                            	**type**\:   :py:class:`Sidtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv>`
                                            
                                            .. attribute:: sr_range_length
                                            
                                            	Length of TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sr_range_size
                                            
                                            	SR Range Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__init__()

                                                self.yang_name = "sr-range-tlv"
                                                self.yang_parent_name = "opaque-ritlv"

                                                self.sr_range_length = YLeaf(YType.uint16, "sr-range-length")

                                                self.sr_range_size = YLeaf(YType.uint32, "sr-range-size")

                                                self.sidtlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv()
                                                self.sidtlv.parent = self
                                                self._children_name_map["sidtlv"] = "sidtlv"
                                                self._children_yang_names.add("sidtlv")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("sr_range_length",
                                                                "sr_range_size") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__setattr__(name, value)


                                            class Sidtlv(Entity):
                                                """
                                                SID sub\-TLV
                                                
                                                .. attribute:: sr_sid_length
                                                
                                                	Length of sub\-TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sr_sid_value
                                                
                                                	SID Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__init__()

                                                    self.yang_name = "sidtlv"
                                                    self.yang_parent_name = "sr-range-tlv"

                                                    self.sr_sid_length = YLeaf(YType.uint16, "sr-sid-length")

                                                    self.sr_sid_value = YLeaf(YType.uint32, "sr-sid-value")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("sr_sid_length",
                                                                    "sr_sid_value") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.sr_sid_length.is_set or
                                                        self.sr_sid_value.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.sr_sid_length.yfilter != YFilter.not_set or
                                                        self.sr_sid_value.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sidtlv" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.sr_sid_length.is_set or self.sr_sid_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sr_sid_length.get_name_leafdata())
                                                    if (self.sr_sid_value.is_set or self.sr_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sr_sid_value.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "sr-sid-length" or name == "sr-sid-value"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "sr-sid-length"):
                                                        self.sr_sid_length = value
                                                        self.sr_sid_length.value_namespace = name_space
                                                        self.sr_sid_length.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sr-sid-value"):
                                                        self.sr_sid_value = value
                                                        self.sr_sid_value.value_namespace = name_space
                                                        self.sr_sid_value.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.sr_range_length.is_set or
                                                    self.sr_range_size.is_set or
                                                    (self.sidtlv is not None and self.sidtlv.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.sr_range_length.yfilter != YFilter.not_set or
                                                    self.sr_range_size.yfilter != YFilter.not_set or
                                                    (self.sidtlv is not None and self.sidtlv.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sr-range-tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.sr_range_length.is_set or self.sr_range_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sr_range_length.get_name_leafdata())
                                                if (self.sr_range_size.is_set or self.sr_range_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sr_range_size.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "sidtlv"):
                                                    if (self.sidtlv is None):
                                                        self.sidtlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv()
                                                        self.sidtlv.parent = self
                                                        self._children_name_map["sidtlv"] = "sidtlv"
                                                    return self.sidtlv

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "sidtlv" or name == "sr-range-length" or name == "sr-range-size"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "sr-range-length"):
                                                    self.sr_range_length = value
                                                    self.sr_range_length.value_namespace = name_space
                                                    self.sr_range_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sr-range-size"):
                                                    self.sr_range_size = value
                                                    self.sr_range_size.value_namespace = name_space
                                                    self.sr_range_size.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.ritlv_internal_type.is_set or
                                                (self.pcedtlv is not None and self.pcedtlv.has_data()) or
                                                (self.rtr_cap_tlv is not None and self.rtr_cap_tlv.has_data()) or
                                                (self.sr_algo_tlv is not None and self.sr_algo_tlv.has_data()) or
                                                (self.sr_range_tlv is not None and self.sr_range_tlv.has_data()) or
                                                (self.unknown_tlv is not None and self.unknown_tlv.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ritlv_internal_type.yfilter != YFilter.not_set or
                                                (self.pcedtlv is not None and self.pcedtlv.has_operation()) or
                                                (self.rtr_cap_tlv is not None and self.rtr_cap_tlv.has_operation()) or
                                                (self.sr_algo_tlv is not None and self.sr_algo_tlv.has_operation()) or
                                                (self.sr_range_tlv is not None and self.sr_range_tlv.has_operation()) or
                                                (self.unknown_tlv is not None and self.unknown_tlv.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "opaque-ritlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ritlv_internal_type.is_set or self.ritlv_internal_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ritlv_internal_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "pcedtlv"):
                                                if (self.pcedtlv is None):
                                                    self.pcedtlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv()
                                                    self.pcedtlv.parent = self
                                                    self._children_name_map["pcedtlv"] = "pcedtlv"
                                                return self.pcedtlv

                                            if (child_yang_name == "rtr-cap-tlv"):
                                                if (self.rtr_cap_tlv is None):
                                                    self.rtr_cap_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv()
                                                    self.rtr_cap_tlv.parent = self
                                                    self._children_name_map["rtr_cap_tlv"] = "rtr-cap-tlv"
                                                return self.rtr_cap_tlv

                                            if (child_yang_name == "sr-algo-tlv"):
                                                if (self.sr_algo_tlv is None):
                                                    self.sr_algo_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv()
                                                    self.sr_algo_tlv.parent = self
                                                    self._children_name_map["sr_algo_tlv"] = "sr-algo-tlv"
                                                return self.sr_algo_tlv

                                            if (child_yang_name == "sr-range-tlv"):
                                                if (self.sr_range_tlv is None):
                                                    self.sr_range_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv()
                                                    self.sr_range_tlv.parent = self
                                                    self._children_name_map["sr_range_tlv"] = "sr-range-tlv"
                                                return self.sr_range_tlv

                                            if (child_yang_name == "unknown-tlv"):
                                                if (self.unknown_tlv is None):
                                                    self.unknown_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv()
                                                    self.unknown_tlv.parent = self
                                                    self._children_name_map["unknown_tlv"] = "unknown-tlv"
                                                return self.unknown_tlv

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "pcedtlv" or name == "rtr-cap-tlv" or name == "sr-algo-tlv" or name == "sr-range-tlv" or name == "unknown-tlv" or name == "ritlv-internal-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ritlv-internal-type"):
                                                self.ritlv_internal_type = value
                                                self.ritlv_internal_type.value_namespace = name_space
                                                self.ritlv_internal_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.opaque_ritlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.opaque_ri_interface_name.is_set or
                                            self.opaque_rilsa_scope.is_set)

                                    def has_operation(self):
                                        for c in self.opaque_ritlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.opaque_ri_interface_name.yfilter != YFilter.not_set or
                                            self.opaque_rilsa_scope.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opaque-router-info-lsa-type" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.opaque_ri_interface_name.is_set or self.opaque_ri_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.opaque_ri_interface_name.get_name_leafdata())
                                        if (self.opaque_rilsa_scope.is_set or self.opaque_rilsa_scope.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.opaque_rilsa_scope.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "opaque-ritlv"):
                                            for c in self.opaque_ritlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.opaque_ritlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "opaque-ritlv" or name == "opaque-ri-interface-name" or name == "opaque-rilsa-scope"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "opaque-ri-interface-name"):
                                            self.opaque_ri_interface_name = value
                                            self.opaque_ri_interface_name.value_namespace = name_space
                                            self.opaque_ri_interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "opaque-rilsa-scope"):
                                            self.opaque_rilsa_scope = value
                                            self.opaque_rilsa_scope.value_namespace = name_space
                                            self.opaque_rilsa_scope.value_namespace_prefix = name_space_prefix


                                class OpaqueEpLsaType(Entity):
                                    """
                                    Extende Prefix LSA type
                                    
                                    .. attribute:: tlv
                                    
                                    	List of TLVs
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__init__()

                                        self.yang_name = "opaque-ep-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"

                                        self.tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__setattr__(name, value)


                                    class Tlv(Entity):
                                        """
                                        List of TLVs
                                        
                                        .. attribute:: mpls_dste_link
                                        
                                        	MPLS DS\-TE supported
                                        	**type**\:  bool
                                        
                                        .. attribute:: mpls_router_id
                                        
                                        	MPLS\-TE Router ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: te_link_sub_tlv
                                        
                                        	List of Sub\-TLVs
                                        	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv>`
                                        
                                        .. attribute:: tlv_data
                                        
                                        	TLV direct data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: tlv_length
                                        
                                        	Length of top\-level TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tlv_type
                                        
                                        	Type of top\-level TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "opaque-ep-lsa-type"

                                            self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                            self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                            self.tlv_data = YLeaf(YType.str, "tlv-data")

                                            self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                            self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                            self.te_link_sub_tlv = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("mpls_dste_link",
                                                            "mpls_router_id",
                                                            "tlv_data",
                                                            "tlv_length",
                                                            "tlv_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__setattr__(name, value)


                                        class TeLinkSubTlv(Entity):
                                            """
                                            List of Sub\-TLVs
                                            
                                            .. attribute:: sub_tlv_length
                                            
                                            	Length of sub TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sub_tlv_type
                                            
                                            	Type of sub TLV
                                            	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                            
                                            .. attribute:: sub_tlv_value
                                            
                                            	Value of sub TLV
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                self.yang_name = "te-link-sub-tlv"
                                                self.yang_parent_name = "tlv"

                                                self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("sub_tlv_length",
                                                                "sub_tlv_type",
                                                                "sub_tlv_value") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.sub_tlv_length.is_set or
                                                    self.sub_tlv_type.is_set or
                                                    self.sub_tlv_value.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.sub_tlv_length.yfilter != YFilter.not_set or
                                                    self.sub_tlv_type.yfilter != YFilter.not_set or
                                                    self.sub_tlv_value.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "te-link-sub-tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.sub_tlv_length.is_set or self.sub_tlv_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sub_tlv_length.get_name_leafdata())
                                                if (self.sub_tlv_type.is_set or self.sub_tlv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sub_tlv_type.get_name_leafdata())
                                                if (self.sub_tlv_value.is_set or self.sub_tlv_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sub_tlv_value.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "sub-tlv-length" or name == "sub-tlv-type" or name == "sub-tlv-value"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "sub-tlv-length"):
                                                    self.sub_tlv_length = value
                                                    self.sub_tlv_length.value_namespace = name_space
                                                    self.sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sub-tlv-type"):
                                                    self.sub_tlv_type = value
                                                    self.sub_tlv_type.value_namespace = name_space
                                                    self.sub_tlv_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sub-tlv-value"):
                                                    self.sub_tlv_value = value
                                                    self.sub_tlv_value.value_namespace = name_space
                                                    self.sub_tlv_value.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.te_link_sub_tlv:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.mpls_dste_link.is_set or
                                                self.mpls_router_id.is_set or
                                                self.tlv_data.is_set or
                                                self.tlv_length.is_set or
                                                self.tlv_type.is_set)

                                        def has_operation(self):
                                            for c in self.te_link_sub_tlv:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.mpls_dste_link.yfilter != YFilter.not_set or
                                                self.mpls_router_id.yfilter != YFilter.not_set or
                                                self.tlv_data.yfilter != YFilter.not_set or
                                                self.tlv_length.yfilter != YFilter.not_set or
                                                self.tlv_type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.mpls_dste_link.is_set or self.mpls_dste_link.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mpls_dste_link.get_name_leafdata())
                                            if (self.mpls_router_id.is_set or self.mpls_router_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mpls_router_id.get_name_leafdata())
                                            if (self.tlv_data.is_set or self.tlv_data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tlv_data.get_name_leafdata())
                                            if (self.tlv_length.is_set or self.tlv_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tlv_length.get_name_leafdata())
                                            if (self.tlv_type.is_set or self.tlv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tlv_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "te-link-sub-tlv"):
                                                for c in self.te_link_sub_tlv:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.te_link_sub_tlv.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "te-link-sub-tlv" or name == "mpls-dste-link" or name == "mpls-router-id" or name == "tlv-data" or name == "tlv-length" or name == "tlv-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "mpls-dste-link"):
                                                self.mpls_dste_link = value
                                                self.mpls_dste_link.value_namespace = name_space
                                                self.mpls_dste_link.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mpls-router-id"):
                                                self.mpls_router_id = value
                                                self.mpls_router_id.value_namespace = name_space
                                                self.mpls_router_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tlv-data"):
                                                self.tlv_data = value
                                                self.tlv_data.value_namespace = name_space
                                                self.tlv_data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tlv-length"):
                                                self.tlv_length = value
                                                self.tlv_length.value_namespace = name_space
                                                self.tlv_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tlv-type"):
                                                self.tlv_type = value
                                                self.tlv_type.value_namespace = name_space
                                                self.tlv_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.tlv:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.tlv:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opaque-ep-lsa-type" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tlv"):
                                            for c in self.tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.tlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tlv"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class OpaqueElLsaType(Entity):
                                    """
                                    Extended Link LSA type
                                    
                                    .. attribute:: tlv
                                    
                                    	List of TLVs
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__init__()

                                        self.yang_name = "opaque-el-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"

                                        self.tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__setattr__(name, value)


                                    class Tlv(Entity):
                                        """
                                        List of TLVs
                                        
                                        .. attribute:: mpls_dste_link
                                        
                                        	MPLS DS\-TE supported
                                        	**type**\:  bool
                                        
                                        .. attribute:: mpls_router_id
                                        
                                        	MPLS\-TE Router ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: te_link_sub_tlv
                                        
                                        	List of Sub\-TLVs
                                        	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv>`
                                        
                                        .. attribute:: tlv_data
                                        
                                        	TLV direct data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: tlv_length
                                        
                                        	Length of top\-level TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tlv_type
                                        
                                        	Type of top\-level TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "opaque-el-lsa-type"

                                            self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                            self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                            self.tlv_data = YLeaf(YType.str, "tlv-data")

                                            self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                            self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                            self.te_link_sub_tlv = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("mpls_dste_link",
                                                            "mpls_router_id",
                                                            "tlv_data",
                                                            "tlv_length",
                                                            "tlv_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__setattr__(name, value)


                                        class TeLinkSubTlv(Entity):
                                            """
                                            List of Sub\-TLVs
                                            
                                            .. attribute:: sub_tlv_length
                                            
                                            	Length of sub TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sub_tlv_type
                                            
                                            	Type of sub TLV
                                            	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                            
                                            .. attribute:: sub_tlv_value
                                            
                                            	Value of sub TLV
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                self.yang_name = "te-link-sub-tlv"
                                                self.yang_parent_name = "tlv"

                                                self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("sub_tlv_length",
                                                                "sub_tlv_type",
                                                                "sub_tlv_value") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.sub_tlv_length.is_set or
                                                    self.sub_tlv_type.is_set or
                                                    self.sub_tlv_value.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.sub_tlv_length.yfilter != YFilter.not_set or
                                                    self.sub_tlv_type.yfilter != YFilter.not_set or
                                                    self.sub_tlv_value.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "te-link-sub-tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.sub_tlv_length.is_set or self.sub_tlv_length.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sub_tlv_length.get_name_leafdata())
                                                if (self.sub_tlv_type.is_set or self.sub_tlv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sub_tlv_type.get_name_leafdata())
                                                if (self.sub_tlv_value.is_set or self.sub_tlv_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sub_tlv_value.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "sub-tlv-length" or name == "sub-tlv-type" or name == "sub-tlv-value"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "sub-tlv-length"):
                                                    self.sub_tlv_length = value
                                                    self.sub_tlv_length.value_namespace = name_space
                                                    self.sub_tlv_length.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sub-tlv-type"):
                                                    self.sub_tlv_type = value
                                                    self.sub_tlv_type.value_namespace = name_space
                                                    self.sub_tlv_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sub-tlv-value"):
                                                    self.sub_tlv_value = value
                                                    self.sub_tlv_value.value_namespace = name_space
                                                    self.sub_tlv_value.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.te_link_sub_tlv:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.mpls_dste_link.is_set or
                                                self.mpls_router_id.is_set or
                                                self.tlv_data.is_set or
                                                self.tlv_length.is_set or
                                                self.tlv_type.is_set)

                                        def has_operation(self):
                                            for c in self.te_link_sub_tlv:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.mpls_dste_link.yfilter != YFilter.not_set or
                                                self.mpls_router_id.yfilter != YFilter.not_set or
                                                self.tlv_data.yfilter != YFilter.not_set or
                                                self.tlv_length.yfilter != YFilter.not_set or
                                                self.tlv_type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.mpls_dste_link.is_set or self.mpls_dste_link.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mpls_dste_link.get_name_leafdata())
                                            if (self.mpls_router_id.is_set or self.mpls_router_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mpls_router_id.get_name_leafdata())
                                            if (self.tlv_data.is_set or self.tlv_data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tlv_data.get_name_leafdata())
                                            if (self.tlv_length.is_set or self.tlv_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tlv_length.get_name_leafdata())
                                            if (self.tlv_type.is_set or self.tlv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tlv_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "te-link-sub-tlv"):
                                                for c in self.te_link_sub_tlv:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.te_link_sub_tlv.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "te-link-sub-tlv" or name == "mpls-dste-link" or name == "mpls-router-id" or name == "tlv-data" or name == "tlv-length" or name == "tlv-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "mpls-dste-link"):
                                                self.mpls_dste_link = value
                                                self.mpls_dste_link.value_namespace = name_space
                                                self.mpls_dste_link.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mpls-router-id"):
                                                self.mpls_router_id = value
                                                self.mpls_router_id.value_namespace = name_space
                                                self.mpls_router_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tlv-data"):
                                                self.tlv_data = value
                                                self.tlv_data.value_namespace = name_space
                                                self.tlv_data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tlv-length"):
                                                self.tlv_length = value
                                                self.tlv_length.value_namespace = name_space
                                                self.tlv_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tlv-type"):
                                                self.tlv_type = value
                                                self.tlv_type.value_namespace = name_space
                                                self.tlv_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.tlv:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.tlv:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opaque-el-lsa-type" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tlv"):
                                            for c in self.tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.tlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tlv"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.internal_lsa_type.is_set or
                                        (self.external_lsa_type is not None and self.external_lsa_type.has_data()) or
                                        (self.network_lsa_type is not None and self.network_lsa_type.has_data()) or
                                        (self.opaque_el_lsa_type is not None and self.opaque_el_lsa_type.has_data()) or
                                        (self.opaque_ep_lsa_type is not None and self.opaque_ep_lsa_type.has_data()) or
                                        (self.opaque_grace_lsa is not None and self.opaque_grace_lsa.has_data()) or
                                        (self.opaque_link_lsa_type is not None and self.opaque_link_lsa_type.has_data()) or
                                        (self.opaque_mpls_te_lsa_type is not None and self.opaque_mpls_te_lsa_type.has_data()) or
                                        (self.opaque_router_info_lsa_type is not None and self.opaque_router_info_lsa_type.has_data()) or
                                        (self.router_lsa_type is not None and self.router_lsa_type.has_data()) or
                                        (self.summary_lsa_type is not None and self.summary_lsa_type.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_lsa_type.yfilter != YFilter.not_set or
                                        (self.external_lsa_type is not None and self.external_lsa_type.has_operation()) or
                                        (self.network_lsa_type is not None and self.network_lsa_type.has_operation()) or
                                        (self.opaque_el_lsa_type is not None and self.opaque_el_lsa_type.has_operation()) or
                                        (self.opaque_ep_lsa_type is not None and self.opaque_ep_lsa_type.has_operation()) or
                                        (self.opaque_grace_lsa is not None and self.opaque_grace_lsa.has_operation()) or
                                        (self.opaque_link_lsa_type is not None and self.opaque_link_lsa_type.has_operation()) or
                                        (self.opaque_mpls_te_lsa_type is not None and self.opaque_mpls_te_lsa_type.has_operation()) or
                                        (self.opaque_router_info_lsa_type is not None and self.opaque_router_info_lsa_type.has_operation()) or
                                        (self.router_lsa_type is not None and self.router_lsa_type.has_operation()) or
                                        (self.summary_lsa_type is not None and self.summary_lsa_type.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "lsa-internal-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_lsa_type.is_set or self.internal_lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_lsa_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "external-lsa-type"):
                                        if (self.external_lsa_type is None):
                                            self.external_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType()
                                            self.external_lsa_type.parent = self
                                            self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                        return self.external_lsa_type

                                    if (child_yang_name == "network-lsa-type"):
                                        if (self.network_lsa_type is None):
                                            self.network_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType()
                                            self.network_lsa_type.parent = self
                                            self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                        return self.network_lsa_type

                                    if (child_yang_name == "opaque-el-lsa-type"):
                                        if (self.opaque_el_lsa_type is None):
                                            self.opaque_el_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType()
                                            self.opaque_el_lsa_type.parent = self
                                            self._children_name_map["opaque_el_lsa_type"] = "opaque-el-lsa-type"
                                        return self.opaque_el_lsa_type

                                    if (child_yang_name == "opaque-ep-lsa-type"):
                                        if (self.opaque_ep_lsa_type is None):
                                            self.opaque_ep_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType()
                                            self.opaque_ep_lsa_type.parent = self
                                            self._children_name_map["opaque_ep_lsa_type"] = "opaque-ep-lsa-type"
                                        return self.opaque_ep_lsa_type

                                    if (child_yang_name == "opaque-grace-lsa"):
                                        if (self.opaque_grace_lsa is None):
                                            self.opaque_grace_lsa = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa()
                                            self.opaque_grace_lsa.parent = self
                                            self._children_name_map["opaque_grace_lsa"] = "opaque-grace-lsa"
                                        return self.opaque_grace_lsa

                                    if (child_yang_name == "opaque-link-lsa-type"):
                                        if (self.opaque_link_lsa_type is None):
                                            self.opaque_link_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType()
                                            self.opaque_link_lsa_type.parent = self
                                            self._children_name_map["opaque_link_lsa_type"] = "opaque-link-lsa-type"
                                        return self.opaque_link_lsa_type

                                    if (child_yang_name == "opaque-mpls-te-lsa-type"):
                                        if (self.opaque_mpls_te_lsa_type is None):
                                            self.opaque_mpls_te_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType()
                                            self.opaque_mpls_te_lsa_type.parent = self
                                            self._children_name_map["opaque_mpls_te_lsa_type"] = "opaque-mpls-te-lsa-type"
                                        return self.opaque_mpls_te_lsa_type

                                    if (child_yang_name == "opaque-router-info-lsa-type"):
                                        if (self.opaque_router_info_lsa_type is None):
                                            self.opaque_router_info_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType()
                                            self.opaque_router_info_lsa_type.parent = self
                                            self._children_name_map["opaque_router_info_lsa_type"] = "opaque-router-info-lsa-type"
                                        return self.opaque_router_info_lsa_type

                                    if (child_yang_name == "router-lsa-type"):
                                        if (self.router_lsa_type is None):
                                            self.router_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType()
                                            self.router_lsa_type.parent = self
                                            self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                        return self.router_lsa_type

                                    if (child_yang_name == "summary-lsa-type"):
                                        if (self.summary_lsa_type is None):
                                            self.summary_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType()
                                            self.summary_lsa_type.parent = self
                                            self._children_name_map["summary_lsa_type"] = "summary-lsa-type"
                                        return self.summary_lsa_type

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "external-lsa-type" or name == "network-lsa-type" or name == "opaque-el-lsa-type" or name == "opaque-ep-lsa-type" or name == "opaque-grace-lsa" or name == "opaque-link-lsa-type" or name == "opaque-mpls-te-lsa-type" or name == "opaque-router-info-lsa-type" or name == "router-lsa-type" or name == "summary-lsa-type" or name == "internal-lsa-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-lsa-type"):
                                        self.internal_lsa_type = value
                                        self.internal_lsa_type.value_namespace = name_space
                                        self.internal_lsa_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.advertising_router.is_set or
                                    self.area_id.is_set or
                                    self.interface_name.is_set or
                                    self.ls_id.is_set or
                                    self.ls_type.is_set or
                                    (self.lsa_detail_data is not None and self.lsa_detail_data.has_data()) or
                                    (self.lsa_header is not None and self.lsa_header.has_data()) or
                                    (self.lsa_internal_data is not None and self.lsa_internal_data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.advertising_router.yfilter != YFilter.not_set or
                                    self.area_id.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.ls_id.yfilter != YFilter.not_set or
                                    self.ls_type.yfilter != YFilter.not_set or
                                    (self.lsa_detail_data is not None and self.lsa_detail_data.has_operation()) or
                                    (self.lsa_header is not None and self.lsa_header.has_operation()) or
                                    (self.lsa_internal_data is not None and self.lsa_internal_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "lsa" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.ls_id.is_set or self.ls_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ls_id.get_name_leafdata())
                                if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ls_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "lsa-detail-data"):
                                    if (self.lsa_detail_data is None):
                                        self.lsa_detail_data = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData()
                                        self.lsa_detail_data.parent = self
                                        self._children_name_map["lsa_detail_data"] = "lsa-detail-data"
                                    return self.lsa_detail_data

                                if (child_yang_name == "lsa-header"):
                                    if (self.lsa_header is None):
                                        self.lsa_header = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                    return self.lsa_header

                                if (child_yang_name == "lsa-internal-data"):
                                    if (self.lsa_internal_data is None):
                                        self.lsa_internal_data = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData()
                                        self.lsa_internal_data.parent = self
                                        self._children_name_map["lsa_internal_data"] = "lsa-internal-data"
                                    return self.lsa_internal_data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "lsa-detail-data" or name == "lsa-header" or name == "lsa-internal-data" or name == "advertising-router" or name == "area-id" or name == "interface-name" or name == "ls-id" or name == "ls-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "advertising-router"):
                                    self.advertising_router = value
                                    self.advertising_router.value_namespace = name_space
                                    self.advertising_router.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-id"):
                                    self.area_id = value
                                    self.area_id.value_namespace = name_space
                                    self.area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ls-id"):
                                    self.ls_id = value
                                    self.ls_id.value_namespace = name_space
                                    self.ls_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ls-type"):
                                    self.ls_type = value
                                    self.ls_type.value_namespace = name_space
                                    self.ls_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.lsa:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.lsa:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "lsas" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "lsa"):
                                for c in self.lsa:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.lsa.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "lsa"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class LsaSummaries(Entity):
                        """
                        Link state advertisement summary table
                        
                        .. attribute:: lsa_summary
                        
                        	LSA summary information
                        	**type**\: list of    :py:class:`LsaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries, self).__init__()

                            self.yang_name = "lsa-summaries"
                            self.yang_parent_name = "database"

                            self.lsa_summary = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries, self).__setattr__(name, value)


                        class LsaSummary(Entity):
                            """
                            LSA summary information
                            
                            .. attribute:: advertising_router
                            
                            	Advertising Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_id
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: external_tag
                            
                            	Route Tag
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: link_count
                            
                            	Number of links
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ls_id
                            
                            	Link state ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ls_type
                            
                            	Link state type
                            	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                            
                            .. attribute:: lsa_header
                            
                            	LSA header information
                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary.LsaHeader>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary, self).__init__()

                                self.yang_name = "lsa-summary"
                                self.yang_parent_name = "lsa-summaries"

                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.external_tag = YLeaf(YType.uint32, "external-tag")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.link_count = YLeaf(YType.uint16, "link-count")

                                self.ls_id = YLeaf(YType.str, "ls-id")

                                self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                self.lsa_header = Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary.LsaHeader()
                                self.lsa_header.parent = self
                                self._children_name_map["lsa_header"] = "lsa-header"
                                self._children_yang_names.add("lsa-header")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("advertising_router",
                                                "area_id",
                                                "external_tag",
                                                "interface_name",
                                                "link_count",
                                                "ls_id",
                                                "ls_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary, self).__setattr__(name, value)


                            class LsaHeader(Entity):
                                """
                                LSA header information
                                
                                .. attribute:: advertising_router
                                
                                	Router ID of Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: checksum
                                
                                	Checksum value
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dn_age_lsa
                                
                                	If true, Do Not Age this LSA
                                	**type**\:  bool
                                
                                .. attribute:: ls_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: lsa_age
                                
                                	LSA's Age (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsa_area_id
                                
                                	Area ID in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: lsid
                                
                                	LS ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: nsf
                                
                                	If true,  LSA received from neighbor during NSF
                                	**type**\:  bool
                                
                                .. attribute:: sequence_number
                                
                                	Current Sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary.LsaHeader, self).__init__()

                                    self.yang_name = "lsa-header"
                                    self.yang_parent_name = "lsa-summary"

                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                    self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                    self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                    self.lsid = YLeaf(YType.str, "lsid")

                                    self.nsf = YLeaf(YType.boolean, "nsf")

                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("advertising_router",
                                                    "checksum",
                                                    "dn_age_lsa",
                                                    "ls_type",
                                                    "lsa_age",
                                                    "lsa_area_id",
                                                    "lsid",
                                                    "nsf",
                                                    "sequence_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary.LsaHeader, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary.LsaHeader, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.advertising_router.is_set or
                                        self.checksum.is_set or
                                        self.dn_age_lsa.is_set or
                                        self.ls_type.is_set or
                                        self.lsa_age.is_set or
                                        self.lsa_area_id.is_set or
                                        self.lsid.is_set or
                                        self.nsf.is_set or
                                        self.sequence_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.advertising_router.yfilter != YFilter.not_set or
                                        self.checksum.yfilter != YFilter.not_set or
                                        self.dn_age_lsa.yfilter != YFilter.not_set or
                                        self.ls_type.yfilter != YFilter.not_set or
                                        self.lsa_age.yfilter != YFilter.not_set or
                                        self.lsa_area_id.yfilter != YFilter.not_set or
                                        self.lsid.yfilter != YFilter.not_set or
                                        self.nsf.yfilter != YFilter.not_set or
                                        self.sequence_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "lsa-header" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                    if (self.checksum.is_set or self.checksum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.checksum.get_name_leafdata())
                                    if (self.dn_age_lsa.is_set or self.dn_age_lsa.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dn_age_lsa.get_name_leafdata())
                                    if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ls_type.get_name_leafdata())
                                    if (self.lsa_age.is_set or self.lsa_age.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_age.get_name_leafdata())
                                    if (self.lsa_area_id.is_set or self.lsa_area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsa_area_id.get_name_leafdata())
                                    if (self.lsid.is_set or self.lsid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsid.get_name_leafdata())
                                    if (self.nsf.is_set or self.nsf.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nsf.get_name_leafdata())
                                    if (self.sequence_number.is_set or self.sequence_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "advertising-router" or name == "checksum" or name == "dn-age-lsa" or name == "ls-type" or name == "lsa-age" or name == "lsa-area-id" or name == "lsid" or name == "nsf" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "advertising-router"):
                                        self.advertising_router = value
                                        self.advertising_router.value_namespace = name_space
                                        self.advertising_router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "checksum"):
                                        self.checksum = value
                                        self.checksum.value_namespace = name_space
                                        self.checksum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dn-age-lsa"):
                                        self.dn_age_lsa = value
                                        self.dn_age_lsa.value_namespace = name_space
                                        self.dn_age_lsa.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ls-type"):
                                        self.ls_type = value
                                        self.ls_type.value_namespace = name_space
                                        self.ls_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-age"):
                                        self.lsa_age = value
                                        self.lsa_age.value_namespace = name_space
                                        self.lsa_age.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsa-area-id"):
                                        self.lsa_area_id = value
                                        self.lsa_area_id.value_namespace = name_space
                                        self.lsa_area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsid"):
                                        self.lsid = value
                                        self.lsid.value_namespace = name_space
                                        self.lsid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nsf"):
                                        self.nsf = value
                                        self.nsf.value_namespace = name_space
                                        self.nsf.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number"):
                                        self.sequence_number = value
                                        self.sequence_number.value_namespace = name_space
                                        self.sequence_number.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.advertising_router.is_set or
                                    self.area_id.is_set or
                                    self.external_tag.is_set or
                                    self.interface_name.is_set or
                                    self.link_count.is_set or
                                    self.ls_id.is_set or
                                    self.ls_type.is_set or
                                    (self.lsa_header is not None and self.lsa_header.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.advertising_router.yfilter != YFilter.not_set or
                                    self.area_id.yfilter != YFilter.not_set or
                                    self.external_tag.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.link_count.yfilter != YFilter.not_set or
                                    self.ls_id.yfilter != YFilter.not_set or
                                    self.ls_type.yfilter != YFilter.not_set or
                                    (self.lsa_header is not None and self.lsa_header.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "lsa-summary" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.advertising_router.is_set or self.advertising_router.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.advertising_router.get_name_leafdata())
                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                if (self.external_tag.is_set or self.external_tag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_tag.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.link_count.is_set or self.link_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.link_count.get_name_leafdata())
                                if (self.ls_id.is_set or self.ls_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ls_id.get_name_leafdata())
                                if (self.ls_type.is_set or self.ls_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ls_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "lsa-header"):
                                    if (self.lsa_header is None):
                                        self.lsa_header = Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                    return self.lsa_header

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "lsa-header" or name == "advertising-router" or name == "area-id" or name == "external-tag" or name == "interface-name" or name == "link-count" or name == "ls-id" or name == "ls-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "advertising-router"):
                                    self.advertising_router = value
                                    self.advertising_router.value_namespace = name_space
                                    self.advertising_router.value_namespace_prefix = name_space_prefix
                                if(value_path == "area-id"):
                                    self.area_id = value
                                    self.area_id.value_namespace = name_space
                                    self.area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "external-tag"):
                                    self.external_tag = value
                                    self.external_tag.value_namespace = name_space
                                    self.external_tag.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "link-count"):
                                    self.link_count = value
                                    self.link_count.value_namespace = name_space
                                    self.link_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "ls-id"):
                                    self.ls_id = value
                                    self.ls_id.value_namespace = name_space
                                    self.ls_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ls-type"):
                                    self.ls_type = value
                                    self.ls_type.value_namespace = name_space
                                    self.ls_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.lsa_summary:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.lsa_summary:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "lsa-summaries" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "lsa-summary"):
                                for c in self.lsa_summary:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.lsa_summary.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "lsa-summary"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.database_areas is not None and self.database_areas.has_data()) or
                            (self.database_summaries is not None and self.database_summaries.has_data()) or
                            (self.database_summary_as is not None and self.database_summary_as.has_data()) or
                            (self.lsa_summaries is not None and self.lsa_summaries.has_data()) or
                            (self.lsas is not None and self.lsas.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.database_areas is not None and self.database_areas.has_operation()) or
                            (self.database_summaries is not None and self.database_summaries.has_operation()) or
                            (self.database_summary_as is not None and self.database_summary_as.has_operation()) or
                            (self.lsa_summaries is not None and self.lsa_summaries.has_operation()) or
                            (self.lsas is not None and self.lsas.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "database" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "database-areas"):
                            if (self.database_areas is None):
                                self.database_areas = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas()
                                self.database_areas.parent = self
                                self._children_name_map["database_areas"] = "database-areas"
                            return self.database_areas

                        if (child_yang_name == "database-summaries"):
                            if (self.database_summaries is None):
                                self.database_summaries = Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries()
                                self.database_summaries.parent = self
                                self._children_name_map["database_summaries"] = "database-summaries"
                            return self.database_summaries

                        if (child_yang_name == "database-summary-as"):
                            if (self.database_summary_as is None):
                                self.database_summary_as = Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs()
                                self.database_summary_as.parent = self
                                self._children_name_map["database_summary_as"] = "database-summary-as"
                            return self.database_summary_as

                        if (child_yang_name == "lsa-summaries"):
                            if (self.lsa_summaries is None):
                                self.lsa_summaries = Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries()
                                self.lsa_summaries.parent = self
                                self._children_name_map["lsa_summaries"] = "lsa-summaries"
                            return self.lsa_summaries

                        if (child_yang_name == "lsas"):
                            if (self.lsas is None):
                                self.lsas = Ospf.Processes.Process.DefaultVrf.Database.Lsas()
                                self.lsas.parent = self
                                self._children_name_map["lsas"] = "lsas"
                            return self.lsas

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "database-areas" or name == "database-summaries" or name == "database-summary-as" or name == "lsa-summaries" or name == "lsas"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class SummaryPrefixes(Entity):
                    """
                    Summary prefix table
                    
                    .. attribute:: summary_prefix
                    
                    	Summary prefix information
                    	**type**\: list of    :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes, self).__init__()

                        self.yang_name = "summary-prefixes"
                        self.yang_parent_name = "default-vrf"

                        self.summary_prefix = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes, self).__setattr__(name, value)


                    class SummaryPrefix(Entity):
                        """
                        Summary prefix information
                        
                        .. attribute:: netmask
                        
                        	Summary Mask
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix
                        
                        	Summary Prefix
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: summary_mask
                        
                        	Summary Netmask
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: summary_metric
                        
                        	Cost of Summary
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: summary_metric_type
                        
                        	Type of Metric
                        	**type**\:   :py:class:`ExMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.ExMetric>`
                        
                        .. attribute:: summary_prefix
                        
                        	Summary prefix
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: summary_tag
                        
                        	Tag associated with this summary prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix, self).__init__()

                            self.yang_name = "summary-prefix"
                            self.yang_parent_name = "summary-prefixes"

                            self.netmask = YLeaf(YType.str, "netmask")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.summary_mask = YLeaf(YType.str, "summary-mask")

                            self.summary_metric = YLeaf(YType.uint32, "summary-metric")

                            self.summary_metric_type = YLeaf(YType.enumeration, "summary-metric-type")

                            self.summary_prefix = YLeaf(YType.str, "summary-prefix")

                            self.summary_tag = YLeaf(YType.uint32, "summary-tag")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("netmask",
                                            "prefix",
                                            "summary_mask",
                                            "summary_metric",
                                            "summary_metric_type",
                                            "summary_prefix",
                                            "summary_tag") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.netmask.is_set or
                                self.prefix.is_set or
                                self.summary_mask.is_set or
                                self.summary_metric.is_set or
                                self.summary_metric_type.is_set or
                                self.summary_prefix.is_set or
                                self.summary_tag.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.netmask.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.summary_mask.yfilter != YFilter.not_set or
                                self.summary_metric.yfilter != YFilter.not_set or
                                self.summary_metric_type.yfilter != YFilter.not_set or
                                self.summary_prefix.yfilter != YFilter.not_set or
                                self.summary_tag.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "summary-prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.netmask.is_set or self.netmask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.netmask.get_name_leafdata())
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.summary_mask.is_set or self.summary_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_mask.get_name_leafdata())
                            if (self.summary_metric.is_set or self.summary_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_metric.get_name_leafdata())
                            if (self.summary_metric_type.is_set or self.summary_metric_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_metric_type.get_name_leafdata())
                            if (self.summary_prefix.is_set or self.summary_prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_prefix.get_name_leafdata())
                            if (self.summary_tag.is_set or self.summary_tag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_tag.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "netmask" or name == "prefix" or name == "summary-mask" or name == "summary-metric" or name == "summary-metric-type" or name == "summary-prefix" or name == "summary-tag"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "netmask"):
                                self.netmask = value
                                self.netmask.value_namespace = name_space
                                self.netmask.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-mask"):
                                self.summary_mask = value
                                self.summary_mask.value_namespace = name_space
                                self.summary_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-metric"):
                                self.summary_metric = value
                                self.summary_metric.value_namespace = name_space
                                self.summary_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-metric-type"):
                                self.summary_metric_type = value
                                self.summary_metric_type.value_namespace = name_space
                                self.summary_metric_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-prefix"):
                                self.summary_prefix = value
                                self.summary_prefix.value_namespace = name_space
                                self.summary_prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-tag"):
                                self.summary_tag = value
                                self.summary_tag.value_namespace = name_space
                                self.summary_tag.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.summary_prefix:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.summary_prefix:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary-prefixes" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "summary-prefix"):
                            for c in self.summary_prefix:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.summary_prefix.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "summary-prefix"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class AreaStatistics(Entity):
                    """
                    Container for Statistics
                    
                    .. attribute:: interface_stats_entries
                    
                    	Statistics innformation Interface table
                    	**type**\:   :py:class:`InterfaceStatsEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.AreaStatistics, self).__init__()

                        self.yang_name = "area-statistics"
                        self.yang_parent_name = "default-vrf"

                        self.interface_stats_entries = Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries()
                        self.interface_stats_entries.parent = self
                        self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                        self._children_yang_names.add("interface-stats-entries")


                    class InterfaceStatsEntries(Entity):
                        """
                        Statistics innformation Interface table
                        
                        .. attribute:: interface_stats_entry
                        
                        	Statistics information for a specific interface
                        	**type**\: list of    :py:class:`InterfaceStatsEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries, self).__init__()

                            self.yang_name = "interface-stats-entries"
                            self.yang_parent_name = "area-statistics"

                            self.interface_stats_entry = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries, self).__setattr__(name, value)


                        class InterfaceStatsEntry(Entity):
                            """
                            Statistics information for a specific interface
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: handle
                            
                            	interface handle type
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: if_entry
                            
                            	interface entry
                            	**type**\: list of    :py:class:`IfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry>`
                            
                            .. attribute:: if_name_str
                            
                            	interface name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__init__()

                                self.yang_name = "interface-stats-entry"
                                self.yang_parent_name = "interface-stats-entries"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.handle = YLeaf(YType.str, "handle")

                                self.if_name_str = YLeaf(YType.str, "if-name-str")

                                self.if_entry = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "handle",
                                                "if_name_str") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__setattr__(name, value)


                            class IfEntry(Entity):
                                """
                                interface entry
                                
                                .. attribute:: area_id
                                
                                	OSPF area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_id_str
                                
                                	OSPF aread id string
                                	**type**\:  str
                                
                                .. attribute:: if_stat
                                
                                	OSPF interface statistics
                                	**type**\: list of    :py:class:`IfStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat>`
                                
                                .. attribute:: madj_intf
                                
                                	OSPF madj interface
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__init__()

                                    self.yang_name = "if-entry"
                                    self.yang_parent_name = "interface-stats-entry"

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.area_id_str = YLeaf(YType.str, "area-id-str")

                                    self.madj_intf = YLeaf(YType.boolean, "madj-intf")

                                    self.if_stat = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("area_id",
                                                    "area_id_str",
                                                    "madj_intf") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__setattr__(name, value)


                                class IfStat(Entity):
                                    """
                                    OSPF interface statistics
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__init__()

                                        self.yang_name = "if-stat"
                                        self.yang_parent_name = "if-entry"

                                        self.entry = YLeaf(YType.uint32, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "if-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.if_stat:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.area_id.is_set or
                                        self.area_id_str.is_set or
                                        self.madj_intf.is_set)

                                def has_operation(self):
                                    for c in self.if_stat:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.area_id.yfilter != YFilter.not_set or
                                        self.area_id_str.yfilter != YFilter.not_set or
                                        self.madj_intf.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "if-entry" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id.get_name_leafdata())
                                    if (self.area_id_str.is_set or self.area_id_str.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area_id_str.get_name_leafdata())
                                    if (self.madj_intf.is_set or self.madj_intf.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.madj_intf.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "if-stat"):
                                        for c in self.if_stat:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.if_stat.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "if-stat" or name == "area-id" or name == "area-id-str" or name == "madj-intf"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "area-id"):
                                        self.area_id = value
                                        self.area_id.value_namespace = name_space
                                        self.area_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area-id-str"):
                                        self.area_id_str = value
                                        self.area_id_str.value_namespace = name_space
                                        self.area_id_str.value_namespace_prefix = name_space_prefix
                                    if(value_path == "madj-intf"):
                                        self.madj_intf = value
                                        self.madj_intf.value_namespace = name_space
                                        self.madj_intf.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.if_entry:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.interface_name.is_set or
                                    self.handle.is_set or
                                    self.if_name_str.is_set)

                            def has_operation(self):
                                for c in self.if_entry:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.handle.yfilter != YFilter.not_set or
                                    self.if_name_str.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-stats-entry" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.handle.is_set or self.handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.handle.get_name_leafdata())
                                if (self.if_name_str.is_set or self.if_name_str.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.if_name_str.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "if-entry"):
                                    for c in self.if_entry:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.if_entry.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "if-entry" or name == "interface-name" or name == "handle" or name == "if-name-str"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "handle"):
                                    self.handle = value
                                    self.handle.value_namespace = name_space
                                    self.handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "if-name-str"):
                                    self.if_name_str = value
                                    self.if_name_str.value_namespace = name_space
                                    self.if_name_str.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_stats_entry:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.interface_stats_entry:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-stats-entries" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface-stats-entry"):
                                for c in self.interface_stats_entry:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_stats_entry.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-stats-entry"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (self.interface_stats_entries is not None and self.interface_stats_entries.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.interface_stats_entries is not None and self.interface_stats_entries.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "area-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-stats-entries"):
                            if (self.interface_stats_entries is None):
                                self.interface_stats_entries = Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries()
                                self.interface_stats_entries.parent = self
                                self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                            return self.interface_stats_entries

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-stats-entries"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class OspfSummary(Entity):
                    """
                    Fast\-reroute topology information
                    
                    .. attribute:: sa_lsa_cnt_type_7ase
                    
                    	sa lsa cnt type 7ase
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_8_ignore
                    
                    	sa lsa cnt type 8 ignore
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_ase
                    
                    	sa lsa cnt type ase
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_mospf
                    
                    	sa lsa cnt type mospf
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_net
                    
                    	sa lsa cnt type net
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_opq_area
                    
                    	sa lsa cnt type opq area
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_opq_as
                    
                    	sa lsa cnt type opq as
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_opq_link
                    
                    	sa lsa cnt type opq link
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_rtr
                    
                    	sa lsa cnt type rtr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_sum_asb
                    
                    	sa lsa cnt type sum asb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_sum_net
                    
                    	sa lsa cnt type sum net
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_areas
                    
                    	sa num areas
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_intf
                    
                    	sa num intf
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_intf_up
                    
                    	sa num intf up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_nbrs
                    
                    	sa num nbrs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_nbrs_up
                    
                    	sa num nbrs up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_slintf_up
                    
                    	sa num slintf up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_vintf_up
                    
                    	sa num vintf up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.OspfSummary, self).__init__()

                        self.yang_name = "ospf-summary"
                        self.yang_parent_name = "default-vrf"

                        self.sa_lsa_cnt_type_7ase = YLeaf(YType.uint32, "sa-lsa-cnt-type-7ase")

                        self.sa_lsa_cnt_type_8_ignore = YLeaf(YType.uint32, "sa-lsa-cnt-type-8-ignore")

                        self.sa_lsa_cnt_type_ase = YLeaf(YType.uint32, "sa-lsa-cnt-type-ase")

                        self.sa_lsa_cnt_type_mospf = YLeaf(YType.uint32, "sa-lsa-cnt-type-mospf")

                        self.sa_lsa_cnt_type_net = YLeaf(YType.uint32, "sa-lsa-cnt-type-net")

                        self.sa_lsa_cnt_type_opq_area = YLeaf(YType.uint32, "sa-lsa-cnt-type-opq-area")

                        self.sa_lsa_cnt_type_opq_as = YLeaf(YType.uint32, "sa-lsa-cnt-type-opq-as")

                        self.sa_lsa_cnt_type_opq_link = YLeaf(YType.uint32, "sa-lsa-cnt-type-opq-link")

                        self.sa_lsa_cnt_type_rtr = YLeaf(YType.uint32, "sa-lsa-cnt-type-rtr")

                        self.sa_lsa_cnt_type_sum_asb = YLeaf(YType.uint32, "sa-lsa-cnt-type-sum-asb")

                        self.sa_lsa_cnt_type_sum_net = YLeaf(YType.uint32, "sa-lsa-cnt-type-sum-net")

                        self.sa_num_areas = YLeaf(YType.uint32, "sa-num-areas")

                        self.sa_num_intf = YLeaf(YType.uint32, "sa-num-intf")

                        self.sa_num_intf_up = YLeaf(YType.uint32, "sa-num-intf-up")

                        self.sa_num_nbrs = YLeaf(YType.uint32, "sa-num-nbrs")

                        self.sa_num_nbrs_up = YLeaf(YType.uint32, "sa-num-nbrs-up")

                        self.sa_num_slintf_up = YLeaf(YType.uint32, "sa-num-slintf-up")

                        self.sa_num_vintf_up = YLeaf(YType.uint32, "sa-num-vintf-up")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("sa_lsa_cnt_type_7ase",
                                        "sa_lsa_cnt_type_8_ignore",
                                        "sa_lsa_cnt_type_ase",
                                        "sa_lsa_cnt_type_mospf",
                                        "sa_lsa_cnt_type_net",
                                        "sa_lsa_cnt_type_opq_area",
                                        "sa_lsa_cnt_type_opq_as",
                                        "sa_lsa_cnt_type_opq_link",
                                        "sa_lsa_cnt_type_rtr",
                                        "sa_lsa_cnt_type_sum_asb",
                                        "sa_lsa_cnt_type_sum_net",
                                        "sa_num_areas",
                                        "sa_num_intf",
                                        "sa_num_intf_up",
                                        "sa_num_nbrs",
                                        "sa_num_nbrs_up",
                                        "sa_num_slintf_up",
                                        "sa_num_vintf_up") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.OspfSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.OspfSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.sa_lsa_cnt_type_7ase.is_set or
                            self.sa_lsa_cnt_type_8_ignore.is_set or
                            self.sa_lsa_cnt_type_ase.is_set or
                            self.sa_lsa_cnt_type_mospf.is_set or
                            self.sa_lsa_cnt_type_net.is_set or
                            self.sa_lsa_cnt_type_opq_area.is_set or
                            self.sa_lsa_cnt_type_opq_as.is_set or
                            self.sa_lsa_cnt_type_opq_link.is_set or
                            self.sa_lsa_cnt_type_rtr.is_set or
                            self.sa_lsa_cnt_type_sum_asb.is_set or
                            self.sa_lsa_cnt_type_sum_net.is_set or
                            self.sa_num_areas.is_set or
                            self.sa_num_intf.is_set or
                            self.sa_num_intf_up.is_set or
                            self.sa_num_nbrs.is_set or
                            self.sa_num_nbrs_up.is_set or
                            self.sa_num_slintf_up.is_set or
                            self.sa_num_vintf_up.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.sa_lsa_cnt_type_7ase.yfilter != YFilter.not_set or
                            self.sa_lsa_cnt_type_8_ignore.yfilter != YFilter.not_set or
                            self.sa_lsa_cnt_type_ase.yfilter != YFilter.not_set or
                            self.sa_lsa_cnt_type_mospf.yfilter != YFilter.not_set or
                            self.sa_lsa_cnt_type_net.yfilter != YFilter.not_set or
                            self.sa_lsa_cnt_type_opq_area.yfilter != YFilter.not_set or
                            self.sa_lsa_cnt_type_opq_as.yfilter != YFilter.not_set or
                            self.sa_lsa_cnt_type_opq_link.yfilter != YFilter.not_set or
                            self.sa_lsa_cnt_type_rtr.yfilter != YFilter.not_set or
                            self.sa_lsa_cnt_type_sum_asb.yfilter != YFilter.not_set or
                            self.sa_lsa_cnt_type_sum_net.yfilter != YFilter.not_set or
                            self.sa_num_areas.yfilter != YFilter.not_set or
                            self.sa_num_intf.yfilter != YFilter.not_set or
                            self.sa_num_intf_up.yfilter != YFilter.not_set or
                            self.sa_num_nbrs.yfilter != YFilter.not_set or
                            self.sa_num_nbrs_up.yfilter != YFilter.not_set or
                            self.sa_num_slintf_up.yfilter != YFilter.not_set or
                            self.sa_num_vintf_up.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ospf-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.sa_lsa_cnt_type_7ase.is_set or self.sa_lsa_cnt_type_7ase.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_lsa_cnt_type_7ase.get_name_leafdata())
                        if (self.sa_lsa_cnt_type_8_ignore.is_set or self.sa_lsa_cnt_type_8_ignore.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_lsa_cnt_type_8_ignore.get_name_leafdata())
                        if (self.sa_lsa_cnt_type_ase.is_set or self.sa_lsa_cnt_type_ase.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_lsa_cnt_type_ase.get_name_leafdata())
                        if (self.sa_lsa_cnt_type_mospf.is_set or self.sa_lsa_cnt_type_mospf.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_lsa_cnt_type_mospf.get_name_leafdata())
                        if (self.sa_lsa_cnt_type_net.is_set or self.sa_lsa_cnt_type_net.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_lsa_cnt_type_net.get_name_leafdata())
                        if (self.sa_lsa_cnt_type_opq_area.is_set or self.sa_lsa_cnt_type_opq_area.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_lsa_cnt_type_opq_area.get_name_leafdata())
                        if (self.sa_lsa_cnt_type_opq_as.is_set or self.sa_lsa_cnt_type_opq_as.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_lsa_cnt_type_opq_as.get_name_leafdata())
                        if (self.sa_lsa_cnt_type_opq_link.is_set or self.sa_lsa_cnt_type_opq_link.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_lsa_cnt_type_opq_link.get_name_leafdata())
                        if (self.sa_lsa_cnt_type_rtr.is_set or self.sa_lsa_cnt_type_rtr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_lsa_cnt_type_rtr.get_name_leafdata())
                        if (self.sa_lsa_cnt_type_sum_asb.is_set or self.sa_lsa_cnt_type_sum_asb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_lsa_cnt_type_sum_asb.get_name_leafdata())
                        if (self.sa_lsa_cnt_type_sum_net.is_set or self.sa_lsa_cnt_type_sum_net.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_lsa_cnt_type_sum_net.get_name_leafdata())
                        if (self.sa_num_areas.is_set or self.sa_num_areas.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_num_areas.get_name_leafdata())
                        if (self.sa_num_intf.is_set or self.sa_num_intf.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_num_intf.get_name_leafdata())
                        if (self.sa_num_intf_up.is_set or self.sa_num_intf_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_num_intf_up.get_name_leafdata())
                        if (self.sa_num_nbrs.is_set or self.sa_num_nbrs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_num_nbrs.get_name_leafdata())
                        if (self.sa_num_nbrs_up.is_set or self.sa_num_nbrs_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_num_nbrs_up.get_name_leafdata())
                        if (self.sa_num_slintf_up.is_set or self.sa_num_slintf_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_num_slintf_up.get_name_leafdata())
                        if (self.sa_num_vintf_up.is_set or self.sa_num_vintf_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_num_vintf_up.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sa-lsa-cnt-type-7ase" or name == "sa-lsa-cnt-type-8-ignore" or name == "sa-lsa-cnt-type-ase" or name == "sa-lsa-cnt-type-mospf" or name == "sa-lsa-cnt-type-net" or name == "sa-lsa-cnt-type-opq-area" or name == "sa-lsa-cnt-type-opq-as" or name == "sa-lsa-cnt-type-opq-link" or name == "sa-lsa-cnt-type-rtr" or name == "sa-lsa-cnt-type-sum-asb" or name == "sa-lsa-cnt-type-sum-net" or name == "sa-num-areas" or name == "sa-num-intf" or name == "sa-num-intf-up" or name == "sa-num-nbrs" or name == "sa-num-nbrs-up" or name == "sa-num-slintf-up" or name == "sa-num-vintf-up"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "sa-lsa-cnt-type-7ase"):
                            self.sa_lsa_cnt_type_7ase = value
                            self.sa_lsa_cnt_type_7ase.value_namespace = name_space
                            self.sa_lsa_cnt_type_7ase.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-lsa-cnt-type-8-ignore"):
                            self.sa_lsa_cnt_type_8_ignore = value
                            self.sa_lsa_cnt_type_8_ignore.value_namespace = name_space
                            self.sa_lsa_cnt_type_8_ignore.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-lsa-cnt-type-ase"):
                            self.sa_lsa_cnt_type_ase = value
                            self.sa_lsa_cnt_type_ase.value_namespace = name_space
                            self.sa_lsa_cnt_type_ase.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-lsa-cnt-type-mospf"):
                            self.sa_lsa_cnt_type_mospf = value
                            self.sa_lsa_cnt_type_mospf.value_namespace = name_space
                            self.sa_lsa_cnt_type_mospf.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-lsa-cnt-type-net"):
                            self.sa_lsa_cnt_type_net = value
                            self.sa_lsa_cnt_type_net.value_namespace = name_space
                            self.sa_lsa_cnt_type_net.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-lsa-cnt-type-opq-area"):
                            self.sa_lsa_cnt_type_opq_area = value
                            self.sa_lsa_cnt_type_opq_area.value_namespace = name_space
                            self.sa_lsa_cnt_type_opq_area.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-lsa-cnt-type-opq-as"):
                            self.sa_lsa_cnt_type_opq_as = value
                            self.sa_lsa_cnt_type_opq_as.value_namespace = name_space
                            self.sa_lsa_cnt_type_opq_as.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-lsa-cnt-type-opq-link"):
                            self.sa_lsa_cnt_type_opq_link = value
                            self.sa_lsa_cnt_type_opq_link.value_namespace = name_space
                            self.sa_lsa_cnt_type_opq_link.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-lsa-cnt-type-rtr"):
                            self.sa_lsa_cnt_type_rtr = value
                            self.sa_lsa_cnt_type_rtr.value_namespace = name_space
                            self.sa_lsa_cnt_type_rtr.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-lsa-cnt-type-sum-asb"):
                            self.sa_lsa_cnt_type_sum_asb = value
                            self.sa_lsa_cnt_type_sum_asb.value_namespace = name_space
                            self.sa_lsa_cnt_type_sum_asb.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-lsa-cnt-type-sum-net"):
                            self.sa_lsa_cnt_type_sum_net = value
                            self.sa_lsa_cnt_type_sum_net.value_namespace = name_space
                            self.sa_lsa_cnt_type_sum_net.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-num-areas"):
                            self.sa_num_areas = value
                            self.sa_num_areas.value_namespace = name_space
                            self.sa_num_areas.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-num-intf"):
                            self.sa_num_intf = value
                            self.sa_num_intf.value_namespace = name_space
                            self.sa_num_intf.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-num-intf-up"):
                            self.sa_num_intf_up = value
                            self.sa_num_intf_up.value_namespace = name_space
                            self.sa_num_intf_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-num-nbrs"):
                            self.sa_num_nbrs = value
                            self.sa_num_nbrs.value_namespace = name_space
                            self.sa_num_nbrs.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-num-nbrs-up"):
                            self.sa_num_nbrs_up = value
                            self.sa_num_nbrs_up.value_namespace = name_space
                            self.sa_num_nbrs_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-num-slintf-up"):
                            self.sa_num_slintf_up = value
                            self.sa_num_slintf_up.value_namespace = name_space
                            self.sa_num_slintf_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-num-vintf-up"):
                            self.sa_num_vintf_up = value
                            self.sa_num_vintf_up.value_namespace = name_space
                            self.sa_num_vintf_up.value_namespace_prefix = name_space_prefix


                class FastReroute(Entity):
                    """
                    Container for FastReroute
                    
                    .. attribute:: topologies
                    
                    	Fast\-reroute topology information table
                    	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.FastReroute, self).__init__()

                        self.yang_name = "fast-reroute"
                        self.yang_parent_name = "default-vrf"

                        self.topologies = Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                        self._children_yang_names.add("topologies")


                    class Topologies(Entity):
                        """
                        Fast\-reroute topology information table
                        
                        .. attribute:: topology
                        
                        	Fast\-reroute topology information
                        	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "fast-reroute"

                            self.topology = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies, self).__setattr__(name, value)


                        class Topology(Entity):
                            """
                            Fast\-reroute topology information
                            
                            .. attribute:: area_id
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: ipfrr_area_revision
                            
                            	IPFRR Topology Revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipfrr_router_id
                            
                            	OSPF Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipfrr_topo
                            
                            	IPFRR Topology entries
                            	**type**\: list of    :py:class:`IpfrrTopo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology.IpfrrTopo>`
                            
                            .. attribute:: ipfrr_topo_area_id
                            
                            	Area ID string in decimal or dotted decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: router_id
                            
                            	Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.ipfrr_area_revision = YLeaf(YType.uint32, "ipfrr-area-revision")

                                self.ipfrr_router_id = YLeaf(YType.str, "ipfrr-router-id")

                                self.ipfrr_topo_area_id = YLeaf(YType.str, "ipfrr-topo-area-id")

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.ipfrr_topo = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("area_id",
                                                "ipfrr_area_revision",
                                                "ipfrr_router_id",
                                                "ipfrr_topo_area_id",
                                                "router_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology, self).__setattr__(name, value)


                            class IpfrrTopo(Entity):
                                """
                                IPFRR Topology entries
                                
                                .. attribute:: distance
                                
                                	IPFRR Topology Distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: distance_reverse
                                
                                	IPFRR Topology Reverse Distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dr
                                
                                	IPFRR Topology DR entry
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_sourced
                                
                                	IPFRR Topology Neighbor Sourced
                                	**type**\:  bool
                                
                                .. attribute:: node_id
                                
                                	IPFRR Topology Node ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: poison
                                
                                	IPFRR Topology rSPT poison
                                	**type**\:  bool
                                
                                .. attribute:: revision
                                
                                	IPFRR Topology Revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: type4
                                
                                	IPFRR Topoogy Type\-4 entry
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology.IpfrrTopo, self).__init__()

                                    self.yang_name = "ipfrr-topo"
                                    self.yang_parent_name = "topology"

                                    self.distance = YLeaf(YType.uint32, "distance")

                                    self.distance_reverse = YLeaf(YType.uint32, "distance-reverse")

                                    self.dr = YLeaf(YType.boolean, "dr")

                                    self.neighbor_sourced = YLeaf(YType.boolean, "neighbor-sourced")

                                    self.node_id = YLeaf(YType.str, "node-id")

                                    self.poison = YLeaf(YType.boolean, "poison")

                                    self.revision = YLeaf(YType.uint32, "revision")

                                    self.type4 = YLeaf(YType.boolean, "type4")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("distance",
                                                    "distance_reverse",
                                                    "dr",
                                                    "neighbor_sourced",
                                                    "node_id",
                                                    "poison",
                                                    "revision",
                                                    "type4") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology.IpfrrTopo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology.IpfrrTopo, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.distance.is_set or
                                        self.distance_reverse.is_set or
                                        self.dr.is_set or
                                        self.neighbor_sourced.is_set or
                                        self.node_id.is_set or
                                        self.poison.is_set or
                                        self.revision.is_set or
                                        self.type4.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.distance.yfilter != YFilter.not_set or
                                        self.distance_reverse.yfilter != YFilter.not_set or
                                        self.dr.yfilter != YFilter.not_set or
                                        self.neighbor_sourced.yfilter != YFilter.not_set or
                                        self.node_id.yfilter != YFilter.not_set or
                                        self.poison.yfilter != YFilter.not_set or
                                        self.revision.yfilter != YFilter.not_set or
                                        self.type4.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipfrr-topo" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.distance.get_name_leafdata())
                                    if (self.distance_reverse.is_set or self.distance_reverse.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.distance_reverse.get_name_leafdata())
                                    if (self.dr.is_set or self.dr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dr.get_name_leafdata())
                                    if (self.neighbor_sourced.is_set or self.neighbor_sourced.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor_sourced.get_name_leafdata())
                                    if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.node_id.get_name_leafdata())
                                    if (self.poison.is_set or self.poison.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.poison.get_name_leafdata())
                                    if (self.revision.is_set or self.revision.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.revision.get_name_leafdata())
                                    if (self.type4.is_set or self.type4.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type4.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "distance" or name == "distance-reverse" or name == "dr" or name == "neighbor-sourced" or name == "node-id" or name == "poison" or name == "revision" or name == "type4"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "distance"):
                                        self.distance = value
                                        self.distance.value_namespace = name_space
                                        self.distance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "distance-reverse"):
                                        self.distance_reverse = value
                                        self.distance_reverse.value_namespace = name_space
                                        self.distance_reverse.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dr"):
                                        self.dr = value
                                        self.dr.value_namespace = name_space
                                        self.dr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor-sourced"):
                                        self.neighbor_sourced = value
                                        self.neighbor_sourced.value_namespace = name_space
                                        self.neighbor_sourced.value_namespace_prefix = name_space_prefix
                                    if(value_path == "node-id"):
                                        self.node_id = value
                                        self.node_id.value_namespace = name_space
                                        self.node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "poison"):
                                        self.poison = value
                                        self.poison.value_namespace = name_space
                                        self.poison.value_namespace_prefix = name_space_prefix
                                    if(value_path == "revision"):
                                        self.revision = value
                                        self.revision.value_namespace = name_space
                                        self.revision.value_namespace_prefix = name_space_prefix
                                    if(value_path == "type4"):
                                        self.type4 = value
                                        self.type4.value_namespace = name_space
                                        self.type4.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.ipfrr_topo:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.area_id.is_set or
                                    self.ipfrr_area_revision.is_set or
                                    self.ipfrr_router_id.is_set or
                                    self.ipfrr_topo_area_id.is_set or
                                    self.router_id.is_set)

                            def has_operation(self):
                                for c in self.ipfrr_topo:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.area_id.yfilter != YFilter.not_set or
                                    self.ipfrr_area_revision.yfilter != YFilter.not_set or
                                    self.ipfrr_router_id.yfilter != YFilter.not_set or
                                    self.ipfrr_topo_area_id.yfilter != YFilter.not_set or
                                    self.router_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "topology" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                if (self.ipfrr_area_revision.is_set or self.ipfrr_area_revision.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipfrr_area_revision.get_name_leafdata())
                                if (self.ipfrr_router_id.is_set or self.ipfrr_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipfrr_router_id.get_name_leafdata())
                                if (self.ipfrr_topo_area_id.is_set or self.ipfrr_topo_area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipfrr_topo_area_id.get_name_leafdata())
                                if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ipfrr-topo"):
                                    for c in self.ipfrr_topo:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology.IpfrrTopo()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.ipfrr_topo.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipfrr-topo" or name == "area-id" or name == "ipfrr-area-revision" or name == "ipfrr-router-id" or name == "ipfrr-topo-area-id" or name == "router-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "area-id"):
                                    self.area_id = value
                                    self.area_id.value_namespace = name_space
                                    self.area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipfrr-area-revision"):
                                    self.ipfrr_area_revision = value
                                    self.ipfrr_area_revision.value_namespace = name_space
                                    self.ipfrr_area_revision.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipfrr-router-id"):
                                    self.ipfrr_router_id = value
                                    self.ipfrr_router_id.value_namespace = name_space
                                    self.ipfrr_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipfrr-topo-area-id"):
                                    self.ipfrr_topo_area_id = value
                                    self.ipfrr_topo_area_id.value_namespace = name_space
                                    self.ipfrr_topo_area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-id"):
                                    self.router_id = value
                                    self.router_id.value_namespace = name_space
                                    self.router_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.topology:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.topology:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topologies" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "topology"):
                                for c in self.topology:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.topology.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "topology"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (self.topologies is not None and self.topologies.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.topologies is not None and self.topologies.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "fast-reroute" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "topologies"):
                            if (self.topologies is None):
                                self.topologies = Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies()
                                self.topologies.parent = self
                                self._children_name_map["topologies"] = "topologies"
                            return self.topologies

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "topologies"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.adjacency_information is not None and self.adjacency_information.has_data()) or
                        (self.area_statistics is not None and self.area_statistics.has_data()) or
                        (self.areas is not None and self.areas.has_data()) or
                        (self.border_routers is not None and self.border_routers.has_data()) or
                        (self.database is not None and self.database.has_data()) or
                        (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                        (self.flood_list_table is not None and self.flood_list_table.has_data()) or
                        (self.interface_information is not None and self.interface_information.has_data()) or
                        (self.mpls_te is not None and self.mpls_te.has_data()) or
                        (self.ospf_summary is not None and self.ospf_summary.has_data()) or
                        (self.process_information is not None and self.process_information.has_data()) or
                        (self.route_information is not None and self.route_information.has_data()) or
                        (self.statistics is not None and self.statistics.has_data()) or
                        (self.summary_prefixes is not None and self.summary_prefixes.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.adjacency_information is not None and self.adjacency_information.has_operation()) or
                        (self.area_statistics is not None and self.area_statistics.has_operation()) or
                        (self.areas is not None and self.areas.has_operation()) or
                        (self.border_routers is not None and self.border_routers.has_operation()) or
                        (self.database is not None and self.database.has_operation()) or
                        (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                        (self.flood_list_table is not None and self.flood_list_table.has_operation()) or
                        (self.interface_information is not None and self.interface_information.has_operation()) or
                        (self.mpls_te is not None and self.mpls_te.has_operation()) or
                        (self.ospf_summary is not None and self.ospf_summary.has_operation()) or
                        (self.process_information is not None and self.process_information.has_operation()) or
                        (self.route_information is not None and self.route_information.has_operation()) or
                        (self.statistics is not None and self.statistics.has_operation()) or
                        (self.summary_prefixes is not None and self.summary_prefixes.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "default-vrf" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "adjacency-information"):
                        if (self.adjacency_information is None):
                            self.adjacency_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation()
                            self.adjacency_information.parent = self
                            self._children_name_map["adjacency_information"] = "adjacency-information"
                        return self.adjacency_information

                    if (child_yang_name == "area-statistics"):
                        if (self.area_statistics is None):
                            self.area_statistics = Ospf.Processes.Process.DefaultVrf.AreaStatistics()
                            self.area_statistics.parent = self
                            self._children_name_map["area_statistics"] = "area-statistics"
                        return self.area_statistics

                    if (child_yang_name == "areas"):
                        if (self.areas is None):
                            self.areas = Ospf.Processes.Process.DefaultVrf.Areas()
                            self.areas.parent = self
                            self._children_name_map["areas"] = "areas"
                        return self.areas

                    if (child_yang_name == "border-routers"):
                        if (self.border_routers is None):
                            self.border_routers = Ospf.Processes.Process.DefaultVrf.BorderRouters()
                            self.border_routers.parent = self
                            self._children_name_map["border_routers"] = "border-routers"
                        return self.border_routers

                    if (child_yang_name == "database"):
                        if (self.database is None):
                            self.database = Ospf.Processes.Process.DefaultVrf.Database()
                            self.database.parent = self
                            self._children_name_map["database"] = "database"
                        return self.database

                    if (child_yang_name == "fast-reroute"):
                        if (self.fast_reroute is None):
                            self.fast_reroute = Ospf.Processes.Process.DefaultVrf.FastReroute()
                            self.fast_reroute.parent = self
                            self._children_name_map["fast_reroute"] = "fast-reroute"
                        return self.fast_reroute

                    if (child_yang_name == "flood-list-table"):
                        if (self.flood_list_table is None):
                            self.flood_list_table = Ospf.Processes.Process.DefaultVrf.FloodListTable()
                            self.flood_list_table.parent = self
                            self._children_name_map["flood_list_table"] = "flood-list-table"
                        return self.flood_list_table

                    if (child_yang_name == "interface-information"):
                        if (self.interface_information is None):
                            self.interface_information = Ospf.Processes.Process.DefaultVrf.InterfaceInformation()
                            self.interface_information.parent = self
                            self._children_name_map["interface_information"] = "interface-information"
                        return self.interface_information

                    if (child_yang_name == "mpls-te"):
                        if (self.mpls_te is None):
                            self.mpls_te = Ospf.Processes.Process.DefaultVrf.MplsTe()
                            self.mpls_te.parent = self
                            self._children_name_map["mpls_te"] = "mpls-te"
                        return self.mpls_te

                    if (child_yang_name == "ospf-summary"):
                        if (self.ospf_summary is None):
                            self.ospf_summary = Ospf.Processes.Process.DefaultVrf.OspfSummary()
                            self.ospf_summary.parent = self
                            self._children_name_map["ospf_summary"] = "ospf-summary"
                        return self.ospf_summary

                    if (child_yang_name == "process-information"):
                        if (self.process_information is None):
                            self.process_information = Ospf.Processes.Process.DefaultVrf.ProcessInformation()
                            self.process_information.parent = self
                            self._children_name_map["process_information"] = "process-information"
                        return self.process_information

                    if (child_yang_name == "route-information"):
                        if (self.route_information is None):
                            self.route_information = Ospf.Processes.Process.DefaultVrf.RouteInformation()
                            self.route_information.parent = self
                            self._children_name_map["route_information"] = "route-information"
                        return self.route_information

                    if (child_yang_name == "statistics"):
                        if (self.statistics is None):
                            self.statistics = Ospf.Processes.Process.DefaultVrf.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                        return self.statistics

                    if (child_yang_name == "summary-prefixes"):
                        if (self.summary_prefixes is None):
                            self.summary_prefixes = Ospf.Processes.Process.DefaultVrf.SummaryPrefixes()
                            self.summary_prefixes.parent = self
                            self._children_name_map["summary_prefixes"] = "summary-prefixes"
                        return self.summary_prefixes

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "adjacency-information" or name == "area-statistics" or name == "areas" or name == "border-routers" or name == "database" or name == "fast-reroute" or name == "flood-list-table" or name == "interface-information" or name == "mpls-te" or name == "ospf-summary" or name == "process-information" or name == "route-information" or name == "statistics" or name == "summary-prefixes"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.process_name.is_set or
                    (self.default_vrf is not None and self.default_vrf.has_data()) or
                    (self.srms is not None and self.srms.has_data()) or
                    (self.vrfs is not None and self.vrfs.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.process_name.yfilter != YFilter.not_set or
                    (self.default_vrf is not None and self.default_vrf.has_operation()) or
                    (self.srms is not None and self.srms.has_operation()) or
                    (self.vrfs is not None and self.vrfs.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "process" + "[process-name='" + self.process_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-ospf-oper:ospf/processes/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.process_name.is_set or self.process_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "default-vrf"):
                    if (self.default_vrf is None):
                        self.default_vrf = Ospf.Processes.Process.DefaultVrf()
                        self.default_vrf.parent = self
                        self._children_name_map["default_vrf"] = "default-vrf"
                    return self.default_vrf

                if (child_yang_name == "srms"):
                    if (self.srms is None):
                        self.srms = Ospf.Processes.Process.Srms()
                        self.srms.parent = self
                        self._children_name_map["srms"] = "srms"
                    return self.srms

                if (child_yang_name == "vrfs"):
                    if (self.vrfs is None):
                        self.vrfs = Ospf.Processes.Process.Vrfs()
                        self.vrfs.parent = self
                        self._children_name_map["vrfs"] = "vrfs"
                    return self.vrfs

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "default-vrf" or name == "srms" or name == "vrfs" or name == "process-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "process-name"):
                    self.process_name = value
                    self.process_name.value_namespace = name_space
                    self.process_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.process:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.process:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "processes" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-ospf-oper:ospf/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "process"):
                for c in self.process:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Ospf.Processes.Process()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.process.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "process"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (self.processes is not None and self.processes.has_data())

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.processes is not None and self.processes.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ipv4-ospf-oper:ospf" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "processes"):
            if (self.processes is None):
                self.processes = Ospf.Processes()
                self.processes.parent = self
                self._children_name_map["processes"] = "processes"
            return self.processes

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "processes"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = Ospf()
        return self._top_entity

